from __future__ import absolute_import
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: TSSArchives_sos.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import TSPMessages_pb2 as TSPMessages__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='TSSArchives_sos.proto',
  package='TSS',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x15TSSArchives_sos.proto\x12\x03TSS\x1a\x11TSPMessages.proto\"2\n\x12SpecSetBoolArchive\x12\r\n\x05value\x18\x01 \x02(\x08\x12\r\n\x05unset\x18\x02 \x02(\x08\"?\n\x13SpecSetColorArchive\x12\x19\n\x05\x63olor\x18\x01 \x01(\x0b\x32\n.TSP.Color\x12\r\n\x05unset\x18\x02 \x02(\x08\"4\n\x14SpecSetDoubleArchive\x12\r\n\x05value\x18\x01 \x02(\x01\x12\r\n\x05unset\x18\x02 \x02(\x08\"5\n\x15SpecSetIntegerArchive\x12\r\n\x05value\x18\x01 \x02(\x05\x12\r\n\x05unset\x18\x02 \x02(\x08\"4\n\x14SpecSetStringArchive\x12\r\n\x05value\x18\x01 \x01(\t\x12\r\n\x05unset\x18\x02 \x02(\x08\"A\n\x0fSpecBoolArchive\x12.\n\rspec_set_bool\x18\x01 \x01(\x0b\x32\x17.TSS.SpecSetBoolArchive\"D\n\x10SpecColorArchive\x12\x30\n\x0espec_set_color\x18\x01 \x01(\x0b\x32\x18.TSS.SpecSetColorArchive\"G\n\x11SpecDoubleArchive\x12\x32\n\x0fspec_set_double\x18\x01 \x01(\x0b\x32\x19.TSS.SpecSetDoubleArchive\"J\n\x12SpecIntegerArchive\x12\x34\n\x10spec_set_integer\x18\x01 \x01(\x0b\x32\x1a.TSS.SpecSetIntegerArchive\"G\n\x11SpecStringArchive\x12\x32\n\x0fspec_set_string\x18\x01 \x01(\x0b\x32\x19.TSS.SpecSetStringArchive')
  ,
  dependencies=[TSPMessages__pb2.DESCRIPTOR,])




_SPECSETBOOLARCHIVE = _descriptor.Descriptor(
  name='SpecSetBoolArchive',
  full_name='TSS.SpecSetBoolArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='TSS.SpecSetBoolArchive.value', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unset', full_name='TSS.SpecSetBoolArchive.unset', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=49,
  serialized_end=99,
)


_SPECSETCOLORARCHIVE = _descriptor.Descriptor(
  name='SpecSetColorArchive',
  full_name='TSS.SpecSetColorArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='color', full_name='TSS.SpecSetColorArchive.color', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unset', full_name='TSS.SpecSetColorArchive.unset', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=101,
  serialized_end=164,
)


_SPECSETDOUBLEARCHIVE = _descriptor.Descriptor(
  name='SpecSetDoubleArchive',
  full_name='TSS.SpecSetDoubleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='TSS.SpecSetDoubleArchive.value', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unset', full_name='TSS.SpecSetDoubleArchive.unset', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=166,
  serialized_end=218,
)


_SPECSETINTEGERARCHIVE = _descriptor.Descriptor(
  name='SpecSetIntegerArchive',
  full_name='TSS.SpecSetIntegerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='TSS.SpecSetIntegerArchive.value', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unset', full_name='TSS.SpecSetIntegerArchive.unset', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=220,
  serialized_end=273,
)


_SPECSETSTRINGARCHIVE = _descriptor.Descriptor(
  name='SpecSetStringArchive',
  full_name='TSS.SpecSetStringArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='TSS.SpecSetStringArchive.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unset', full_name='TSS.SpecSetStringArchive.unset', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=275,
  serialized_end=327,
)


_SPECBOOLARCHIVE = _descriptor.Descriptor(
  name='SpecBoolArchive',
  full_name='TSS.SpecBoolArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spec_set_bool', full_name='TSS.SpecBoolArchive.spec_set_bool', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=329,
  serialized_end=394,
)


_SPECCOLORARCHIVE = _descriptor.Descriptor(
  name='SpecColorArchive',
  full_name='TSS.SpecColorArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spec_set_color', full_name='TSS.SpecColorArchive.spec_set_color', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=396,
  serialized_end=464,
)


_SPECDOUBLEARCHIVE = _descriptor.Descriptor(
  name='SpecDoubleArchive',
  full_name='TSS.SpecDoubleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spec_set_double', full_name='TSS.SpecDoubleArchive.spec_set_double', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=466,
  serialized_end=537,
)


_SPECINTEGERARCHIVE = _descriptor.Descriptor(
  name='SpecIntegerArchive',
  full_name='TSS.SpecIntegerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spec_set_integer', full_name='TSS.SpecIntegerArchive.spec_set_integer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=539,
  serialized_end=613,
)


_SPECSTRINGARCHIVE = _descriptor.Descriptor(
  name='SpecStringArchive',
  full_name='TSS.SpecStringArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spec_set_string', full_name='TSS.SpecStringArchive.spec_set_string', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=615,
  serialized_end=686,
)

_SPECSETCOLORARCHIVE.fields_by_name['color'].message_type = TSPMessages__pb2._COLOR
_SPECBOOLARCHIVE.fields_by_name['spec_set_bool'].message_type = _SPECSETBOOLARCHIVE
_SPECCOLORARCHIVE.fields_by_name['spec_set_color'].message_type = _SPECSETCOLORARCHIVE
_SPECDOUBLEARCHIVE.fields_by_name['spec_set_double'].message_type = _SPECSETDOUBLEARCHIVE
_SPECINTEGERARCHIVE.fields_by_name['spec_set_integer'].message_type = _SPECSETINTEGERARCHIVE
_SPECSTRINGARCHIVE.fields_by_name['spec_set_string'].message_type = _SPECSETSTRINGARCHIVE
DESCRIPTOR.message_types_by_name['SpecSetBoolArchive'] = _SPECSETBOOLARCHIVE
DESCRIPTOR.message_types_by_name['SpecSetColorArchive'] = _SPECSETCOLORARCHIVE
DESCRIPTOR.message_types_by_name['SpecSetDoubleArchive'] = _SPECSETDOUBLEARCHIVE
DESCRIPTOR.message_types_by_name['SpecSetIntegerArchive'] = _SPECSETINTEGERARCHIVE
DESCRIPTOR.message_types_by_name['SpecSetStringArchive'] = _SPECSETSTRINGARCHIVE
DESCRIPTOR.message_types_by_name['SpecBoolArchive'] = _SPECBOOLARCHIVE
DESCRIPTOR.message_types_by_name['SpecColorArchive'] = _SPECCOLORARCHIVE
DESCRIPTOR.message_types_by_name['SpecDoubleArchive'] = _SPECDOUBLEARCHIVE
DESCRIPTOR.message_types_by_name['SpecIntegerArchive'] = _SPECINTEGERARCHIVE
DESCRIPTOR.message_types_by_name['SpecStringArchive'] = _SPECSTRINGARCHIVE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SpecSetBoolArchive = _reflection.GeneratedProtocolMessageType('SpecSetBoolArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECSETBOOLARCHIVE,
  __module__ = 'TSSArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSS.SpecSetBoolArchive)
  ))
_sym_db.RegisterMessage(SpecSetBoolArchive)

SpecSetColorArchive = _reflection.GeneratedProtocolMessageType('SpecSetColorArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECSETCOLORARCHIVE,
  __module__ = 'TSSArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSS.SpecSetColorArchive)
  ))
_sym_db.RegisterMessage(SpecSetColorArchive)

SpecSetDoubleArchive = _reflection.GeneratedProtocolMessageType('SpecSetDoubleArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECSETDOUBLEARCHIVE,
  __module__ = 'TSSArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSS.SpecSetDoubleArchive)
  ))
_sym_db.RegisterMessage(SpecSetDoubleArchive)

SpecSetIntegerArchive = _reflection.GeneratedProtocolMessageType('SpecSetIntegerArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECSETINTEGERARCHIVE,
  __module__ = 'TSSArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSS.SpecSetIntegerArchive)
  ))
_sym_db.RegisterMessage(SpecSetIntegerArchive)

SpecSetStringArchive = _reflection.GeneratedProtocolMessageType('SpecSetStringArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECSETSTRINGARCHIVE,
  __module__ = 'TSSArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSS.SpecSetStringArchive)
  ))
_sym_db.RegisterMessage(SpecSetStringArchive)

SpecBoolArchive = _reflection.GeneratedProtocolMessageType('SpecBoolArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECBOOLARCHIVE,
  __module__ = 'TSSArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSS.SpecBoolArchive)
  ))
_sym_db.RegisterMessage(SpecBoolArchive)

SpecColorArchive = _reflection.GeneratedProtocolMessageType('SpecColorArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECCOLORARCHIVE,
  __module__ = 'TSSArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSS.SpecColorArchive)
  ))
_sym_db.RegisterMessage(SpecColorArchive)

SpecDoubleArchive = _reflection.GeneratedProtocolMessageType('SpecDoubleArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECDOUBLEARCHIVE,
  __module__ = 'TSSArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSS.SpecDoubleArchive)
  ))
_sym_db.RegisterMessage(SpecDoubleArchive)

SpecIntegerArchive = _reflection.GeneratedProtocolMessageType('SpecIntegerArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECINTEGERARCHIVE,
  __module__ = 'TSSArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSS.SpecIntegerArchive)
  ))
_sym_db.RegisterMessage(SpecIntegerArchive)

SpecStringArchive = _reflection.GeneratedProtocolMessageType('SpecStringArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECSTRINGARCHIVE,
  __module__ = 'TSSArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSS.SpecStringArchive)
  ))
_sym_db.RegisterMessage(SpecStringArchive)


# @@protoc_insertion_point(module_scope)
