from __future__ import absolute_import
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: TSWPCommandArchives_sos.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import TSPMessages_pb2 as TSPMessages__pb2
from . import TSWPArchives_sos_pb2 as TSWPArchives__sos__pb2
from . import TSWPCommandArchives_pb2 as TSWPCommandArchives__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='TSWPCommandArchives_sos.proto',
  package='TSWP',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x1dTSWPCommandArchives_sos.proto\x12\x04TSWP\x1a\x11TSPMessages.proto\x1a\x16TSWPArchives_sos.proto\x1a\x19TSWPCommandArchives.proto\"\xab\x02\n,CharacterStyleChangePropertyCommand_GArchive\x12\x30\n\x05super\x18\x01 \x02(\x0b\x32!.TSWP.StorageActionCommandArchive\x12\x1e\n\nrange_list\x18\x02 \x03(\x0b\x32\n.TSP.Range\x12\x1c\n\x14range_list_undefined\x18\x03 \x01(\x08\x12\x41\n\x0b\x63hange_list\x18\x04 \x03(\x0b\x32,.TSWP.CharacterStylePropertyChangeSetArchive\x12\x1d\n\x15\x63hange_list_undefined\x18\x05 \x01(\x08\x12)\n!disable_character_style_promotion\x18\x06 \x02(\x08\"\x80\x02\n,ParagraphStyleChangePropertyCommand_GArchive\x12\x30\n\x05super\x18\x01 \x02(\x0b\x32!.TSWP.StorageActionCommandArchive\x12\x1e\n\nrange_list\x18\x02 \x03(\x0b\x32\n.TSP.Range\x12\x1c\n\x14range_list_undefined\x18\x03 \x01(\x08\x12\x41\n\x0b\x63hange_list\x18\x04 \x03(\x0b\x32,.TSWP.ParagraphStylePropertyChangeSetArchive\x12\x1d\n\x15\x63hange_list_undefined\x18\x05 \x01(\x08')
  ,
  dependencies=[TSPMessages__pb2.DESCRIPTOR,TSWPArchives__sos__pb2.DESCRIPTOR,TSWPCommandArchives__pb2.DESCRIPTOR,])




_CHARACTERSTYLECHANGEPROPERTYCOMMAND_GARCHIVE = _descriptor.Descriptor(
  name='CharacterStyleChangePropertyCommand_GArchive',
  full_name='TSWP.CharacterStyleChangePropertyCommand_GArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.CharacterStyleChangePropertyCommand_GArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range_list', full_name='TSWP.CharacterStyleChangePropertyCommand_GArchive.range_list', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range_list_undefined', full_name='TSWP.CharacterStyleChangePropertyCommand_GArchive.range_list_undefined', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='change_list', full_name='TSWP.CharacterStyleChangePropertyCommand_GArchive.change_list', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='change_list_undefined', full_name='TSWP.CharacterStyleChangePropertyCommand_GArchive.change_list_undefined', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='disable_character_style_promotion', full_name='TSWP.CharacterStyleChangePropertyCommand_GArchive.disable_character_style_promotion', index=5,
      number=6, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=110,
  serialized_end=409,
)


_PARAGRAPHSTYLECHANGEPROPERTYCOMMAND_GARCHIVE = _descriptor.Descriptor(
  name='ParagraphStyleChangePropertyCommand_GArchive',
  full_name='TSWP.ParagraphStyleChangePropertyCommand_GArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.ParagraphStyleChangePropertyCommand_GArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range_list', full_name='TSWP.ParagraphStyleChangePropertyCommand_GArchive.range_list', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range_list_undefined', full_name='TSWP.ParagraphStyleChangePropertyCommand_GArchive.range_list_undefined', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='change_list', full_name='TSWP.ParagraphStyleChangePropertyCommand_GArchive.change_list', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='change_list_undefined', full_name='TSWP.ParagraphStyleChangePropertyCommand_GArchive.change_list_undefined', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=412,
  serialized_end=668,
)

_CHARACTERSTYLECHANGEPROPERTYCOMMAND_GARCHIVE.fields_by_name['super'].message_type = TSWPCommandArchives__pb2._STORAGEACTIONCOMMANDARCHIVE
_CHARACTERSTYLECHANGEPROPERTYCOMMAND_GARCHIVE.fields_by_name['range_list'].message_type = TSPMessages__pb2._RANGE
_CHARACTERSTYLECHANGEPROPERTYCOMMAND_GARCHIVE.fields_by_name['change_list'].message_type = TSWPArchives__sos__pb2._CHARACTERSTYLEPROPERTYCHANGESETARCHIVE
_PARAGRAPHSTYLECHANGEPROPERTYCOMMAND_GARCHIVE.fields_by_name['super'].message_type = TSWPCommandArchives__pb2._STORAGEACTIONCOMMANDARCHIVE
_PARAGRAPHSTYLECHANGEPROPERTYCOMMAND_GARCHIVE.fields_by_name['range_list'].message_type = TSPMessages__pb2._RANGE
_PARAGRAPHSTYLECHANGEPROPERTYCOMMAND_GARCHIVE.fields_by_name['change_list'].message_type = TSWPArchives__sos__pb2._PARAGRAPHSTYLEPROPERTYCHANGESETARCHIVE
DESCRIPTOR.message_types_by_name['CharacterStyleChangePropertyCommand_GArchive'] = _CHARACTERSTYLECHANGEPROPERTYCOMMAND_GARCHIVE
DESCRIPTOR.message_types_by_name['ParagraphStyleChangePropertyCommand_GArchive'] = _PARAGRAPHSTYLECHANGEPROPERTYCOMMAND_GARCHIVE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CharacterStyleChangePropertyCommand_GArchive = _reflection.GeneratedProtocolMessageType('CharacterStyleChangePropertyCommand_GArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARACTERSTYLECHANGEPROPERTYCOMMAND_GARCHIVE,
  __module__ = 'TSWPCommandArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.CharacterStyleChangePropertyCommand_GArchive)
  ))
_sym_db.RegisterMessage(CharacterStyleChangePropertyCommand_GArchive)

ParagraphStyleChangePropertyCommand_GArchive = _reflection.GeneratedProtocolMessageType('ParagraphStyleChangePropertyCommand_GArchive', (_message.Message,), dict(
  DESCRIPTOR = _PARAGRAPHSTYLECHANGEPROPERTYCOMMAND_GARCHIVE,
  __module__ = 'TSWPCommandArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.ParagraphStyleChangePropertyCommand_GArchive)
  ))
_sym_db.RegisterMessage(ParagraphStyleChangePropertyCommand_GArchive)


# @@protoc_insertion_point(module_scope)
