from __future__ import absolute_import
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: TSPArchiveMessages.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import TSPMessages_pb2 as TSPMessages__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='TSPArchiveMessages.proto',
  package='TSP',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x18TSPArchiveMessages.proto\x12\x03TSP\x1a\x11TSPMessages.proto\"`\n\x0b\x41rchiveInfo\x12\x12\n\nidentifier\x18\x01 \x01(\x04\x12\'\n\rmessage_infos\x18\x02 \x03(\x0b\x32\x10.TSP.MessageInfo\x12\x14\n\x0cshould_merge\x18\x03 \x01(\x08\"\xbb\x02\n\x0bMessageInfo\x12\x0c\n\x04type\x18\x01 \x02(\r\x12\x0f\n\x07version\x18\x02 \x03(\r\x12\x0e\n\x06length\x18\x03 \x02(\r\x12#\n\x0b\x66ield_infos\x18\x04 \x03(\x0b\x32\x0e.TSP.FieldInfo\x12\x19\n\x11object_references\x18\x05 \x03(\x04\x12\x17\n\x0f\x64\x61ta_references\x18\x06 \x03(\x04\x12\x1a\n\x12\x62\x61se_message_index\x18\x07 \x01(\r\x12\x1a\n\x12\x64iff_merge_version\x18\x08 \x03(\r\x12\'\n\x0f\x64iff_field_path\x18\t \x01(\x0b\x32\x0e.TSP.FieldPath\x12(\n\x10\x66ields_to_remove\x18\n \x03(\x0b\x32\x0e.TSP.FieldPath\x12\x19\n\x11\x64iff_read_version\x18\x0b \x03(\r\"\xda\x04\n\tFieldInfo\x12\x1c\n\x04path\x18\x01 \x02(\x0b\x32\x0e.TSP.FieldPath\x12!\n\x04type\x18\x02 \x01(\x0e\x32\x13.TSP.FieldInfo.Type\x12;\n\x12unknown_field_rule\x18\x03 \x01(\x0e\x32\x1f.TSP.FieldInfo.UnknownFieldRule\x12\x19\n\x11object_references\x18\x04 \x03(\x04\x12\x17\n\x0f\x64\x61ta_references\x18\x05 \x03(\x04\x12\x37\n\x10known_field_rule\x18\x06 \x01(\x0e\x32\x1d.TSP.FieldInfo.KnownFieldRule\x12\x1b\n\x13known_field_version\x18\x07 \x03(\r\x12&\n\x1eknown_field_feature_identifier\x18\x08 \x01(\t\"F\n\x04Type\x12\t\n\x05Value\x10\x00\x12\x13\n\x0fObjectReference\x10\x01\x12\x11\n\rDataReference\x10\x02\x12\x0b\n\x07Message\x10\x03\"|\n\x10UnknownFieldRule\x12\"\n\x1eIgnoreAndPreserveUntilModified\x10\x00\x12\x15\n\x11IgnoreAndPreserve\x10\x01\x12\x12\n\x0eMustUnderstand\x10\x02\x12\x19\n\x0cNotSupported\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\"W\n\x0eKnownFieldRule\x12\x08\n\x04None\x10\x00\x12#\n\x1fPreserveNewerValueUntilModified\x10\x01\x12\x16\n\x12PreserveNewerValue\x10\x02\"\x19\n\tFieldPath\x12\x0c\n\x04path\x18\x01 \x03(\r\"\xfb\x04\n\rComponentInfo\x12\x12\n\nidentifier\x18\x01 \x02(\x04\x12\x19\n\x11preferred_locator\x18\x02 \x02(\t\x12\x0f\n\x07locator\x18\x03 \x01(\t\x12\x1d\n\x15\x64ocument_read_version\x18\x04 \x03(\r\x12\x1e\n\x16\x64ocument_write_version\x18\x05 \x03(\r\x12<\n\x13\x65xternal_references\x18\x06 \x03(\x0b\x32\x1f.TSP.ComponentExternalReference\x12\x34\n\x0f\x64\x61ta_references\x18\x07 \x03(\x0b\x32\x1b.TSP.ComponentDataReference\x12(\n is_stored_outside_object_archive\x18\n \x01(\x08\x12\x38\n\x17object_uuid_map_entries\x18\x0b \x03(\x0b\x32\x17.TSP.ObjectUUIDMapEntry\x12\x12\n\nsave_token\x18\x0c \x01(\x04\x12\'\n\rfeature_infos\x18\r \x03(\x0b\x32\x10.TSP.FeatureInfo\x12\x1e\n\x16\x63omponent_read_version\x18\x0e \x03(\r\x12\"\n\x1a\x63omponent_required_version\x18\x0f \x03(\r\x12\x1d\n\x15\x63ompression_algorithm\x18\x10 \x01(\r\x12\x16\n\x0e\x63\x61n_be_dropped\x18\x11 \x01(\x08\x12\x46\n\x1dversioned_external_references\x18\x12 \x03(\x0b\x32\x1f.TSP.ComponentExternalReference\x12\x13\n\x0bis_wasteful\x18\x13 \x01(\x08\"f\n\x1a\x43omponentExternalReference\x12\x1c\n\x14\x63omponent_identifier\x18\x01 \x02(\x04\x12\x19\n\x11object_identifier\x18\x02 \x01(\x04\x12\x0f\n\x07is_weak\x18\x03 \x01(\x08\"1\n\x16\x43omponentDataReference\x12\x17\n\x0f\x64\x61ta_identifier\x18\x01 \x02(\x04\"A\n\x12ObjectUUIDMapEntry\x12\x12\n\nidentifier\x18\x01 \x02(\x04\x12\x17\n\x04uuid\x18\x02 \x02(\x0b\x32\t.TSP.UUID\"N\n\x0b\x46\x65\x61tureInfo\x12\x12\n\nidentifier\x18\x01 \x02(\t\x12\x14\n\x0cread_version\x18\x02 \x03(\r\x12\x15\n\rwrite_version\x18\x03 \x03(\r\"\xd8\x03\n\x0fPackageMetadata\x12\x1e\n\x16last_object_identifier\x18\x01 \x02(\x04\x12\'\n\x08revision\x18\x02 \x01(\x0b\x32\x15.TSP.DocumentRevision\x12&\n\ncomponents\x18\x03 \x03(\x0b\x32\x12.TSP.ComponentInfo\x12\x1c\n\x05\x64\x61tas\x18\x04 \x03(\x0b\x32\r.TSP.DataInfo\x12\x14\n\x0cread_version\x18\x05 \x03(\r\x12\x15\n\rwrite_version\x18\x06 \x03(\r\x12\x1b\n\x13\x66ile_format_version\x18\x07 \x03(\r\x12\x12\n\nsave_token\x18\x08 \x01(\x04\x12@\n\x16preferred_package_type\x18\t \x01(\x0e\x32 .TSP.PackageMetadata.PackageType\x12)\n\x11\x64\x61ta_metadata_map\x18\n \x01(\x0b\x32\x0e.TSP.Reference\x12\x30\n\x14versioned_components\x18\x0b \x03(\x0b\x32\x12.TSP.ComponentInfo\"9\n\x0bPackageType\x12\x0b\n\x07\x44\x65\x66\x61ult\x10\x00\x12\r\n\tDirectory\x10\x01\x12\x0e\n\nSingleFile\x10\x02\"P\n\x10\x44ocumentRevision\x12\x13\n\x0bsequence_32\x18\x03 \x01(\x05\x12\x12\n\nidentifier\x18\x02 \x01(\t\x12\x13\n\x0bsequence_64\x18\x01 \x01(\x04\"\xbf\x01\n\x12PasteboardMetadata\x12\x0f\n\x07version\x18\x01 \x03(\r\x12\x10\n\x08\x61pp_name\x18\x02 \x02(\t\x12\x1c\n\x05\x64\x61tas\x18\x03 \x03(\x0b\x32\r.TSP.DataInfo\x12\'\n\x14source_document_uuid\x18\x05 \x01(\x0b\x32\t.TSP.UUID\x12)\n\x11\x64\x61ta_metadata_map\x18\x06 \x01(\x0b\x32\x0e.TSP.Reference\x12\x14\n\x0cread_version\x18\x07 \x03(\r\"\xb6\x03\n\x08\x44\x61taInfo\x12\x12\n\nidentifier\x18\x01 \x02(\x04\x12\x0e\n\x06\x64igest\x18\x02 \x02(\x0c\x12\x1b\n\x13preferred_file_name\x18\x03 \x02(\t\x12\x11\n\tfile_name\x18\x04 \x01(\t\x12!\n\x19\x64ocument_resource_locator\x18\x05 \x01(\t\x12\x1c\n\x14source_bookmark_data\x18\x06 \x01(\x0c\x12\x12\n\nremote_url\x18\x07 \x01(\t\x12\x14\n\x0c\x63\x61n_download\x18\x08 \x01(\x08\x12\x42\n\x11\x64ownload_priority\x18\t \x01(\x0e\x32\x1e.TSP.DataInfo.DownloadPriority:\x07\x44\x65\x66\x61ult\x12\'\n\nattributes\x18\n \x01(\x0b\x32\x13.TSP.DataAttributes\x12,\n\x0f\x65ncryption_info\x18\x0b \x01(\x0b\x32\x13.TSP.EncryptionInfo\x12%\n\x1dpasteboard_external_file_path\x18\x63 \x01(\t\")\n\x10\x44ownloadPriority\x12\x08\n\x04High\x10\x00\x12\x0b\n\x07\x44\x65\x66\x61ult\x10\x01\"\xb3\x01\n\x0f\x44\x61taMetadataMap\x12H\n\x15\x64\x61ta_metadata_entries\x18\x01 \x03(\x0b\x32).TSP.DataMetadataMap.DataMetadataMapEntry\x1aV\n\x14\x44\x61taMetadataMapEntry\x12\x17\n\x0f\x64\x61ta_identifier\x18\x01 \x02(\x04\x12%\n\rdata_metadata\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\"2\n\x0c\x44\x61taMetadata\x12\"\n\x0e\x66\x61llback_color\x18\x01 \x01(\x0b\x32\n.TSP.Color\"u\n\x0e\x45ncryptionInfo\x12\x16\n\x0e\x64\x65\x63oded_length\x18\x01 \x01(\x04\x12\x1c\n\x14preferred_block_size\x18\x02 \x01(\x04\x12-\n\x0b\x62lock_infos\x18\x03 \x03(\x0b\x32\x18.TSP.EncryptionBlockInfo\"E\n\x13\x45ncryptionBlockInfo\x12\x16\n\x0e\x65ncoded_length\x18\x01 \x02(\x04\x12\x16\n\x0e\x64\x65\x63oded_length\x18\x02 \x01(\x04\"\xc5\x01\n\x11ViewStateMetadata\x12\x0f\n\x07version\x18\x01 \x03(\r\x12\x1f\n\x0cversion_uuid\x18\x04 \x01(\x0b\x32\t.TSP.UUID\x12%\n\tcomponent\x18\x03 \x02(\x0b\x32\x12.TSP.ComponentInfo\x12\x41\n external_object_uuid_map_entries\x18\x05 \x03(\x0b\x32\x17.TSP.ObjectUUIDMapEntry\x12\x14\n\x0cread_version\x18\x06 \x03(\r\"\xc1\x02\n\x1bObjectSerializationMetadata\x12\x0f\n\x07version\x18\x01 \x03(\r\x12\'\n\x14source_document_uuid\x18\x02 \x01(\x0b\x32\t.TSP.UUID\x12\x1f\n\x0cversion_uuid\x18\x03 \x01(\x0b\x32\t.TSP.UUID\x12%\n\tcomponent\x18\x04 \x02(\x0b\x32\x12.TSP.ComponentInfo\x12\x1c\n\x05\x64\x61tas\x18\x05 \x03(\x0b\x32\r.TSP.DataInfo\x12\x41\n external_object_uuid_map_entries\x18\x06 \x03(\x0b\x32\x17.TSP.ObjectUUIDMapEntry\x12)\n\x11\x64\x61ta_metadata_map\x18\x07 \x01(\x0b\x32\x0e.TSP.Reference\x12\x14\n\x0cread_version\x18\x08 \x03(\r\"\x90\x01\n\x1cObjectSerializationDirectory\x12\x38\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\'.TSP.ObjectSerializationDirectory.Entry\x1a\x36\n\x05\x45ntry\x12\x0f\n\x07locator\x18\x01 \x02(\t\x12\x0e\n\x06offset\x18\x02 \x02(\x04\x12\x0c\n\x04size\x18\x03 \x02(\x04\"4\n\x10\x44ocumentMetadata\x12 \n\x18is_in_collaboration_mode\x18\x01 \x01(\x08\"i\n\x0fSupportMetadata\x12 \n\x18is_in_collaboration_mode\x18\x01 \x01(\x08\x12\x34\n\x18\x61\x63knowledged_server_data\x18\x02 \x03(\x0b\x32\x12.TSP.DataReference')
  ,
  dependencies=[TSPMessages__pb2.DESCRIPTOR,])



_FIELDINFO_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='TSP.FieldInfo.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Value', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ObjectReference', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DataReference', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Message', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=786,
  serialized_end=856,
)
_sym_db.RegisterEnumDescriptor(_FIELDINFO_TYPE)

_FIELDINFO_UNKNOWNFIELDRULE = _descriptor.EnumDescriptor(
  name='UnknownFieldRule',
  full_name='TSP.FieldInfo.UnknownFieldRule',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='IgnoreAndPreserveUntilModified', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IgnoreAndPreserve', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MustUnderstand', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NotSupported', index=3, number=-1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=858,
  serialized_end=982,
)
_sym_db.RegisterEnumDescriptor(_FIELDINFO_UNKNOWNFIELDRULE)

_FIELDINFO_KNOWNFIELDRULE = _descriptor.EnumDescriptor(
  name='KnownFieldRule',
  full_name='TSP.FieldInfo.KnownFieldRule',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='None', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PreserveNewerValueUntilModified', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PreserveNewerValue', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=984,
  serialized_end=1071,
)
_sym_db.RegisterEnumDescriptor(_FIELDINFO_KNOWNFIELDRULE)

_PACKAGEMETADATA_PACKAGETYPE = _descriptor.EnumDescriptor(
  name='PackageType',
  full_name='TSP.PackageMetadata.PackageType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Default', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Directory', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SingleFile', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2456,
  serialized_end=2513,
)
_sym_db.RegisterEnumDescriptor(_PACKAGEMETADATA_PACKAGETYPE)

_DATAINFO_DOWNLOADPRIORITY = _descriptor.EnumDescriptor(
  name='DownloadPriority',
  full_name='TSP.DataInfo.DownloadPriority',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='High', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Default', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3189,
  serialized_end=3230,
)
_sym_db.RegisterEnumDescriptor(_DATAINFO_DOWNLOADPRIORITY)


_ARCHIVEINFO = _descriptor.Descriptor(
  name='ArchiveInfo',
  full_name='TSP.ArchiveInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='TSP.ArchiveInfo.identifier', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message_infos', full_name='TSP.ArchiveInfo.message_infos', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='should_merge', full_name='TSP.ArchiveInfo.should_merge', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=52,
  serialized_end=148,
)


_MESSAGEINFO = _descriptor.Descriptor(
  name='MessageInfo',
  full_name='TSP.MessageInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='TSP.MessageInfo.type', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='TSP.MessageInfo.version', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='length', full_name='TSP.MessageInfo.length', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='field_infos', full_name='TSP.MessageInfo.field_infos', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='object_references', full_name='TSP.MessageInfo.object_references', index=4,
      number=5, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_references', full_name='TSP.MessageInfo.data_references', index=5,
      number=6, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='base_message_index', full_name='TSP.MessageInfo.base_message_index', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='diff_merge_version', full_name='TSP.MessageInfo.diff_merge_version', index=7,
      number=8, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='diff_field_path', full_name='TSP.MessageInfo.diff_field_path', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fields_to_remove', full_name='TSP.MessageInfo.fields_to_remove', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='diff_read_version', full_name='TSP.MessageInfo.diff_read_version', index=10,
      number=11, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=151,
  serialized_end=466,
)


_FIELDINFO = _descriptor.Descriptor(
  name='FieldInfo',
  full_name='TSP.FieldInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='TSP.FieldInfo.path', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='TSP.FieldInfo.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unknown_field_rule', full_name='TSP.FieldInfo.unknown_field_rule', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='object_references', full_name='TSP.FieldInfo.object_references', index=3,
      number=4, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_references', full_name='TSP.FieldInfo.data_references', index=4,
      number=5, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='known_field_rule', full_name='TSP.FieldInfo.known_field_rule', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='known_field_version', full_name='TSP.FieldInfo.known_field_version', index=6,
      number=7, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='known_field_feature_identifier', full_name='TSP.FieldInfo.known_field_feature_identifier', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FIELDINFO_TYPE,
    _FIELDINFO_UNKNOWNFIELDRULE,
    _FIELDINFO_KNOWNFIELDRULE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=469,
  serialized_end=1071,
)


_FIELDPATH = _descriptor.Descriptor(
  name='FieldPath',
  full_name='TSP.FieldPath',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='TSP.FieldPath.path', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1073,
  serialized_end=1098,
)


_COMPONENTINFO = _descriptor.Descriptor(
  name='ComponentInfo',
  full_name='TSP.ComponentInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='TSP.ComponentInfo.identifier', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preferred_locator', full_name='TSP.ComponentInfo.preferred_locator', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='locator', full_name='TSP.ComponentInfo.locator', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='document_read_version', full_name='TSP.ComponentInfo.document_read_version', index=3,
      number=4, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='document_write_version', full_name='TSP.ComponentInfo.document_write_version', index=4,
      number=5, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='external_references', full_name='TSP.ComponentInfo.external_references', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_references', full_name='TSP.ComponentInfo.data_references', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_stored_outside_object_archive', full_name='TSP.ComponentInfo.is_stored_outside_object_archive', index=7,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='object_uuid_map_entries', full_name='TSP.ComponentInfo.object_uuid_map_entries', index=8,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='save_token', full_name='TSP.ComponentInfo.save_token', index=9,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feature_infos', full_name='TSP.ComponentInfo.feature_infos', index=10,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='component_read_version', full_name='TSP.ComponentInfo.component_read_version', index=11,
      number=14, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='component_required_version', full_name='TSP.ComponentInfo.component_required_version', index=12,
      number=15, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='compression_algorithm', full_name='TSP.ComponentInfo.compression_algorithm', index=13,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='can_be_dropped', full_name='TSP.ComponentInfo.can_be_dropped', index=14,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='versioned_external_references', full_name='TSP.ComponentInfo.versioned_external_references', index=15,
      number=18, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_wasteful', full_name='TSP.ComponentInfo.is_wasteful', index=16,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1101,
  serialized_end=1736,
)


_COMPONENTEXTERNALREFERENCE = _descriptor.Descriptor(
  name='ComponentExternalReference',
  full_name='TSP.ComponentExternalReference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='component_identifier', full_name='TSP.ComponentExternalReference.component_identifier', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='object_identifier', full_name='TSP.ComponentExternalReference.object_identifier', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_weak', full_name='TSP.ComponentExternalReference.is_weak', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1738,
  serialized_end=1840,
)


_COMPONENTDATAREFERENCE = _descriptor.Descriptor(
  name='ComponentDataReference',
  full_name='TSP.ComponentDataReference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_identifier', full_name='TSP.ComponentDataReference.data_identifier', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1842,
  serialized_end=1891,
)


_OBJECTUUIDMAPENTRY = _descriptor.Descriptor(
  name='ObjectUUIDMapEntry',
  full_name='TSP.ObjectUUIDMapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='TSP.ObjectUUIDMapEntry.identifier', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='TSP.ObjectUUIDMapEntry.uuid', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1893,
  serialized_end=1958,
)


_FEATUREINFO = _descriptor.Descriptor(
  name='FeatureInfo',
  full_name='TSP.FeatureInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='TSP.FeatureInfo.identifier', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='read_version', full_name='TSP.FeatureInfo.read_version', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='write_version', full_name='TSP.FeatureInfo.write_version', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1960,
  serialized_end=2038,
)


_PACKAGEMETADATA = _descriptor.Descriptor(
  name='PackageMetadata',
  full_name='TSP.PackageMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='last_object_identifier', full_name='TSP.PackageMetadata.last_object_identifier', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='revision', full_name='TSP.PackageMetadata.revision', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='components', full_name='TSP.PackageMetadata.components', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='datas', full_name='TSP.PackageMetadata.datas', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='read_version', full_name='TSP.PackageMetadata.read_version', index=4,
      number=5, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='write_version', full_name='TSP.PackageMetadata.write_version', index=5,
      number=6, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_format_version', full_name='TSP.PackageMetadata.file_format_version', index=6,
      number=7, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='save_token', full_name='TSP.PackageMetadata.save_token', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preferred_package_type', full_name='TSP.PackageMetadata.preferred_package_type', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_metadata_map', full_name='TSP.PackageMetadata.data_metadata_map', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='versioned_components', full_name='TSP.PackageMetadata.versioned_components', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PACKAGEMETADATA_PACKAGETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2041,
  serialized_end=2513,
)


_DOCUMENTREVISION = _descriptor.Descriptor(
  name='DocumentRevision',
  full_name='TSP.DocumentRevision',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sequence_32', full_name='TSP.DocumentRevision.sequence_32', index=0,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='identifier', full_name='TSP.DocumentRevision.identifier', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sequence_64', full_name='TSP.DocumentRevision.sequence_64', index=2,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2515,
  serialized_end=2595,
)


_PASTEBOARDMETADATA = _descriptor.Descriptor(
  name='PasteboardMetadata',
  full_name='TSP.PasteboardMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='TSP.PasteboardMetadata.version', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_name', full_name='TSP.PasteboardMetadata.app_name', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='datas', full_name='TSP.PasteboardMetadata.datas', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source_document_uuid', full_name='TSP.PasteboardMetadata.source_document_uuid', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_metadata_map', full_name='TSP.PasteboardMetadata.data_metadata_map', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='read_version', full_name='TSP.PasteboardMetadata.read_version', index=5,
      number=7, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2598,
  serialized_end=2789,
)


_DATAINFO = _descriptor.Descriptor(
  name='DataInfo',
  full_name='TSP.DataInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='TSP.DataInfo.identifier', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='digest', full_name='TSP.DataInfo.digest', index=1,
      number=2, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preferred_file_name', full_name='TSP.DataInfo.preferred_file_name', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_name', full_name='TSP.DataInfo.file_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='document_resource_locator', full_name='TSP.DataInfo.document_resource_locator', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source_bookmark_data', full_name='TSP.DataInfo.source_bookmark_data', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remote_url', full_name='TSP.DataInfo.remote_url', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='can_download', full_name='TSP.DataInfo.can_download', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='download_priority', full_name='TSP.DataInfo.download_priority', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='TSP.DataInfo.attributes', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='encryption_info', full_name='TSP.DataInfo.encryption_info', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pasteboard_external_file_path', full_name='TSP.DataInfo.pasteboard_external_file_path', index=11,
      number=99, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DATAINFO_DOWNLOADPRIORITY,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2792,
  serialized_end=3230,
)


_DATAMETADATAMAP_DATAMETADATAMAPENTRY = _descriptor.Descriptor(
  name='DataMetadataMapEntry',
  full_name='TSP.DataMetadataMap.DataMetadataMapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_identifier', full_name='TSP.DataMetadataMap.DataMetadataMapEntry.data_identifier', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_metadata', full_name='TSP.DataMetadataMap.DataMetadataMapEntry.data_metadata', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3326,
  serialized_end=3412,
)

_DATAMETADATAMAP = _descriptor.Descriptor(
  name='DataMetadataMap',
  full_name='TSP.DataMetadataMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_metadata_entries', full_name='TSP.DataMetadataMap.data_metadata_entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_DATAMETADATAMAP_DATAMETADATAMAPENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3233,
  serialized_end=3412,
)


_DATAMETADATA = _descriptor.Descriptor(
  name='DataMetadata',
  full_name='TSP.DataMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fallback_color', full_name='TSP.DataMetadata.fallback_color', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3414,
  serialized_end=3464,
)


_ENCRYPTIONINFO = _descriptor.Descriptor(
  name='EncryptionInfo',
  full_name='TSP.EncryptionInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='decoded_length', full_name='TSP.EncryptionInfo.decoded_length', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preferred_block_size', full_name='TSP.EncryptionInfo.preferred_block_size', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block_infos', full_name='TSP.EncryptionInfo.block_infos', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3466,
  serialized_end=3583,
)


_ENCRYPTIONBLOCKINFO = _descriptor.Descriptor(
  name='EncryptionBlockInfo',
  full_name='TSP.EncryptionBlockInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='encoded_length', full_name='TSP.EncryptionBlockInfo.encoded_length', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='decoded_length', full_name='TSP.EncryptionBlockInfo.decoded_length', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3585,
  serialized_end=3654,
)


_VIEWSTATEMETADATA = _descriptor.Descriptor(
  name='ViewStateMetadata',
  full_name='TSP.ViewStateMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='TSP.ViewStateMetadata.version', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version_uuid', full_name='TSP.ViewStateMetadata.version_uuid', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='component', full_name='TSP.ViewStateMetadata.component', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='external_object_uuid_map_entries', full_name='TSP.ViewStateMetadata.external_object_uuid_map_entries', index=3,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='read_version', full_name='TSP.ViewStateMetadata.read_version', index=4,
      number=6, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3657,
  serialized_end=3854,
)


_OBJECTSERIALIZATIONMETADATA = _descriptor.Descriptor(
  name='ObjectSerializationMetadata',
  full_name='TSP.ObjectSerializationMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='TSP.ObjectSerializationMetadata.version', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source_document_uuid', full_name='TSP.ObjectSerializationMetadata.source_document_uuid', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version_uuid', full_name='TSP.ObjectSerializationMetadata.version_uuid', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='component', full_name='TSP.ObjectSerializationMetadata.component', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='datas', full_name='TSP.ObjectSerializationMetadata.datas', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='external_object_uuid_map_entries', full_name='TSP.ObjectSerializationMetadata.external_object_uuid_map_entries', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_metadata_map', full_name='TSP.ObjectSerializationMetadata.data_metadata_map', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='read_version', full_name='TSP.ObjectSerializationMetadata.read_version', index=7,
      number=8, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3857,
  serialized_end=4178,
)


_OBJECTSERIALIZATIONDIRECTORY_ENTRY = _descriptor.Descriptor(
  name='Entry',
  full_name='TSP.ObjectSerializationDirectory.Entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='locator', full_name='TSP.ObjectSerializationDirectory.Entry.locator', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offset', full_name='TSP.ObjectSerializationDirectory.Entry.offset', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='TSP.ObjectSerializationDirectory.Entry.size', index=2,
      number=3, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4271,
  serialized_end=4325,
)

_OBJECTSERIALIZATIONDIRECTORY = _descriptor.Descriptor(
  name='ObjectSerializationDirectory',
  full_name='TSP.ObjectSerializationDirectory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='TSP.ObjectSerializationDirectory.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_OBJECTSERIALIZATIONDIRECTORY_ENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4181,
  serialized_end=4325,
)


_DOCUMENTMETADATA = _descriptor.Descriptor(
  name='DocumentMetadata',
  full_name='TSP.DocumentMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_in_collaboration_mode', full_name='TSP.DocumentMetadata.is_in_collaboration_mode', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4327,
  serialized_end=4379,
)


_SUPPORTMETADATA = _descriptor.Descriptor(
  name='SupportMetadata',
  full_name='TSP.SupportMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_in_collaboration_mode', full_name='TSP.SupportMetadata.is_in_collaboration_mode', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='acknowledged_server_data', full_name='TSP.SupportMetadata.acknowledged_server_data', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4381,
  serialized_end=4486,
)

_ARCHIVEINFO.fields_by_name['message_infos'].message_type = _MESSAGEINFO
_MESSAGEINFO.fields_by_name['field_infos'].message_type = _FIELDINFO
_MESSAGEINFO.fields_by_name['diff_field_path'].message_type = _FIELDPATH
_MESSAGEINFO.fields_by_name['fields_to_remove'].message_type = _FIELDPATH
_FIELDINFO.fields_by_name['path'].message_type = _FIELDPATH
_FIELDINFO.fields_by_name['type'].enum_type = _FIELDINFO_TYPE
_FIELDINFO.fields_by_name['unknown_field_rule'].enum_type = _FIELDINFO_UNKNOWNFIELDRULE
_FIELDINFO.fields_by_name['known_field_rule'].enum_type = _FIELDINFO_KNOWNFIELDRULE
_FIELDINFO_TYPE.containing_type = _FIELDINFO
_FIELDINFO_UNKNOWNFIELDRULE.containing_type = _FIELDINFO
_FIELDINFO_KNOWNFIELDRULE.containing_type = _FIELDINFO
_COMPONENTINFO.fields_by_name['external_references'].message_type = _COMPONENTEXTERNALREFERENCE
_COMPONENTINFO.fields_by_name['data_references'].message_type = _COMPONENTDATAREFERENCE
_COMPONENTINFO.fields_by_name['object_uuid_map_entries'].message_type = _OBJECTUUIDMAPENTRY
_COMPONENTINFO.fields_by_name['feature_infos'].message_type = _FEATUREINFO
_COMPONENTINFO.fields_by_name['versioned_external_references'].message_type = _COMPONENTEXTERNALREFERENCE
_OBJECTUUIDMAPENTRY.fields_by_name['uuid'].message_type = TSPMessages__pb2._UUID
_PACKAGEMETADATA.fields_by_name['revision'].message_type = _DOCUMENTREVISION
_PACKAGEMETADATA.fields_by_name['components'].message_type = _COMPONENTINFO
_PACKAGEMETADATA.fields_by_name['datas'].message_type = _DATAINFO
_PACKAGEMETADATA.fields_by_name['preferred_package_type'].enum_type = _PACKAGEMETADATA_PACKAGETYPE
_PACKAGEMETADATA.fields_by_name['data_metadata_map'].message_type = TSPMessages__pb2._REFERENCE
_PACKAGEMETADATA.fields_by_name['versioned_components'].message_type = _COMPONENTINFO
_PACKAGEMETADATA_PACKAGETYPE.containing_type = _PACKAGEMETADATA
_PASTEBOARDMETADATA.fields_by_name['datas'].message_type = _DATAINFO
_PASTEBOARDMETADATA.fields_by_name['source_document_uuid'].message_type = TSPMessages__pb2._UUID
_PASTEBOARDMETADATA.fields_by_name['data_metadata_map'].message_type = TSPMessages__pb2._REFERENCE
_DATAINFO.fields_by_name['download_priority'].enum_type = _DATAINFO_DOWNLOADPRIORITY
_DATAINFO.fields_by_name['attributes'].message_type = TSPMessages__pb2._DATAATTRIBUTES
_DATAINFO.fields_by_name['encryption_info'].message_type = _ENCRYPTIONINFO
_DATAINFO_DOWNLOADPRIORITY.containing_type = _DATAINFO
_DATAMETADATAMAP_DATAMETADATAMAPENTRY.fields_by_name['data_metadata'].message_type = TSPMessages__pb2._REFERENCE
_DATAMETADATAMAP_DATAMETADATAMAPENTRY.containing_type = _DATAMETADATAMAP
_DATAMETADATAMAP.fields_by_name['data_metadata_entries'].message_type = _DATAMETADATAMAP_DATAMETADATAMAPENTRY
_DATAMETADATA.fields_by_name['fallback_color'].message_type = TSPMessages__pb2._COLOR
_ENCRYPTIONINFO.fields_by_name['block_infos'].message_type = _ENCRYPTIONBLOCKINFO
_VIEWSTATEMETADATA.fields_by_name['version_uuid'].message_type = TSPMessages__pb2._UUID
_VIEWSTATEMETADATA.fields_by_name['component'].message_type = _COMPONENTINFO
_VIEWSTATEMETADATA.fields_by_name['external_object_uuid_map_entries'].message_type = _OBJECTUUIDMAPENTRY
_OBJECTSERIALIZATIONMETADATA.fields_by_name['source_document_uuid'].message_type = TSPMessages__pb2._UUID
_OBJECTSERIALIZATIONMETADATA.fields_by_name['version_uuid'].message_type = TSPMessages__pb2._UUID
_OBJECTSERIALIZATIONMETADATA.fields_by_name['component'].message_type = _COMPONENTINFO
_OBJECTSERIALIZATIONMETADATA.fields_by_name['datas'].message_type = _DATAINFO
_OBJECTSERIALIZATIONMETADATA.fields_by_name['external_object_uuid_map_entries'].message_type = _OBJECTUUIDMAPENTRY
_OBJECTSERIALIZATIONMETADATA.fields_by_name['data_metadata_map'].message_type = TSPMessages__pb2._REFERENCE
_OBJECTSERIALIZATIONDIRECTORY_ENTRY.containing_type = _OBJECTSERIALIZATIONDIRECTORY
_OBJECTSERIALIZATIONDIRECTORY.fields_by_name['entries'].message_type = _OBJECTSERIALIZATIONDIRECTORY_ENTRY
_SUPPORTMETADATA.fields_by_name['acknowledged_server_data'].message_type = TSPMessages__pb2._DATAREFERENCE
DESCRIPTOR.message_types_by_name['ArchiveInfo'] = _ARCHIVEINFO
DESCRIPTOR.message_types_by_name['MessageInfo'] = _MESSAGEINFO
DESCRIPTOR.message_types_by_name['FieldInfo'] = _FIELDINFO
DESCRIPTOR.message_types_by_name['FieldPath'] = _FIELDPATH
DESCRIPTOR.message_types_by_name['ComponentInfo'] = _COMPONENTINFO
DESCRIPTOR.message_types_by_name['ComponentExternalReference'] = _COMPONENTEXTERNALREFERENCE
DESCRIPTOR.message_types_by_name['ComponentDataReference'] = _COMPONENTDATAREFERENCE
DESCRIPTOR.message_types_by_name['ObjectUUIDMapEntry'] = _OBJECTUUIDMAPENTRY
DESCRIPTOR.message_types_by_name['FeatureInfo'] = _FEATUREINFO
DESCRIPTOR.message_types_by_name['PackageMetadata'] = _PACKAGEMETADATA
DESCRIPTOR.message_types_by_name['DocumentRevision'] = _DOCUMENTREVISION
DESCRIPTOR.message_types_by_name['PasteboardMetadata'] = _PASTEBOARDMETADATA
DESCRIPTOR.message_types_by_name['DataInfo'] = _DATAINFO
DESCRIPTOR.message_types_by_name['DataMetadataMap'] = _DATAMETADATAMAP
DESCRIPTOR.message_types_by_name['DataMetadata'] = _DATAMETADATA
DESCRIPTOR.message_types_by_name['EncryptionInfo'] = _ENCRYPTIONINFO
DESCRIPTOR.message_types_by_name['EncryptionBlockInfo'] = _ENCRYPTIONBLOCKINFO
DESCRIPTOR.message_types_by_name['ViewStateMetadata'] = _VIEWSTATEMETADATA
DESCRIPTOR.message_types_by_name['ObjectSerializationMetadata'] = _OBJECTSERIALIZATIONMETADATA
DESCRIPTOR.message_types_by_name['ObjectSerializationDirectory'] = _OBJECTSERIALIZATIONDIRECTORY
DESCRIPTOR.message_types_by_name['DocumentMetadata'] = _DOCUMENTMETADATA
DESCRIPTOR.message_types_by_name['SupportMetadata'] = _SUPPORTMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ArchiveInfo = _reflection.GeneratedProtocolMessageType('ArchiveInfo', (_message.Message,), dict(
  DESCRIPTOR = _ARCHIVEINFO,
  __module__ = 'TSPArchiveMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.ArchiveInfo)
  ))
_sym_db.RegisterMessage(ArchiveInfo)

MessageInfo = _reflection.GeneratedProtocolMessageType('MessageInfo', (_message.Message,), dict(
  DESCRIPTOR = _MESSAGEINFO,
  __module__ = 'TSPArchiveMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.MessageInfo)
  ))
_sym_db.RegisterMessage(MessageInfo)

FieldInfo = _reflection.GeneratedProtocolMessageType('FieldInfo', (_message.Message,), dict(
  DESCRIPTOR = _FIELDINFO,
  __module__ = 'TSPArchiveMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.FieldInfo)
  ))
_sym_db.RegisterMessage(FieldInfo)

FieldPath = _reflection.GeneratedProtocolMessageType('FieldPath', (_message.Message,), dict(
  DESCRIPTOR = _FIELDPATH,
  __module__ = 'TSPArchiveMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.FieldPath)
  ))
_sym_db.RegisterMessage(FieldPath)

ComponentInfo = _reflection.GeneratedProtocolMessageType('ComponentInfo', (_message.Message,), dict(
  DESCRIPTOR = _COMPONENTINFO,
  __module__ = 'TSPArchiveMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.ComponentInfo)
  ))
_sym_db.RegisterMessage(ComponentInfo)

ComponentExternalReference = _reflection.GeneratedProtocolMessageType('ComponentExternalReference', (_message.Message,), dict(
  DESCRIPTOR = _COMPONENTEXTERNALREFERENCE,
  __module__ = 'TSPArchiveMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.ComponentExternalReference)
  ))
_sym_db.RegisterMessage(ComponentExternalReference)

ComponentDataReference = _reflection.GeneratedProtocolMessageType('ComponentDataReference', (_message.Message,), dict(
  DESCRIPTOR = _COMPONENTDATAREFERENCE,
  __module__ = 'TSPArchiveMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.ComponentDataReference)
  ))
_sym_db.RegisterMessage(ComponentDataReference)

ObjectUUIDMapEntry = _reflection.GeneratedProtocolMessageType('ObjectUUIDMapEntry', (_message.Message,), dict(
  DESCRIPTOR = _OBJECTUUIDMAPENTRY,
  __module__ = 'TSPArchiveMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.ObjectUUIDMapEntry)
  ))
_sym_db.RegisterMessage(ObjectUUIDMapEntry)

FeatureInfo = _reflection.GeneratedProtocolMessageType('FeatureInfo', (_message.Message,), dict(
  DESCRIPTOR = _FEATUREINFO,
  __module__ = 'TSPArchiveMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.FeatureInfo)
  ))
_sym_db.RegisterMessage(FeatureInfo)

PackageMetadata = _reflection.GeneratedProtocolMessageType('PackageMetadata', (_message.Message,), dict(
  DESCRIPTOR = _PACKAGEMETADATA,
  __module__ = 'TSPArchiveMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.PackageMetadata)
  ))
_sym_db.RegisterMessage(PackageMetadata)

DocumentRevision = _reflection.GeneratedProtocolMessageType('DocumentRevision', (_message.Message,), dict(
  DESCRIPTOR = _DOCUMENTREVISION,
  __module__ = 'TSPArchiveMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.DocumentRevision)
  ))
_sym_db.RegisterMessage(DocumentRevision)

PasteboardMetadata = _reflection.GeneratedProtocolMessageType('PasteboardMetadata', (_message.Message,), dict(
  DESCRIPTOR = _PASTEBOARDMETADATA,
  __module__ = 'TSPArchiveMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.PasteboardMetadata)
  ))
_sym_db.RegisterMessage(PasteboardMetadata)

DataInfo = _reflection.GeneratedProtocolMessageType('DataInfo', (_message.Message,), dict(
  DESCRIPTOR = _DATAINFO,
  __module__ = 'TSPArchiveMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.DataInfo)
  ))
_sym_db.RegisterMessage(DataInfo)

DataMetadataMap = _reflection.GeneratedProtocolMessageType('DataMetadataMap', (_message.Message,), dict(

  DataMetadataMapEntry = _reflection.GeneratedProtocolMessageType('DataMetadataMapEntry', (_message.Message,), dict(
    DESCRIPTOR = _DATAMETADATAMAP_DATAMETADATAMAPENTRY,
    __module__ = 'TSPArchiveMessages_pb2'
    # @@protoc_insertion_point(class_scope:TSP.DataMetadataMap.DataMetadataMapEntry)
    ))
  ,
  DESCRIPTOR = _DATAMETADATAMAP,
  __module__ = 'TSPArchiveMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.DataMetadataMap)
  ))
_sym_db.RegisterMessage(DataMetadataMap)
_sym_db.RegisterMessage(DataMetadataMap.DataMetadataMapEntry)

DataMetadata = _reflection.GeneratedProtocolMessageType('DataMetadata', (_message.Message,), dict(
  DESCRIPTOR = _DATAMETADATA,
  __module__ = 'TSPArchiveMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.DataMetadata)
  ))
_sym_db.RegisterMessage(DataMetadata)

EncryptionInfo = _reflection.GeneratedProtocolMessageType('EncryptionInfo', (_message.Message,), dict(
  DESCRIPTOR = _ENCRYPTIONINFO,
  __module__ = 'TSPArchiveMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.EncryptionInfo)
  ))
_sym_db.RegisterMessage(EncryptionInfo)

EncryptionBlockInfo = _reflection.GeneratedProtocolMessageType('EncryptionBlockInfo', (_message.Message,), dict(
  DESCRIPTOR = _ENCRYPTIONBLOCKINFO,
  __module__ = 'TSPArchiveMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.EncryptionBlockInfo)
  ))
_sym_db.RegisterMessage(EncryptionBlockInfo)

ViewStateMetadata = _reflection.GeneratedProtocolMessageType('ViewStateMetadata', (_message.Message,), dict(
  DESCRIPTOR = _VIEWSTATEMETADATA,
  __module__ = 'TSPArchiveMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.ViewStateMetadata)
  ))
_sym_db.RegisterMessage(ViewStateMetadata)

ObjectSerializationMetadata = _reflection.GeneratedProtocolMessageType('ObjectSerializationMetadata', (_message.Message,), dict(
  DESCRIPTOR = _OBJECTSERIALIZATIONMETADATA,
  __module__ = 'TSPArchiveMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.ObjectSerializationMetadata)
  ))
_sym_db.RegisterMessage(ObjectSerializationMetadata)

ObjectSerializationDirectory = _reflection.GeneratedProtocolMessageType('ObjectSerializationDirectory', (_message.Message,), dict(

  Entry = _reflection.GeneratedProtocolMessageType('Entry', (_message.Message,), dict(
    DESCRIPTOR = _OBJECTSERIALIZATIONDIRECTORY_ENTRY,
    __module__ = 'TSPArchiveMessages_pb2'
    # @@protoc_insertion_point(class_scope:TSP.ObjectSerializationDirectory.Entry)
    ))
  ,
  DESCRIPTOR = _OBJECTSERIALIZATIONDIRECTORY,
  __module__ = 'TSPArchiveMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.ObjectSerializationDirectory)
  ))
_sym_db.RegisterMessage(ObjectSerializationDirectory)
_sym_db.RegisterMessage(ObjectSerializationDirectory.Entry)

DocumentMetadata = _reflection.GeneratedProtocolMessageType('DocumentMetadata', (_message.Message,), dict(
  DESCRIPTOR = _DOCUMENTMETADATA,
  __module__ = 'TSPArchiveMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.DocumentMetadata)
  ))
_sym_db.RegisterMessage(DocumentMetadata)

SupportMetadata = _reflection.GeneratedProtocolMessageType('SupportMetadata', (_message.Message,), dict(
  DESCRIPTOR = _SUPPORTMETADATA,
  __module__ = 'TSPArchiveMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.SupportMetadata)
  ))
_sym_db.RegisterMessage(SupportMetadata)


# @@protoc_insertion_point(module_scope)
