from __future__ import absolute_import
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: KNCommandArchives_sos.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import TSACommandArchives_sos_pb2 as TSACommandArchives__sos__pb2
from . import TSKArchives_pb2 as TSKArchives__pb2
from . import TSPMessages_pb2 as TSPMessages__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='KNCommandArchives_sos.proto',
  package='KN',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x1bKNCommandArchives_sos.proto\x12\x02KN\x1a\x1cTSACommandArchives_sos.proto\x1a\x11TSKArchives.proto\x1a\x11TSPMessages.proto\"\xfb\x01\n-InducedVerifyDocumentWithServerCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12%\n\x12slide_node_id_list\x18\x02 \x03(\x0b\x32\t.TSP.UUID\x12$\n\x1cslide_node_id_list_undefined\x18\x03 \x01(\x08\x12,\n\x19master_slide_node_id_list\x18\x04 \x03(\x0b\x32\t.TSP.UUID\x12+\n#master_slide_node_id_list_undefined\x18\x05 \x01(\x08\"\x80\x01\n4InducedVerifyDrawableZOrdersWithServerCommandArchive\x12H\n\x05super\x18\x01 \x02(\x0b\x32\x39.TSA.InducedVerifyDrawableZOrdersWithServerCommandArchive\"S\n CommandSlideReapplyMasterArchive\x12/\n\x05super\x18\x01 \x02(\x0b\x32 .TSA.CommandReapplyMasterArchive')
  ,
  dependencies=[TSACommandArchives__sos__pb2.DESCRIPTOR,TSKArchives__pb2.DESCRIPTOR,TSPMessages__pb2.DESCRIPTOR,])




_INDUCEDVERIFYDOCUMENTWITHSERVERCOMMANDARCHIVE = _descriptor.Descriptor(
  name='InducedVerifyDocumentWithServerCommandArchive',
  full_name='KN.InducedVerifyDocumentWithServerCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.InducedVerifyDocumentWithServerCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slide_node_id_list', full_name='KN.InducedVerifyDocumentWithServerCommandArchive.slide_node_id_list', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slide_node_id_list_undefined', full_name='KN.InducedVerifyDocumentWithServerCommandArchive.slide_node_id_list_undefined', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='master_slide_node_id_list', full_name='KN.InducedVerifyDocumentWithServerCommandArchive.master_slide_node_id_list', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='master_slide_node_id_list_undefined', full_name='KN.InducedVerifyDocumentWithServerCommandArchive.master_slide_node_id_list_undefined', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=104,
  serialized_end=355,
)


_INDUCEDVERIFYDRAWABLEZORDERSWITHSERVERCOMMANDARCHIVE = _descriptor.Descriptor(
  name='InducedVerifyDrawableZOrdersWithServerCommandArchive',
  full_name='KN.InducedVerifyDrawableZOrdersWithServerCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.InducedVerifyDrawableZOrdersWithServerCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=358,
  serialized_end=486,
)


_COMMANDSLIDEREAPPLYMASTERARCHIVE = _descriptor.Descriptor(
  name='CommandSlideReapplyMasterArchive',
  full_name='KN.CommandSlideReapplyMasterArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.CommandSlideReapplyMasterArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=488,
  serialized_end=571,
)

_INDUCEDVERIFYDOCUMENTWITHSERVERCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_INDUCEDVERIFYDOCUMENTWITHSERVERCOMMANDARCHIVE.fields_by_name['slide_node_id_list'].message_type = TSPMessages__pb2._UUID
_INDUCEDVERIFYDOCUMENTWITHSERVERCOMMANDARCHIVE.fields_by_name['master_slide_node_id_list'].message_type = TSPMessages__pb2._UUID
_INDUCEDVERIFYDRAWABLEZORDERSWITHSERVERCOMMANDARCHIVE.fields_by_name['super'].message_type = TSACommandArchives__sos__pb2._INDUCEDVERIFYDRAWABLEZORDERSWITHSERVERCOMMANDARCHIVE
_COMMANDSLIDEREAPPLYMASTERARCHIVE.fields_by_name['super'].message_type = TSACommandArchives__sos__pb2._COMMANDREAPPLYMASTERARCHIVE
DESCRIPTOR.message_types_by_name['InducedVerifyDocumentWithServerCommandArchive'] = _INDUCEDVERIFYDOCUMENTWITHSERVERCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['InducedVerifyDrawableZOrdersWithServerCommandArchive'] = _INDUCEDVERIFYDRAWABLEZORDERSWITHSERVERCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['CommandSlideReapplyMasterArchive'] = _COMMANDSLIDEREAPPLYMASTERARCHIVE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

InducedVerifyDocumentWithServerCommandArchive = _reflection.GeneratedProtocolMessageType('InducedVerifyDocumentWithServerCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _INDUCEDVERIFYDOCUMENTWITHSERVERCOMMANDARCHIVE,
  __module__ = 'KNCommandArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:KN.InducedVerifyDocumentWithServerCommandArchive)
  ))
_sym_db.RegisterMessage(InducedVerifyDocumentWithServerCommandArchive)

InducedVerifyDrawableZOrdersWithServerCommandArchive = _reflection.GeneratedProtocolMessageType('InducedVerifyDrawableZOrdersWithServerCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _INDUCEDVERIFYDRAWABLEZORDERSWITHSERVERCOMMANDARCHIVE,
  __module__ = 'KNCommandArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:KN.InducedVerifyDrawableZOrdersWithServerCommandArchive)
  ))
_sym_db.RegisterMessage(InducedVerifyDrawableZOrdersWithServerCommandArchive)

CommandSlideReapplyMasterArchive = _reflection.GeneratedProtocolMessageType('CommandSlideReapplyMasterArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSLIDEREAPPLYMASTERARCHIVE,
  __module__ = 'KNCommandArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:KN.CommandSlideReapplyMasterArchive)
  ))
_sym_db.RegisterMessage(CommandSlideReapplyMasterArchive)


# @@protoc_insertion_point(module_scope)
