from __future__ import absolute_import
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: TSCHArchives_Common.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import TSPMessages_pb2 as TSPMessages__pb2
from . import TSKArchives_pb2 as TSKArchives__pb2
from . import TSDArchives_pb2 as TSDArchives__pb2
from . import TSSArchives_pb2 as TSSArchives__pb2
from . import TSCH3DArchives_pb2 as TSCH3DArchives__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='TSCHArchives_Common.proto',
  package='TSCH',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x19TSCHArchives_Common.proto\x12\x04TSCH\x1a\x11TSPMessages.proto\x1a\x11TSKArchives.proto\x1a\x11TSDArchives.proto\x1a\x11TSSArchives.proto\x1a\x14TSCH3DArchives.proto\"B\n\x0bRectArchive\x12\x1a\n\x06origin\x18\x01 \x02(\x0b\x32\n.TSP.Point\x12\x17\n\x04size\x18\x02 \x02(\x0b\x32\t.TSP.Size\"5\n\x1b\x43hartsNSNumberDoubleArchive\x12\x16\n\x0enumber_archive\x18\x01 \x01(\x01\"7\n$ChartsNSArrayOfNSNumberDoubleArchive\x12\x0f\n\x07numbers\x18\x01 \x03(\x01\"\xd0\x01\n\x1c\x44\x45PRECATEDChart3DFillArchive\x12\x1e\n\x04\x66ill\x18\x01 \x01(\x0b\x32\x10.TSD.FillArchive\x12\x38\n\rlightingmodel\x18\x02 \x01(\x0b\x32!.TSCH.Chart3DLightingModelArchive\x12\x15\n\rtextureset_id\x18\x03 \x01(\t\x12)\n\tfill_type\x18\x04 \x01(\x0e\x32\x16.TSCH.FillPropertyType\x12\x14\n\x0cseries_index\x18\x05 \x01(\r\"@\n\x11\x43hartStyleArchive\x12 \n\x05super\x18\x01 \x01(\x0b\x32\x11.TSS.StyleArchive*\t\x08\x90N\x10\x80\x80\x80\x80\x02\"C\n\x14\x43hartNonStyleArchive\x12 \n\x05super\x18\x01 \x01(\x0b\x32\x11.TSS.StyleArchive*\t\x08\x90N\x10\x80\x80\x80\x80\x02\"A\n\x12LegendStyleArchive\x12 \n\x05super\x18\x01 \x01(\x0b\x32\x11.TSS.StyleArchive*\t\x08\x90N\x10\x80\x80\x80\x80\x02\"D\n\x15LegendNonStyleArchive\x12 \n\x05super\x18\x01 \x01(\x0b\x32\x11.TSS.StyleArchive*\t\x08\x90N\x10\x80\x80\x80\x80\x02\"D\n\x15\x43hartAxisStyleArchive\x12 \n\x05super\x18\x01 \x01(\x0b\x32\x11.TSS.StyleArchive*\t\x08\x90N\x10\x80\x80\x80\x80\x02\"G\n\x18\x43hartAxisNonStyleArchive\x12 \n\x05super\x18\x01 \x01(\x0b\x32\x11.TSS.StyleArchive*\t\x08\x90N\x10\x80\x80\x80\x80\x02\"F\n\x17\x43hartSeriesStyleArchive\x12 \n\x05super\x18\x01 \x01(\x0b\x32\x11.TSS.StyleArchive*\t\x08\x90N\x10\x80\x80\x80\x80\x02\"I\n\x1a\x43hartSeriesNonStyleArchive\x12 \n\x05super\x18\x01 \x01(\x0b\x32\x11.TSS.StyleArchive*\t\x08\x90N\x10\x80\x80\x80\x80\x02\"f\n\tGridValue\x12\x15\n\rnumeric_value\x18\x01 \x01(\x01\x12\x16\n\x0e\x64\x61te_value_1_0\x18\x02 \x01(\x01\x12\x16\n\x0e\x64uration_value\x18\x03 \x01(\x01\x12\x12\n\ndate_value\x18\x04 \x01(\x01\")\n\x07GridRow\x12\x1e\n\x05value\x18\x01 \x03(\x0b\x32\x0f.TSCH.GridValue\"H\n\x19ReferenceLineStyleArchive\x12 \n\x05super\x18\x01 \x01(\x0b\x32\x11.TSS.StyleArchive*\t\x08\x90N\x10\x80\x80\x80\x80\x02\"K\n\x1cReferenceLineNonStyleArchive\x12 \n\x05super\x18\x01 \x01(\x0b\x32\x11.TSS.StyleArchive*\t\x08\x90N\x10\x80\x80\x80\x80\x02*\xa6\x05\n\tChartType\x12\x16\n\x12undefinedChartType\x10\x00\x12\x15\n\x11\x63olumnChartType2D\x10\x01\x12\x12\n\x0e\x62\x61rChartType2D\x10\x02\x12\x13\n\x0flineChartType2D\x10\x03\x12\x13\n\x0f\x61reaChartType2D\x10\x04\x12\x12\n\x0epieChartType2D\x10\x05\x12\x1c\n\x18stackedColumnChartType2D\x10\x06\x12\x19\n\x15stackedBarChartType2D\x10\x07\x12\x1a\n\x16stackedAreaChartType2D\x10\x08\x12\x16\n\x12scatterChartType2D\x10\t\x12\x14\n\x10mixedChartType2D\x10\n\x12\x16\n\x12twoAxisChartType2D\x10\x0b\x12\x15\n\x11\x63olumnChartType3D\x10\x0c\x12\x12\n\x0e\x62\x61rChartType3D\x10\r\x12\x13\n\x0flineChartType3D\x10\x0e\x12\x13\n\x0f\x61reaChartType3D\x10\x0f\x12\x12\n\x0epieChartType3D\x10\x10\x12\x1c\n\x18stackedColumnChartType3D\x10\x11\x12\x19\n\x15stackedBarChartType3D\x10\x12\x12\x1a\n\x16stackedAreaChartType3D\x10\x13\x12\x1e\n\x1amultiDataColumnChartType2D\x10\x14\x12\x1b\n\x17multiDataBarChartType2D\x10\x15\x12\x15\n\x11\x62ubbleChartType2D\x10\x16\x12\x1f\n\x1bmultiDataScatterChartType2D\x10\x17\x12\x1e\n\x1amultiDataBubbleChartType2D\x10\x18\x12\x14\n\x10\x64onutChartType2D\x10\x19\x12\x14\n\x10\x64onutChartType3D\x10\x1a*j\n\x08\x41xisType\x12\x15\n\x11\x61xis_type_unknown\x10\x00\x12\x0f\n\x0b\x61xis_type_x\x10\x01\x12\x0f\n\x0b\x61xis_type_y\x10\x02\x12\x11\n\raxis_type_pie\x10\x03\x12\x12\n\x0e\x61xis_type_size\x10\x04*g\n\rScatterFormat\x12\x1a\n\x16scatter_format_unknown\x10\x00\x12\x1d\n\x19scatter_format_separate_x\x10\x01\x12\x1b\n\x17scatter_format_shared_x\x10\x02*l\n\x0fSeriesDirection\x12\x1c\n\x18series_direction_unknown\x10\x00\x12\x1b\n\x17series_direction_by_row\x10\x01\x12\x1e\n\x1aseries_direction_by_column\x10\x02*\xe3\x01\n\x0fNumberValueType\x12\x1a\n\x16numberValueTypeDecimal\x10\x00\x12\x1b\n\x17numberValueTypeCurrency\x10\x01\x12\x1d\n\x19numberValueTypePercentage\x10\x02\x12\x1d\n\x19numberValueTypeScientific\x10\x03\x12\x1b\n\x17numberValueTypeFraction\x10\x04\x12\x17\n\x13numberValueTypeBase\x10\x05\x12#\n\x16numberValueTypeUnknown\x10\x99\xf8\xff\xff\xff\xff\xff\xff\xff\x01*\xba\x01\n\x13NegativeNumberStyle\x12\x1c\n\x18negativeNumberStyleMinus\x10\x00\x12\x1a\n\x16negativeNumberStyleRed\x10\x01\x12\"\n\x1enegativeNumberStyleParentheses\x10\x02\x12(\n$negativeNumberStyleRedAndParentheses\x10\x03\x12\x1b\n\x17negativeNumberStyleNone\x10\x04*\xeb\x02\n\x10\x46ractionAccuracy\x12\x1f\n\x1b\x66ractionAccuracyConflicting\x10\x00\x12)\n\x1c\x66ractionAccuracyUpToOneDigit\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12*\n\x1d\x66ractionAccuracyUpToTwoDigits\x10\xfe\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12,\n\x1f\x66ractionAccuracyUpToThreeDigits\x10\xfd\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x1a\n\x16\x66ractionAccuracyHalves\x10\x02\x12\x1c\n\x18\x66ractionAccuracyQuarters\x10\x04\x12\x1b\n\x17\x66ractionAccuracyEighths\x10\x08\x12\x1e\n\x1a\x66ractionAccuracySixteenths\x10\x10\x12\x1a\n\x16\x66ractionAccuracyTenths\x10\n\x12\x1e\n\x1a\x66ractionAccuracyHundredths\x10\x64')
  ,
  dependencies=[TSPMessages__pb2.DESCRIPTOR,TSKArchives__pb2.DESCRIPTOR,TSDArchives__pb2.DESCRIPTOR,TSSArchives__pb2.DESCRIPTOR,TSCH3DArchives__pb2.DESCRIPTOR,])

_CHARTTYPE = _descriptor.EnumDescriptor(
  name='ChartType',
  full_name='TSCH.ChartType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='undefinedChartType', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='columnChartType2D', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='barChartType2D', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='lineChartType2D', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='areaChartType2D', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='pieChartType2D', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='stackedColumnChartType2D', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='stackedBarChartType2D', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='stackedAreaChartType2D', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='scatterChartType2D', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='mixedChartType2D', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='twoAxisChartType2D', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='columnChartType3D', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='barChartType3D', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='lineChartType3D', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='areaChartType3D', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='pieChartType3D', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='stackedColumnChartType3D', index=17, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='stackedBarChartType3D', index=18, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='stackedAreaChartType3D', index=19, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='multiDataColumnChartType2D', index=20, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='multiDataBarChartType2D', index=21, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='bubbleChartType2D', index=22, number=22,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='multiDataScatterChartType2D', index=23, number=23,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='multiDataBubbleChartType2D', index=24, number=24,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='donutChartType2D', index=25, number=25,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='donutChartType3D', index=26, number=26,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1385,
  serialized_end=2063,
)
_sym_db.RegisterEnumDescriptor(_CHARTTYPE)

ChartType = enum_type_wrapper.EnumTypeWrapper(_CHARTTYPE)
_AXISTYPE = _descriptor.EnumDescriptor(
  name='AxisType',
  full_name='TSCH.AxisType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='axis_type_unknown', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='axis_type_x', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='axis_type_y', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='axis_type_pie', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='axis_type_size', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2065,
  serialized_end=2171,
)
_sym_db.RegisterEnumDescriptor(_AXISTYPE)

AxisType = enum_type_wrapper.EnumTypeWrapper(_AXISTYPE)
_SCATTERFORMAT = _descriptor.EnumDescriptor(
  name='ScatterFormat',
  full_name='TSCH.ScatterFormat',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='scatter_format_unknown', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='scatter_format_separate_x', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='scatter_format_shared_x', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2173,
  serialized_end=2276,
)
_sym_db.RegisterEnumDescriptor(_SCATTERFORMAT)

ScatterFormat = enum_type_wrapper.EnumTypeWrapper(_SCATTERFORMAT)
_SERIESDIRECTION = _descriptor.EnumDescriptor(
  name='SeriesDirection',
  full_name='TSCH.SeriesDirection',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='series_direction_unknown', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='series_direction_by_row', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='series_direction_by_column', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2278,
  serialized_end=2386,
)
_sym_db.RegisterEnumDescriptor(_SERIESDIRECTION)

SeriesDirection = enum_type_wrapper.EnumTypeWrapper(_SERIESDIRECTION)
_NUMBERVALUETYPE = _descriptor.EnumDescriptor(
  name='NumberValueType',
  full_name='TSCH.NumberValueType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='numberValueTypeDecimal', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='numberValueTypeCurrency', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='numberValueTypePercentage', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='numberValueTypeScientific', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='numberValueTypeFraction', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='numberValueTypeBase', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='numberValueTypeUnknown', index=6, number=-999,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2389,
  serialized_end=2616,
)
_sym_db.RegisterEnumDescriptor(_NUMBERVALUETYPE)

NumberValueType = enum_type_wrapper.EnumTypeWrapper(_NUMBERVALUETYPE)
_NEGATIVENUMBERSTYLE = _descriptor.EnumDescriptor(
  name='NegativeNumberStyle',
  full_name='TSCH.NegativeNumberStyle',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='negativeNumberStyleMinus', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='negativeNumberStyleRed', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='negativeNumberStyleParentheses', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='negativeNumberStyleRedAndParentheses', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='negativeNumberStyleNone', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2619,
  serialized_end=2805,
)
_sym_db.RegisterEnumDescriptor(_NEGATIVENUMBERSTYLE)

NegativeNumberStyle = enum_type_wrapper.EnumTypeWrapper(_NEGATIVENUMBERSTYLE)
_FRACTIONACCURACY = _descriptor.EnumDescriptor(
  name='FractionAccuracy',
  full_name='TSCH.FractionAccuracy',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='fractionAccuracyConflicting', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='fractionAccuracyUpToOneDigit', index=1, number=-1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='fractionAccuracyUpToTwoDigits', index=2, number=-2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='fractionAccuracyUpToThreeDigits', index=3, number=-3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='fractionAccuracyHalves', index=4, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='fractionAccuracyQuarters', index=5, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='fractionAccuracyEighths', index=6, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='fractionAccuracySixteenths', index=7, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='fractionAccuracyTenths', index=8, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='fractionAccuracyHundredths', index=9, number=100,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2808,
  serialized_end=3171,
)
_sym_db.RegisterEnumDescriptor(_FRACTIONACCURACY)

FractionAccuracy = enum_type_wrapper.EnumTypeWrapper(_FRACTIONACCURACY)
undefinedChartType = 0
columnChartType2D = 1
barChartType2D = 2
lineChartType2D = 3
areaChartType2D = 4
pieChartType2D = 5
stackedColumnChartType2D = 6
stackedBarChartType2D = 7
stackedAreaChartType2D = 8
scatterChartType2D = 9
mixedChartType2D = 10
twoAxisChartType2D = 11
columnChartType3D = 12
barChartType3D = 13
lineChartType3D = 14
areaChartType3D = 15
pieChartType3D = 16
stackedColumnChartType3D = 17
stackedBarChartType3D = 18
stackedAreaChartType3D = 19
multiDataColumnChartType2D = 20
multiDataBarChartType2D = 21
bubbleChartType2D = 22
multiDataScatterChartType2D = 23
multiDataBubbleChartType2D = 24
donutChartType2D = 25
donutChartType3D = 26
axis_type_unknown = 0
axis_type_x = 1
axis_type_y = 2
axis_type_pie = 3
axis_type_size = 4
scatter_format_unknown = 0
scatter_format_separate_x = 1
scatter_format_shared_x = 2
series_direction_unknown = 0
series_direction_by_row = 1
series_direction_by_column = 2
numberValueTypeDecimal = 0
numberValueTypeCurrency = 1
numberValueTypePercentage = 2
numberValueTypeScientific = 3
numberValueTypeFraction = 4
numberValueTypeBase = 5
numberValueTypeUnknown = -999
negativeNumberStyleMinus = 0
negativeNumberStyleRed = 1
negativeNumberStyleParentheses = 2
negativeNumberStyleRedAndParentheses = 3
negativeNumberStyleNone = 4
fractionAccuracyConflicting = 0
fractionAccuracyUpToOneDigit = -1
fractionAccuracyUpToTwoDigits = -2
fractionAccuracyUpToThreeDigits = -3
fractionAccuracyHalves = 2
fractionAccuracyQuarters = 4
fractionAccuracyEighths = 8
fractionAccuracySixteenths = 16
fractionAccuracyTenths = 10
fractionAccuracyHundredths = 100



_RECTARCHIVE = _descriptor.Descriptor(
  name='RectArchive',
  full_name='TSCH.RectArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='origin', full_name='TSCH.RectArchive.origin', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='TSCH.RectArchive.size', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=133,
  serialized_end=199,
)


_CHARTSNSNUMBERDOUBLEARCHIVE = _descriptor.Descriptor(
  name='ChartsNSNumberDoubleArchive',
  full_name='TSCH.ChartsNSNumberDoubleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='number_archive', full_name='TSCH.ChartsNSNumberDoubleArchive.number_archive', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=201,
  serialized_end=254,
)


_CHARTSNSARRAYOFNSNUMBERDOUBLEARCHIVE = _descriptor.Descriptor(
  name='ChartsNSArrayOfNSNumberDoubleArchive',
  full_name='TSCH.ChartsNSArrayOfNSNumberDoubleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='numbers', full_name='TSCH.ChartsNSArrayOfNSNumberDoubleArchive.numbers', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=256,
  serialized_end=311,
)


_DEPRECATEDCHART3DFILLARCHIVE = _descriptor.Descriptor(
  name='DEPRECATEDChart3DFillArchive',
  full_name='TSCH.DEPRECATEDChart3DFillArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fill', full_name='TSCH.DEPRECATEDChart3DFillArchive.fill', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lightingmodel', full_name='TSCH.DEPRECATEDChart3DFillArchive.lightingmodel', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='textureset_id', full_name='TSCH.DEPRECATEDChart3DFillArchive.textureset_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fill_type', full_name='TSCH.DEPRECATEDChart3DFillArchive.fill_type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='series_index', full_name='TSCH.DEPRECATEDChart3DFillArchive.series_index', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=314,
  serialized_end=522,
)


_CHARTSTYLEARCHIVE = _descriptor.Descriptor(
  name='ChartStyleArchive',
  full_name='TSCH.ChartStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.ChartStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(10000, 536870912), ],
  oneofs=[
  ],
  serialized_start=524,
  serialized_end=588,
)


_CHARTNONSTYLEARCHIVE = _descriptor.Descriptor(
  name='ChartNonStyleArchive',
  full_name='TSCH.ChartNonStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.ChartNonStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(10000, 536870912), ],
  oneofs=[
  ],
  serialized_start=590,
  serialized_end=657,
)


_LEGENDSTYLEARCHIVE = _descriptor.Descriptor(
  name='LegendStyleArchive',
  full_name='TSCH.LegendStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.LegendStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(10000, 536870912), ],
  oneofs=[
  ],
  serialized_start=659,
  serialized_end=724,
)


_LEGENDNONSTYLEARCHIVE = _descriptor.Descriptor(
  name='LegendNonStyleArchive',
  full_name='TSCH.LegendNonStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.LegendNonStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(10000, 536870912), ],
  oneofs=[
  ],
  serialized_start=726,
  serialized_end=794,
)


_CHARTAXISSTYLEARCHIVE = _descriptor.Descriptor(
  name='ChartAxisStyleArchive',
  full_name='TSCH.ChartAxisStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.ChartAxisStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(10000, 536870912), ],
  oneofs=[
  ],
  serialized_start=796,
  serialized_end=864,
)


_CHARTAXISNONSTYLEARCHIVE = _descriptor.Descriptor(
  name='ChartAxisNonStyleArchive',
  full_name='TSCH.ChartAxisNonStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.ChartAxisNonStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(10000, 536870912), ],
  oneofs=[
  ],
  serialized_start=866,
  serialized_end=937,
)


_CHARTSERIESSTYLEARCHIVE = _descriptor.Descriptor(
  name='ChartSeriesStyleArchive',
  full_name='TSCH.ChartSeriesStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.ChartSeriesStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(10000, 536870912), ],
  oneofs=[
  ],
  serialized_start=939,
  serialized_end=1009,
)


_CHARTSERIESNONSTYLEARCHIVE = _descriptor.Descriptor(
  name='ChartSeriesNonStyleArchive',
  full_name='TSCH.ChartSeriesNonStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.ChartSeriesNonStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(10000, 536870912), ],
  oneofs=[
  ],
  serialized_start=1011,
  serialized_end=1084,
)


_GRIDVALUE = _descriptor.Descriptor(
  name='GridValue',
  full_name='TSCH.GridValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='numeric_value', full_name='TSCH.GridValue.numeric_value', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date_value_1_0', full_name='TSCH.GridValue.date_value_1_0', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration_value', full_name='TSCH.GridValue.duration_value', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date_value', full_name='TSCH.GridValue.date_value', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1086,
  serialized_end=1188,
)


_GRIDROW = _descriptor.Descriptor(
  name='GridRow',
  full_name='TSCH.GridRow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='TSCH.GridRow.value', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1190,
  serialized_end=1231,
)


_REFERENCELINESTYLEARCHIVE = _descriptor.Descriptor(
  name='ReferenceLineStyleArchive',
  full_name='TSCH.ReferenceLineStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.ReferenceLineStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(10000, 536870912), ],
  oneofs=[
  ],
  serialized_start=1233,
  serialized_end=1305,
)


_REFERENCELINENONSTYLEARCHIVE = _descriptor.Descriptor(
  name='ReferenceLineNonStyleArchive',
  full_name='TSCH.ReferenceLineNonStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.ReferenceLineNonStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(10000, 536870912), ],
  oneofs=[
  ],
  serialized_start=1307,
  serialized_end=1382,
)

_RECTARCHIVE.fields_by_name['origin'].message_type = TSPMessages__pb2._POINT
_RECTARCHIVE.fields_by_name['size'].message_type = TSPMessages__pb2._SIZE
_DEPRECATEDCHART3DFILLARCHIVE.fields_by_name['fill'].message_type = TSDArchives__pb2._FILLARCHIVE
_DEPRECATEDCHART3DFILLARCHIVE.fields_by_name['lightingmodel'].message_type = TSCH3DArchives__pb2._CHART3DLIGHTINGMODELARCHIVE
_DEPRECATEDCHART3DFILLARCHIVE.fields_by_name['fill_type'].enum_type = TSCH3DArchives__pb2._FILLPROPERTYTYPE
_CHARTSTYLEARCHIVE.fields_by_name['super'].message_type = TSSArchives__pb2._STYLEARCHIVE
_CHARTNONSTYLEARCHIVE.fields_by_name['super'].message_type = TSSArchives__pb2._STYLEARCHIVE
_LEGENDSTYLEARCHIVE.fields_by_name['super'].message_type = TSSArchives__pb2._STYLEARCHIVE
_LEGENDNONSTYLEARCHIVE.fields_by_name['super'].message_type = TSSArchives__pb2._STYLEARCHIVE
_CHARTAXISSTYLEARCHIVE.fields_by_name['super'].message_type = TSSArchives__pb2._STYLEARCHIVE
_CHARTAXISNONSTYLEARCHIVE.fields_by_name['super'].message_type = TSSArchives__pb2._STYLEARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['super'].message_type = TSSArchives__pb2._STYLEARCHIVE
_CHARTSERIESNONSTYLEARCHIVE.fields_by_name['super'].message_type = TSSArchives__pb2._STYLEARCHIVE
_GRIDROW.fields_by_name['value'].message_type = _GRIDVALUE
_REFERENCELINESTYLEARCHIVE.fields_by_name['super'].message_type = TSSArchives__pb2._STYLEARCHIVE
_REFERENCELINENONSTYLEARCHIVE.fields_by_name['super'].message_type = TSSArchives__pb2._STYLEARCHIVE
DESCRIPTOR.message_types_by_name['RectArchive'] = _RECTARCHIVE
DESCRIPTOR.message_types_by_name['ChartsNSNumberDoubleArchive'] = _CHARTSNSNUMBERDOUBLEARCHIVE
DESCRIPTOR.message_types_by_name['ChartsNSArrayOfNSNumberDoubleArchive'] = _CHARTSNSARRAYOFNSNUMBERDOUBLEARCHIVE
DESCRIPTOR.message_types_by_name['DEPRECATEDChart3DFillArchive'] = _DEPRECATEDCHART3DFILLARCHIVE
DESCRIPTOR.message_types_by_name['ChartStyleArchive'] = _CHARTSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['ChartNonStyleArchive'] = _CHARTNONSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['LegendStyleArchive'] = _LEGENDSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['LegendNonStyleArchive'] = _LEGENDNONSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['ChartAxisStyleArchive'] = _CHARTAXISSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['ChartAxisNonStyleArchive'] = _CHARTAXISNONSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['ChartSeriesStyleArchive'] = _CHARTSERIESSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['ChartSeriesNonStyleArchive'] = _CHARTSERIESNONSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['GridValue'] = _GRIDVALUE
DESCRIPTOR.message_types_by_name['GridRow'] = _GRIDROW
DESCRIPTOR.message_types_by_name['ReferenceLineStyleArchive'] = _REFERENCELINESTYLEARCHIVE
DESCRIPTOR.message_types_by_name['ReferenceLineNonStyleArchive'] = _REFERENCELINENONSTYLEARCHIVE
DESCRIPTOR.enum_types_by_name['ChartType'] = _CHARTTYPE
DESCRIPTOR.enum_types_by_name['AxisType'] = _AXISTYPE
DESCRIPTOR.enum_types_by_name['ScatterFormat'] = _SCATTERFORMAT
DESCRIPTOR.enum_types_by_name['SeriesDirection'] = _SERIESDIRECTION
DESCRIPTOR.enum_types_by_name['NumberValueType'] = _NUMBERVALUETYPE
DESCRIPTOR.enum_types_by_name['NegativeNumberStyle'] = _NEGATIVENUMBERSTYLE
DESCRIPTOR.enum_types_by_name['FractionAccuracy'] = _FRACTIONACCURACY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RectArchive = _reflection.GeneratedProtocolMessageType('RectArchive', (_message.Message,), dict(
  DESCRIPTOR = _RECTARCHIVE,
  __module__ = 'TSCHArchives_Common_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.RectArchive)
  ))
_sym_db.RegisterMessage(RectArchive)

ChartsNSNumberDoubleArchive = _reflection.GeneratedProtocolMessageType('ChartsNSNumberDoubleArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTSNSNUMBERDOUBLEARCHIVE,
  __module__ = 'TSCHArchives_Common_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartsNSNumberDoubleArchive)
  ))
_sym_db.RegisterMessage(ChartsNSNumberDoubleArchive)

ChartsNSArrayOfNSNumberDoubleArchive = _reflection.GeneratedProtocolMessageType('ChartsNSArrayOfNSNumberDoubleArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTSNSARRAYOFNSNUMBERDOUBLEARCHIVE,
  __module__ = 'TSCHArchives_Common_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartsNSArrayOfNSNumberDoubleArchive)
  ))
_sym_db.RegisterMessage(ChartsNSArrayOfNSNumberDoubleArchive)

DEPRECATEDChart3DFillArchive = _reflection.GeneratedProtocolMessageType('DEPRECATEDChart3DFillArchive', (_message.Message,), dict(
  DESCRIPTOR = _DEPRECATEDCHART3DFILLARCHIVE,
  __module__ = 'TSCHArchives_Common_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.DEPRECATEDChart3DFillArchive)
  ))
_sym_db.RegisterMessage(DEPRECATEDChart3DFillArchive)

ChartStyleArchive = _reflection.GeneratedProtocolMessageType('ChartStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTSTYLEARCHIVE,
  __module__ = 'TSCHArchives_Common_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartStyleArchive)
  ))
_sym_db.RegisterMessage(ChartStyleArchive)

ChartNonStyleArchive = _reflection.GeneratedProtocolMessageType('ChartNonStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTNONSTYLEARCHIVE,
  __module__ = 'TSCHArchives_Common_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartNonStyleArchive)
  ))
_sym_db.RegisterMessage(ChartNonStyleArchive)

LegendStyleArchive = _reflection.GeneratedProtocolMessageType('LegendStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _LEGENDSTYLEARCHIVE,
  __module__ = 'TSCHArchives_Common_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.LegendStyleArchive)
  ))
_sym_db.RegisterMessage(LegendStyleArchive)

LegendNonStyleArchive = _reflection.GeneratedProtocolMessageType('LegendNonStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _LEGENDNONSTYLEARCHIVE,
  __module__ = 'TSCHArchives_Common_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.LegendNonStyleArchive)
  ))
_sym_db.RegisterMessage(LegendNonStyleArchive)

ChartAxisStyleArchive = _reflection.GeneratedProtocolMessageType('ChartAxisStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTAXISSTYLEARCHIVE,
  __module__ = 'TSCHArchives_Common_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartAxisStyleArchive)
  ))
_sym_db.RegisterMessage(ChartAxisStyleArchive)

ChartAxisNonStyleArchive = _reflection.GeneratedProtocolMessageType('ChartAxisNonStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTAXISNONSTYLEARCHIVE,
  __module__ = 'TSCHArchives_Common_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartAxisNonStyleArchive)
  ))
_sym_db.RegisterMessage(ChartAxisNonStyleArchive)

ChartSeriesStyleArchive = _reflection.GeneratedProtocolMessageType('ChartSeriesStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTSERIESSTYLEARCHIVE,
  __module__ = 'TSCHArchives_Common_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartSeriesStyleArchive)
  ))
_sym_db.RegisterMessage(ChartSeriesStyleArchive)

ChartSeriesNonStyleArchive = _reflection.GeneratedProtocolMessageType('ChartSeriesNonStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTSERIESNONSTYLEARCHIVE,
  __module__ = 'TSCHArchives_Common_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartSeriesNonStyleArchive)
  ))
_sym_db.RegisterMessage(ChartSeriesNonStyleArchive)

GridValue = _reflection.GeneratedProtocolMessageType('GridValue', (_message.Message,), dict(
  DESCRIPTOR = _GRIDVALUE,
  __module__ = 'TSCHArchives_Common_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.GridValue)
  ))
_sym_db.RegisterMessage(GridValue)

GridRow = _reflection.GeneratedProtocolMessageType('GridRow', (_message.Message,), dict(
  DESCRIPTOR = _GRIDROW,
  __module__ = 'TSCHArchives_Common_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.GridRow)
  ))
_sym_db.RegisterMessage(GridRow)

ReferenceLineStyleArchive = _reflection.GeneratedProtocolMessageType('ReferenceLineStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _REFERENCELINESTYLEARCHIVE,
  __module__ = 'TSCHArchives_Common_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ReferenceLineStyleArchive)
  ))
_sym_db.RegisterMessage(ReferenceLineStyleArchive)

ReferenceLineNonStyleArchive = _reflection.GeneratedProtocolMessageType('ReferenceLineNonStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _REFERENCELINENONSTYLEARCHIVE,
  __module__ = 'TSCHArchives_Common_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ReferenceLineNonStyleArchive)
  ))
_sym_db.RegisterMessage(ReferenceLineNonStyleArchive)


# @@protoc_insertion_point(module_scope)
