from __future__ import absolute_import
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: TSACommandArchives_sos.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import TSAArchives_sos_pb2 as TSAArchives__sos__pb2
from . import TSKArchives_pb2 as TSKArchives__pb2
from . import TSPMessages_pb2 as TSPMessages__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='TSACommandArchives_sos.proto',
  package='TSA',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x1cTSACommandArchives_sos.proto\x12\x03TSA\x1a\x15TSAArchives_sos.proto\x1a\x11TSKArchives.proto\x1a\x11TSPMessages.proto\"\xd2\x01\n4InducedVerifyDrawableZOrdersWithServerCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x45\n\x1dserver_drawable_z_order_lists\x18\x02 \x03(\x0b\x32\x1e.TSA.DrawableZOrderListArchive\x12/\n\'server_drawable_z_order_lists_undefined\x18\x03 \x01(\x08\"\xb8\x01\n#PropagateMasterChangeCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x36\n#uuids_of_previously_visited_objects\x18\x02 \x03(\x0b\x32\t.TSP.UUID\x12\x35\n-uuids_of_previously_visited_objects_undefined\x18\x03 \x01(\x08\"\x97\x01\n\x1b\x43ommandReapplyMasterArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12!\n\x0eitems_to_visit\x18\x02 \x03(\x0b\x32\t.TSP.UUID\x12 \n\x18items_to_visit_undefined\x18\x03 \x01(\x08\x12\x0f\n\x07is_undo\x18\x04 \x02(\x08\"L\n&VerifyDocumentWithServerCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\"\x9c\x01\n-VerifyDrawableZOrdersWithServerCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12#\n\x10\x64rawable_id_list\x18\x02 \x03(\x0b\x32\t.TSP.UUID\x12\"\n\x1a\x64rawable_id_list_undefined\x18\x03 \x01(\x08\"\x90\x01\n%VerifyObjectsWithServerCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12!\n\x0eobject_id_list\x18\x02 \x03(\x0b\x32\t.TSP.UUID\x12 \n\x18object_id_list_undefined\x18\x03 \x01(\x08\"\x82\x01\n.VerifyTransformHistoryWithServerCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x16\n\x0esequence_start\x18\x02 \x02(\x05\x12\x14\n\x0csequence_end\x18\x03 \x02(\x05')
  ,
  dependencies=[TSAArchives__sos__pb2.DESCRIPTOR,TSKArchives__pb2.DESCRIPTOR,TSPMessages__pb2.DESCRIPTOR,])




_INDUCEDVERIFYDRAWABLEZORDERSWITHSERVERCOMMANDARCHIVE = _descriptor.Descriptor(
  name='InducedVerifyDrawableZOrdersWithServerCommandArchive',
  full_name='TSA.InducedVerifyDrawableZOrdersWithServerCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSA.InducedVerifyDrawableZOrdersWithServerCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='server_drawable_z_order_lists', full_name='TSA.InducedVerifyDrawableZOrdersWithServerCommandArchive.server_drawable_z_order_lists', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='server_drawable_z_order_lists_undefined', full_name='TSA.InducedVerifyDrawableZOrdersWithServerCommandArchive.server_drawable_z_order_lists_undefined', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=99,
  serialized_end=309,
)


_PROPAGATEMASTERCHANGECOMMANDARCHIVE = _descriptor.Descriptor(
  name='PropagateMasterChangeCommandArchive',
  full_name='TSA.PropagateMasterChangeCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSA.PropagateMasterChangeCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uuids_of_previously_visited_objects', full_name='TSA.PropagateMasterChangeCommandArchive.uuids_of_previously_visited_objects', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uuids_of_previously_visited_objects_undefined', full_name='TSA.PropagateMasterChangeCommandArchive.uuids_of_previously_visited_objects_undefined', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=312,
  serialized_end=496,
)


_COMMANDREAPPLYMASTERARCHIVE = _descriptor.Descriptor(
  name='CommandReapplyMasterArchive',
  full_name='TSA.CommandReapplyMasterArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSA.CommandReapplyMasterArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='items_to_visit', full_name='TSA.CommandReapplyMasterArchive.items_to_visit', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='items_to_visit_undefined', full_name='TSA.CommandReapplyMasterArchive.items_to_visit_undefined', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_undo', full_name='TSA.CommandReapplyMasterArchive.is_undo', index=3,
      number=4, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=499,
  serialized_end=650,
)


_VERIFYDOCUMENTWITHSERVERCOMMANDARCHIVE = _descriptor.Descriptor(
  name='VerifyDocumentWithServerCommandArchive',
  full_name='TSA.VerifyDocumentWithServerCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSA.VerifyDocumentWithServerCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=652,
  serialized_end=728,
)


_VERIFYDRAWABLEZORDERSWITHSERVERCOMMANDARCHIVE = _descriptor.Descriptor(
  name='VerifyDrawableZOrdersWithServerCommandArchive',
  full_name='TSA.VerifyDrawableZOrdersWithServerCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSA.VerifyDrawableZOrdersWithServerCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='drawable_id_list', full_name='TSA.VerifyDrawableZOrdersWithServerCommandArchive.drawable_id_list', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='drawable_id_list_undefined', full_name='TSA.VerifyDrawableZOrdersWithServerCommandArchive.drawable_id_list_undefined', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=731,
  serialized_end=887,
)


_VERIFYOBJECTSWITHSERVERCOMMANDARCHIVE = _descriptor.Descriptor(
  name='VerifyObjectsWithServerCommandArchive',
  full_name='TSA.VerifyObjectsWithServerCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSA.VerifyObjectsWithServerCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='object_id_list', full_name='TSA.VerifyObjectsWithServerCommandArchive.object_id_list', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='object_id_list_undefined', full_name='TSA.VerifyObjectsWithServerCommandArchive.object_id_list_undefined', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=890,
  serialized_end=1034,
)


_VERIFYTRANSFORMHISTORYWITHSERVERCOMMANDARCHIVE = _descriptor.Descriptor(
  name='VerifyTransformHistoryWithServerCommandArchive',
  full_name='TSA.VerifyTransformHistoryWithServerCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSA.VerifyTransformHistoryWithServerCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sequence_start', full_name='TSA.VerifyTransformHistoryWithServerCommandArchive.sequence_start', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sequence_end', full_name='TSA.VerifyTransformHistoryWithServerCommandArchive.sequence_end', index=2,
      number=3, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1037,
  serialized_end=1167,
)

_INDUCEDVERIFYDRAWABLEZORDERSWITHSERVERCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_INDUCEDVERIFYDRAWABLEZORDERSWITHSERVERCOMMANDARCHIVE.fields_by_name['server_drawable_z_order_lists'].message_type = TSAArchives__sos__pb2._DRAWABLEZORDERLISTARCHIVE
_PROPAGATEMASTERCHANGECOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_PROPAGATEMASTERCHANGECOMMANDARCHIVE.fields_by_name['uuids_of_previously_visited_objects'].message_type = TSPMessages__pb2._UUID
_COMMANDREAPPLYMASTERARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDREAPPLYMASTERARCHIVE.fields_by_name['items_to_visit'].message_type = TSPMessages__pb2._UUID
_VERIFYDOCUMENTWITHSERVERCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_VERIFYDRAWABLEZORDERSWITHSERVERCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_VERIFYDRAWABLEZORDERSWITHSERVERCOMMANDARCHIVE.fields_by_name['drawable_id_list'].message_type = TSPMessages__pb2._UUID
_VERIFYOBJECTSWITHSERVERCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_VERIFYOBJECTSWITHSERVERCOMMANDARCHIVE.fields_by_name['object_id_list'].message_type = TSPMessages__pb2._UUID
_VERIFYTRANSFORMHISTORYWITHSERVERCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
DESCRIPTOR.message_types_by_name['InducedVerifyDrawableZOrdersWithServerCommandArchive'] = _INDUCEDVERIFYDRAWABLEZORDERSWITHSERVERCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['PropagateMasterChangeCommandArchive'] = _PROPAGATEMASTERCHANGECOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['CommandReapplyMasterArchive'] = _COMMANDREAPPLYMASTERARCHIVE
DESCRIPTOR.message_types_by_name['VerifyDocumentWithServerCommandArchive'] = _VERIFYDOCUMENTWITHSERVERCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['VerifyDrawableZOrdersWithServerCommandArchive'] = _VERIFYDRAWABLEZORDERSWITHSERVERCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['VerifyObjectsWithServerCommandArchive'] = _VERIFYOBJECTSWITHSERVERCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['VerifyTransformHistoryWithServerCommandArchive'] = _VERIFYTRANSFORMHISTORYWITHSERVERCOMMANDARCHIVE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

InducedVerifyDrawableZOrdersWithServerCommandArchive = _reflection.GeneratedProtocolMessageType('InducedVerifyDrawableZOrdersWithServerCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _INDUCEDVERIFYDRAWABLEZORDERSWITHSERVERCOMMANDARCHIVE,
  __module__ = 'TSACommandArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSA.InducedVerifyDrawableZOrdersWithServerCommandArchive)
  ))
_sym_db.RegisterMessage(InducedVerifyDrawableZOrdersWithServerCommandArchive)

PropagateMasterChangeCommandArchive = _reflection.GeneratedProtocolMessageType('PropagateMasterChangeCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _PROPAGATEMASTERCHANGECOMMANDARCHIVE,
  __module__ = 'TSACommandArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSA.PropagateMasterChangeCommandArchive)
  ))
_sym_db.RegisterMessage(PropagateMasterChangeCommandArchive)

CommandReapplyMasterArchive = _reflection.GeneratedProtocolMessageType('CommandReapplyMasterArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDREAPPLYMASTERARCHIVE,
  __module__ = 'TSACommandArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSA.CommandReapplyMasterArchive)
  ))
_sym_db.RegisterMessage(CommandReapplyMasterArchive)

VerifyDocumentWithServerCommandArchive = _reflection.GeneratedProtocolMessageType('VerifyDocumentWithServerCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _VERIFYDOCUMENTWITHSERVERCOMMANDARCHIVE,
  __module__ = 'TSACommandArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSA.VerifyDocumentWithServerCommandArchive)
  ))
_sym_db.RegisterMessage(VerifyDocumentWithServerCommandArchive)

VerifyDrawableZOrdersWithServerCommandArchive = _reflection.GeneratedProtocolMessageType('VerifyDrawableZOrdersWithServerCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _VERIFYDRAWABLEZORDERSWITHSERVERCOMMANDARCHIVE,
  __module__ = 'TSACommandArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSA.VerifyDrawableZOrdersWithServerCommandArchive)
  ))
_sym_db.RegisterMessage(VerifyDrawableZOrdersWithServerCommandArchive)

VerifyObjectsWithServerCommandArchive = _reflection.GeneratedProtocolMessageType('VerifyObjectsWithServerCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _VERIFYOBJECTSWITHSERVERCOMMANDARCHIVE,
  __module__ = 'TSACommandArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSA.VerifyObjectsWithServerCommandArchive)
  ))
_sym_db.RegisterMessage(VerifyObjectsWithServerCommandArchive)

VerifyTransformHistoryWithServerCommandArchive = _reflection.GeneratedProtocolMessageType('VerifyTransformHistoryWithServerCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _VERIFYTRANSFORMHISTORYWITHSERVERCOMMANDARCHIVE,
  __module__ = 'TSACommandArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSA.VerifyTransformHistoryWithServerCommandArchive)
  ))
_sym_db.RegisterMessage(VerifyTransformHistoryWithServerCommandArchive)


# @@protoc_insertion_point(module_scope)
