from __future__ import absolute_import
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: TSWPArchives.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import TSPMessages_pb2 as TSPMessages__pb2
from . import TSSArchives_pb2 as TSSArchives__pb2
from . import TSDArchives_pb2 as TSDArchives__pb2
from . import TSKArchives_pb2 as TSKArchives__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='TSWPArchives.proto',
  package='TSWP',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x12TSWPArchives.proto\x12\x04TSWP\x1a\x11TSPMessages.proto\x1a\x11TSSArchives.proto\x1a\x11TSDArchives.proto\x1a\x11TSKArchives.proto\"\xe1\x01\n\x10SelectionArchive\x12!\n\x04type\x18\x01 \x02(\x0e\x32\x13.TSWP.SelectionType\x12\x19\n\x05range\x18\x02 \x02(\x0b\x32\n.TSP.Range\x12<\n\x16styleInsertionBehavior\x18\x03 \x02(\x0e\x32\x1c.TSWP.StyleInsertionBehavior\x12*\n\rcaretAffinity\x18\x04 \x02(\x0e\x32\x13.TSWP.CaretAffinity\x12%\n\x11smart_field_range\x18\x05 \x02(\x0b\x32\n.TSP.Range\"\x9f\x01\n\x14ObjectAttributeTable\x12;\n\x07\x65ntries\x18\x01 \x03(\x0b\x32*.TSWP.ObjectAttributeTable.ObjectAttribute\x1aJ\n\x0fObjectAttribute\x12\x17\n\x0f\x63haracter_index\x18\x01 \x02(\r\x12\x1e\n\x06object\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\"\x8f\x01\n\x14StringAttributeTable\x12;\n\x07\x65ntries\x18\x01 \x03(\x0b\x32*.TSWP.StringAttributeTable.StringAttribute\x1a:\n\x0fStringAttribute\x12\x17\n\x0f\x63haracter_index\x18\x01 \x02(\r\x12\x0e\n\x06object\x18\x02 \x01(\t\"\xa6\x01\n\x16ParaDataAttributeTable\x12?\n\x07\x65ntries\x18\x01 \x03(\x0b\x32..TSWP.ParaDataAttributeTable.ParaDataAttribute\x1aK\n\x11ParaDataAttribute\x12\x17\n\x0f\x63haracter_index\x18\x01 \x02(\r\x12\r\n\x05\x66irst\x18\x02 \x02(\r\x12\x0e\n\x06second\x18\x03 \x02(\r\"\xc8\x01\n\x1eOverlappingFieldAttributeTable\x12O\n\x07\x65ntries\x18\x01 \x03(\x0b\x32>.TSWP.OverlappingFieldAttributeTable.OverlappingFieldAttribute\x1aU\n\x19OverlappingFieldAttribute\x12\x19\n\x05range\x18\x01 \x02(\x0b\x32\n.TSP.Range\x12\x1d\n\x05\x66ield\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\"\xe0\x0b\n\x0eStorageArchive\x12\x34\n\x04kind\x18\x01 \x01(\x0e\x32\x1d.TSWP.StorageArchive.KindType:\x07TEXTBOX\x12#\n\x0bstyle_sheet\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12\x0c\n\x04text\x18\x03 \x03(\t\x12\x11\n\thas_itext\x18\x04 \x01(\x08\x12\x13\n\x0bin_document\x18\n \x01(\x08\x12\x34\n\x10table_para_style\x18\x05 \x01(\x0b\x32\x1a.TSWP.ObjectAttributeTable\x12\x35\n\x0ftable_para_data\x18\x06 \x01(\x0b\x32\x1c.TSWP.ParaDataAttributeTable\x12\x34\n\x10table_list_style\x18\x07 \x01(\x0b\x32\x1a.TSWP.ObjectAttributeTable\x12\x34\n\x10table_char_style\x18\x08 \x01(\x0b\x32\x1a.TSWP.ObjectAttributeTable\x12\x34\n\x10table_attachment\x18\t \x01(\x0b\x32\x1a.TSWP.ObjectAttributeTable\x12\x34\n\x10table_smartfield\x18\x0b \x01(\x0b\x32\x1a.TSWP.ObjectAttributeTable\x12\x36\n\x12table_layout_style\x18\x0c \x01(\x0b\x32\x1a.TSWP.ObjectAttributeTable\x12\x37\n\x11table_para_starts\x18\x0e \x01(\x0b\x32\x1c.TSWP.ParaDataAttributeTable\x12\x32\n\x0etable_bookmark\x18\x0f \x01(\x0b\x32\x1a.TSWP.ObjectAttributeTable\x12\x32\n\x0etable_footnote\x18\x10 \x01(\x0b\x32\x1a.TSWP.ObjectAttributeTable\x12\x31\n\rtable_section\x18\x11 \x01(\x0b\x32\x1a.TSWP.ObjectAttributeTable\x12\x33\n\x0ftable_rubyfield\x18\x12 \x01(\x0b\x32\x1a.TSWP.ObjectAttributeTable\x12\x32\n\x0etable_language\x18\x13 \x01(\x0b\x32\x1a.TSWP.StringAttributeTable\x12\x33\n\x0ftable_dictation\x18\x14 \x01(\x0b\x32\x1a.TSWP.StringAttributeTable\x12\x33\n\x0ftable_insertion\x18\x15 \x01(\x0b\x32\x1a.TSWP.ObjectAttributeTable\x12\x32\n\x0etable_deletion\x18\x16 \x01(\x0b\x32\x1a.TSWP.ObjectAttributeTable\x12\x33\n\x0ftable_highlight\x18\x17 \x01(\x0b\x32\x1a.TSWP.ObjectAttributeTable\x12\x35\n\x0ftable_para_bidi\x18\x18 \x01(\x0b\x32\x1c.TSWP.ParaDataAttributeTable\x12I\n\x1btable_overlapping_highlight\x18\x19 \x01(\x0b\x32$.TSWP.OverlappingFieldAttributeTable\x12\x45\n\x17table_pencil_annotation\x18\x1a \x01(\x0b\x32$.TSWP.OverlappingFieldAttributeTable\x12\x35\n\x11table_tatechuyoko\x18\x1b \x01(\x0b\x32\x1a.TSWP.ObjectAttributeTable\x12\x38\n\x14table_drop_cap_style\x18\x1c \x01(\x0b\x32\x1a.TSWP.ObjectAttributeTable\"v\n\x08KindType\x12\x08\n\x04\x42ODY\x10\x00\x12\n\n\x06HEADER\x10\x01\x12\x0c\n\x08\x46OOTNOTE\x10\x02\x12\x0b\n\x07TEXTBOX\x10\x03\x12\x08\n\x04NOTE\x10\x04\x12\x08\n\x04\x43\x45LL\x10\x05\x12\x10\n\x0cUNCLASSIFIED\x10\x06\x12\x13\n\x0fTABLEOFCONTENTS\x10\x07\"^\n\x10HighlightArchive\x12&\n\x0e\x63ommentStorage\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\x12\"\n\x1atext_attribute_uuid_string\x18\x02 \x01(\t\"p\n\x17PencilAnnotationArchive\x12\x31\n\x19pencil_annotation_storage\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\x12\"\n\x1atext_attribute_uuid_string\x18\x02 \x01(\t\"D\n\x12\x46ontFeatureArchive\x12\x14\n\x0c\x66\x65\x61ture_type\x18\x01 \x02(\r\x12\x18\n\x10\x66\x65\x61ture_selector\x18\x02 \x02(\r\"\x85\x10\n\x1f\x43haracterStylePropertiesArchive\x12\x0c\n\x04\x62old\x18\x01 \x01(\x08\x12\x0e\n\x06italic\x18\x02 \x01(\x08\x12\x11\n\tfont_size\x18\x03 \x01(\x02\x12\x16\n\x0e\x66ont_name_null\x18\x04 \x01(\x08\x12\x11\n\tfont_name\x18\x05 \x01(\t\x12\x17\n\x0f\x66ont_color_null\x18\x06 \x01(\x08\x12\x1e\n\nfont_color\x18\x07 \x01(\x0b\x32\n.TSP.Color\x12\x15\n\rlanguage_null\x18\x08 \x01(\x08\x12\x10\n\x08language\x18\t \x01(\t\x12J\n\x0bsuperscript\x18\n \x01(\x0e\x32\x35.TSWP.CharacterStylePropertiesArchive.SuperscriptType\x12\x46\n\tunderline\x18\x0b \x01(\x0e\x32\x33.TSWP.CharacterStylePropertiesArchive.UnderlineType\x12H\n\nstrikethru\x18\x0c \x01(\x0e\x32\x34.TSWP.CharacterStylePropertiesArchive.StrikethruType\x12P\n\x0e\x63\x61pitalization\x18\r \x01(\x0e\x32\x38.TSWP.CharacterStylePropertiesArchive.CapitalizationType\x12\x16\n\x0e\x62\x61seline_shift\x18\x0e \x01(\x02\x12\x0f\n\x07kerning\x18\x0f \x01(\x02\x12\x46\n\tligatures\x18\x10 \x01(\x0e\x32\x33.TSWP.CharacterStylePropertiesArchive.LigaturesType\x12\x1a\n\x12outline_color_null\x18\x11 \x01(\x08\x12!\n\routline_color\x18\x12 \x01(\x0b\x32\n.TSP.Color\x12\x0f\n\x07outline\x18\x13 \x01(\x02\x12\x13\n\x0bshadow_null\x18\x14 \x01(\x08\x12\"\n\x06shadow\x18\x15 \x01(\x0b\x32\x12.TSD.ShadowArchive\x12\x1d\n\x15strikethru_color_null\x18\x16 \x01(\x08\x12$\n\x10strikethru_color\x18\x17 \x01(\x0b\x32\n.TSP.Color\x12\x18\n\x10strikethru_width\x18\x18 \x01(\x02\x12\x1d\n\x15\x62\x61\x63kground_color_null\x18\x19 \x01(\x08\x12$\n\x10\x62\x61\x63kground_color\x18\x1a \x01(\x0b\x32\n.TSP.Color\x12\x10\n\x08tracking\x18\x1b \x01(\x02\x12\x1c\n\x14underline_color_null\x18\x1c \x01(\x08\x12#\n\x0funderline_color\x18\x1d \x01(\x0b\x32\n.TSP.Color\x12\x17\n\x0funderline_width\x18\x1e \x01(\x02\x12\x17\n\x0fword_strikethru\x18\x1f \x01(\x08\x12\x16\n\x0eword_underline\x18  \x01(\x08\x12\x1a\n\x12\x66ont_features_null\x18! \x01(\x08\x12/\n\rfont_features\x18\" \x03(\x0b\x32\x18.TSWP.FontFeatureArchive\x12\x35\n\x11writing_direction\x18# \x01(\x0e\x32\x1a.TSWP.WritingDirectionType\x12\x1b\n\x13\x65mphasis_marks_null\x18$ \x01(\x08\x12\x16\n\x0e\x65mphasis_marks\x18% \x01(\t\x12$\n\x1c\x63ompatibility_font_name_null\x18& \x01(\x08\x12\x1f\n\x17\x63ompatibility_font_name\x18\' \x01(\t\x12\x1b\n\x13is_named_point_size\x18( \x01(\x08\x12\'\n\x1f\x63\x61pitalization_uses_linguistics\x18) \x01(\x08\x12\x15\n\rtate_chu_yoko\x18* \x01(\x08\x12\x17\n\x0ftsd_stroke_null\x18+ \x01(\x08\x12&\n\ntsd_stroke\x18, \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x15\n\rtsd_fill_null\x18- \x01(\x08\x12\"\n\x08tsd_fill\x18. \x01(\x0b\x32\x10.TSD.FillArchive\x12+\n#tsd_fill_should_fill_text_container\x18/ \x01(\x08\"L\n\x12\x43\x61pitalizationType\x12\x0b\n\x07kNoCaps\x10\x00\x12\x0c\n\x08kAllCaps\x10\x01\x12\x0e\n\nkSmallCaps\x10\x02\x12\x0b\n\x07kTitled\x10\x03\"a\n\rUnderlineType\x12\x10\n\x0ckNoUnderline\x10\x00\x12\x14\n\x10kSingleUnderline\x10\x01\x12\x14\n\x10kDoubleUnderline\x10\x02\x12\x12\n\x0ekWavyUnderline\x10\x03\"R\n\rLigaturesType\x12\x16\n\x12kRequiredLigatures\x10\x00\x12\x16\n\x12kStandardLigatures\x10\x01\x12\x11\n\rkAllLigatures\x10\x02\"h\n\x0eStrikethruType\x12\x11\n\rkNoStrikethru\x10\x00\x12\x15\n\x11kSingleStrikethru\x10\x01\x12\x15\n\x11kDoubleStrikethru\x10\x02\x12\x15\n\x11kTripleStrikethru\x10\x03\"B\n\x0fSuperscriptType\x12\r\n\tkNoScript\x10\x00\x12\x10\n\x0ckSuperscript\x10\x01\x12\x0e\n\nkSubscript\x10\x02\"\x91\x01\n\x15\x43haracterStyleArchive\x12 \n\x05super\x18\x01 \x02(\x0b\x32\x11.TSS.StyleArchive\x12\x16\n\x0eoverride_count\x18\n \x01(\r\x12>\n\x0f\x63har_properties\x18\x0b \x01(\x0b\x32%.TSWP.CharacterStylePropertiesArchive\"\xda\x01\n\nTabArchive\x12\x10\n\x08position\x18\x01 \x01(\x02\x12\x34\n\talignment\x18\x02 \x01(\x0e\x32!.TSWP.TabArchive.TabAlignmentType\x12\x0e\n\x06leader\x18\x03 \x01(\t\"t\n\x10TabAlignmentType\x12\x15\n\x11kTabAlignmentLeft\x10\x00\x12\x17\n\x13kTabAlignmentCenter\x10\x01\x12\x16\n\x12kTabAlignmentRight\x10\x02\x12\x18\n\x14kTabAlignmentDecimal\x10\x03\"-\n\x0bTabsArchive\x12\x1e\n\x04tabs\x18\x01 \x03(\x0b\x32\x10.TSWP.TabArchive\"\x8f\x02\n\x12LineSpacingArchive\x12:\n\x04mode\x18\x01 \x01(\x0e\x32,.TSWP.LineSpacingArchive.LineSpacingModeType\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x02\x12\x14\n\x0c\x62\x61selineRule\x18\x03 \x01(\x02\"\x96\x01\n\x13LineSpacingModeType\x12\x18\n\x14kRelativeLineSpacing\x10\x00\x12\x17\n\x13kMinimumLineSpacing\x10\x01\x12\x15\n\x11kExactLineSpacing\x10\x02\x12\x17\n\x13kMaximumLineSpacing\x10\x03\x12\x1c\n\x18kSpaceBetweenLineSpacing\x10\x04\"\x88\x0c\n\x1fParagraphStylePropertiesArchive\x12J\n\talignment\x18\x01 \x01(\x0e\x32\x37.TSWP.ParagraphStylePropertiesArchive.TextAlignmentType\x12\x18\n\x10\x64\x65\x63imal_tab_null\x18\x02 \x01(\x08\x12\x13\n\x0b\x64\x65\x63imal_tab\x18\x03 \x01(\t\x12\x19\n\x11\x64\x65\x66\x61ult_tab_stops\x18\x04 \x01(\x02\x12\x11\n\tfill_null\x18\x05 \x01(\x08\x12\x18\n\x04\x66ill\x18\x06 \x01(\x0b\x32\n.TSP.Color\x12\x19\n\x11\x66irst_line_indent\x18\x07 \x01(\x02\x12\x11\n\thyphenate\x18\x08 \x01(\x08\x12\x1b\n\x13keep_lines_together\x18\t \x01(\x08\x12\x16\n\x0ekeep_with_next\x18\n \x01(\x08\x12\x13\n\x0bleft_indent\x18\x0b \x01(\x02\x12\x19\n\x11line_spacing_null\x18\x0c \x01(\x08\x12.\n\x0cline_spacing\x18\r \x01(\x0b\x32\x18.TSWP.LineSpacingArchive\x12\x19\n\x11page_break_before\x18\x0e \x01(\x08\x12J\n\x07\x62orders\x18\x0f \x01(\x0e\x32\x39.TSWP.ParagraphStylePropertiesArchive.ParagraphBorderType\x12\x18\n\x10rule_offset_null\x18\x10 \x01(\x08\x12\x1f\n\x0brule_offset\x18\x11 \x01(\x0b\x32\n.TSP.Point\x12\x12\n\nrule_width\x18\x12 \x01(\x02\x12\x14\n\x0cright_indent\x18\x13 \x01(\x02\x12\x13\n\x0bspace_after\x18\x14 \x01(\x02\x12\x14\n\x0cspace_before\x18\x15 \x01(\x02\x12\x11\n\ttabs_null\x18\x18 \x01(\x08\x12\x1f\n\x04tabs\x18\x19 \x01(\x0b\x32\x11.TSWP.TabsArchive\x12\x15\n\rwidow_control\x18\x1a \x01(\x08\x12\x15\n\routline_level\x18\x1b \x01(\r\x12M\n\routline_style\x18\x1c \x01(\x0e\x32\x36.TSWP.ParagraphStylePropertiesArchive.OutlineStyleType\x12\x1f\n\x17\x66ollowing_style_id_null\x18\x1d \x01(\x08\x12\x1a\n\x12\x66ollowing_style_id\x18\x1e \x01(\t\x12\x13\n\x0bstroke_null\x18\x1f \x01(\x08\x12\"\n\x06stroke\x18  \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x13\n\x0bshow_in_toc\x18! \x01(\x08\x12\x19\n\x11toc_style_id_null\x18\" \x01(\x08\x12\x14\n\x0ctoc_style_id\x18# \x01(\t\x12\x35\n\x11writing_direction\x18& \x01(\x0e\x32\x1a.TSWP.WritingDirectionType\x12\x17\n\x0flist_style_null\x18\' \x01(\x08\x12\"\n\nlist_style\x18( \x01(\x0b\x32\x0e.TSP.Reference\x12\x1c\n\x14\x66ollowing_style_null\x18) \x01(\x08\x12\'\n\x0f\x66ollowing_style\x18* \x01(\x0b\x32\x0e.TSP.Reference\x12\x1e\n\x16show_in_bookmarks_list\x18+ \x01(\x08\x12\x1d\n\x15show_in_toc_navigator\x18, \x01(\x08\"^\n\x11TextAlignmentType\x12\r\n\tTATvalue0\x10\x00\x12\r\n\tTATvalue1\x10\x01\x12\r\n\tTATvalue2\x10\x02\x12\r\n\tTATvalue3\x10\x03\x12\r\n\tTATvalue4\x10\x04\"`\n\x13ParagraphBorderType\x12\r\n\tPBTvalue0\x10\x00\x12\r\n\tPBTvalue1\x10\x01\x12\r\n\tPBTvalue2\x10\x02\x12\r\n\tPBTvalue3\x10\x03\x12\r\n\tPBTvalue4\x10\x04\"?\n\x10OutlineStyleType\x12\r\n\tOSTvalue0\x10\x00\x12\r\n\tOSTvalue1\x10\x01\x12\r\n\tOSTvalue2\x10\x02\"\xd1\x01\n\x15ParagraphStyleArchive\x12 \n\x05super\x18\x01 \x02(\x0b\x32\x11.TSS.StyleArchive\x12\x16\n\x0eoverride_count\x18\n \x01(\r\x12>\n\x0f\x63har_properties\x18\x0b \x01(\x0b\x32%.TSWP.CharacterStylePropertiesArchive\x12>\n\x0fpara_properties\x18\x0c \x01(\x0b\x32%.TSWP.ParagraphStylePropertiesArchive\"\xd0\x18\n\x10ListStyleArchive\x12 \n\x05super\x18\x01 \x02(\x0b\x32\x11.TSS.StyleArchive\x12\x16\n\x0eoverride_count\x18\n \x01(\r\x12\x35\n\x0blabel_types\x18\x0b \x03(\x0e\x32 .TSWP.ListStyleArchive.LabelType\x12\x14\n\x0ctext_indents\x18\x0c \x03(\x02\x12\x0f\n\x07indents\x18\r \x03(\x02\x12\x38\n\ngeometries\x18\x0e \x03(\x0b\x32$.TSWP.ListStyleArchive.LabelGeometry\x12\x37\n\x0cnumber_types\x18\x0f \x03(\x0e\x32!.TSWP.ListStyleArchive.NumberType\x12\x0f\n\x07strings\x18\x10 \x03(\t\x12\x31\n\x06images\x18\x11 \x03(\x0b\x32!.TSWP.ListStyleArchive.LabelImage\x12\x13\n\x0bshadow_null\x18\x12 \x01(\x08\x12\"\n\x06shadow\x18\x13 \x01(\x0b\x32\x12.TSD.ShadowArchive\x12\x17\n\x0f\x66ont_color_null\x18\x14 \x01(\x08\x12\x1e\n\nfont_color\x18\x15 \x01(\x0b\x32\n.TSP.Color\x12\x16\n\x0e\x66ont_name_null\x18\x16 \x01(\x08\x12\x11\n\tfont_name\x18\x17 \x01(\t\x12\x35\n\x11writing_direction\x18\x18 \x01(\x0e\x32\x1a.TSWP.WritingDirectionType\x12\x16\n\x0etiered_numbers\x18\x19 \x03(\x08\x1aY\n\rLabelGeometry\x12\x10\n\x05scale\x18\x01 \x01(\x02:\x01\x31\x12\x17\n\x0f\x62\x61seline_offset\x18\x02 \x01(\x02\x12\x1d\n\x0fscale_with_text\x18\x03 \x01(\x08:\x04true\x1ak\n\nLabelImage\x12!\n\x05image\x18\x03 \x01(\x0b\x32\x12.TSP.DataReference\x12\x12\n\nimage_null\x18\x02 \x01(\x08\x12&\n\x0e\x64\x61tabase_image\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\"<\n\tLabelType\x12\t\n\x05kNone\x10\x00\x12\n\n\x06kImage\x10\x01\x12\x0b\n\x07kString\x10\x02\x12\x0b\n\x07kNumber\x10\x03\"\xfa\x11\n\nNumberType\x12\x13\n\x0fkNumericDecimal\x10\x00\x12\x17\n\x13kNumericDoubleParen\x10\x01\x12\x16\n\x12kNumericRightParen\x10\x02\x12\x16\n\x12kRomanUpperDecimal\x10\x03\x12\x1a\n\x16kRomanUpperDoubleParen\x10\x04\x12\x19\n\x15kRomanUpperRightParen\x10\x05\x12\x16\n\x12kRomanLowerDecimal\x10\x06\x12\x1a\n\x16kRomanLowerDoubleParen\x10\x07\x12\x19\n\x15kRomanLowerRightParen\x10\x08\x12\x16\n\x12kAlphaUpperDecimal\x10\t\x12\x1a\n\x16kAlphaUpperDoubleParen\x10\n\x12\x19\n\x15kAlphaUpperRightParen\x10\x0b\x12\x16\n\x12kAlphaLowerDecimal\x10\x0c\x12\x1a\n\x16kAlphaLowerDoubleParen\x10\r\x12\x19\n\x15kAlphaLowerRightParen\x10\x0e\x12#\n\x1fkIdeographicJapaneseDecimalKind\x10\x0f\x12\'\n#kIdeographicJapaneseDoubleParenKind\x10\x10\x12&\n\"kIdeographicJapaneseRightParenKind\x10\x11\x12\x18\n\x14kHiraganaDecimalKind\x10\x12\x12\x1c\n\x18kHiraganaDoubleParenKind\x10\x13\x12\x1b\n\x17kHiraganaRightParenKind\x10\x14\x12\x18\n\x14kKatakanaDecimalKind\x10\x15\x12\x1c\n\x18kKatakanaDoubleParenKind\x10\x16\x12\x1b\n\x17kKatakanaRightParenKind\x10\x17\x12\x1d\n\x19kHiraganaIrohaDecimalKind\x10\x18\x12!\n\x1dkHiraganaIrohaDoubleParenKind\x10\x19\x12 \n\x1ckHiraganaIrohaRightParenKind\x10\x1a\x12\x1d\n\x19kKatakanaIrohaDecimalKind\x10\x1b\x12!\n\x1dkKatakanaIrohaDoubleParenKind\x10\x1c\x12 \n\x1ckKatakanaIrohaRightParenKind\x10\x1d\x12,\n(kIdeographicSimplifiedChineseDecimalKind\x10\x1e\x12\x30\n,kIdeographicSimplifiedChineseDoubleParenKind\x10\x1f\x12/\n+kIdeographicSimplifiedChineseRightParenKind\x10 \x12-\n)kIdeographicTraditionalChineseDecimalKind\x10!\x12\x31\n-kIdeographicTraditionalChineseDoubleParenKind\x10\"\x12\x30\n,kIdeographicTraditionalChineseRightParenKind\x10#\x12)\n%kIdeographicFormalJapaneseDecimalKind\x10$\x12-\n)kIdeographicFormalJapaneseDoubleParenKind\x10%\x12,\n(kIdeographicFormalJapaneseRightParenKind\x10&\x12\x32\n.kIdeographicFormalSimplifiedChineseDecimalKind\x10\'\x12\x36\n2kIdeographicFormalSimplifiedChineseDoubleParenKind\x10(\x12\x35\n1kIdeographicFormalSimplifiedChineseRightParenKind\x10)\x12\x33\n/kIdeographicFormalTraditionalChineseDecimalKind\x10*\x12\x37\n3kIdeographicFormalTraditionalChineseDoubleParenKind\x10+\x12\x36\n2kIdeographicFormalTraditionalChineseRightParenKind\x10,\x12\x1e\n\x1akKoreanAlphabetDecimalKind\x10-\x12\"\n\x1ekKoreanAlphabetDoubleParenKind\x10.\x12!\n\x1dkKoreanAlphabetRightParenKind\x10/\x12\x16\n\x12kCircledNumberKind\x10\x30\x12\x1e\n\x1akArabianNumericDecimalKind\x10\x31\x12\"\n\x1ekArabianNumericDoubleParenKind\x10\x32\x12!\n\x1dkArabianNumericRightParenKind\x10\x33\x12\x1c\n\x18kArabianAlphaDecimalKind\x10\x34\x12 \n\x1ckArabianAlphaDoubleParenKind\x10\x35\x12\x1f\n\x1bkArabianAlphaRightParenKind\x10\x36\x12\x1c\n\x18kArabianAbjadDecimalKind\x10\x37\x12 \n\x1ckArabianAbjadDoubleParenKind\x10\x38\x12\x1f\n\x1bkArabianAbjadRightParenKind\x10\x39\x12\x1b\n\x17kHebrewAlphaDecimalKind\x10:\x12\x1f\n\x1bkHebrewAlphaDoubleParenKind\x10;\x12\x1e\n\x1akHebrewAlphaRightParenKind\x10<\x12\x1f\n\x1bkHebrewBiblicalStandardKind\x10=\x12\x1e\n\x1akHebrewBiblicalDecimalKind\x10>\x12\"\n\x1ekHebrewBiblicalDoubleParenKind\x10?\x12!\n\x1dkHebrewBiblicalRightParenKind\x10@\"\x80\x01\n\x16TextStylePresetArchive\x12\x19\n\x11preset_identifier\x18\x01 \x01(\t\x12\'\n\x0fparagraph_style\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12\"\n\nlist_style\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\"\xf5\x02\n\x0e\x43olumnsArchive\x12?\n\requal_columns\x18\x01 \x01(\x0b\x32(.TSWP.ColumnsArchive.EqualColumnsArchive\x12\x46\n\x11non_equal_columns\x18\x02 \x01(\x0b\x32+.TSWP.ColumnsArchive.NonEqualColumnsArchive\x1a\x31\n\x13\x45qualColumnsArchive\x12\r\n\x05\x63ount\x18\x01 \x01(\r\x12\x0b\n\x03gap\x18\x02 \x01(\x02\x1a\xa6\x01\n\x16NonEqualColumnsArchive\x12\r\n\x05\x66irst\x18\x01 \x02(\x02\x12N\n\tfollowing\x18\x02 \x03(\x0b\x32;.TSWP.ColumnsArchive.NonEqualColumnsArchive.GapWidthArchive\x1a-\n\x0fGapWidthArchive\x12\x0b\n\x03gap\x18\x01 \x02(\x02\x12\r\n\x05width\x18\x02 \x02(\x02\"J\n\x0ePaddingArchive\x12\x0c\n\x04left\x18\x01 \x01(\x02\x12\x0b\n\x03top\x18\x02 \x01(\x02\x12\r\n\x05right\x18\x03 \x01(\x02\x12\x0e\n\x06\x62ottom\x18\x04 \x01(\x02\"\xb5\x04\n\x1c\x43olumnStylePropertiesArchive\x12\x12\n\ncontinuous\x18\x01 \x01(\x08\x12\x15\n\rshrink_to_fit\x18\x02 \x01(\x08\x12\x15\n\rvertical_text\x18\x03 \x01(\x08\x12\x1c\n\x14min_horizontal_inset\x18\x04 \x01(\x02\x12T\n\x12vertical_alignment\x18\x05 \x01(\x0e\x32\x38.TSWP.ColumnStylePropertiesArchive.VerticalAlignmentType\x12\x14\n\x0c\x63olumns_null\x18\x06 \x01(\x08\x12%\n\x07\x63olumns\x18\x07 \x01(\x0b\x32\x14.TSWP.ColumnsArchive\x12\x14\n\x0cmargins_null\x18\x08 \x01(\x08\x12%\n\x07margins\x18\t \x01(\x0b\x32\x14.TSWP.PaddingArchive\x12\x14\n\x0cpadding_null\x18\n \x01(\x08\x12%\n\x07padding\x18\x0b \x01(\x0b\x32\x14.TSWP.PaddingArchive\x12\x35\n\x11writing_direction\x18\x0c \x01(\x0e\x32\x1a.TSWP.WritingDirectionType\"q\n\x15VerticalAlignmentType\x12\x12\n\x0ekFrameAlignTop\x10\x00\x12\x15\n\x11kFrameAlignMiddle\x10\x01\x12\x15\n\x11kFrameAlignBottom\x10\x02\x12\x16\n\x12kFrameAlignJustify\x10\x03\"\x8d\x01\n\x12\x43olumnStyleArchive\x12 \n\x05super\x18\x01 \x02(\x0b\x32\x11.TSS.StyleArchive\x12\x16\n\x0eoverride_count\x18\n \x01(\r\x12=\n\x11\x63olumn_properties\x18\x0b \x01(\x0b\x32\".TSWP.ColumnStylePropertiesArchive\"\x91\x04\n\x1bShapeStylePropertiesArchive\x12\x15\n\rshrink_to_fit\x18\x01 \x01(\x08\x12S\n\x12vertical_alignment\x18\x02 \x01(\x0e\x32\x37.TSWP.ShapeStylePropertiesArchive.VerticalAlignmentType\x12\x14\n\x0c\x63olumns_null\x18\x03 \x01(\x08\x12%\n\x07\x63olumns\x18\x04 \x01(\x0b\x32\x14.TSWP.ColumnsArchive\x12\x14\n\x0cpadding_null\x18\x05 \x01(\x08\x12%\n\x07padding\x18\x06 \x01(\x0b\x32\x14.TSWP.PaddingArchive\x12!\n\x19\x64\x65\x66\x61ult_text_preset_index\x18\x07 \x01(\r\x12\x15\n\rvertical_text\x18\x08 \x01(\x08\x12\x1c\n\x14paragraph_style_null\x18\t \x01(\x08\x12\'\n\x0fparagraph_style\x18\n \x01(\x0b\x32\x0e.TSP.Reference\x12\x18\n\x10vertical_text_40\x18\x0b \x01(\x08\"q\n\x15VerticalAlignmentType\x12\x12\n\x0ekFrameAlignTop\x10\x00\x12\x15\n\x11kFrameAlignMiddle\x10\x01\x12\x15\n\x11kFrameAlignBottom\x10\x02\x12\x16\n\x12kFrameAlignJustify\x10\x03\"\x8f\x01\n\x11ShapeStyleArchive\x12%\n\x05super\x18\x01 \x02(\x0b\x32\x16.TSD.ShapeStyleArchive\x12\x16\n\x0eoverride_count\x18\n \x01(\r\x12;\n\x10shape_properties\x18\x0b \x01(\x0b\x32!.TSWP.ShapeStylePropertiesArchive\"\xd3\x03\n\x13ThemePresetsArchive\x12*\n\x12list_style_presets\x18\x01 \x03(\x0b\x32\x0e.TSP.Reference\x12*\n\x12text_style_presets\x18\x02 \x03(\x0b\x32\x0e.TSP.Reference\x12\x33\n\x1bimported_text_style_presets\x18\x03 \x03(\x0b\x32\x0e.TSP.Reference\x12/\n\x17toc_entry_style_presets\x18\x04 \x03(\x0b\x32\x0e.TSP.Reference\x12,\n\x14toc_settings_presets\x18\x05 \x03(\x0b\x32\x0e.TSP.Reference\x12/\n\x17\x63haracter_style_presets\x18\x06 \x03(\x0b\x32\x0e.TSP.Reference\x12/\n\x17paragraph_style_presets\x18\x07 \x03(\x0b\x32\x0e.TSP.Reference\x12-\n\x15\x64ropcap_style_presets\x18\x08 \x03(\x0b\x32\x0e.TSP.Reference2?\n\textension\x12\x11.TSS.ThemeArchive\x18n \x01(\x0b\x32\x19.TSWP.ThemePresetsArchive\"T\n\x1cTextPresetDisplayItemArchive\x12\x1e\n\x06preset\x18\x01 \x02(\x0b\x32\x0e.TSP.Reference\x12\x14\n\x0c\x64isplay_name\x18\x02 \x02(\t\"\x85\x01\n\x1eTOCEntryStylePropertiesArchive\x12\x1e\n\x16page_number_style_null\x18\x01 \x01(\x08\x12)\n\x11page_number_style\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12\x18\n\x10show_page_number\x18\x03 \x01(\x08\"\x80\x01\n\x14TOCEntryStyleArchive\x12*\n\x05super\x18\x01 \x02(\x0b\x32\x1b.TSWP.ParagraphStyleArchive\x12<\n\x0etoc_properties\x18\x02 \x01(\x0b\x32$.TSWP.TOCEntryStylePropertiesArchive\"\xe8\x01\n\x12TOCSettingsArchive\x12\x10\n\x08toc_name\x18\x01 \x01(\t\x12\x11\n\ttoc_scope\x18\x02 \x01(\r\x12\x36\n\x07\x65ntries\x18\x03 \x03(\x0b\x32%.TSWP.TOCSettingsArchive.TOCEntryData\x1au\n\x0cTOCEntryData\x12\'\n\x0fparagraph_style\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\x12\'\n\x0ftoc_entry_style\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12\x13\n\x0bshow_in_toc\x18\x03 \x01(\x08\"\x9b\x02\n\x17TOCEntryInstanceArchive\x12\x17\n\x0fparagraph_index\x18\x01 \x02(\r\x12\x13\n\x0bpage_number\x18\x02 \x02(\r\x12\x15\n\rnumber_format\x18\x03 \x02(\r\x12\x0f\n\x07heading\x18\x04 \x02(\t\x12%\n\rindexed_style\x18\x05 \x02(\x0b\x32\x0e.TSP.Reference\x12*\n\x12indexed_list_style\x18\x06 \x01(\x0b\x32\x0e.TSP.Reference\x12\x1a\n\x12indexed_list_start\x18\x07 \x01(\r\x12\x1f\n\x17indexed_paragraph_level\x18\x08 \x01(\r\x12\x1a\n\x12number_format_name\x18\t \x01(\t\"\xc9\x17\n\x0fUndoTransaction\x12\x37\n\x07\x65ntries\x18\x01 \x03(\x0b\x32&.TSWP.UndoTransaction.UnionTransaction\x12?\n\rgroup_entries\x18\x02 \x03(\x0b\x32(.TSWP.UndoTransaction.StorageActionGroup\x12\r\n\x05\x66lags\x18\x03 \x01(\r\x12\x0f\n\x07version\x18\x04 \x01(\r\x1a\x44\n\x12GenericTransaction\x12\x0e\n\x06value1\x18\x01 \x02(\r\x12\x0e\n\x06value2\x18\x02 \x02(\r\x12\x0e\n\x06value3\x18\x03 \x02(\r\x1a[\n\x0fTextTransaction\x12\x17\n\x0finsert_location\x18\x01 \x02(\r\x12\x15\n\rinsert_length\x18\x02 \x02(\r\x12\x18\n\x10string_to_delete\x18\x03 \x01(\t\x1aY\n\x14\x43harIndexTransaction\x12\x12\n\nchar_index\x18\x01 \x02(\r\x12\r\n\x05\x63ount\x18\x02 \x02(\r\x12\x1e\n\x06object\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x1aJ\n\x1bReplaceCharIndexTransaction\x12\x17\n\x0f\x61ttribute_index\x18\x01 \x02(\r\x12\x12\n\nchar_index\x18\x02 \x02(\r\x1ax\n\x19\x41ttributeIndexTransaction\x12\x17\n\x0f\x61ttribute_index\x18\x01 \x02(\r\x12\x12\n\nchar_index\x18\x02 \x02(\r\x12\x1e\n\x06object\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12\x0e\n\x06string\x18\x04 \x01(\t\x1a~\n\x1aInsertAttributeTransaction\x12\x17\n\x0f\x61ttribute_index\x18\x01 \x02(\r\x12\x17\n\x0f\x61ttribute_count\x18\x02 \x02(\r\x12\x1e\n\x06object\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12\x0e\n\x06string\x18\x04 \x01(\t\x1aH\n\x14InsertNilTransaction\x12\x17\n\x0f\x61ttribute_index\x18\x01 \x02(\r\x12\x17\n\x0f\x61ttribute_count\x18\x02 \x02(\r\x1aW\n\x14\x43harDeltaTransaction\x12\x12\n\nchar_index\x18\x01 \x02(\r\x12\x17\n\x0f\x61ttribute_index\x18\x02 \x02(\r\x12\x12\n\nchar_delta\x18\x03 \x02(\x11\x1a\x66\n\x18ParagraphDataTransaction\x12\x17\n\x0f\x61ttribute_index\x18\x01 \x02(\r\x12\r\n\x05\x66irst\x18\x02 \x02(\r\x12\x0e\n\x06second\x18\x03 \x02(\r\x12\x12\n\nchar_index\x18\x04 \x02(\r\x1a\x46\n\x15ObjectDOLCTransaction\x12\r\n\x05\x66lags\x18\x01 \x02(\r\x12\x1e\n\x06object\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x1a\x45\n\x11\x43TDateTransaction\x12\x17\n\x0f\x61ttribute_index\x18\x01 \x02(\r\x12\x17\n\x04\x64\x61te\x18\x02 \x01(\x0b\x32\t.TSP.Date\x1a\xa8\x06\n\x10UnionTransaction\x12,\n\x04kind\x18\x01 \x02(\x0e\x32\x1e.TSWP.UndoTransaction.UndoKind\x12\r\n\x05table\x18\x02 \x01(\r\x12\x39\n\x07generic\x18\x05 \x01(\x0b\x32(.TSWP.UndoTransaction.GenericTransaction\x12\x33\n\x04text\x18\x06 \x01(\x0b\x32%.TSWP.UndoTransaction.TextTransaction\x12>\n\nchar_index\x18\x07 \x01(\x0b\x32*.TSWP.UndoTransaction.CharIndexTransaction\x12M\n\x12replace_char_index\x18\x08 \x01(\x0b\x32\x31.TSWP.UndoTransaction.ReplaceCharIndexTransaction\x12H\n\x0f\x61ttribute_index\x18\t \x01(\x0b\x32/.TSWP.UndoTransaction.AttributeIndexTransaction\x12>\n\ninsert_nil\x18\n \x01(\x0b\x32*.TSWP.UndoTransaction.InsertNilTransaction\x12J\n\x10insert_attribute\x18\x0b \x01(\x0b\x32\x30.TSWP.UndoTransaction.InsertAttributeTransaction\x12>\n\nchar_delta\x18\x0c \x01(\x0b\x32*.TSWP.UndoTransaction.CharDeltaTransaction\x12\x46\n\x0eparagraph_data\x18\r \x01(\x0b\x32..TSWP.UndoTransaction.ParagraphDataTransaction\x12@\n\x0bobject_dolc\x18\x0e \x01(\x0b\x32+.TSWP.UndoTransaction.ObjectDOLCTransaction\x12\x38\n\x07\x63t_date\x18\x0f \x01(\x0b\x32\'.TSWP.UndoTransaction.CTDateTransaction\x1a\xe7\x02\n\rStorageAction\x12.\n\x04kind\x18\x01 \x02(\x0e\x32 .TSWP.UndoTransaction.ActionKind\x12\r\n\x05\x66lags\x18\x02 \x01(\r\x12\r\n\x05table\x18\x03 \x01(\r\x12\x19\n\x05range\x18\x04 \x01(\x0b\x32\n.TSP.Range\x12\x0e\n\x06string\x18\x05 \x01(\t\x12\x1e\n\x06object\x18\x06 \x01(\x0b\x32\x0e.TSP.Reference\x12\x17\n\x04\x64\x61te\x18\x07 \x01(\x0b\x32\t.TSP.Date\x12\x17\n\x0fparagraph_level\x18\x08 \x01(\r\x12\x17\n\x0fparagraph_flags\x18\t \x01(\r\x12\x17\n\x0fparagraph_value\x18\n \x01(\r\x12\x17\n\x0fplacement_index\x18\x0b \x01(\x05\x12\x1b\n\x13placement_uuid_path\x18\x0c \x01(\t\x12#\n\x0bundo_object\x18\r \x01(\x0b\x32\x0e.TSP.Reference\x1a\x92\x02\n\x12StorageActionGroup\x12\x33\n\x04kind\x18\x01 \x02(\x0e\x32%.TSWP.UndoTransaction.ActionGroupKind\x12<\n\x0f\x66orward_actions\x18\x03 \x03(\x0b\x32#.TSWP.UndoTransaction.StorageAction\x12\x44\n\x17inverse_forward_actions\x18\x04 \x03(\x0b\x32#.TSWP.UndoTransaction.StorageAction\x12\x43\n\x16inverse_detail_actions\x18\x06 \x03(\x0b\x32#.TSWP.UndoTransaction.StorageAction\"\xe6\x01\n\x08UndoKind\x12\x10\n\x0cREPLACE_TEXT\x10\x01\x12\x14\n\x10INSERT_ATTRIBUTE\x10\x02\x12\x14\n\x10\x44\x45LETE_ATTRIBUTE\x10\x03\x12\x17\n\x13\x41\x44JUST_CHAR_INDEXES\x10\x04\x12\x1d\n\x19\x43OMPR_ADJUST_CHAR_INDEXES\x10\x05\x12\x16\n\x12REPLACE_CHAR_INDEX\x10\x06\x12\x12\n\x0eREPLACE_OBJECT\x10\x07\x12\x1a\n\x16REPLACE_PARAGRAPH_DATA\x10\x08\x12\x0f\n\x0bOBJECT_DOLC\x10\t\x12\x0b\n\x07\x43T_DATE\x10\n\"I\n\nActionKind\x12\x14\n\x10\x41\x43TION_UNDEFINED\x10\x00\x12\x0f\n\x0b\x41\x43TION_TEXT\x10\x01\x12\x14\n\x10\x41\x43TION_ATTRIBUTE\x10\x02\"`\n\x0f\x41\x63tionGroupKind\x12\x1a\n\x16\x41\x43TION_GROUP_UNDEFINED\x10\x00\x12\x15\n\x11\x41\x43TION_GROUP_TEXT\x10\x01\x12\x1a\n\x16\x41\x43TION_GROUP_ATTRIBUTE\x10\x02\"P\n\x1dUndoTransactionWrapperArchive\x12/\n\x10undo_transaction\x18\x01 \x02(\x0b\x32\x15.TSWP.UndoTransaction\"\xc3\x01\n\x10ShapeInfoArchive\x12 \n\x05super\x18\x01 \x02(\x0b\x32\x11.TSD.ShapeArchive\x12.\n\x12\x64\x65precated_storage\x18\x02 \x01(\x0b\x32\x0e.TSP.ReferenceB\x02\x18\x01\x12!\n\ttext_flow\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12%\n\rowned_storage\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\x12\x13\n\x0bis_text_box\x18\x06 \x01(\x08\"d\n\x12\x43ommentInfoArchive\x12%\n\x05super\x18\x01 \x02(\x0b\x32\x16.TSWP.ShapeInfoArchive\x12\'\n\x0f\x63omment_storage\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\"\xdb\x01\n\x0eTOCInfoArchive\x12%\n\x05super\x18\x01 \x02(\x0b\x32\x16.TSWP.ShapeInfoArchive\x12$\n\x0ctoc_settings\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12&\n\x0etoc_entry_data\x18\x03 \x03(\x0b\x32\x0e.TSP.Reference\x12&\n\x12page_number_ranges\x18\x04 \x03(\x0b\x32\n.TSP.Range\x12,\n$sync_toc_settings_with_toc_navigator\x18\x05 \x01(\x08\"5\n\x14TOCLayoutHintArchive\x12\x1d\n\tcharRange\x18\x01 \x02(\x0b\x32\n.TSP.Range\"\xfd\x01\n\x13\x45quationInfoArchive2.\n\x13\x65quation_source_old\x12\x11.TSD.ImageArchive\x18\x64 \x01(\t2Z\n\x18\x65quation_text_properties\x12\x11.TSD.ImageArchive\x18\x65 \x01(\x0b\x32%.TSWP.CharacterStylePropertiesArchive2)\n\x0e\x65quation_depth\x12\x11.TSD.ImageArchive\x18\x66 \x01(\x02\x32/\n\x14\x65quation_source_text\x12\x11.TSD.ImageArchive\x18g \x01(\t\"\xb0\x01\n\x18TextualAttachmentArchive\x12\x19\n\x11string_equivalent\x18\x01 \x01(\t\x12\x31\n\x04kind\x18\x02 \x01(\x0e\x32#.TSWP.TextualAttachmentArchive.Kind\"F\n\x04Kind\x12\x13\n\x0fkKindPageNumber\x10\x00\x12\x12\n\x0ekKindPageCount\x10\x01\x12\x15\n\x11kKindFootnoteMark\x10\x02\"\x7f\n\"TSWPTOCPageNumberAttachmentArchive\x12-\n\x05super\x18\x01 \x01(\x0b\x32\x1e.TSWP.TextualAttachmentArchive\x12\x13\n\x0bpage_number\x18\x02 \x01(\t\x12\x15\n\rbookmark_name\x18\x03 \x01(\t\"\x17\n\x15UIGraphicalAttachment\"\x8f\x01\n\x19\x44rawableAttachmentArchive\x12 \n\x08\x64rawable\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\x12\x15\n\rh_offset_type\x18\x02 \x01(\r\x12\x10\n\x08h_offset\x18\x03 \x01(\x02\x12\x15\n\rv_offset_type\x18\x04 \x01(\r\x12\x10\n\x08v_offset\x18\x05 \x01(\x02\"F\n\x14TOCAttachmentArchive\x12.\n\x05super\x18\x01 \x02(\x0b\x32\x1f.TSWP.DrawableAttachmentArchive\"\x9a\x01\n\"FootnoteReferenceAttachmentArchive\x12-\n\x05super\x18\x01 \x01(\x0b\x32\x1e.TSWP.TextualAttachmentArchive\x12)\n\x11\x63ontained_storage\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12\x1a\n\x12\x63ustom_mark_string\x18\x03 \x01(\t\"\x91\x01\n\x17NumberAttachmentArchive\x12-\n\x05super\x18\x01 \x01(\x0b\x32\x1e.TSWP.TextualAttachmentArchive\x12\x15\n\rnumber_format\x18\x02 \x01(\r\x12\x14\n\x0cstring_value\x18\x03 \x01(\t\x12\x1a\n\x12number_format_name\x18\x04 \x01(\t\"7\n\x11SmartFieldArchive\x12\"\n\x1atext_attribute_uuid_string\x18\x01 \x01(\t\"P\n\x15HyperlinkFieldArchive\x12&\n\x05super\x18\x01 \x01(\x0b\x32\x17.TSWP.SmartFieldArchive\x12\x0f\n\x07url_ref\x18\x02 \x01(\t\"o\n\x1cPlaceholderSmartFieldArchive\x12&\n\x05super\x18\x01 \x01(\x0b\x32\x17.TSWP.SmartFieldArchive\x12\x13\n\x0blocalizable\x18\x02 \x01(\x08\x12\x12\n\nscript_tag\x18\x03 \x01(\t\"\x80\x01\n UnsupportedHyperlinkFieldArchive\x12\x31\n\x05super\x18\x01 \x01(\x0b\x32\".TSWP.PlaceholderSmartFieldArchive\x12\x0f\n\x07url_ref\x18\x02 \x01(\t\x12\x18\n\x10url_original_ref\x18\x03 \x01(\t\"\xbd\x01\n\x1d\x42ibliographySmartFieldArchive\x12&\n\x05super\x18\x03 \x01(\x0b\x32\x17.TSWP.SmartFieldArchive\x12(\n\x10\x63itation_records\x18\x02 \x03(\x0b\x32\x0e.TSP.Reference\x12\x13\n\x0blocalizable\x18\x04 \x01(\x08\x12\x35\n\told_super\x18\x01 \x01(\x0b\x32\".TSWP.PlaceholderSmartFieldArchive\"\xd1\x01\n\x15\x43itationRecordArchive\x12\x13\n\x0b\x65ndnote_xml\x18\x01 \x01(\t\x12\x19\n\x11hide_author_names\x18\x02 \x01(\x08\x12\x11\n\thide_year\x18\x03 \x01(\x08\x12\x12\n\npage_range\x18\x04 \x01(\t\x12\x0e\n\x06prefix\x18\x05 \x01(\t\x12\x0e\n\x06suffix\x18\x06 \x01(\t\x12\x16\n\x0e\x61uthors_string\x18\x07 \x01(\t\x12\r\n\x05title\x18\x08 \x01(\t\x12\x0c\n\x04year\x18\t \x01(\t\x12\x0c\n\x04type\x18\n \x01(\t\"\xb9\x01\n\x19\x43itationSmartFieldArchive\x12&\n\x05super\x18\x03 \x01(\x0b\x32\x17.TSWP.SmartFieldArchive\x12(\n\x10\x63itation_records\x18\x02 \x03(\x0b\x32\x0e.TSP.Reference\x12\x13\n\x0blocalizable\x18\x04 \x01(\x08\x12\x35\n\told_super\x18\x01 \x01(\x0b\x32\".TSWP.PlaceholderSmartFieldArchive\"\xaf\x05\n\x19\x44\x61teTimeSmartFieldArchive\x12&\n\x05super\x18\x01 \x01(\x0b\x32\x17.TSWP.SmartFieldArchive\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\t\x12\x19\n\x11locale_identifier\x18\x03 \x01(\t\x12J\n\ndate_style\x18\x04 \x01(\x0e\x32\x36.TSWP.DateTimeSmartFieldArchive.DateTimeFormatterStyle\x12J\n\ntime_style\x18\x05 \x01(\x0e\x32\x36.TSWP.DateTimeSmartFieldArchive.DateTimeFormatterStyle\x12G\n\x0bupdate_plan\x18\x06 \x01(\x0e\x32\x32.TSWP.DateTimeSmartFieldArchive.DateTimeUpdatePlan\x12\x14\n\x0cneeds_update\x18\x07 \x01(\x08\x12\x17\n\x04\x64\x61te\x18\x08 \x01(\x0b\x32\t.TSP.Date\"l\n\x12\x44\x61teTimeUpdatePlan\x12\x1c\n\x18kDateTimeUpdatePlanNever\x10\x00\x12\x1b\n\x17kDateTimeUpdatePlanAuto\x10\x01\x12\x1b\n\x17kDateTimeUpdatePlanOnce\x10\x02\"\xc0\x01\n\x16\x44\x61teTimeFormatterStyle\x12\x1f\n\x1bkDateTimeFormatterStyleNone\x10\x00\x12 \n\x1ckDateTimeFormatterStyleShort\x10\x01\x12!\n\x1dkDateTimeFormatterStyleMedium\x10\x02\x12\x1f\n\x1bkDateTimeFormatterStyleLong\x10\x03\x12\x1f\n\x1bkDateTimeFormatterStyleFull\x10\x04\"l\n\x14\x42ookmarkFieldArchive\x12&\n\x05super\x18\x01 \x01(\x0b\x32\x17.TSWP.SmartFieldArchive\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06ranged\x18\x03 \x01(\r\x12\x0e\n\x06hidden\x18\x04 \x01(\r\"e\n\x19\x46ilenameSmartFieldArchive\x12\x31\n\x05super\x18\x01 \x01(\x0b\x32\".TSWP.PlaceholderSmartFieldArchive\x12\x15\n\rdisplay_flags\x18\x02 \x01(\r\"\xd4\x02\n\x16MergeSmartFieldArchive\x12\x31\n\x05super\x18\x01 \x01(\x0b\x32\".TSWP.PlaceholderSmartFieldArchive\x12\x10\n\x08property\x18\x02 \x01(\t\x12\r\n\x05label\x18\x03 \x01(\t\x12\x0b\n\x03key\x18\x04 \x01(\t\x12<\n\x08\x63\x61tegory\x18\x05 \x01(\x0e\x32*.TSWP.MergeSmartFieldArchive.MergeCategory\x12%\n\x1drequires_following_whitespace\x18\x06 \x01(\x08\x12\x12\n\nwhitespace\x18\x07 \x01(\t\x12\x0c\n\x04guid\x18\x08 \x01(\t\x12\x13\n\x0btable_field\x18\t \x01(\t\"=\n\rMergeCategory\x12\x14\n\x10kMergeCategoryTo\x10\x00\x12\x16\n\x12kMergeCategoryFrom\x10\x01\"\xe7\x01\n\x14TOCSmartFieldArchive\x12\x31\n\x05super\x18\x01 \x01(\x0b\x32\".TSWP.PlaceholderSmartFieldArchive\x12\x38\n\x0btoc_entries\x18\x02 \x03(\x0b\x32#.TSWP.TOCSmartFieldArchive.TOCEntry\x1a\x62\n\x08TOCEntry\x12\x15\n\rbookmark_name\x18\x01 \x01(\t\x12$\n\x0ctarget_style\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12\x19\n\x05range\x18\x03 \x01(\x0b\x32\n.TSP.Range\"M\n\x10RubyFieldArchive\x12&\n\x05super\x18\x01 \x01(\x0b\x32\x17.TSWP.SmartFieldArchive\x12\x11\n\truby_text\x18\x02 \x01(\t\"A\n\x17TateChuYokoFieldArchive\x12&\n\x05super\x18\x01 \x01(\x0b\x32\x17.TSWP.SmartFieldArchive\"\xdc\x01\n\rChangeArchive\x12,\n\x04kind\x18\x01 \x01(\x0e\x32\x1e.TSWP.ChangeArchive.ChangeKind\x12\x1f\n\x07session\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12\x17\n\x04\x64\x61te\x18\x03 \x01(\x0b\x32\t.TSP.Date\x12\"\n\x1atext_attribute_uuid_string\x18\x04 \x01(\t\"?\n\nChangeKind\x12\x18\n\x14kChangeKindInsertion\x10\x01\x12\x17\n\x13kChangeKindDeletion\x10\x02\"d\n\x14\x43hangeSessionArchive\x12\x13\n\x0bsession_uid\x18\x01 \x01(\r\x12\x1e\n\x06\x61uthor\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12\x17\n\x04\x64\x61te\x18\x03 \x01(\x0b\x32\t.TSP.Date\"C\n\x19SectionPlaceholderArchive\x12&\n\x0eparent_storage\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\"\x1b\n\x19HyperlinkSelectionArchive\"}\n\x0f\x46lowInfoArchive\x12$\n\x0ctext_storage\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\x12!\n\ttextboxes\x18\x02 \x03(\x0b\x32\x0e.TSP.Reference\x12!\n\x19user_interface_identifier\x18\x03 \x01(\r\"f\n\x18\x46lowInfoContainerArchive\x12\"\n\nflow_infos\x18\x01 \x03(\x0b\x32\x0e.TSP.Reference\x12&\n\x1enext_user_interface_identifier\x18\x02 \x01(\r\"\x90\x05\n\x0e\x44ropCapArchive\x12.\n\x04type\x18\x01 \x01(\x0e\x32 .TSWP.DropCapArchive.DropCapType\x12\x1a\n\x0fnumber_of_lines\x18\x02 \x01(\r:\x01\x33\x12\x1e\n\x16number_of_raised_lines\x18\x03 \x01(\r\x12\x1a\n\x12\x64\x65precated_outdent\x18\x04 \x01(\x02\x12\x0f\n\x07outdent\x18\x0b \x01(\x01\x12\x1a\n\x12\x64\x65precated_padding\x18\x05 \x01(\x02\x12\x0f\n\x07padding\x18\x0c \x01(\x01\x12\x37\n\twrap_type\x18\x06 \x01(\x0e\x32$.TSWP.DropCapArchive.DropCapWrapType\x12\x15\n\rshape_enabled\x18\x07 \x01(\x08\x12 \n\x18\x64\x65precated_corner_radius\x18\x08 \x01(\x02\x12\x15\n\rcorner_radius\x18\r \x01(\x01\x12\"\n\x1a\x64\x65precated_character_scale\x18\t \x01(\x02\x12\x1a\n\x0f\x63haracter_scale\x18\x0e \x01(\x01:\x01\x31\x12\x1f\n\x14number_of_characters\x18\n \x01(\r:\x01\x31\"Z\n\x0b\x44ropCapType\x12\x17\n\x13TSWPDropCapTypeText\x10\x00\x12\x18\n\x14TSWPDropCapTypeShape\x10\x01\x12\x18\n\x14TSWPDropCapTypeImage\x10\x02\"r\n\x0f\x44ropCapWrapType\x12\"\n\x1eTSWPDropCapWrapTypeRectangular\x10\x00\x12\x1e\n\x1aTSWPDropCapWrapTypeContour\x10\x01\x12\x1b\n\x17TSWPDropCapWrapTypeNone\x10\x02\"\xcb\x01\n\x1d\x44ropCapStylePropertiesArchive\x12&\n\x08\x64rop_cap\x18\x01 \x01(\x0b\x32\x14.TSWP.DropCapArchive\x12\x31\n\x15\x64rop_cap_shape_stroke\x18\x03 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12 \n\x18\x64rop_cap_shape_fill_null\x18\x04 \x01(\x08\x12-\n\x13\x64rop_cap_shape_fill\x18\x05 \x01(\x0b\x32\x10.TSD.FillArchive\"\xd1\x01\n\x13\x44ropCapStyleArchive\x12 \n\x05super\x18\x01 \x02(\x0b\x32\x11.TSS.StyleArchive\x12\x16\n\x0eoverride_count\x18\n \x01(\r\x12>\n\x0f\x63har_properties\x18\x0b \x01(\x0b\x32%.TSWP.CharacterStylePropertiesArchive\x12@\n\x13\x64rop_cap_properties\x18\x0c \x01(\x0b\x32#.TSWP.DropCapStylePropertiesArchive*\xf4\x01\n\rSelectionType\x12\x18\n\x14SelectionType_Normal\x10\x00\x12\x1b\n\x17SelectionType_ListLabel\x10\x01\x12\x1b\n\x17SelectionType_ListTopic\x10\x02\x12\x19\n\x15SelectionType_Replace\x10\x03\x12 \n\x1cSelectionType_CopyPasteStyle\x10\x04\x12\x1a\n\x16SelectionType_Replace2\x10\x05\x12\x1c\n\x18SelectionType_SmartField\x10\x06\x12\x18\n\x14SelectionType_Visual\x10\x07*\x86\x01\n\x16StyleInsertionBehavior\x12!\n\x1dStyleInsertionBehavior_NoGrow\x10\x00\x12#\n\x1fStyleInsertionBehavior_GrowLeft\x10\x01\x12$\n StyleInsertionBehavior_GrowRight\x10\x02*?\n\rCaretAffinity\x12\x17\n\x13\x43\x61retAffinity_Start\x10\x00\x12\x15\n\x11\x43\x61retAffinity_End\x10\x01*\x81\x01\n\x14WritingDirectionType\x12%\n\x18kWritingDirectionNatural\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12 \n\x1ckWritingDirectionLeftToRight\x10\x00\x12 \n\x1ckWritingDirectionRightToLeft\x10\x01:G\n\x07padding\x12 .TSS.CommandPropertyEntryArchive\x18\x64 \x01(\x0b\x32\x14.TSWP.PaddingArchive')
  ,
  dependencies=[TSPMessages__pb2.DESCRIPTOR,TSSArchives__pb2.DESCRIPTOR,TSDArchives__pb2.DESCRIPTOR,TSKArchives__pb2.DESCRIPTOR,])

_SELECTIONTYPE = _descriptor.EnumDescriptor(
  name='SelectionType',
  full_name='TSWP.SelectionType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SelectionType_Normal', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SelectionType_ListLabel', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SelectionType_ListTopic', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SelectionType_Replace', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SelectionType_CopyPasteStyle', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SelectionType_Replace2', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SelectionType_SmartField', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SelectionType_Visual', index=7, number=7,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=22900,
  serialized_end=23144,
)
_sym_db.RegisterEnumDescriptor(_SELECTIONTYPE)

SelectionType = enum_type_wrapper.EnumTypeWrapper(_SELECTIONTYPE)
_STYLEINSERTIONBEHAVIOR = _descriptor.EnumDescriptor(
  name='StyleInsertionBehavior',
  full_name='TSWP.StyleInsertionBehavior',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='StyleInsertionBehavior_NoGrow', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='StyleInsertionBehavior_GrowLeft', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='StyleInsertionBehavior_GrowRight', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=23147,
  serialized_end=23281,
)
_sym_db.RegisterEnumDescriptor(_STYLEINSERTIONBEHAVIOR)

StyleInsertionBehavior = enum_type_wrapper.EnumTypeWrapper(_STYLEINSERTIONBEHAVIOR)
_CARETAFFINITY = _descriptor.EnumDescriptor(
  name='CaretAffinity',
  full_name='TSWP.CaretAffinity',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CaretAffinity_Start', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CaretAffinity_End', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=23283,
  serialized_end=23346,
)
_sym_db.RegisterEnumDescriptor(_CARETAFFINITY)

CaretAffinity = enum_type_wrapper.EnumTypeWrapper(_CARETAFFINITY)
_WRITINGDIRECTIONTYPE = _descriptor.EnumDescriptor(
  name='WritingDirectionType',
  full_name='TSWP.WritingDirectionType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='kWritingDirectionNatural', index=0, number=-1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kWritingDirectionLeftToRight', index=1, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kWritingDirectionRightToLeft', index=2, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=23349,
  serialized_end=23478,
)
_sym_db.RegisterEnumDescriptor(_WRITINGDIRECTIONTYPE)

WritingDirectionType = enum_type_wrapper.EnumTypeWrapper(_WRITINGDIRECTIONTYPE)
SelectionType_Normal = 0
SelectionType_ListLabel = 1
SelectionType_ListTopic = 2
SelectionType_Replace = 3
SelectionType_CopyPasteStyle = 4
SelectionType_Replace2 = 5
SelectionType_SmartField = 6
SelectionType_Visual = 7
StyleInsertionBehavior_NoGrow = 0
StyleInsertionBehavior_GrowLeft = 1
StyleInsertionBehavior_GrowRight = 2
CaretAffinity_Start = 0
CaretAffinity_End = 1
kWritingDirectionNatural = -1
kWritingDirectionLeftToRight = 0
kWritingDirectionRightToLeft = 1

PADDING_FIELD_NUMBER = 100
padding = _descriptor.FieldDescriptor(
  name='padding', full_name='TSWP.padding', index=0,
  number=100, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR)

_STORAGEARCHIVE_KINDTYPE = _descriptor.EnumDescriptor(
  name='KindType',
  full_name='TSWP.StorageArchive.KindType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BODY', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HEADER', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FOOTNOTE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEXTBOX', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOTE', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CELL', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNCLASSIFIED', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TABLEOFCONTENTS', index=7, number=7,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2399,
  serialized_end=2517,
)
_sym_db.RegisterEnumDescriptor(_STORAGEARCHIVE_KINDTYPE)

_CHARACTERSTYLEPROPERTIESARCHIVE_CAPITALIZATIONTYPE = _descriptor.EnumDescriptor(
  name='CapitalizationType',
  full_name='TSWP.CharacterStylePropertiesArchive.CapitalizationType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='kNoCaps', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kAllCaps', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kSmallCaps', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kTitled', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4420,
  serialized_end=4496,
)
_sym_db.RegisterEnumDescriptor(_CHARACTERSTYLEPROPERTIESARCHIVE_CAPITALIZATIONTYPE)

_CHARACTERSTYLEPROPERTIESARCHIVE_UNDERLINETYPE = _descriptor.EnumDescriptor(
  name='UnderlineType',
  full_name='TSWP.CharacterStylePropertiesArchive.UnderlineType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='kNoUnderline', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kSingleUnderline', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kDoubleUnderline', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kWavyUnderline', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4498,
  serialized_end=4595,
)
_sym_db.RegisterEnumDescriptor(_CHARACTERSTYLEPROPERTIESARCHIVE_UNDERLINETYPE)

_CHARACTERSTYLEPROPERTIESARCHIVE_LIGATURESTYPE = _descriptor.EnumDescriptor(
  name='LigaturesType',
  full_name='TSWP.CharacterStylePropertiesArchive.LigaturesType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='kRequiredLigatures', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kStandardLigatures', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kAllLigatures', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4597,
  serialized_end=4679,
)
_sym_db.RegisterEnumDescriptor(_CHARACTERSTYLEPROPERTIESARCHIVE_LIGATURESTYPE)

_CHARACTERSTYLEPROPERTIESARCHIVE_STRIKETHRUTYPE = _descriptor.EnumDescriptor(
  name='StrikethruType',
  full_name='TSWP.CharacterStylePropertiesArchive.StrikethruType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='kNoStrikethru', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kSingleStrikethru', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kDoubleStrikethru', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kTripleStrikethru', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4681,
  serialized_end=4785,
)
_sym_db.RegisterEnumDescriptor(_CHARACTERSTYLEPROPERTIESARCHIVE_STRIKETHRUTYPE)

_CHARACTERSTYLEPROPERTIESARCHIVE_SUPERSCRIPTTYPE = _descriptor.EnumDescriptor(
  name='SuperscriptType',
  full_name='TSWP.CharacterStylePropertiesArchive.SuperscriptType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='kNoScript', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kSuperscript', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kSubscript', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4787,
  serialized_end=4853,
)
_sym_db.RegisterEnumDescriptor(_CHARACTERSTYLEPROPERTIESARCHIVE_SUPERSCRIPTTYPE)

_TABARCHIVE_TABALIGNMENTTYPE = _descriptor.EnumDescriptor(
  name='TabAlignmentType',
  full_name='TSWP.TabArchive.TabAlignmentType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='kTabAlignmentLeft', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kTabAlignmentCenter', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kTabAlignmentRight', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kTabAlignmentDecimal', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5106,
  serialized_end=5222,
)
_sym_db.RegisterEnumDescriptor(_TABARCHIVE_TABALIGNMENTTYPE)

_LINESPACINGARCHIVE_LINESPACINGMODETYPE = _descriptor.EnumDescriptor(
  name='LineSpacingModeType',
  full_name='TSWP.LineSpacingArchive.LineSpacingModeType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='kRelativeLineSpacing', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kMinimumLineSpacing', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kExactLineSpacing', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kMaximumLineSpacing', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kSpaceBetweenLineSpacing', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5393,
  serialized_end=5543,
)
_sym_db.RegisterEnumDescriptor(_LINESPACINGARCHIVE_LINESPACINGMODETYPE)

_PARAGRAPHSTYLEPROPERTIESARCHIVE_TEXTALIGNMENTTYPE = _descriptor.EnumDescriptor(
  name='TextAlignmentType',
  full_name='TSWP.ParagraphStylePropertiesArchive.TextAlignmentType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TATvalue0', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TATvalue1', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TATvalue2', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TATvalue3', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TATvalue4', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6833,
  serialized_end=6927,
)
_sym_db.RegisterEnumDescriptor(_PARAGRAPHSTYLEPROPERTIESARCHIVE_TEXTALIGNMENTTYPE)

_PARAGRAPHSTYLEPROPERTIESARCHIVE_PARAGRAPHBORDERTYPE = _descriptor.EnumDescriptor(
  name='ParagraphBorderType',
  full_name='TSWP.ParagraphStylePropertiesArchive.ParagraphBorderType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PBTvalue0', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PBTvalue1', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PBTvalue2', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PBTvalue3', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PBTvalue4', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6929,
  serialized_end=7025,
)
_sym_db.RegisterEnumDescriptor(_PARAGRAPHSTYLEPROPERTIESARCHIVE_PARAGRAPHBORDERTYPE)

_PARAGRAPHSTYLEPROPERTIESARCHIVE_OUTLINESTYLETYPE = _descriptor.EnumDescriptor(
  name='OutlineStyleType',
  full_name='TSWP.ParagraphStylePropertiesArchive.OutlineStyleType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OSTvalue0', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OSTvalue1', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OSTvalue2', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7027,
  serialized_end=7090,
)
_sym_db.RegisterEnumDescriptor(_PARAGRAPHSTYLEPROPERTIESARCHIVE_OUTLINESTYLETYPE)

_LISTSTYLEARCHIVE_LABELTYPE = _descriptor.EnumDescriptor(
  name='LabelType',
  full_name='TSWP.ListStyleArchive.LabelType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='kNone', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kImage', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kString', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kNumber', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8096,
  serialized_end=8156,
)
_sym_db.RegisterEnumDescriptor(_LISTSTYLEARCHIVE_LABELTYPE)

_LISTSTYLEARCHIVE_NUMBERTYPE = _descriptor.EnumDescriptor(
  name='NumberType',
  full_name='TSWP.ListStyleArchive.NumberType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='kNumericDecimal', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kNumericDoubleParen', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kNumericRightParen', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kRomanUpperDecimal', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kRomanUpperDoubleParen', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kRomanUpperRightParen', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kRomanLowerDecimal', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kRomanLowerDoubleParen', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kRomanLowerRightParen', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kAlphaUpperDecimal', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kAlphaUpperDoubleParen', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kAlphaUpperRightParen', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kAlphaLowerDecimal', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kAlphaLowerDoubleParen', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kAlphaLowerRightParen', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kIdeographicJapaneseDecimalKind', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kIdeographicJapaneseDoubleParenKind', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kIdeographicJapaneseRightParenKind', index=17, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kHiraganaDecimalKind', index=18, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kHiraganaDoubleParenKind', index=19, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kHiraganaRightParenKind', index=20, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKatakanaDecimalKind', index=21, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKatakanaDoubleParenKind', index=22, number=22,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKatakanaRightParenKind', index=23, number=23,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kHiraganaIrohaDecimalKind', index=24, number=24,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kHiraganaIrohaDoubleParenKind', index=25, number=25,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kHiraganaIrohaRightParenKind', index=26, number=26,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKatakanaIrohaDecimalKind', index=27, number=27,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKatakanaIrohaDoubleParenKind', index=28, number=28,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKatakanaIrohaRightParenKind', index=29, number=29,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kIdeographicSimplifiedChineseDecimalKind', index=30, number=30,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kIdeographicSimplifiedChineseDoubleParenKind', index=31, number=31,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kIdeographicSimplifiedChineseRightParenKind', index=32, number=32,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kIdeographicTraditionalChineseDecimalKind', index=33, number=33,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kIdeographicTraditionalChineseDoubleParenKind', index=34, number=34,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kIdeographicTraditionalChineseRightParenKind', index=35, number=35,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kIdeographicFormalJapaneseDecimalKind', index=36, number=36,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kIdeographicFormalJapaneseDoubleParenKind', index=37, number=37,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kIdeographicFormalJapaneseRightParenKind', index=38, number=38,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kIdeographicFormalSimplifiedChineseDecimalKind', index=39, number=39,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kIdeographicFormalSimplifiedChineseDoubleParenKind', index=40, number=40,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kIdeographicFormalSimplifiedChineseRightParenKind', index=41, number=41,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kIdeographicFormalTraditionalChineseDecimalKind', index=42, number=42,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kIdeographicFormalTraditionalChineseDoubleParenKind', index=43, number=43,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kIdeographicFormalTraditionalChineseRightParenKind', index=44, number=44,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKoreanAlphabetDecimalKind', index=45, number=45,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKoreanAlphabetDoubleParenKind', index=46, number=46,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKoreanAlphabetRightParenKind', index=47, number=47,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kCircledNumberKind', index=48, number=48,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kArabianNumericDecimalKind', index=49, number=49,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kArabianNumericDoubleParenKind', index=50, number=50,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kArabianNumericRightParenKind', index=51, number=51,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kArabianAlphaDecimalKind', index=52, number=52,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kArabianAlphaDoubleParenKind', index=53, number=53,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kArabianAlphaRightParenKind', index=54, number=54,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kArabianAbjadDecimalKind', index=55, number=55,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kArabianAbjadDoubleParenKind', index=56, number=56,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kArabianAbjadRightParenKind', index=57, number=57,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kHebrewAlphaDecimalKind', index=58, number=58,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kHebrewAlphaDoubleParenKind', index=59, number=59,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kHebrewAlphaRightParenKind', index=60, number=60,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kHebrewBiblicalStandardKind', index=61, number=61,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kHebrewBiblicalDecimalKind', index=62, number=62,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kHebrewBiblicalDoubleParenKind', index=63, number=63,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kHebrewBiblicalRightParenKind', index=64, number=64,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8159,
  serialized_end=10457,
)
_sym_db.RegisterEnumDescriptor(_LISTSTYLEARCHIVE_NUMBERTYPE)

_COLUMNSTYLEPROPERTIESARCHIVE_VERTICALALIGNMENTTYPE = _descriptor.EnumDescriptor(
  name='VerticalAlignmentType',
  full_name='TSWP.ColumnStylePropertiesArchive.VerticalAlignmentType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='kFrameAlignTop', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kFrameAlignMiddle', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kFrameAlignBottom', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kFrameAlignJustify', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11495,
  serialized_end=11608,
)
_sym_db.RegisterEnumDescriptor(_COLUMNSTYLEPROPERTIESARCHIVE_VERTICALALIGNMENTTYPE)

_SHAPESTYLEPROPERTIESARCHIVE_VERTICALALIGNMENTTYPE = _descriptor.EnumDescriptor(
  name='VerticalAlignmentType',
  full_name='TSWP.ShapeStylePropertiesArchive.VerticalAlignmentType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='kFrameAlignTop', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kFrameAlignMiddle', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kFrameAlignBottom', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kFrameAlignJustify', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11495,
  serialized_end=11608,
)
_sym_db.RegisterEnumDescriptor(_SHAPESTYLEPROPERTIESARCHIVE_VERTICALALIGNMENTTYPE)

_UNDOTRANSACTION_UNDOKIND = _descriptor.EnumDescriptor(
  name='UndoKind',
  full_name='TSWP.UndoTransaction.UndoKind',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='REPLACE_TEXT', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INSERT_ATTRIBUTE', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DELETE_ATTRIBUTE', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADJUST_CHAR_INDEXES', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMPR_ADJUST_CHAR_INDEXES', index=4, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REPLACE_CHAR_INDEX', index=5, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REPLACE_OBJECT', index=6, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REPLACE_PARAGRAPH_DATA', index=7, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OBJECT_DOLC', index=8, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_DATE', index=9, number=10,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=16391,
  serialized_end=16621,
)
_sym_db.RegisterEnumDescriptor(_UNDOTRANSACTION_UNDOKIND)

_UNDOTRANSACTION_ACTIONKIND = _descriptor.EnumDescriptor(
  name='ActionKind',
  full_name='TSWP.UndoTransaction.ActionKind',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ACTION_UNDEFINED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACTION_TEXT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACTION_ATTRIBUTE', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=16623,
  serialized_end=16696,
)
_sym_db.RegisterEnumDescriptor(_UNDOTRANSACTION_ACTIONKIND)

_UNDOTRANSACTION_ACTIONGROUPKIND = _descriptor.EnumDescriptor(
  name='ActionGroupKind',
  full_name='TSWP.UndoTransaction.ActionGroupKind',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ACTION_GROUP_UNDEFINED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACTION_GROUP_TEXT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACTION_GROUP_ATTRIBUTE', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=16698,
  serialized_end=16794,
)
_sym_db.RegisterEnumDescriptor(_UNDOTRANSACTION_ACTIONGROUPKIND)

_TEXTUALATTACHMENTARCHIVE_KIND = _descriptor.EnumDescriptor(
  name='Kind',
  full_name='TSWP.TextualAttachmentArchive.Kind',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='kKindPageNumber', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindPageCount', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindFootnoteMark', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=17818,
  serialized_end=17888,
)
_sym_db.RegisterEnumDescriptor(_TEXTUALATTACHMENTARCHIVE_KIND)

_DATETIMESMARTFIELDARCHIVE_DATETIMEUPDATEPLAN = _descriptor.EnumDescriptor(
  name='DateTimeUpdatePlan',
  full_name='TSWP.DateTimeSmartFieldArchive.DateTimeUpdatePlan',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='kDateTimeUpdatePlanNever', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kDateTimeUpdatePlanAuto', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kDateTimeUpdatePlanOnce', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=19927,
  serialized_end=20035,
)
_sym_db.RegisterEnumDescriptor(_DATETIMESMARTFIELDARCHIVE_DATETIMEUPDATEPLAN)

_DATETIMESMARTFIELDARCHIVE_DATETIMEFORMATTERSTYLE = _descriptor.EnumDescriptor(
  name='DateTimeFormatterStyle',
  full_name='TSWP.DateTimeSmartFieldArchive.DateTimeFormatterStyle',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='kDateTimeFormatterStyleNone', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kDateTimeFormatterStyleShort', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kDateTimeFormatterStyleMedium', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kDateTimeFormatterStyleLong', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kDateTimeFormatterStyleFull', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=20038,
  serialized_end=20230,
)
_sym_db.RegisterEnumDescriptor(_DATETIMESMARTFIELDARCHIVE_DATETIMEFORMATTERSTYLE)

_MERGESMARTFIELDARCHIVE_MERGECATEGORY = _descriptor.EnumDescriptor(
  name='MergeCategory',
  full_name='TSWP.MergeSmartFieldArchive.MergeCategory',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='kMergeCategoryTo', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kMergeCategoryFrom', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=20725,
  serialized_end=20786,
)
_sym_db.RegisterEnumDescriptor(_MERGESMARTFIELDARCHIVE_MERGECATEGORY)

_CHANGEARCHIVE_CHANGEKIND = _descriptor.EnumDescriptor(
  name='ChangeKind',
  full_name='TSWP.ChangeArchive.ChangeKind',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='kChangeKindInsertion', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kChangeKindDeletion', index=1, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=21326,
  serialized_end=21389,
)
_sym_db.RegisterEnumDescriptor(_CHANGEARCHIVE_CHANGEKIND)

_DROPCAPARCHIVE_DROPCAPTYPE = _descriptor.EnumDescriptor(
  name='DropCapType',
  full_name='TSWP.DropCapArchive.DropCapType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TSWPDropCapTypeText', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TSWPDropCapTypeShape', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TSWPDropCapTypeImage', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=22273,
  serialized_end=22363,
)
_sym_db.RegisterEnumDescriptor(_DROPCAPARCHIVE_DROPCAPTYPE)

_DROPCAPARCHIVE_DROPCAPWRAPTYPE = _descriptor.EnumDescriptor(
  name='DropCapWrapType',
  full_name='TSWP.DropCapArchive.DropCapWrapType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TSWPDropCapWrapTypeRectangular', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TSWPDropCapWrapTypeContour', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TSWPDropCapWrapTypeNone', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=22365,
  serialized_end=22479,
)
_sym_db.RegisterEnumDescriptor(_DROPCAPARCHIVE_DROPCAPWRAPTYPE)


_SELECTIONARCHIVE = _descriptor.Descriptor(
  name='SelectionArchive',
  full_name='TSWP.SelectionArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='TSWP.SelectionArchive.type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range', full_name='TSWP.SelectionArchive.range', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='styleInsertionBehavior', full_name='TSWP.SelectionArchive.styleInsertionBehavior', index=2,
      number=3, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='caretAffinity', full_name='TSWP.SelectionArchive.caretAffinity', index=3,
      number=4, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='smart_field_range', full_name='TSWP.SelectionArchive.smart_field_range', index=4,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=105,
  serialized_end=330,
)


_OBJECTATTRIBUTETABLE_OBJECTATTRIBUTE = _descriptor.Descriptor(
  name='ObjectAttribute',
  full_name='TSWP.ObjectAttributeTable.ObjectAttribute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='character_index', full_name='TSWP.ObjectAttributeTable.ObjectAttribute.character_index', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='object', full_name='TSWP.ObjectAttributeTable.ObjectAttribute.object', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=418,
  serialized_end=492,
)

_OBJECTATTRIBUTETABLE = _descriptor.Descriptor(
  name='ObjectAttributeTable',
  full_name='TSWP.ObjectAttributeTable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='TSWP.ObjectAttributeTable.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_OBJECTATTRIBUTETABLE_OBJECTATTRIBUTE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=333,
  serialized_end=492,
)


_STRINGATTRIBUTETABLE_STRINGATTRIBUTE = _descriptor.Descriptor(
  name='StringAttribute',
  full_name='TSWP.StringAttributeTable.StringAttribute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='character_index', full_name='TSWP.StringAttributeTable.StringAttribute.character_index', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='object', full_name='TSWP.StringAttributeTable.StringAttribute.object', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=580,
  serialized_end=638,
)

_STRINGATTRIBUTETABLE = _descriptor.Descriptor(
  name='StringAttributeTable',
  full_name='TSWP.StringAttributeTable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='TSWP.StringAttributeTable.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_STRINGATTRIBUTETABLE_STRINGATTRIBUTE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=495,
  serialized_end=638,
)


_PARADATAATTRIBUTETABLE_PARADATAATTRIBUTE = _descriptor.Descriptor(
  name='ParaDataAttribute',
  full_name='TSWP.ParaDataAttributeTable.ParaDataAttribute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='character_index', full_name='TSWP.ParaDataAttributeTable.ParaDataAttribute.character_index', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='first', full_name='TSWP.ParaDataAttributeTable.ParaDataAttribute.first', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='second', full_name='TSWP.ParaDataAttributeTable.ParaDataAttribute.second', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=732,
  serialized_end=807,
)

_PARADATAATTRIBUTETABLE = _descriptor.Descriptor(
  name='ParaDataAttributeTable',
  full_name='TSWP.ParaDataAttributeTable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='TSWP.ParaDataAttributeTable.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_PARADATAATTRIBUTETABLE_PARADATAATTRIBUTE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=641,
  serialized_end=807,
)


_OVERLAPPINGFIELDATTRIBUTETABLE_OVERLAPPINGFIELDATTRIBUTE = _descriptor.Descriptor(
  name='OverlappingFieldAttribute',
  full_name='TSWP.OverlappingFieldAttributeTable.OverlappingFieldAttribute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='range', full_name='TSWP.OverlappingFieldAttributeTable.OverlappingFieldAttribute.range', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='field', full_name='TSWP.OverlappingFieldAttributeTable.OverlappingFieldAttribute.field', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=925,
  serialized_end=1010,
)

_OVERLAPPINGFIELDATTRIBUTETABLE = _descriptor.Descriptor(
  name='OverlappingFieldAttributeTable',
  full_name='TSWP.OverlappingFieldAttributeTable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='TSWP.OverlappingFieldAttributeTable.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_OVERLAPPINGFIELDATTRIBUTETABLE_OVERLAPPINGFIELDATTRIBUTE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=810,
  serialized_end=1010,
)


_STORAGEARCHIVE = _descriptor.Descriptor(
  name='StorageArchive',
  full_name='TSWP.StorageArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='kind', full_name='TSWP.StorageArchive.kind', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=3,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='style_sheet', full_name='TSWP.StorageArchive.style_sheet', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text', full_name='TSWP.StorageArchive.text', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='has_itext', full_name='TSWP.StorageArchive.has_itext', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='in_document', full_name='TSWP.StorageArchive.in_document', index=4,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_para_style', full_name='TSWP.StorageArchive.table_para_style', index=5,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_para_data', full_name='TSWP.StorageArchive.table_para_data', index=6,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_list_style', full_name='TSWP.StorageArchive.table_list_style', index=7,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_char_style', full_name='TSWP.StorageArchive.table_char_style', index=8,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_attachment', full_name='TSWP.StorageArchive.table_attachment', index=9,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_smartfield', full_name='TSWP.StorageArchive.table_smartfield', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_layout_style', full_name='TSWP.StorageArchive.table_layout_style', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_para_starts', full_name='TSWP.StorageArchive.table_para_starts', index=12,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_bookmark', full_name='TSWP.StorageArchive.table_bookmark', index=13,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_footnote', full_name='TSWP.StorageArchive.table_footnote', index=14,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_section', full_name='TSWP.StorageArchive.table_section', index=15,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_rubyfield', full_name='TSWP.StorageArchive.table_rubyfield', index=16,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_language', full_name='TSWP.StorageArchive.table_language', index=17,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_dictation', full_name='TSWP.StorageArchive.table_dictation', index=18,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_insertion', full_name='TSWP.StorageArchive.table_insertion', index=19,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_deletion', full_name='TSWP.StorageArchive.table_deletion', index=20,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_highlight', full_name='TSWP.StorageArchive.table_highlight', index=21,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_para_bidi', full_name='TSWP.StorageArchive.table_para_bidi', index=22,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_overlapping_highlight', full_name='TSWP.StorageArchive.table_overlapping_highlight', index=23,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_pencil_annotation', full_name='TSWP.StorageArchive.table_pencil_annotation', index=24,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_tatechuyoko', full_name='TSWP.StorageArchive.table_tatechuyoko', index=25,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_drop_cap_style', full_name='TSWP.StorageArchive.table_drop_cap_style', index=26,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STORAGEARCHIVE_KINDTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1013,
  serialized_end=2517,
)


_HIGHLIGHTARCHIVE = _descriptor.Descriptor(
  name='HighlightArchive',
  full_name='TSWP.HighlightArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='commentStorage', full_name='TSWP.HighlightArchive.commentStorage', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text_attribute_uuid_string', full_name='TSWP.HighlightArchive.text_attribute_uuid_string', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2519,
  serialized_end=2613,
)


_PENCILANNOTATIONARCHIVE = _descriptor.Descriptor(
  name='PencilAnnotationArchive',
  full_name='TSWP.PencilAnnotationArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pencil_annotation_storage', full_name='TSWP.PencilAnnotationArchive.pencil_annotation_storage', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text_attribute_uuid_string', full_name='TSWP.PencilAnnotationArchive.text_attribute_uuid_string', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2615,
  serialized_end=2727,
)


_FONTFEATUREARCHIVE = _descriptor.Descriptor(
  name='FontFeatureArchive',
  full_name='TSWP.FontFeatureArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_type', full_name='TSWP.FontFeatureArchive.feature_type', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feature_selector', full_name='TSWP.FontFeatureArchive.feature_selector', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2729,
  serialized_end=2797,
)


_CHARACTERSTYLEPROPERTIESARCHIVE = _descriptor.Descriptor(
  name='CharacterStylePropertiesArchive',
  full_name='TSWP.CharacterStylePropertiesArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='bold', full_name='TSWP.CharacterStylePropertiesArchive.bold', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='italic', full_name='TSWP.CharacterStylePropertiesArchive.italic', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='font_size', full_name='TSWP.CharacterStylePropertiesArchive.font_size', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='font_name_null', full_name='TSWP.CharacterStylePropertiesArchive.font_name_null', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='font_name', full_name='TSWP.CharacterStylePropertiesArchive.font_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='font_color_null', full_name='TSWP.CharacterStylePropertiesArchive.font_color_null', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='font_color', full_name='TSWP.CharacterStylePropertiesArchive.font_color', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='language_null', full_name='TSWP.CharacterStylePropertiesArchive.language_null', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='language', full_name='TSWP.CharacterStylePropertiesArchive.language', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='superscript', full_name='TSWP.CharacterStylePropertiesArchive.superscript', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='underline', full_name='TSWP.CharacterStylePropertiesArchive.underline', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='strikethru', full_name='TSWP.CharacterStylePropertiesArchive.strikethru', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='capitalization', full_name='TSWP.CharacterStylePropertiesArchive.capitalization', index=12,
      number=13, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='baseline_shift', full_name='TSWP.CharacterStylePropertiesArchive.baseline_shift', index=13,
      number=14, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='kerning', full_name='TSWP.CharacterStylePropertiesArchive.kerning', index=14,
      number=15, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ligatures', full_name='TSWP.CharacterStylePropertiesArchive.ligatures', index=15,
      number=16, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outline_color_null', full_name='TSWP.CharacterStylePropertiesArchive.outline_color_null', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outline_color', full_name='TSWP.CharacterStylePropertiesArchive.outline_color', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outline', full_name='TSWP.CharacterStylePropertiesArchive.outline', index=18,
      number=19, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shadow_null', full_name='TSWP.CharacterStylePropertiesArchive.shadow_null', index=19,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shadow', full_name='TSWP.CharacterStylePropertiesArchive.shadow', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='strikethru_color_null', full_name='TSWP.CharacterStylePropertiesArchive.strikethru_color_null', index=21,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='strikethru_color', full_name='TSWP.CharacterStylePropertiesArchive.strikethru_color', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='strikethru_width', full_name='TSWP.CharacterStylePropertiesArchive.strikethru_width', index=23,
      number=24, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='background_color_null', full_name='TSWP.CharacterStylePropertiesArchive.background_color_null', index=24,
      number=25, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='background_color', full_name='TSWP.CharacterStylePropertiesArchive.background_color', index=25,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tracking', full_name='TSWP.CharacterStylePropertiesArchive.tracking', index=26,
      number=27, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='underline_color_null', full_name='TSWP.CharacterStylePropertiesArchive.underline_color_null', index=27,
      number=28, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='underline_color', full_name='TSWP.CharacterStylePropertiesArchive.underline_color', index=28,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='underline_width', full_name='TSWP.CharacterStylePropertiesArchive.underline_width', index=29,
      number=30, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='word_strikethru', full_name='TSWP.CharacterStylePropertiesArchive.word_strikethru', index=30,
      number=31, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='word_underline', full_name='TSWP.CharacterStylePropertiesArchive.word_underline', index=31,
      number=32, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='font_features_null', full_name='TSWP.CharacterStylePropertiesArchive.font_features_null', index=32,
      number=33, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='font_features', full_name='TSWP.CharacterStylePropertiesArchive.font_features', index=33,
      number=34, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='writing_direction', full_name='TSWP.CharacterStylePropertiesArchive.writing_direction', index=34,
      number=35, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='emphasis_marks_null', full_name='TSWP.CharacterStylePropertiesArchive.emphasis_marks_null', index=35,
      number=36, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='emphasis_marks', full_name='TSWP.CharacterStylePropertiesArchive.emphasis_marks', index=36,
      number=37, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='compatibility_font_name_null', full_name='TSWP.CharacterStylePropertiesArchive.compatibility_font_name_null', index=37,
      number=38, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='compatibility_font_name', full_name='TSWP.CharacterStylePropertiesArchive.compatibility_font_name', index=38,
      number=39, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_named_point_size', full_name='TSWP.CharacterStylePropertiesArchive.is_named_point_size', index=39,
      number=40, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='capitalization_uses_linguistics', full_name='TSWP.CharacterStylePropertiesArchive.capitalization_uses_linguistics', index=40,
      number=41, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tate_chu_yoko', full_name='TSWP.CharacterStylePropertiesArchive.tate_chu_yoko', index=41,
      number=42, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tsd_stroke_null', full_name='TSWP.CharacterStylePropertiesArchive.tsd_stroke_null', index=42,
      number=43, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tsd_stroke', full_name='TSWP.CharacterStylePropertiesArchive.tsd_stroke', index=43,
      number=44, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tsd_fill_null', full_name='TSWP.CharacterStylePropertiesArchive.tsd_fill_null', index=44,
      number=45, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tsd_fill', full_name='TSWP.CharacterStylePropertiesArchive.tsd_fill', index=45,
      number=46, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tsd_fill_should_fill_text_container', full_name='TSWP.CharacterStylePropertiesArchive.tsd_fill_should_fill_text_container', index=46,
      number=47, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CHARACTERSTYLEPROPERTIESARCHIVE_CAPITALIZATIONTYPE,
    _CHARACTERSTYLEPROPERTIESARCHIVE_UNDERLINETYPE,
    _CHARACTERSTYLEPROPERTIESARCHIVE_LIGATURESTYPE,
    _CHARACTERSTYLEPROPERTIESARCHIVE_STRIKETHRUTYPE,
    _CHARACTERSTYLEPROPERTIESARCHIVE_SUPERSCRIPTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2800,
  serialized_end=4853,
)


_CHARACTERSTYLEARCHIVE = _descriptor.Descriptor(
  name='CharacterStyleArchive',
  full_name='TSWP.CharacterStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.CharacterStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='override_count', full_name='TSWP.CharacterStyleArchive.override_count', index=1,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='char_properties', full_name='TSWP.CharacterStyleArchive.char_properties', index=2,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4856,
  serialized_end=5001,
)


_TABARCHIVE = _descriptor.Descriptor(
  name='TabArchive',
  full_name='TSWP.TabArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='position', full_name='TSWP.TabArchive.position', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='alignment', full_name='TSWP.TabArchive.alignment', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='leader', full_name='TSWP.TabArchive.leader', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TABARCHIVE_TABALIGNMENTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5004,
  serialized_end=5222,
)


_TABSARCHIVE = _descriptor.Descriptor(
  name='TabsArchive',
  full_name='TSWP.TabsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tabs', full_name='TSWP.TabsArchive.tabs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5224,
  serialized_end=5269,
)


_LINESPACINGARCHIVE = _descriptor.Descriptor(
  name='LineSpacingArchive',
  full_name='TSWP.LineSpacingArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='TSWP.LineSpacingArchive.mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='amount', full_name='TSWP.LineSpacingArchive.amount', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='baselineRule', full_name='TSWP.LineSpacingArchive.baselineRule', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LINESPACINGARCHIVE_LINESPACINGMODETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5272,
  serialized_end=5543,
)


_PARAGRAPHSTYLEPROPERTIESARCHIVE = _descriptor.Descriptor(
  name='ParagraphStylePropertiesArchive',
  full_name='TSWP.ParagraphStylePropertiesArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='alignment', full_name='TSWP.ParagraphStylePropertiesArchive.alignment', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='decimal_tab_null', full_name='TSWP.ParagraphStylePropertiesArchive.decimal_tab_null', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='decimal_tab', full_name='TSWP.ParagraphStylePropertiesArchive.decimal_tab', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_tab_stops', full_name='TSWP.ParagraphStylePropertiesArchive.default_tab_stops', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fill_null', full_name='TSWP.ParagraphStylePropertiesArchive.fill_null', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fill', full_name='TSWP.ParagraphStylePropertiesArchive.fill', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='first_line_indent', full_name='TSWP.ParagraphStylePropertiesArchive.first_line_indent', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hyphenate', full_name='TSWP.ParagraphStylePropertiesArchive.hyphenate', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keep_lines_together', full_name='TSWP.ParagraphStylePropertiesArchive.keep_lines_together', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keep_with_next', full_name='TSWP.ParagraphStylePropertiesArchive.keep_with_next', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='left_indent', full_name='TSWP.ParagraphStylePropertiesArchive.left_indent', index=10,
      number=11, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_spacing_null', full_name='TSWP.ParagraphStylePropertiesArchive.line_spacing_null', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_spacing', full_name='TSWP.ParagraphStylePropertiesArchive.line_spacing', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page_break_before', full_name='TSWP.ParagraphStylePropertiesArchive.page_break_before', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='borders', full_name='TSWP.ParagraphStylePropertiesArchive.borders', index=14,
      number=15, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rule_offset_null', full_name='TSWP.ParagraphStylePropertiesArchive.rule_offset_null', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rule_offset', full_name='TSWP.ParagraphStylePropertiesArchive.rule_offset', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rule_width', full_name='TSWP.ParagraphStylePropertiesArchive.rule_width', index=17,
      number=18, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='right_indent', full_name='TSWP.ParagraphStylePropertiesArchive.right_indent', index=18,
      number=19, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='space_after', full_name='TSWP.ParagraphStylePropertiesArchive.space_after', index=19,
      number=20, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='space_before', full_name='TSWP.ParagraphStylePropertiesArchive.space_before', index=20,
      number=21, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tabs_null', full_name='TSWP.ParagraphStylePropertiesArchive.tabs_null', index=21,
      number=24, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tabs', full_name='TSWP.ParagraphStylePropertiesArchive.tabs', index=22,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='widow_control', full_name='TSWP.ParagraphStylePropertiesArchive.widow_control', index=23,
      number=26, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outline_level', full_name='TSWP.ParagraphStylePropertiesArchive.outline_level', index=24,
      number=27, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outline_style', full_name='TSWP.ParagraphStylePropertiesArchive.outline_style', index=25,
      number=28, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='following_style_id_null', full_name='TSWP.ParagraphStylePropertiesArchive.following_style_id_null', index=26,
      number=29, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='following_style_id', full_name='TSWP.ParagraphStylePropertiesArchive.following_style_id', index=27,
      number=30, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stroke_null', full_name='TSWP.ParagraphStylePropertiesArchive.stroke_null', index=28,
      number=31, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stroke', full_name='TSWP.ParagraphStylePropertiesArchive.stroke', index=29,
      number=32, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='show_in_toc', full_name='TSWP.ParagraphStylePropertiesArchive.show_in_toc', index=30,
      number=33, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='toc_style_id_null', full_name='TSWP.ParagraphStylePropertiesArchive.toc_style_id_null', index=31,
      number=34, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='toc_style_id', full_name='TSWP.ParagraphStylePropertiesArchive.toc_style_id', index=32,
      number=35, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='writing_direction', full_name='TSWP.ParagraphStylePropertiesArchive.writing_direction', index=33,
      number=38, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='list_style_null', full_name='TSWP.ParagraphStylePropertiesArchive.list_style_null', index=34,
      number=39, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='list_style', full_name='TSWP.ParagraphStylePropertiesArchive.list_style', index=35,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='following_style_null', full_name='TSWP.ParagraphStylePropertiesArchive.following_style_null', index=36,
      number=41, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='following_style', full_name='TSWP.ParagraphStylePropertiesArchive.following_style', index=37,
      number=42, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='show_in_bookmarks_list', full_name='TSWP.ParagraphStylePropertiesArchive.show_in_bookmarks_list', index=38,
      number=43, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='show_in_toc_navigator', full_name='TSWP.ParagraphStylePropertiesArchive.show_in_toc_navigator', index=39,
      number=44, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PARAGRAPHSTYLEPROPERTIESARCHIVE_TEXTALIGNMENTTYPE,
    _PARAGRAPHSTYLEPROPERTIESARCHIVE_PARAGRAPHBORDERTYPE,
    _PARAGRAPHSTYLEPROPERTIESARCHIVE_OUTLINESTYLETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5546,
  serialized_end=7090,
)


_PARAGRAPHSTYLEARCHIVE = _descriptor.Descriptor(
  name='ParagraphStyleArchive',
  full_name='TSWP.ParagraphStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.ParagraphStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='override_count', full_name='TSWP.ParagraphStyleArchive.override_count', index=1,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='char_properties', full_name='TSWP.ParagraphStyleArchive.char_properties', index=2,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='para_properties', full_name='TSWP.ParagraphStyleArchive.para_properties', index=3,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7093,
  serialized_end=7302,
)


_LISTSTYLEARCHIVE_LABELGEOMETRY = _descriptor.Descriptor(
  name='LabelGeometry',
  full_name='TSWP.ListStyleArchive.LabelGeometry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='scale', full_name='TSWP.ListStyleArchive.LabelGeometry.scale', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='baseline_offset', full_name='TSWP.ListStyleArchive.LabelGeometry.baseline_offset', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scale_with_text', full_name='TSWP.ListStyleArchive.LabelGeometry.scale_with_text', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7896,
  serialized_end=7985,
)

_LISTSTYLEARCHIVE_LABELIMAGE = _descriptor.Descriptor(
  name='LabelImage',
  full_name='TSWP.ListStyleArchive.LabelImage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='image', full_name='TSWP.ListStyleArchive.LabelImage.image', index=0,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image_null', full_name='TSWP.ListStyleArchive.LabelImage.image_null', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='database_image', full_name='TSWP.ListStyleArchive.LabelImage.database_image', index=2,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7987,
  serialized_end=8094,
)

_LISTSTYLEARCHIVE = _descriptor.Descriptor(
  name='ListStyleArchive',
  full_name='TSWP.ListStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.ListStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='override_count', full_name='TSWP.ListStyleArchive.override_count', index=1,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_types', full_name='TSWP.ListStyleArchive.label_types', index=2,
      number=11, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text_indents', full_name='TSWP.ListStyleArchive.text_indents', index=3,
      number=12, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='indents', full_name='TSWP.ListStyleArchive.indents', index=4,
      number=13, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geometries', full_name='TSWP.ListStyleArchive.geometries', index=5,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='number_types', full_name='TSWP.ListStyleArchive.number_types', index=6,
      number=15, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='strings', full_name='TSWP.ListStyleArchive.strings', index=7,
      number=16, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='images', full_name='TSWP.ListStyleArchive.images', index=8,
      number=17, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shadow_null', full_name='TSWP.ListStyleArchive.shadow_null', index=9,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shadow', full_name='TSWP.ListStyleArchive.shadow', index=10,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='font_color_null', full_name='TSWP.ListStyleArchive.font_color_null', index=11,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='font_color', full_name='TSWP.ListStyleArchive.font_color', index=12,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='font_name_null', full_name='TSWP.ListStyleArchive.font_name_null', index=13,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='font_name', full_name='TSWP.ListStyleArchive.font_name', index=14,
      number=23, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='writing_direction', full_name='TSWP.ListStyleArchive.writing_direction', index=15,
      number=24, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tiered_numbers', full_name='TSWP.ListStyleArchive.tiered_numbers', index=16,
      number=25, type=8, cpp_type=7, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_LISTSTYLEARCHIVE_LABELGEOMETRY, _LISTSTYLEARCHIVE_LABELIMAGE, ],
  enum_types=[
    _LISTSTYLEARCHIVE_LABELTYPE,
    _LISTSTYLEARCHIVE_NUMBERTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7305,
  serialized_end=10457,
)


_TEXTSTYLEPRESETARCHIVE = _descriptor.Descriptor(
  name='TextStylePresetArchive',
  full_name='TSWP.TextStylePresetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='preset_identifier', full_name='TSWP.TextStylePresetArchive.preset_identifier', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paragraph_style', full_name='TSWP.TextStylePresetArchive.paragraph_style', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='list_style', full_name='TSWP.TextStylePresetArchive.list_style', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10460,
  serialized_end=10588,
)


_COLUMNSARCHIVE_EQUALCOLUMNSARCHIVE = _descriptor.Descriptor(
  name='EqualColumnsArchive',
  full_name='TSWP.ColumnsArchive.EqualColumnsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='TSWP.ColumnsArchive.EqualColumnsArchive.count', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gap', full_name='TSWP.ColumnsArchive.EqualColumnsArchive.gap', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10746,
  serialized_end=10795,
)

_COLUMNSARCHIVE_NONEQUALCOLUMNSARCHIVE_GAPWIDTHARCHIVE = _descriptor.Descriptor(
  name='GapWidthArchive',
  full_name='TSWP.ColumnsArchive.NonEqualColumnsArchive.GapWidthArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gap', full_name='TSWP.ColumnsArchive.NonEqualColumnsArchive.GapWidthArchive.gap', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='width', full_name='TSWP.ColumnsArchive.NonEqualColumnsArchive.GapWidthArchive.width', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10919,
  serialized_end=10964,
)

_COLUMNSARCHIVE_NONEQUALCOLUMNSARCHIVE = _descriptor.Descriptor(
  name='NonEqualColumnsArchive',
  full_name='TSWP.ColumnsArchive.NonEqualColumnsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='first', full_name='TSWP.ColumnsArchive.NonEqualColumnsArchive.first', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='following', full_name='TSWP.ColumnsArchive.NonEqualColumnsArchive.following', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_COLUMNSARCHIVE_NONEQUALCOLUMNSARCHIVE_GAPWIDTHARCHIVE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10798,
  serialized_end=10964,
)

_COLUMNSARCHIVE = _descriptor.Descriptor(
  name='ColumnsArchive',
  full_name='TSWP.ColumnsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='equal_columns', full_name='TSWP.ColumnsArchive.equal_columns', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='non_equal_columns', full_name='TSWP.ColumnsArchive.non_equal_columns', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_COLUMNSARCHIVE_EQUALCOLUMNSARCHIVE, _COLUMNSARCHIVE_NONEQUALCOLUMNSARCHIVE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10591,
  serialized_end=10964,
)


_PADDINGARCHIVE = _descriptor.Descriptor(
  name='PaddingArchive',
  full_name='TSWP.PaddingArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='left', full_name='TSWP.PaddingArchive.left', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='top', full_name='TSWP.PaddingArchive.top', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='right', full_name='TSWP.PaddingArchive.right', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bottom', full_name='TSWP.PaddingArchive.bottom', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10966,
  serialized_end=11040,
)


_COLUMNSTYLEPROPERTIESARCHIVE = _descriptor.Descriptor(
  name='ColumnStylePropertiesArchive',
  full_name='TSWP.ColumnStylePropertiesArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='continuous', full_name='TSWP.ColumnStylePropertiesArchive.continuous', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shrink_to_fit', full_name='TSWP.ColumnStylePropertiesArchive.shrink_to_fit', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vertical_text', full_name='TSWP.ColumnStylePropertiesArchive.vertical_text', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='min_horizontal_inset', full_name='TSWP.ColumnStylePropertiesArchive.min_horizontal_inset', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vertical_alignment', full_name='TSWP.ColumnStylePropertiesArchive.vertical_alignment', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='columns_null', full_name='TSWP.ColumnStylePropertiesArchive.columns_null', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='columns', full_name='TSWP.ColumnStylePropertiesArchive.columns', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='margins_null', full_name='TSWP.ColumnStylePropertiesArchive.margins_null', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='margins', full_name='TSWP.ColumnStylePropertiesArchive.margins', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='padding_null', full_name='TSWP.ColumnStylePropertiesArchive.padding_null', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='padding', full_name='TSWP.ColumnStylePropertiesArchive.padding', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='writing_direction', full_name='TSWP.ColumnStylePropertiesArchive.writing_direction', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _COLUMNSTYLEPROPERTIESARCHIVE_VERTICALALIGNMENTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11043,
  serialized_end=11608,
)


_COLUMNSTYLEARCHIVE = _descriptor.Descriptor(
  name='ColumnStyleArchive',
  full_name='TSWP.ColumnStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.ColumnStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='override_count', full_name='TSWP.ColumnStyleArchive.override_count', index=1,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column_properties', full_name='TSWP.ColumnStyleArchive.column_properties', index=2,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11611,
  serialized_end=11752,
)


_SHAPESTYLEPROPERTIESARCHIVE = _descriptor.Descriptor(
  name='ShapeStylePropertiesArchive',
  full_name='TSWP.ShapeStylePropertiesArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='shrink_to_fit', full_name='TSWP.ShapeStylePropertiesArchive.shrink_to_fit', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vertical_alignment', full_name='TSWP.ShapeStylePropertiesArchive.vertical_alignment', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='columns_null', full_name='TSWP.ShapeStylePropertiesArchive.columns_null', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='columns', full_name='TSWP.ShapeStylePropertiesArchive.columns', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='padding_null', full_name='TSWP.ShapeStylePropertiesArchive.padding_null', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='padding', full_name='TSWP.ShapeStylePropertiesArchive.padding', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_text_preset_index', full_name='TSWP.ShapeStylePropertiesArchive.default_text_preset_index', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vertical_text', full_name='TSWP.ShapeStylePropertiesArchive.vertical_text', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paragraph_style_null', full_name='TSWP.ShapeStylePropertiesArchive.paragraph_style_null', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paragraph_style', full_name='TSWP.ShapeStylePropertiesArchive.paragraph_style', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vertical_text_40', full_name='TSWP.ShapeStylePropertiesArchive.vertical_text_40', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SHAPESTYLEPROPERTIESARCHIVE_VERTICALALIGNMENTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11755,
  serialized_end=12284,
)


_SHAPESTYLEARCHIVE = _descriptor.Descriptor(
  name='ShapeStyleArchive',
  full_name='TSWP.ShapeStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.ShapeStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='override_count', full_name='TSWP.ShapeStyleArchive.override_count', index=1,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shape_properties', full_name='TSWP.ShapeStyleArchive.shape_properties', index=2,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12287,
  serialized_end=12430,
)


_THEMEPRESETSARCHIVE = _descriptor.Descriptor(
  name='ThemePresetsArchive',
  full_name='TSWP.ThemePresetsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='list_style_presets', full_name='TSWP.ThemePresetsArchive.list_style_presets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text_style_presets', full_name='TSWP.ThemePresetsArchive.text_style_presets', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='imported_text_style_presets', full_name='TSWP.ThemePresetsArchive.imported_text_style_presets', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='toc_entry_style_presets', full_name='TSWP.ThemePresetsArchive.toc_entry_style_presets', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='toc_settings_presets', full_name='TSWP.ThemePresetsArchive.toc_settings_presets', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='character_style_presets', full_name='TSWP.ThemePresetsArchive.character_style_presets', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paragraph_style_presets', full_name='TSWP.ThemePresetsArchive.paragraph_style_presets', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dropcap_style_presets', full_name='TSWP.ThemePresetsArchive.dropcap_style_presets', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
    _descriptor.FieldDescriptor(
      name='extension', full_name='TSWP.ThemePresetsArchive.extension', index=0,
      number=110, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12433,
  serialized_end=12900,
)


_TEXTPRESETDISPLAYITEMARCHIVE = _descriptor.Descriptor(
  name='TextPresetDisplayItemArchive',
  full_name='TSWP.TextPresetDisplayItemArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='preset', full_name='TSWP.TextPresetDisplayItemArchive.preset', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='display_name', full_name='TSWP.TextPresetDisplayItemArchive.display_name', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12902,
  serialized_end=12986,
)


_TOCENTRYSTYLEPROPERTIESARCHIVE = _descriptor.Descriptor(
  name='TOCEntryStylePropertiesArchive',
  full_name='TSWP.TOCEntryStylePropertiesArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='page_number_style_null', full_name='TSWP.TOCEntryStylePropertiesArchive.page_number_style_null', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page_number_style', full_name='TSWP.TOCEntryStylePropertiesArchive.page_number_style', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='show_page_number', full_name='TSWP.TOCEntryStylePropertiesArchive.show_page_number', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12989,
  serialized_end=13122,
)


_TOCENTRYSTYLEARCHIVE = _descriptor.Descriptor(
  name='TOCEntryStyleArchive',
  full_name='TSWP.TOCEntryStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.TOCEntryStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='toc_properties', full_name='TSWP.TOCEntryStyleArchive.toc_properties', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13125,
  serialized_end=13253,
)


_TOCSETTINGSARCHIVE_TOCENTRYDATA = _descriptor.Descriptor(
  name='TOCEntryData',
  full_name='TSWP.TOCSettingsArchive.TOCEntryData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='paragraph_style', full_name='TSWP.TOCSettingsArchive.TOCEntryData.paragraph_style', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='toc_entry_style', full_name='TSWP.TOCSettingsArchive.TOCEntryData.toc_entry_style', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='show_in_toc', full_name='TSWP.TOCSettingsArchive.TOCEntryData.show_in_toc', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13371,
  serialized_end=13488,
)

_TOCSETTINGSARCHIVE = _descriptor.Descriptor(
  name='TOCSettingsArchive',
  full_name='TSWP.TOCSettingsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='toc_name', full_name='TSWP.TOCSettingsArchive.toc_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='toc_scope', full_name='TSWP.TOCSettingsArchive.toc_scope', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entries', full_name='TSWP.TOCSettingsArchive.entries', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_TOCSETTINGSARCHIVE_TOCENTRYDATA, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13256,
  serialized_end=13488,
)


_TOCENTRYINSTANCEARCHIVE = _descriptor.Descriptor(
  name='TOCEntryInstanceArchive',
  full_name='TSWP.TOCEntryInstanceArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='paragraph_index', full_name='TSWP.TOCEntryInstanceArchive.paragraph_index', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page_number', full_name='TSWP.TOCEntryInstanceArchive.page_number', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='number_format', full_name='TSWP.TOCEntryInstanceArchive.number_format', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='heading', full_name='TSWP.TOCEntryInstanceArchive.heading', index=3,
      number=4, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='indexed_style', full_name='TSWP.TOCEntryInstanceArchive.indexed_style', index=4,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='indexed_list_style', full_name='TSWP.TOCEntryInstanceArchive.indexed_list_style', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='indexed_list_start', full_name='TSWP.TOCEntryInstanceArchive.indexed_list_start', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='indexed_paragraph_level', full_name='TSWP.TOCEntryInstanceArchive.indexed_paragraph_level', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='number_format_name', full_name='TSWP.TOCEntryInstanceArchive.number_format_name', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13491,
  serialized_end=13774,
)


_UNDOTRANSACTION_GENERICTRANSACTION = _descriptor.Descriptor(
  name='GenericTransaction',
  full_name='TSWP.UndoTransaction.GenericTransaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value1', full_name='TSWP.UndoTransaction.GenericTransaction.value1', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value2', full_name='TSWP.UndoTransaction.GenericTransaction.value2', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value3', full_name='TSWP.UndoTransaction.GenericTransaction.value3', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13950,
  serialized_end=14018,
)

_UNDOTRANSACTION_TEXTTRANSACTION = _descriptor.Descriptor(
  name='TextTransaction',
  full_name='TSWP.UndoTransaction.TextTransaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='insert_location', full_name='TSWP.UndoTransaction.TextTransaction.insert_location', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='insert_length', full_name='TSWP.UndoTransaction.TextTransaction.insert_length', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='string_to_delete', full_name='TSWP.UndoTransaction.TextTransaction.string_to_delete', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14020,
  serialized_end=14111,
)

_UNDOTRANSACTION_CHARINDEXTRANSACTION = _descriptor.Descriptor(
  name='CharIndexTransaction',
  full_name='TSWP.UndoTransaction.CharIndexTransaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='char_index', full_name='TSWP.UndoTransaction.CharIndexTransaction.char_index', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='count', full_name='TSWP.UndoTransaction.CharIndexTransaction.count', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='object', full_name='TSWP.UndoTransaction.CharIndexTransaction.object', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14113,
  serialized_end=14202,
)

_UNDOTRANSACTION_REPLACECHARINDEXTRANSACTION = _descriptor.Descriptor(
  name='ReplaceCharIndexTransaction',
  full_name='TSWP.UndoTransaction.ReplaceCharIndexTransaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='attribute_index', full_name='TSWP.UndoTransaction.ReplaceCharIndexTransaction.attribute_index', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='char_index', full_name='TSWP.UndoTransaction.ReplaceCharIndexTransaction.char_index', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14204,
  serialized_end=14278,
)

_UNDOTRANSACTION_ATTRIBUTEINDEXTRANSACTION = _descriptor.Descriptor(
  name='AttributeIndexTransaction',
  full_name='TSWP.UndoTransaction.AttributeIndexTransaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='attribute_index', full_name='TSWP.UndoTransaction.AttributeIndexTransaction.attribute_index', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='char_index', full_name='TSWP.UndoTransaction.AttributeIndexTransaction.char_index', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='object', full_name='TSWP.UndoTransaction.AttributeIndexTransaction.object', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='string', full_name='TSWP.UndoTransaction.AttributeIndexTransaction.string', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14280,
  serialized_end=14400,
)

_UNDOTRANSACTION_INSERTATTRIBUTETRANSACTION = _descriptor.Descriptor(
  name='InsertAttributeTransaction',
  full_name='TSWP.UndoTransaction.InsertAttributeTransaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='attribute_index', full_name='TSWP.UndoTransaction.InsertAttributeTransaction.attribute_index', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attribute_count', full_name='TSWP.UndoTransaction.InsertAttributeTransaction.attribute_count', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='object', full_name='TSWP.UndoTransaction.InsertAttributeTransaction.object', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='string', full_name='TSWP.UndoTransaction.InsertAttributeTransaction.string', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14402,
  serialized_end=14528,
)

_UNDOTRANSACTION_INSERTNILTRANSACTION = _descriptor.Descriptor(
  name='InsertNilTransaction',
  full_name='TSWP.UndoTransaction.InsertNilTransaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='attribute_index', full_name='TSWP.UndoTransaction.InsertNilTransaction.attribute_index', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attribute_count', full_name='TSWP.UndoTransaction.InsertNilTransaction.attribute_count', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14530,
  serialized_end=14602,
)

_UNDOTRANSACTION_CHARDELTATRANSACTION = _descriptor.Descriptor(
  name='CharDeltaTransaction',
  full_name='TSWP.UndoTransaction.CharDeltaTransaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='char_index', full_name='TSWP.UndoTransaction.CharDeltaTransaction.char_index', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attribute_index', full_name='TSWP.UndoTransaction.CharDeltaTransaction.attribute_index', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='char_delta', full_name='TSWP.UndoTransaction.CharDeltaTransaction.char_delta', index=2,
      number=3, type=17, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14604,
  serialized_end=14691,
)

_UNDOTRANSACTION_PARAGRAPHDATATRANSACTION = _descriptor.Descriptor(
  name='ParagraphDataTransaction',
  full_name='TSWP.UndoTransaction.ParagraphDataTransaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='attribute_index', full_name='TSWP.UndoTransaction.ParagraphDataTransaction.attribute_index', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='first', full_name='TSWP.UndoTransaction.ParagraphDataTransaction.first', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='second', full_name='TSWP.UndoTransaction.ParagraphDataTransaction.second', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='char_index', full_name='TSWP.UndoTransaction.ParagraphDataTransaction.char_index', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14693,
  serialized_end=14795,
)

_UNDOTRANSACTION_OBJECTDOLCTRANSACTION = _descriptor.Descriptor(
  name='ObjectDOLCTransaction',
  full_name='TSWP.UndoTransaction.ObjectDOLCTransaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='flags', full_name='TSWP.UndoTransaction.ObjectDOLCTransaction.flags', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='object', full_name='TSWP.UndoTransaction.ObjectDOLCTransaction.object', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14797,
  serialized_end=14867,
)

_UNDOTRANSACTION_CTDATETRANSACTION = _descriptor.Descriptor(
  name='CTDateTransaction',
  full_name='TSWP.UndoTransaction.CTDateTransaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='attribute_index', full_name='TSWP.UndoTransaction.CTDateTransaction.attribute_index', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='TSWP.UndoTransaction.CTDateTransaction.date', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14869,
  serialized_end=14938,
)

_UNDOTRANSACTION_UNIONTRANSACTION = _descriptor.Descriptor(
  name='UnionTransaction',
  full_name='TSWP.UndoTransaction.UnionTransaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='kind', full_name='TSWP.UndoTransaction.UnionTransaction.kind', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table', full_name='TSWP.UndoTransaction.UnionTransaction.table', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='generic', full_name='TSWP.UndoTransaction.UnionTransaction.generic', index=2,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text', full_name='TSWP.UndoTransaction.UnionTransaction.text', index=3,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='char_index', full_name='TSWP.UndoTransaction.UnionTransaction.char_index', index=4,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='replace_char_index', full_name='TSWP.UndoTransaction.UnionTransaction.replace_char_index', index=5,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attribute_index', full_name='TSWP.UndoTransaction.UnionTransaction.attribute_index', index=6,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='insert_nil', full_name='TSWP.UndoTransaction.UnionTransaction.insert_nil', index=7,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='insert_attribute', full_name='TSWP.UndoTransaction.UnionTransaction.insert_attribute', index=8,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='char_delta', full_name='TSWP.UndoTransaction.UnionTransaction.char_delta', index=9,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paragraph_data', full_name='TSWP.UndoTransaction.UnionTransaction.paragraph_data', index=10,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='object_dolc', full_name='TSWP.UndoTransaction.UnionTransaction.object_dolc', index=11,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ct_date', full_name='TSWP.UndoTransaction.UnionTransaction.ct_date', index=12,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14941,
  serialized_end=15749,
)

_UNDOTRANSACTION_STORAGEACTION = _descriptor.Descriptor(
  name='StorageAction',
  full_name='TSWP.UndoTransaction.StorageAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='kind', full_name='TSWP.UndoTransaction.StorageAction.kind', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='TSWP.UndoTransaction.StorageAction.flags', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table', full_name='TSWP.UndoTransaction.StorageAction.table', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range', full_name='TSWP.UndoTransaction.StorageAction.range', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='string', full_name='TSWP.UndoTransaction.StorageAction.string', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='object', full_name='TSWP.UndoTransaction.StorageAction.object', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='TSWP.UndoTransaction.StorageAction.date', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paragraph_level', full_name='TSWP.UndoTransaction.StorageAction.paragraph_level', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paragraph_flags', full_name='TSWP.UndoTransaction.StorageAction.paragraph_flags', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paragraph_value', full_name='TSWP.UndoTransaction.StorageAction.paragraph_value', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='placement_index', full_name='TSWP.UndoTransaction.StorageAction.placement_index', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='placement_uuid_path', full_name='TSWP.UndoTransaction.StorageAction.placement_uuid_path', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_object', full_name='TSWP.UndoTransaction.StorageAction.undo_object', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15752,
  serialized_end=16111,
)

_UNDOTRANSACTION_STORAGEACTIONGROUP = _descriptor.Descriptor(
  name='StorageActionGroup',
  full_name='TSWP.UndoTransaction.StorageActionGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='kind', full_name='TSWP.UndoTransaction.StorageActionGroup.kind', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='forward_actions', full_name='TSWP.UndoTransaction.StorageActionGroup.forward_actions', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inverse_forward_actions', full_name='TSWP.UndoTransaction.StorageActionGroup.inverse_forward_actions', index=2,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inverse_detail_actions', full_name='TSWP.UndoTransaction.StorageActionGroup.inverse_detail_actions', index=3,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16114,
  serialized_end=16388,
)

_UNDOTRANSACTION = _descriptor.Descriptor(
  name='UndoTransaction',
  full_name='TSWP.UndoTransaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='TSWP.UndoTransaction.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group_entries', full_name='TSWP.UndoTransaction.group_entries', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='TSWP.UndoTransaction.flags', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='TSWP.UndoTransaction.version', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_UNDOTRANSACTION_GENERICTRANSACTION, _UNDOTRANSACTION_TEXTTRANSACTION, _UNDOTRANSACTION_CHARINDEXTRANSACTION, _UNDOTRANSACTION_REPLACECHARINDEXTRANSACTION, _UNDOTRANSACTION_ATTRIBUTEINDEXTRANSACTION, _UNDOTRANSACTION_INSERTATTRIBUTETRANSACTION, _UNDOTRANSACTION_INSERTNILTRANSACTION, _UNDOTRANSACTION_CHARDELTATRANSACTION, _UNDOTRANSACTION_PARAGRAPHDATATRANSACTION, _UNDOTRANSACTION_OBJECTDOLCTRANSACTION, _UNDOTRANSACTION_CTDATETRANSACTION, _UNDOTRANSACTION_UNIONTRANSACTION, _UNDOTRANSACTION_STORAGEACTION, _UNDOTRANSACTION_STORAGEACTIONGROUP, ],
  enum_types=[
    _UNDOTRANSACTION_UNDOKIND,
    _UNDOTRANSACTION_ACTIONKIND,
    _UNDOTRANSACTION_ACTIONGROUPKIND,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13777,
  serialized_end=16794,
)


_UNDOTRANSACTIONWRAPPERARCHIVE = _descriptor.Descriptor(
  name='UndoTransactionWrapperArchive',
  full_name='TSWP.UndoTransactionWrapperArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='undo_transaction', full_name='TSWP.UndoTransactionWrapperArchive.undo_transaction', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16796,
  serialized_end=16876,
)


_SHAPEINFOARCHIVE = _descriptor.Descriptor(
  name='ShapeInfoArchive',
  full_name='TSWP.ShapeInfoArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.ShapeInfoArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated_storage', full_name='TSWP.ShapeInfoArchive.deprecated_storage', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text_flow', full_name='TSWP.ShapeInfoArchive.text_flow', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owned_storage', full_name='TSWP.ShapeInfoArchive.owned_storage', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_text_box', full_name='TSWP.ShapeInfoArchive.is_text_box', index=4,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16879,
  serialized_end=17074,
)


_COMMENTINFOARCHIVE = _descriptor.Descriptor(
  name='CommentInfoArchive',
  full_name='TSWP.CommentInfoArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.CommentInfoArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='comment_storage', full_name='TSWP.CommentInfoArchive.comment_storage', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17076,
  serialized_end=17176,
)


_TOCINFOARCHIVE = _descriptor.Descriptor(
  name='TOCInfoArchive',
  full_name='TSWP.TOCInfoArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.TOCInfoArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='toc_settings', full_name='TSWP.TOCInfoArchive.toc_settings', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='toc_entry_data', full_name='TSWP.TOCInfoArchive.toc_entry_data', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page_number_ranges', full_name='TSWP.TOCInfoArchive.page_number_ranges', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sync_toc_settings_with_toc_navigator', full_name='TSWP.TOCInfoArchive.sync_toc_settings_with_toc_navigator', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17179,
  serialized_end=17398,
)


_TOCLAYOUTHINTARCHIVE = _descriptor.Descriptor(
  name='TOCLayoutHintArchive',
  full_name='TSWP.TOCLayoutHintArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='charRange', full_name='TSWP.TOCLayoutHintArchive.charRange', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17400,
  serialized_end=17453,
)


_EQUATIONINFOARCHIVE = _descriptor.Descriptor(
  name='EquationInfoArchive',
  full_name='TSWP.EquationInfoArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
    _descriptor.FieldDescriptor(
      name='equation_source_old', full_name='TSWP.EquationInfoArchive.equation_source_old', index=0,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='equation_text_properties', full_name='TSWP.EquationInfoArchive.equation_text_properties', index=1,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='equation_depth', full_name='TSWP.EquationInfoArchive.equation_depth', index=2,
      number=102, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='equation_source_text', full_name='TSWP.EquationInfoArchive.equation_source_text', index=3,
      number=103, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17456,
  serialized_end=17709,
)


_TEXTUALATTACHMENTARCHIVE = _descriptor.Descriptor(
  name='TextualAttachmentArchive',
  full_name='TSWP.TextualAttachmentArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='string_equivalent', full_name='TSWP.TextualAttachmentArchive.string_equivalent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='kind', full_name='TSWP.TextualAttachmentArchive.kind', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TEXTUALATTACHMENTARCHIVE_KIND,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17712,
  serialized_end=17888,
)


_TSWPTOCPAGENUMBERATTACHMENTARCHIVE = _descriptor.Descriptor(
  name='TSWPTOCPageNumberAttachmentArchive',
  full_name='TSWP.TSWPTOCPageNumberAttachmentArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.TSWPTOCPageNumberAttachmentArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page_number', full_name='TSWP.TSWPTOCPageNumberAttachmentArchive.page_number', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bookmark_name', full_name='TSWP.TSWPTOCPageNumberAttachmentArchive.bookmark_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17890,
  serialized_end=18017,
)


_UIGRAPHICALATTACHMENT = _descriptor.Descriptor(
  name='UIGraphicalAttachment',
  full_name='TSWP.UIGraphicalAttachment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18019,
  serialized_end=18042,
)


_DRAWABLEATTACHMENTARCHIVE = _descriptor.Descriptor(
  name='DrawableAttachmentArchive',
  full_name='TSWP.DrawableAttachmentArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='drawable', full_name='TSWP.DrawableAttachmentArchive.drawable', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='h_offset_type', full_name='TSWP.DrawableAttachmentArchive.h_offset_type', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='h_offset', full_name='TSWP.DrawableAttachmentArchive.h_offset', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='v_offset_type', full_name='TSWP.DrawableAttachmentArchive.v_offset_type', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='v_offset', full_name='TSWP.DrawableAttachmentArchive.v_offset', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18045,
  serialized_end=18188,
)


_TOCATTACHMENTARCHIVE = _descriptor.Descriptor(
  name='TOCAttachmentArchive',
  full_name='TSWP.TOCAttachmentArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.TOCAttachmentArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18190,
  serialized_end=18260,
)


_FOOTNOTEREFERENCEATTACHMENTARCHIVE = _descriptor.Descriptor(
  name='FootnoteReferenceAttachmentArchive',
  full_name='TSWP.FootnoteReferenceAttachmentArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.FootnoteReferenceAttachmentArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='contained_storage', full_name='TSWP.FootnoteReferenceAttachmentArchive.contained_storage', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_mark_string', full_name='TSWP.FootnoteReferenceAttachmentArchive.custom_mark_string', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18263,
  serialized_end=18417,
)


_NUMBERATTACHMENTARCHIVE = _descriptor.Descriptor(
  name='NumberAttachmentArchive',
  full_name='TSWP.NumberAttachmentArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.NumberAttachmentArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='number_format', full_name='TSWP.NumberAttachmentArchive.number_format', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='string_value', full_name='TSWP.NumberAttachmentArchive.string_value', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='number_format_name', full_name='TSWP.NumberAttachmentArchive.number_format_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18420,
  serialized_end=18565,
)


_SMARTFIELDARCHIVE = _descriptor.Descriptor(
  name='SmartFieldArchive',
  full_name='TSWP.SmartFieldArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='text_attribute_uuid_string', full_name='TSWP.SmartFieldArchive.text_attribute_uuid_string', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18567,
  serialized_end=18622,
)


_HYPERLINKFIELDARCHIVE = _descriptor.Descriptor(
  name='HyperlinkFieldArchive',
  full_name='TSWP.HyperlinkFieldArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.HyperlinkFieldArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='url_ref', full_name='TSWP.HyperlinkFieldArchive.url_ref', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18624,
  serialized_end=18704,
)


_PLACEHOLDERSMARTFIELDARCHIVE = _descriptor.Descriptor(
  name='PlaceholderSmartFieldArchive',
  full_name='TSWP.PlaceholderSmartFieldArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.PlaceholderSmartFieldArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='localizable', full_name='TSWP.PlaceholderSmartFieldArchive.localizable', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='script_tag', full_name='TSWP.PlaceholderSmartFieldArchive.script_tag', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18706,
  serialized_end=18817,
)


_UNSUPPORTEDHYPERLINKFIELDARCHIVE = _descriptor.Descriptor(
  name='UnsupportedHyperlinkFieldArchive',
  full_name='TSWP.UnsupportedHyperlinkFieldArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.UnsupportedHyperlinkFieldArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='url_ref', full_name='TSWP.UnsupportedHyperlinkFieldArchive.url_ref', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='url_original_ref', full_name='TSWP.UnsupportedHyperlinkFieldArchive.url_original_ref', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18820,
  serialized_end=18948,
)


_BIBLIOGRAPHYSMARTFIELDARCHIVE = _descriptor.Descriptor(
  name='BibliographySmartFieldArchive',
  full_name='TSWP.BibliographySmartFieldArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.BibliographySmartFieldArchive.super', index=0,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='citation_records', full_name='TSWP.BibliographySmartFieldArchive.citation_records', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='localizable', full_name='TSWP.BibliographySmartFieldArchive.localizable', index=2,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_super', full_name='TSWP.BibliographySmartFieldArchive.old_super', index=3,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18951,
  serialized_end=19140,
)


_CITATIONRECORDARCHIVE = _descriptor.Descriptor(
  name='CitationRecordArchive',
  full_name='TSWP.CitationRecordArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='endnote_xml', full_name='TSWP.CitationRecordArchive.endnote_xml', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hide_author_names', full_name='TSWP.CitationRecordArchive.hide_author_names', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hide_year', full_name='TSWP.CitationRecordArchive.hide_year', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page_range', full_name='TSWP.CitationRecordArchive.page_range', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prefix', full_name='TSWP.CitationRecordArchive.prefix', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='suffix', full_name='TSWP.CitationRecordArchive.suffix', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='authors_string', full_name='TSWP.CitationRecordArchive.authors_string', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='title', full_name='TSWP.CitationRecordArchive.title', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='year', full_name='TSWP.CitationRecordArchive.year', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='TSWP.CitationRecordArchive.type', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19143,
  serialized_end=19352,
)


_CITATIONSMARTFIELDARCHIVE = _descriptor.Descriptor(
  name='CitationSmartFieldArchive',
  full_name='TSWP.CitationSmartFieldArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.CitationSmartFieldArchive.super', index=0,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='citation_records', full_name='TSWP.CitationSmartFieldArchive.citation_records', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='localizable', full_name='TSWP.CitationSmartFieldArchive.localizable', index=2,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_super', full_name='TSWP.CitationSmartFieldArchive.old_super', index=3,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19355,
  serialized_end=19540,
)


_DATETIMESMARTFIELDARCHIVE = _descriptor.Descriptor(
  name='DateTimeSmartFieldArchive',
  full_name='TSWP.DateTimeSmartFieldArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.DateTimeSmartFieldArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='format', full_name='TSWP.DateTimeSmartFieldArchive.format', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='locale_identifier', full_name='TSWP.DateTimeSmartFieldArchive.locale_identifier', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date_style', full_name='TSWP.DateTimeSmartFieldArchive.date_style', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_style', full_name='TSWP.DateTimeSmartFieldArchive.time_style', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update_plan', full_name='TSWP.DateTimeSmartFieldArchive.update_plan', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='needs_update', full_name='TSWP.DateTimeSmartFieldArchive.needs_update', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='TSWP.DateTimeSmartFieldArchive.date', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DATETIMESMARTFIELDARCHIVE_DATETIMEUPDATEPLAN,
    _DATETIMESMARTFIELDARCHIVE_DATETIMEFORMATTERSTYLE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19543,
  serialized_end=20230,
)


_BOOKMARKFIELDARCHIVE = _descriptor.Descriptor(
  name='BookmarkFieldArchive',
  full_name='TSWP.BookmarkFieldArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.BookmarkFieldArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='TSWP.BookmarkFieldArchive.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ranged', full_name='TSWP.BookmarkFieldArchive.ranged', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hidden', full_name='TSWP.BookmarkFieldArchive.hidden', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20232,
  serialized_end=20340,
)


_FILENAMESMARTFIELDARCHIVE = _descriptor.Descriptor(
  name='FilenameSmartFieldArchive',
  full_name='TSWP.FilenameSmartFieldArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.FilenameSmartFieldArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='display_flags', full_name='TSWP.FilenameSmartFieldArchive.display_flags', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20342,
  serialized_end=20443,
)


_MERGESMARTFIELDARCHIVE = _descriptor.Descriptor(
  name='MergeSmartFieldArchive',
  full_name='TSWP.MergeSmartFieldArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.MergeSmartFieldArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='property', full_name='TSWP.MergeSmartFieldArchive.property', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label', full_name='TSWP.MergeSmartFieldArchive.label', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='key', full_name='TSWP.MergeSmartFieldArchive.key', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category', full_name='TSWP.MergeSmartFieldArchive.category', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='requires_following_whitespace', full_name='TSWP.MergeSmartFieldArchive.requires_following_whitespace', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='whitespace', full_name='TSWP.MergeSmartFieldArchive.whitespace', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='guid', full_name='TSWP.MergeSmartFieldArchive.guid', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_field', full_name='TSWP.MergeSmartFieldArchive.table_field', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MERGESMARTFIELDARCHIVE_MERGECATEGORY,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20446,
  serialized_end=20786,
)


_TOCSMARTFIELDARCHIVE_TOCENTRY = _descriptor.Descriptor(
  name='TOCEntry',
  full_name='TSWP.TOCSmartFieldArchive.TOCEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='bookmark_name', full_name='TSWP.TOCSmartFieldArchive.TOCEntry.bookmark_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target_style', full_name='TSWP.TOCSmartFieldArchive.TOCEntry.target_style', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range', full_name='TSWP.TOCSmartFieldArchive.TOCEntry.range', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20922,
  serialized_end=21020,
)

_TOCSMARTFIELDARCHIVE = _descriptor.Descriptor(
  name='TOCSmartFieldArchive',
  full_name='TSWP.TOCSmartFieldArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.TOCSmartFieldArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='toc_entries', full_name='TSWP.TOCSmartFieldArchive.toc_entries', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_TOCSMARTFIELDARCHIVE_TOCENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20789,
  serialized_end=21020,
)


_RUBYFIELDARCHIVE = _descriptor.Descriptor(
  name='RubyFieldArchive',
  full_name='TSWP.RubyFieldArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.RubyFieldArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ruby_text', full_name='TSWP.RubyFieldArchive.ruby_text', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21022,
  serialized_end=21099,
)


_TATECHUYOKOFIELDARCHIVE = _descriptor.Descriptor(
  name='TateChuYokoFieldArchive',
  full_name='TSWP.TateChuYokoFieldArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.TateChuYokoFieldArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21101,
  serialized_end=21166,
)


_CHANGEARCHIVE = _descriptor.Descriptor(
  name='ChangeArchive',
  full_name='TSWP.ChangeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='kind', full_name='TSWP.ChangeArchive.kind', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='session', full_name='TSWP.ChangeArchive.session', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='TSWP.ChangeArchive.date', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text_attribute_uuid_string', full_name='TSWP.ChangeArchive.text_attribute_uuid_string', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CHANGEARCHIVE_CHANGEKIND,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21169,
  serialized_end=21389,
)


_CHANGESESSIONARCHIVE = _descriptor.Descriptor(
  name='ChangeSessionArchive',
  full_name='TSWP.ChangeSessionArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_uid', full_name='TSWP.ChangeSessionArchive.session_uid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='author', full_name='TSWP.ChangeSessionArchive.author', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='TSWP.ChangeSessionArchive.date', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21391,
  serialized_end=21491,
)


_SECTIONPLACEHOLDERARCHIVE = _descriptor.Descriptor(
  name='SectionPlaceholderArchive',
  full_name='TSWP.SectionPlaceholderArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent_storage', full_name='TSWP.SectionPlaceholderArchive.parent_storage', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21493,
  serialized_end=21560,
)


_HYPERLINKSELECTIONARCHIVE = _descriptor.Descriptor(
  name='HyperlinkSelectionArchive',
  full_name='TSWP.HyperlinkSelectionArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21562,
  serialized_end=21589,
)


_FLOWINFOARCHIVE = _descriptor.Descriptor(
  name='FlowInfoArchive',
  full_name='TSWP.FlowInfoArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='text_storage', full_name='TSWP.FlowInfoArchive.text_storage', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='textboxes', full_name='TSWP.FlowInfoArchive.textboxes', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_interface_identifier', full_name='TSWP.FlowInfoArchive.user_interface_identifier', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21591,
  serialized_end=21716,
)


_FLOWINFOCONTAINERARCHIVE = _descriptor.Descriptor(
  name='FlowInfoContainerArchive',
  full_name='TSWP.FlowInfoContainerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='flow_infos', full_name='TSWP.FlowInfoContainerArchive.flow_infos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next_user_interface_identifier', full_name='TSWP.FlowInfoContainerArchive.next_user_interface_identifier', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21718,
  serialized_end=21820,
)


_DROPCAPARCHIVE = _descriptor.Descriptor(
  name='DropCapArchive',
  full_name='TSWP.DropCapArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='TSWP.DropCapArchive.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='number_of_lines', full_name='TSWP.DropCapArchive.number_of_lines', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=3,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='number_of_raised_lines', full_name='TSWP.DropCapArchive.number_of_raised_lines', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated_outdent', full_name='TSWP.DropCapArchive.deprecated_outdent', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outdent', full_name='TSWP.DropCapArchive.outdent', index=4,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated_padding', full_name='TSWP.DropCapArchive.deprecated_padding', index=5,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='padding', full_name='TSWP.DropCapArchive.padding', index=6,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wrap_type', full_name='TSWP.DropCapArchive.wrap_type', index=7,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shape_enabled', full_name='TSWP.DropCapArchive.shape_enabled', index=8,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated_corner_radius', full_name='TSWP.DropCapArchive.deprecated_corner_radius', index=9,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='corner_radius', full_name='TSWP.DropCapArchive.corner_radius', index=10,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated_character_scale', full_name='TSWP.DropCapArchive.deprecated_character_scale', index=11,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='character_scale', full_name='TSWP.DropCapArchive.character_scale', index=12,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='number_of_characters', full_name='TSWP.DropCapArchive.number_of_characters', index=13,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DROPCAPARCHIVE_DROPCAPTYPE,
    _DROPCAPARCHIVE_DROPCAPWRAPTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21823,
  serialized_end=22479,
)


_DROPCAPSTYLEPROPERTIESARCHIVE = _descriptor.Descriptor(
  name='DropCapStylePropertiesArchive',
  full_name='TSWP.DropCapStylePropertiesArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='drop_cap', full_name='TSWP.DropCapStylePropertiesArchive.drop_cap', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='drop_cap_shape_stroke', full_name='TSWP.DropCapStylePropertiesArchive.drop_cap_shape_stroke', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='drop_cap_shape_fill_null', full_name='TSWP.DropCapStylePropertiesArchive.drop_cap_shape_fill_null', index=2,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='drop_cap_shape_fill', full_name='TSWP.DropCapStylePropertiesArchive.drop_cap_shape_fill', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22482,
  serialized_end=22685,
)


_DROPCAPSTYLEARCHIVE = _descriptor.Descriptor(
  name='DropCapStyleArchive',
  full_name='TSWP.DropCapStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.DropCapStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='override_count', full_name='TSWP.DropCapStyleArchive.override_count', index=1,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='char_properties', full_name='TSWP.DropCapStyleArchive.char_properties', index=2,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='drop_cap_properties', full_name='TSWP.DropCapStyleArchive.drop_cap_properties', index=3,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22688,
  serialized_end=22897,
)

_SELECTIONARCHIVE.fields_by_name['type'].enum_type = _SELECTIONTYPE
_SELECTIONARCHIVE.fields_by_name['range'].message_type = TSPMessages__pb2._RANGE
_SELECTIONARCHIVE.fields_by_name['styleInsertionBehavior'].enum_type = _STYLEINSERTIONBEHAVIOR
_SELECTIONARCHIVE.fields_by_name['caretAffinity'].enum_type = _CARETAFFINITY
_SELECTIONARCHIVE.fields_by_name['smart_field_range'].message_type = TSPMessages__pb2._RANGE
_OBJECTATTRIBUTETABLE_OBJECTATTRIBUTE.fields_by_name['object'].message_type = TSPMessages__pb2._REFERENCE
_OBJECTATTRIBUTETABLE_OBJECTATTRIBUTE.containing_type = _OBJECTATTRIBUTETABLE
_OBJECTATTRIBUTETABLE.fields_by_name['entries'].message_type = _OBJECTATTRIBUTETABLE_OBJECTATTRIBUTE
_STRINGATTRIBUTETABLE_STRINGATTRIBUTE.containing_type = _STRINGATTRIBUTETABLE
_STRINGATTRIBUTETABLE.fields_by_name['entries'].message_type = _STRINGATTRIBUTETABLE_STRINGATTRIBUTE
_PARADATAATTRIBUTETABLE_PARADATAATTRIBUTE.containing_type = _PARADATAATTRIBUTETABLE
_PARADATAATTRIBUTETABLE.fields_by_name['entries'].message_type = _PARADATAATTRIBUTETABLE_PARADATAATTRIBUTE
_OVERLAPPINGFIELDATTRIBUTETABLE_OVERLAPPINGFIELDATTRIBUTE.fields_by_name['range'].message_type = TSPMessages__pb2._RANGE
_OVERLAPPINGFIELDATTRIBUTETABLE_OVERLAPPINGFIELDATTRIBUTE.fields_by_name['field'].message_type = TSPMessages__pb2._REFERENCE
_OVERLAPPINGFIELDATTRIBUTETABLE_OVERLAPPINGFIELDATTRIBUTE.containing_type = _OVERLAPPINGFIELDATTRIBUTETABLE
_OVERLAPPINGFIELDATTRIBUTETABLE.fields_by_name['entries'].message_type = _OVERLAPPINGFIELDATTRIBUTETABLE_OVERLAPPINGFIELDATTRIBUTE
_STORAGEARCHIVE.fields_by_name['kind'].enum_type = _STORAGEARCHIVE_KINDTYPE
_STORAGEARCHIVE.fields_by_name['style_sheet'].message_type = TSPMessages__pb2._REFERENCE
_STORAGEARCHIVE.fields_by_name['table_para_style'].message_type = _OBJECTATTRIBUTETABLE
_STORAGEARCHIVE.fields_by_name['table_para_data'].message_type = _PARADATAATTRIBUTETABLE
_STORAGEARCHIVE.fields_by_name['table_list_style'].message_type = _OBJECTATTRIBUTETABLE
_STORAGEARCHIVE.fields_by_name['table_char_style'].message_type = _OBJECTATTRIBUTETABLE
_STORAGEARCHIVE.fields_by_name['table_attachment'].message_type = _OBJECTATTRIBUTETABLE
_STORAGEARCHIVE.fields_by_name['table_smartfield'].message_type = _OBJECTATTRIBUTETABLE
_STORAGEARCHIVE.fields_by_name['table_layout_style'].message_type = _OBJECTATTRIBUTETABLE
_STORAGEARCHIVE.fields_by_name['table_para_starts'].message_type = _PARADATAATTRIBUTETABLE
_STORAGEARCHIVE.fields_by_name['table_bookmark'].message_type = _OBJECTATTRIBUTETABLE
_STORAGEARCHIVE.fields_by_name['table_footnote'].message_type = _OBJECTATTRIBUTETABLE
_STORAGEARCHIVE.fields_by_name['table_section'].message_type = _OBJECTATTRIBUTETABLE
_STORAGEARCHIVE.fields_by_name['table_rubyfield'].message_type = _OBJECTATTRIBUTETABLE
_STORAGEARCHIVE.fields_by_name['table_language'].message_type = _STRINGATTRIBUTETABLE
_STORAGEARCHIVE.fields_by_name['table_dictation'].message_type = _STRINGATTRIBUTETABLE
_STORAGEARCHIVE.fields_by_name['table_insertion'].message_type = _OBJECTATTRIBUTETABLE
_STORAGEARCHIVE.fields_by_name['table_deletion'].message_type = _OBJECTATTRIBUTETABLE
_STORAGEARCHIVE.fields_by_name['table_highlight'].message_type = _OBJECTATTRIBUTETABLE
_STORAGEARCHIVE.fields_by_name['table_para_bidi'].message_type = _PARADATAATTRIBUTETABLE
_STORAGEARCHIVE.fields_by_name['table_overlapping_highlight'].message_type = _OVERLAPPINGFIELDATTRIBUTETABLE
_STORAGEARCHIVE.fields_by_name['table_pencil_annotation'].message_type = _OVERLAPPINGFIELDATTRIBUTETABLE
_STORAGEARCHIVE.fields_by_name['table_tatechuyoko'].message_type = _OBJECTATTRIBUTETABLE
_STORAGEARCHIVE.fields_by_name['table_drop_cap_style'].message_type = _OBJECTATTRIBUTETABLE
_STORAGEARCHIVE_KINDTYPE.containing_type = _STORAGEARCHIVE
_HIGHLIGHTARCHIVE.fields_by_name['commentStorage'].message_type = TSPMessages__pb2._REFERENCE
_PENCILANNOTATIONARCHIVE.fields_by_name['pencil_annotation_storage'].message_type = TSPMessages__pb2._REFERENCE
_CHARACTERSTYLEPROPERTIESARCHIVE.fields_by_name['font_color'].message_type = TSPMessages__pb2._COLOR
_CHARACTERSTYLEPROPERTIESARCHIVE.fields_by_name['superscript'].enum_type = _CHARACTERSTYLEPROPERTIESARCHIVE_SUPERSCRIPTTYPE
_CHARACTERSTYLEPROPERTIESARCHIVE.fields_by_name['underline'].enum_type = _CHARACTERSTYLEPROPERTIESARCHIVE_UNDERLINETYPE
_CHARACTERSTYLEPROPERTIESARCHIVE.fields_by_name['strikethru'].enum_type = _CHARACTERSTYLEPROPERTIESARCHIVE_STRIKETHRUTYPE
_CHARACTERSTYLEPROPERTIESARCHIVE.fields_by_name['capitalization'].enum_type = _CHARACTERSTYLEPROPERTIESARCHIVE_CAPITALIZATIONTYPE
_CHARACTERSTYLEPROPERTIESARCHIVE.fields_by_name['ligatures'].enum_type = _CHARACTERSTYLEPROPERTIESARCHIVE_LIGATURESTYPE
_CHARACTERSTYLEPROPERTIESARCHIVE.fields_by_name['outline_color'].message_type = TSPMessages__pb2._COLOR
_CHARACTERSTYLEPROPERTIESARCHIVE.fields_by_name['shadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARACTERSTYLEPROPERTIESARCHIVE.fields_by_name['strikethru_color'].message_type = TSPMessages__pb2._COLOR
_CHARACTERSTYLEPROPERTIESARCHIVE.fields_by_name['background_color'].message_type = TSPMessages__pb2._COLOR
_CHARACTERSTYLEPROPERTIESARCHIVE.fields_by_name['underline_color'].message_type = TSPMessages__pb2._COLOR
_CHARACTERSTYLEPROPERTIESARCHIVE.fields_by_name['font_features'].message_type = _FONTFEATUREARCHIVE
_CHARACTERSTYLEPROPERTIESARCHIVE.fields_by_name['writing_direction'].enum_type = _WRITINGDIRECTIONTYPE
_CHARACTERSTYLEPROPERTIESARCHIVE.fields_by_name['tsd_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARACTERSTYLEPROPERTIESARCHIVE.fields_by_name['tsd_fill'].message_type = TSDArchives__pb2._FILLARCHIVE
_CHARACTERSTYLEPROPERTIESARCHIVE_CAPITALIZATIONTYPE.containing_type = _CHARACTERSTYLEPROPERTIESARCHIVE
_CHARACTERSTYLEPROPERTIESARCHIVE_UNDERLINETYPE.containing_type = _CHARACTERSTYLEPROPERTIESARCHIVE
_CHARACTERSTYLEPROPERTIESARCHIVE_LIGATURESTYPE.containing_type = _CHARACTERSTYLEPROPERTIESARCHIVE
_CHARACTERSTYLEPROPERTIESARCHIVE_STRIKETHRUTYPE.containing_type = _CHARACTERSTYLEPROPERTIESARCHIVE
_CHARACTERSTYLEPROPERTIESARCHIVE_SUPERSCRIPTTYPE.containing_type = _CHARACTERSTYLEPROPERTIESARCHIVE
_CHARACTERSTYLEARCHIVE.fields_by_name['super'].message_type = TSSArchives__pb2._STYLEARCHIVE
_CHARACTERSTYLEARCHIVE.fields_by_name['char_properties'].message_type = _CHARACTERSTYLEPROPERTIESARCHIVE
_TABARCHIVE.fields_by_name['alignment'].enum_type = _TABARCHIVE_TABALIGNMENTTYPE
_TABARCHIVE_TABALIGNMENTTYPE.containing_type = _TABARCHIVE
_TABSARCHIVE.fields_by_name['tabs'].message_type = _TABARCHIVE
_LINESPACINGARCHIVE.fields_by_name['mode'].enum_type = _LINESPACINGARCHIVE_LINESPACINGMODETYPE
_LINESPACINGARCHIVE_LINESPACINGMODETYPE.containing_type = _LINESPACINGARCHIVE
_PARAGRAPHSTYLEPROPERTIESARCHIVE.fields_by_name['alignment'].enum_type = _PARAGRAPHSTYLEPROPERTIESARCHIVE_TEXTALIGNMENTTYPE
_PARAGRAPHSTYLEPROPERTIESARCHIVE.fields_by_name['fill'].message_type = TSPMessages__pb2._COLOR
_PARAGRAPHSTYLEPROPERTIESARCHIVE.fields_by_name['line_spacing'].message_type = _LINESPACINGARCHIVE
_PARAGRAPHSTYLEPROPERTIESARCHIVE.fields_by_name['borders'].enum_type = _PARAGRAPHSTYLEPROPERTIESARCHIVE_PARAGRAPHBORDERTYPE
_PARAGRAPHSTYLEPROPERTIESARCHIVE.fields_by_name['rule_offset'].message_type = TSPMessages__pb2._POINT
_PARAGRAPHSTYLEPROPERTIESARCHIVE.fields_by_name['tabs'].message_type = _TABSARCHIVE
_PARAGRAPHSTYLEPROPERTIESARCHIVE.fields_by_name['outline_style'].enum_type = _PARAGRAPHSTYLEPROPERTIESARCHIVE_OUTLINESTYLETYPE
_PARAGRAPHSTYLEPROPERTIESARCHIVE.fields_by_name['stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_PARAGRAPHSTYLEPROPERTIESARCHIVE.fields_by_name['writing_direction'].enum_type = _WRITINGDIRECTIONTYPE
_PARAGRAPHSTYLEPROPERTIESARCHIVE.fields_by_name['list_style'].message_type = TSPMessages__pb2._REFERENCE
_PARAGRAPHSTYLEPROPERTIESARCHIVE.fields_by_name['following_style'].message_type = TSPMessages__pb2._REFERENCE
_PARAGRAPHSTYLEPROPERTIESARCHIVE_TEXTALIGNMENTTYPE.containing_type = _PARAGRAPHSTYLEPROPERTIESARCHIVE
_PARAGRAPHSTYLEPROPERTIESARCHIVE_PARAGRAPHBORDERTYPE.containing_type = _PARAGRAPHSTYLEPROPERTIESARCHIVE
_PARAGRAPHSTYLEPROPERTIESARCHIVE_OUTLINESTYLETYPE.containing_type = _PARAGRAPHSTYLEPROPERTIESARCHIVE
_PARAGRAPHSTYLEARCHIVE.fields_by_name['super'].message_type = TSSArchives__pb2._STYLEARCHIVE
_PARAGRAPHSTYLEARCHIVE.fields_by_name['char_properties'].message_type = _CHARACTERSTYLEPROPERTIESARCHIVE
_PARAGRAPHSTYLEARCHIVE.fields_by_name['para_properties'].message_type = _PARAGRAPHSTYLEPROPERTIESARCHIVE
_LISTSTYLEARCHIVE_LABELGEOMETRY.containing_type = _LISTSTYLEARCHIVE
_LISTSTYLEARCHIVE_LABELIMAGE.fields_by_name['image'].message_type = TSPMessages__pb2._DATAREFERENCE
_LISTSTYLEARCHIVE_LABELIMAGE.fields_by_name['database_image'].message_type = TSPMessages__pb2._REFERENCE
_LISTSTYLEARCHIVE_LABELIMAGE.containing_type = _LISTSTYLEARCHIVE
_LISTSTYLEARCHIVE.fields_by_name['super'].message_type = TSSArchives__pb2._STYLEARCHIVE
_LISTSTYLEARCHIVE.fields_by_name['label_types'].enum_type = _LISTSTYLEARCHIVE_LABELTYPE
_LISTSTYLEARCHIVE.fields_by_name['geometries'].message_type = _LISTSTYLEARCHIVE_LABELGEOMETRY
_LISTSTYLEARCHIVE.fields_by_name['number_types'].enum_type = _LISTSTYLEARCHIVE_NUMBERTYPE
_LISTSTYLEARCHIVE.fields_by_name['images'].message_type = _LISTSTYLEARCHIVE_LABELIMAGE
_LISTSTYLEARCHIVE.fields_by_name['shadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_LISTSTYLEARCHIVE.fields_by_name['font_color'].message_type = TSPMessages__pb2._COLOR
_LISTSTYLEARCHIVE.fields_by_name['writing_direction'].enum_type = _WRITINGDIRECTIONTYPE
_LISTSTYLEARCHIVE_LABELTYPE.containing_type = _LISTSTYLEARCHIVE
_LISTSTYLEARCHIVE_NUMBERTYPE.containing_type = _LISTSTYLEARCHIVE
_TEXTSTYLEPRESETARCHIVE.fields_by_name['paragraph_style'].message_type = TSPMessages__pb2._REFERENCE
_TEXTSTYLEPRESETARCHIVE.fields_by_name['list_style'].message_type = TSPMessages__pb2._REFERENCE
_COLUMNSARCHIVE_EQUALCOLUMNSARCHIVE.containing_type = _COLUMNSARCHIVE
_COLUMNSARCHIVE_NONEQUALCOLUMNSARCHIVE_GAPWIDTHARCHIVE.containing_type = _COLUMNSARCHIVE_NONEQUALCOLUMNSARCHIVE
_COLUMNSARCHIVE_NONEQUALCOLUMNSARCHIVE.fields_by_name['following'].message_type = _COLUMNSARCHIVE_NONEQUALCOLUMNSARCHIVE_GAPWIDTHARCHIVE
_COLUMNSARCHIVE_NONEQUALCOLUMNSARCHIVE.containing_type = _COLUMNSARCHIVE
_COLUMNSARCHIVE.fields_by_name['equal_columns'].message_type = _COLUMNSARCHIVE_EQUALCOLUMNSARCHIVE
_COLUMNSARCHIVE.fields_by_name['non_equal_columns'].message_type = _COLUMNSARCHIVE_NONEQUALCOLUMNSARCHIVE
_COLUMNSTYLEPROPERTIESARCHIVE.fields_by_name['vertical_alignment'].enum_type = _COLUMNSTYLEPROPERTIESARCHIVE_VERTICALALIGNMENTTYPE
_COLUMNSTYLEPROPERTIESARCHIVE.fields_by_name['columns'].message_type = _COLUMNSARCHIVE
_COLUMNSTYLEPROPERTIESARCHIVE.fields_by_name['margins'].message_type = _PADDINGARCHIVE
_COLUMNSTYLEPROPERTIESARCHIVE.fields_by_name['padding'].message_type = _PADDINGARCHIVE
_COLUMNSTYLEPROPERTIESARCHIVE.fields_by_name['writing_direction'].enum_type = _WRITINGDIRECTIONTYPE
_COLUMNSTYLEPROPERTIESARCHIVE_VERTICALALIGNMENTTYPE.containing_type = _COLUMNSTYLEPROPERTIESARCHIVE
_COLUMNSTYLEARCHIVE.fields_by_name['super'].message_type = TSSArchives__pb2._STYLEARCHIVE
_COLUMNSTYLEARCHIVE.fields_by_name['column_properties'].message_type = _COLUMNSTYLEPROPERTIESARCHIVE
_SHAPESTYLEPROPERTIESARCHIVE.fields_by_name['vertical_alignment'].enum_type = _SHAPESTYLEPROPERTIESARCHIVE_VERTICALALIGNMENTTYPE
_SHAPESTYLEPROPERTIESARCHIVE.fields_by_name['columns'].message_type = _COLUMNSARCHIVE
_SHAPESTYLEPROPERTIESARCHIVE.fields_by_name['padding'].message_type = _PADDINGARCHIVE
_SHAPESTYLEPROPERTIESARCHIVE.fields_by_name['paragraph_style'].message_type = TSPMessages__pb2._REFERENCE
_SHAPESTYLEPROPERTIESARCHIVE_VERTICALALIGNMENTTYPE.containing_type = _SHAPESTYLEPROPERTIESARCHIVE
_SHAPESTYLEARCHIVE.fields_by_name['super'].message_type = TSDArchives__pb2._SHAPESTYLEARCHIVE
_SHAPESTYLEARCHIVE.fields_by_name['shape_properties'].message_type = _SHAPESTYLEPROPERTIESARCHIVE
_THEMEPRESETSARCHIVE.fields_by_name['list_style_presets'].message_type = TSPMessages__pb2._REFERENCE
_THEMEPRESETSARCHIVE.fields_by_name['text_style_presets'].message_type = TSPMessages__pb2._REFERENCE
_THEMEPRESETSARCHIVE.fields_by_name['imported_text_style_presets'].message_type = TSPMessages__pb2._REFERENCE
_THEMEPRESETSARCHIVE.fields_by_name['toc_entry_style_presets'].message_type = TSPMessages__pb2._REFERENCE
_THEMEPRESETSARCHIVE.fields_by_name['toc_settings_presets'].message_type = TSPMessages__pb2._REFERENCE
_THEMEPRESETSARCHIVE.fields_by_name['character_style_presets'].message_type = TSPMessages__pb2._REFERENCE
_THEMEPRESETSARCHIVE.fields_by_name['paragraph_style_presets'].message_type = TSPMessages__pb2._REFERENCE
_THEMEPRESETSARCHIVE.fields_by_name['dropcap_style_presets'].message_type = TSPMessages__pb2._REFERENCE
_TEXTPRESETDISPLAYITEMARCHIVE.fields_by_name['preset'].message_type = TSPMessages__pb2._REFERENCE
_TOCENTRYSTYLEPROPERTIESARCHIVE.fields_by_name['page_number_style'].message_type = TSPMessages__pb2._REFERENCE
_TOCENTRYSTYLEARCHIVE.fields_by_name['super'].message_type = _PARAGRAPHSTYLEARCHIVE
_TOCENTRYSTYLEARCHIVE.fields_by_name['toc_properties'].message_type = _TOCENTRYSTYLEPROPERTIESARCHIVE
_TOCSETTINGSARCHIVE_TOCENTRYDATA.fields_by_name['paragraph_style'].message_type = TSPMessages__pb2._REFERENCE
_TOCSETTINGSARCHIVE_TOCENTRYDATA.fields_by_name['toc_entry_style'].message_type = TSPMessages__pb2._REFERENCE
_TOCSETTINGSARCHIVE_TOCENTRYDATA.containing_type = _TOCSETTINGSARCHIVE
_TOCSETTINGSARCHIVE.fields_by_name['entries'].message_type = _TOCSETTINGSARCHIVE_TOCENTRYDATA
_TOCENTRYINSTANCEARCHIVE.fields_by_name['indexed_style'].message_type = TSPMessages__pb2._REFERENCE
_TOCENTRYINSTANCEARCHIVE.fields_by_name['indexed_list_style'].message_type = TSPMessages__pb2._REFERENCE
_UNDOTRANSACTION_GENERICTRANSACTION.containing_type = _UNDOTRANSACTION
_UNDOTRANSACTION_TEXTTRANSACTION.containing_type = _UNDOTRANSACTION
_UNDOTRANSACTION_CHARINDEXTRANSACTION.fields_by_name['object'].message_type = TSPMessages__pb2._REFERENCE
_UNDOTRANSACTION_CHARINDEXTRANSACTION.containing_type = _UNDOTRANSACTION
_UNDOTRANSACTION_REPLACECHARINDEXTRANSACTION.containing_type = _UNDOTRANSACTION
_UNDOTRANSACTION_ATTRIBUTEINDEXTRANSACTION.fields_by_name['object'].message_type = TSPMessages__pb2._REFERENCE
_UNDOTRANSACTION_ATTRIBUTEINDEXTRANSACTION.containing_type = _UNDOTRANSACTION
_UNDOTRANSACTION_INSERTATTRIBUTETRANSACTION.fields_by_name['object'].message_type = TSPMessages__pb2._REFERENCE
_UNDOTRANSACTION_INSERTATTRIBUTETRANSACTION.containing_type = _UNDOTRANSACTION
_UNDOTRANSACTION_INSERTNILTRANSACTION.containing_type = _UNDOTRANSACTION
_UNDOTRANSACTION_CHARDELTATRANSACTION.containing_type = _UNDOTRANSACTION
_UNDOTRANSACTION_PARAGRAPHDATATRANSACTION.containing_type = _UNDOTRANSACTION
_UNDOTRANSACTION_OBJECTDOLCTRANSACTION.fields_by_name['object'].message_type = TSPMessages__pb2._REFERENCE
_UNDOTRANSACTION_OBJECTDOLCTRANSACTION.containing_type = _UNDOTRANSACTION
_UNDOTRANSACTION_CTDATETRANSACTION.fields_by_name['date'].message_type = TSPMessages__pb2._DATE
_UNDOTRANSACTION_CTDATETRANSACTION.containing_type = _UNDOTRANSACTION
_UNDOTRANSACTION_UNIONTRANSACTION.fields_by_name['kind'].enum_type = _UNDOTRANSACTION_UNDOKIND
_UNDOTRANSACTION_UNIONTRANSACTION.fields_by_name['generic'].message_type = _UNDOTRANSACTION_GENERICTRANSACTION
_UNDOTRANSACTION_UNIONTRANSACTION.fields_by_name['text'].message_type = _UNDOTRANSACTION_TEXTTRANSACTION
_UNDOTRANSACTION_UNIONTRANSACTION.fields_by_name['char_index'].message_type = _UNDOTRANSACTION_CHARINDEXTRANSACTION
_UNDOTRANSACTION_UNIONTRANSACTION.fields_by_name['replace_char_index'].message_type = _UNDOTRANSACTION_REPLACECHARINDEXTRANSACTION
_UNDOTRANSACTION_UNIONTRANSACTION.fields_by_name['attribute_index'].message_type = _UNDOTRANSACTION_ATTRIBUTEINDEXTRANSACTION
_UNDOTRANSACTION_UNIONTRANSACTION.fields_by_name['insert_nil'].message_type = _UNDOTRANSACTION_INSERTNILTRANSACTION
_UNDOTRANSACTION_UNIONTRANSACTION.fields_by_name['insert_attribute'].message_type = _UNDOTRANSACTION_INSERTATTRIBUTETRANSACTION
_UNDOTRANSACTION_UNIONTRANSACTION.fields_by_name['char_delta'].message_type = _UNDOTRANSACTION_CHARDELTATRANSACTION
_UNDOTRANSACTION_UNIONTRANSACTION.fields_by_name['paragraph_data'].message_type = _UNDOTRANSACTION_PARAGRAPHDATATRANSACTION
_UNDOTRANSACTION_UNIONTRANSACTION.fields_by_name['object_dolc'].message_type = _UNDOTRANSACTION_OBJECTDOLCTRANSACTION
_UNDOTRANSACTION_UNIONTRANSACTION.fields_by_name['ct_date'].message_type = _UNDOTRANSACTION_CTDATETRANSACTION
_UNDOTRANSACTION_UNIONTRANSACTION.containing_type = _UNDOTRANSACTION
_UNDOTRANSACTION_STORAGEACTION.fields_by_name['kind'].enum_type = _UNDOTRANSACTION_ACTIONKIND
_UNDOTRANSACTION_STORAGEACTION.fields_by_name['range'].message_type = TSPMessages__pb2._RANGE
_UNDOTRANSACTION_STORAGEACTION.fields_by_name['object'].message_type = TSPMessages__pb2._REFERENCE
_UNDOTRANSACTION_STORAGEACTION.fields_by_name['date'].message_type = TSPMessages__pb2._DATE
_UNDOTRANSACTION_STORAGEACTION.fields_by_name['undo_object'].message_type = TSPMessages__pb2._REFERENCE
_UNDOTRANSACTION_STORAGEACTION.containing_type = _UNDOTRANSACTION
_UNDOTRANSACTION_STORAGEACTIONGROUP.fields_by_name['kind'].enum_type = _UNDOTRANSACTION_ACTIONGROUPKIND
_UNDOTRANSACTION_STORAGEACTIONGROUP.fields_by_name['forward_actions'].message_type = _UNDOTRANSACTION_STORAGEACTION
_UNDOTRANSACTION_STORAGEACTIONGROUP.fields_by_name['inverse_forward_actions'].message_type = _UNDOTRANSACTION_STORAGEACTION
_UNDOTRANSACTION_STORAGEACTIONGROUP.fields_by_name['inverse_detail_actions'].message_type = _UNDOTRANSACTION_STORAGEACTION
_UNDOTRANSACTION_STORAGEACTIONGROUP.containing_type = _UNDOTRANSACTION
_UNDOTRANSACTION.fields_by_name['entries'].message_type = _UNDOTRANSACTION_UNIONTRANSACTION
_UNDOTRANSACTION.fields_by_name['group_entries'].message_type = _UNDOTRANSACTION_STORAGEACTIONGROUP
_UNDOTRANSACTION_UNDOKIND.containing_type = _UNDOTRANSACTION
_UNDOTRANSACTION_ACTIONKIND.containing_type = _UNDOTRANSACTION
_UNDOTRANSACTION_ACTIONGROUPKIND.containing_type = _UNDOTRANSACTION
_UNDOTRANSACTIONWRAPPERARCHIVE.fields_by_name['undo_transaction'].message_type = _UNDOTRANSACTION
_SHAPEINFOARCHIVE.fields_by_name['super'].message_type = TSDArchives__pb2._SHAPEARCHIVE
_SHAPEINFOARCHIVE.fields_by_name['deprecated_storage'].message_type = TSPMessages__pb2._REFERENCE
_SHAPEINFOARCHIVE.fields_by_name['text_flow'].message_type = TSPMessages__pb2._REFERENCE
_SHAPEINFOARCHIVE.fields_by_name['owned_storage'].message_type = TSPMessages__pb2._REFERENCE
_COMMENTINFOARCHIVE.fields_by_name['super'].message_type = _SHAPEINFOARCHIVE
_COMMENTINFOARCHIVE.fields_by_name['comment_storage'].message_type = TSPMessages__pb2._REFERENCE
_TOCINFOARCHIVE.fields_by_name['super'].message_type = _SHAPEINFOARCHIVE
_TOCINFOARCHIVE.fields_by_name['toc_settings'].message_type = TSPMessages__pb2._REFERENCE
_TOCINFOARCHIVE.fields_by_name['toc_entry_data'].message_type = TSPMessages__pb2._REFERENCE
_TOCINFOARCHIVE.fields_by_name['page_number_ranges'].message_type = TSPMessages__pb2._RANGE
_TOCLAYOUTHINTARCHIVE.fields_by_name['charRange'].message_type = TSPMessages__pb2._RANGE
_TEXTUALATTACHMENTARCHIVE.fields_by_name['kind'].enum_type = _TEXTUALATTACHMENTARCHIVE_KIND
_TEXTUALATTACHMENTARCHIVE_KIND.containing_type = _TEXTUALATTACHMENTARCHIVE
_TSWPTOCPAGENUMBERATTACHMENTARCHIVE.fields_by_name['super'].message_type = _TEXTUALATTACHMENTARCHIVE
_DRAWABLEATTACHMENTARCHIVE.fields_by_name['drawable'].message_type = TSPMessages__pb2._REFERENCE
_TOCATTACHMENTARCHIVE.fields_by_name['super'].message_type = _DRAWABLEATTACHMENTARCHIVE
_FOOTNOTEREFERENCEATTACHMENTARCHIVE.fields_by_name['super'].message_type = _TEXTUALATTACHMENTARCHIVE
_FOOTNOTEREFERENCEATTACHMENTARCHIVE.fields_by_name['contained_storage'].message_type = TSPMessages__pb2._REFERENCE
_NUMBERATTACHMENTARCHIVE.fields_by_name['super'].message_type = _TEXTUALATTACHMENTARCHIVE
_HYPERLINKFIELDARCHIVE.fields_by_name['super'].message_type = _SMARTFIELDARCHIVE
_PLACEHOLDERSMARTFIELDARCHIVE.fields_by_name['super'].message_type = _SMARTFIELDARCHIVE
_UNSUPPORTEDHYPERLINKFIELDARCHIVE.fields_by_name['super'].message_type = _PLACEHOLDERSMARTFIELDARCHIVE
_BIBLIOGRAPHYSMARTFIELDARCHIVE.fields_by_name['super'].message_type = _SMARTFIELDARCHIVE
_BIBLIOGRAPHYSMARTFIELDARCHIVE.fields_by_name['citation_records'].message_type = TSPMessages__pb2._REFERENCE
_BIBLIOGRAPHYSMARTFIELDARCHIVE.fields_by_name['old_super'].message_type = _PLACEHOLDERSMARTFIELDARCHIVE
_CITATIONSMARTFIELDARCHIVE.fields_by_name['super'].message_type = _SMARTFIELDARCHIVE
_CITATIONSMARTFIELDARCHIVE.fields_by_name['citation_records'].message_type = TSPMessages__pb2._REFERENCE
_CITATIONSMARTFIELDARCHIVE.fields_by_name['old_super'].message_type = _PLACEHOLDERSMARTFIELDARCHIVE
_DATETIMESMARTFIELDARCHIVE.fields_by_name['super'].message_type = _SMARTFIELDARCHIVE
_DATETIMESMARTFIELDARCHIVE.fields_by_name['date_style'].enum_type = _DATETIMESMARTFIELDARCHIVE_DATETIMEFORMATTERSTYLE
_DATETIMESMARTFIELDARCHIVE.fields_by_name['time_style'].enum_type = _DATETIMESMARTFIELDARCHIVE_DATETIMEFORMATTERSTYLE
_DATETIMESMARTFIELDARCHIVE.fields_by_name['update_plan'].enum_type = _DATETIMESMARTFIELDARCHIVE_DATETIMEUPDATEPLAN
_DATETIMESMARTFIELDARCHIVE.fields_by_name['date'].message_type = TSPMessages__pb2._DATE
_DATETIMESMARTFIELDARCHIVE_DATETIMEUPDATEPLAN.containing_type = _DATETIMESMARTFIELDARCHIVE
_DATETIMESMARTFIELDARCHIVE_DATETIMEFORMATTERSTYLE.containing_type = _DATETIMESMARTFIELDARCHIVE
_BOOKMARKFIELDARCHIVE.fields_by_name['super'].message_type = _SMARTFIELDARCHIVE
_FILENAMESMARTFIELDARCHIVE.fields_by_name['super'].message_type = _PLACEHOLDERSMARTFIELDARCHIVE
_MERGESMARTFIELDARCHIVE.fields_by_name['super'].message_type = _PLACEHOLDERSMARTFIELDARCHIVE
_MERGESMARTFIELDARCHIVE.fields_by_name['category'].enum_type = _MERGESMARTFIELDARCHIVE_MERGECATEGORY
_MERGESMARTFIELDARCHIVE_MERGECATEGORY.containing_type = _MERGESMARTFIELDARCHIVE
_TOCSMARTFIELDARCHIVE_TOCENTRY.fields_by_name['target_style'].message_type = TSPMessages__pb2._REFERENCE
_TOCSMARTFIELDARCHIVE_TOCENTRY.fields_by_name['range'].message_type = TSPMessages__pb2._RANGE
_TOCSMARTFIELDARCHIVE_TOCENTRY.containing_type = _TOCSMARTFIELDARCHIVE
_TOCSMARTFIELDARCHIVE.fields_by_name['super'].message_type = _PLACEHOLDERSMARTFIELDARCHIVE
_TOCSMARTFIELDARCHIVE.fields_by_name['toc_entries'].message_type = _TOCSMARTFIELDARCHIVE_TOCENTRY
_RUBYFIELDARCHIVE.fields_by_name['super'].message_type = _SMARTFIELDARCHIVE
_TATECHUYOKOFIELDARCHIVE.fields_by_name['super'].message_type = _SMARTFIELDARCHIVE
_CHANGEARCHIVE.fields_by_name['kind'].enum_type = _CHANGEARCHIVE_CHANGEKIND
_CHANGEARCHIVE.fields_by_name['session'].message_type = TSPMessages__pb2._REFERENCE
_CHANGEARCHIVE.fields_by_name['date'].message_type = TSPMessages__pb2._DATE
_CHANGEARCHIVE_CHANGEKIND.containing_type = _CHANGEARCHIVE
_CHANGESESSIONARCHIVE.fields_by_name['author'].message_type = TSPMessages__pb2._REFERENCE
_CHANGESESSIONARCHIVE.fields_by_name['date'].message_type = TSPMessages__pb2._DATE
_SECTIONPLACEHOLDERARCHIVE.fields_by_name['parent_storage'].message_type = TSPMessages__pb2._REFERENCE
_FLOWINFOARCHIVE.fields_by_name['text_storage'].message_type = TSPMessages__pb2._REFERENCE
_FLOWINFOARCHIVE.fields_by_name['textboxes'].message_type = TSPMessages__pb2._REFERENCE
_FLOWINFOCONTAINERARCHIVE.fields_by_name['flow_infos'].message_type = TSPMessages__pb2._REFERENCE
_DROPCAPARCHIVE.fields_by_name['type'].enum_type = _DROPCAPARCHIVE_DROPCAPTYPE
_DROPCAPARCHIVE.fields_by_name['wrap_type'].enum_type = _DROPCAPARCHIVE_DROPCAPWRAPTYPE
_DROPCAPARCHIVE_DROPCAPTYPE.containing_type = _DROPCAPARCHIVE
_DROPCAPARCHIVE_DROPCAPWRAPTYPE.containing_type = _DROPCAPARCHIVE
_DROPCAPSTYLEPROPERTIESARCHIVE.fields_by_name['drop_cap'].message_type = _DROPCAPARCHIVE
_DROPCAPSTYLEPROPERTIESARCHIVE.fields_by_name['drop_cap_shape_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_DROPCAPSTYLEPROPERTIESARCHIVE.fields_by_name['drop_cap_shape_fill'].message_type = TSDArchives__pb2._FILLARCHIVE
_DROPCAPSTYLEARCHIVE.fields_by_name['super'].message_type = TSSArchives__pb2._STYLEARCHIVE
_DROPCAPSTYLEARCHIVE.fields_by_name['char_properties'].message_type = _CHARACTERSTYLEPROPERTIESARCHIVE
_DROPCAPSTYLEARCHIVE.fields_by_name['drop_cap_properties'].message_type = _DROPCAPSTYLEPROPERTIESARCHIVE
DESCRIPTOR.message_types_by_name['SelectionArchive'] = _SELECTIONARCHIVE
DESCRIPTOR.message_types_by_name['ObjectAttributeTable'] = _OBJECTATTRIBUTETABLE
DESCRIPTOR.message_types_by_name['StringAttributeTable'] = _STRINGATTRIBUTETABLE
DESCRIPTOR.message_types_by_name['ParaDataAttributeTable'] = _PARADATAATTRIBUTETABLE
DESCRIPTOR.message_types_by_name['OverlappingFieldAttributeTable'] = _OVERLAPPINGFIELDATTRIBUTETABLE
DESCRIPTOR.message_types_by_name['StorageArchive'] = _STORAGEARCHIVE
DESCRIPTOR.message_types_by_name['HighlightArchive'] = _HIGHLIGHTARCHIVE
DESCRIPTOR.message_types_by_name['PencilAnnotationArchive'] = _PENCILANNOTATIONARCHIVE
DESCRIPTOR.message_types_by_name['FontFeatureArchive'] = _FONTFEATUREARCHIVE
DESCRIPTOR.message_types_by_name['CharacterStylePropertiesArchive'] = _CHARACTERSTYLEPROPERTIESARCHIVE
DESCRIPTOR.message_types_by_name['CharacterStyleArchive'] = _CHARACTERSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['TabArchive'] = _TABARCHIVE
DESCRIPTOR.message_types_by_name['TabsArchive'] = _TABSARCHIVE
DESCRIPTOR.message_types_by_name['LineSpacingArchive'] = _LINESPACINGARCHIVE
DESCRIPTOR.message_types_by_name['ParagraphStylePropertiesArchive'] = _PARAGRAPHSTYLEPROPERTIESARCHIVE
DESCRIPTOR.message_types_by_name['ParagraphStyleArchive'] = _PARAGRAPHSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['ListStyleArchive'] = _LISTSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['TextStylePresetArchive'] = _TEXTSTYLEPRESETARCHIVE
DESCRIPTOR.message_types_by_name['ColumnsArchive'] = _COLUMNSARCHIVE
DESCRIPTOR.message_types_by_name['PaddingArchive'] = _PADDINGARCHIVE
DESCRIPTOR.message_types_by_name['ColumnStylePropertiesArchive'] = _COLUMNSTYLEPROPERTIESARCHIVE
DESCRIPTOR.message_types_by_name['ColumnStyleArchive'] = _COLUMNSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['ShapeStylePropertiesArchive'] = _SHAPESTYLEPROPERTIESARCHIVE
DESCRIPTOR.message_types_by_name['ShapeStyleArchive'] = _SHAPESTYLEARCHIVE
DESCRIPTOR.message_types_by_name['ThemePresetsArchive'] = _THEMEPRESETSARCHIVE
DESCRIPTOR.message_types_by_name['TextPresetDisplayItemArchive'] = _TEXTPRESETDISPLAYITEMARCHIVE
DESCRIPTOR.message_types_by_name['TOCEntryStylePropertiesArchive'] = _TOCENTRYSTYLEPROPERTIESARCHIVE
DESCRIPTOR.message_types_by_name['TOCEntryStyleArchive'] = _TOCENTRYSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['TOCSettingsArchive'] = _TOCSETTINGSARCHIVE
DESCRIPTOR.message_types_by_name['TOCEntryInstanceArchive'] = _TOCENTRYINSTANCEARCHIVE
DESCRIPTOR.message_types_by_name['UndoTransaction'] = _UNDOTRANSACTION
DESCRIPTOR.message_types_by_name['UndoTransactionWrapperArchive'] = _UNDOTRANSACTIONWRAPPERARCHIVE
DESCRIPTOR.message_types_by_name['ShapeInfoArchive'] = _SHAPEINFOARCHIVE
DESCRIPTOR.message_types_by_name['CommentInfoArchive'] = _COMMENTINFOARCHIVE
DESCRIPTOR.message_types_by_name['TOCInfoArchive'] = _TOCINFOARCHIVE
DESCRIPTOR.message_types_by_name['TOCLayoutHintArchive'] = _TOCLAYOUTHINTARCHIVE
DESCRIPTOR.message_types_by_name['EquationInfoArchive'] = _EQUATIONINFOARCHIVE
DESCRIPTOR.message_types_by_name['TextualAttachmentArchive'] = _TEXTUALATTACHMENTARCHIVE
DESCRIPTOR.message_types_by_name['TSWPTOCPageNumberAttachmentArchive'] = _TSWPTOCPAGENUMBERATTACHMENTARCHIVE
DESCRIPTOR.message_types_by_name['UIGraphicalAttachment'] = _UIGRAPHICALATTACHMENT
DESCRIPTOR.message_types_by_name['DrawableAttachmentArchive'] = _DRAWABLEATTACHMENTARCHIVE
DESCRIPTOR.message_types_by_name['TOCAttachmentArchive'] = _TOCATTACHMENTARCHIVE
DESCRIPTOR.message_types_by_name['FootnoteReferenceAttachmentArchive'] = _FOOTNOTEREFERENCEATTACHMENTARCHIVE
DESCRIPTOR.message_types_by_name['NumberAttachmentArchive'] = _NUMBERATTACHMENTARCHIVE
DESCRIPTOR.message_types_by_name['SmartFieldArchive'] = _SMARTFIELDARCHIVE
DESCRIPTOR.message_types_by_name['HyperlinkFieldArchive'] = _HYPERLINKFIELDARCHIVE
DESCRIPTOR.message_types_by_name['PlaceholderSmartFieldArchive'] = _PLACEHOLDERSMARTFIELDARCHIVE
DESCRIPTOR.message_types_by_name['UnsupportedHyperlinkFieldArchive'] = _UNSUPPORTEDHYPERLINKFIELDARCHIVE
DESCRIPTOR.message_types_by_name['BibliographySmartFieldArchive'] = _BIBLIOGRAPHYSMARTFIELDARCHIVE
DESCRIPTOR.message_types_by_name['CitationRecordArchive'] = _CITATIONRECORDARCHIVE
DESCRIPTOR.message_types_by_name['CitationSmartFieldArchive'] = _CITATIONSMARTFIELDARCHIVE
DESCRIPTOR.message_types_by_name['DateTimeSmartFieldArchive'] = _DATETIMESMARTFIELDARCHIVE
DESCRIPTOR.message_types_by_name['BookmarkFieldArchive'] = _BOOKMARKFIELDARCHIVE
DESCRIPTOR.message_types_by_name['FilenameSmartFieldArchive'] = _FILENAMESMARTFIELDARCHIVE
DESCRIPTOR.message_types_by_name['MergeSmartFieldArchive'] = _MERGESMARTFIELDARCHIVE
DESCRIPTOR.message_types_by_name['TOCSmartFieldArchive'] = _TOCSMARTFIELDARCHIVE
DESCRIPTOR.message_types_by_name['RubyFieldArchive'] = _RUBYFIELDARCHIVE
DESCRIPTOR.message_types_by_name['TateChuYokoFieldArchive'] = _TATECHUYOKOFIELDARCHIVE
DESCRIPTOR.message_types_by_name['ChangeArchive'] = _CHANGEARCHIVE
DESCRIPTOR.message_types_by_name['ChangeSessionArchive'] = _CHANGESESSIONARCHIVE
DESCRIPTOR.message_types_by_name['SectionPlaceholderArchive'] = _SECTIONPLACEHOLDERARCHIVE
DESCRIPTOR.message_types_by_name['HyperlinkSelectionArchive'] = _HYPERLINKSELECTIONARCHIVE
DESCRIPTOR.message_types_by_name['FlowInfoArchive'] = _FLOWINFOARCHIVE
DESCRIPTOR.message_types_by_name['FlowInfoContainerArchive'] = _FLOWINFOCONTAINERARCHIVE
DESCRIPTOR.message_types_by_name['DropCapArchive'] = _DROPCAPARCHIVE
DESCRIPTOR.message_types_by_name['DropCapStylePropertiesArchive'] = _DROPCAPSTYLEPROPERTIESARCHIVE
DESCRIPTOR.message_types_by_name['DropCapStyleArchive'] = _DROPCAPSTYLEARCHIVE
DESCRIPTOR.enum_types_by_name['SelectionType'] = _SELECTIONTYPE
DESCRIPTOR.enum_types_by_name['StyleInsertionBehavior'] = _STYLEINSERTIONBEHAVIOR
DESCRIPTOR.enum_types_by_name['CaretAffinity'] = _CARETAFFINITY
DESCRIPTOR.enum_types_by_name['WritingDirectionType'] = _WRITINGDIRECTIONTYPE
DESCRIPTOR.extensions_by_name['padding'] = padding
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SelectionArchive = _reflection.GeneratedProtocolMessageType('SelectionArchive', (_message.Message,), dict(
  DESCRIPTOR = _SELECTIONARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.SelectionArchive)
  ))
_sym_db.RegisterMessage(SelectionArchive)

ObjectAttributeTable = _reflection.GeneratedProtocolMessageType('ObjectAttributeTable', (_message.Message,), dict(

  ObjectAttribute = _reflection.GeneratedProtocolMessageType('ObjectAttribute', (_message.Message,), dict(
    DESCRIPTOR = _OBJECTATTRIBUTETABLE_OBJECTATTRIBUTE,
    __module__ = 'TSWPArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSWP.ObjectAttributeTable.ObjectAttribute)
    ))
  ,
  DESCRIPTOR = _OBJECTATTRIBUTETABLE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.ObjectAttributeTable)
  ))
_sym_db.RegisterMessage(ObjectAttributeTable)
_sym_db.RegisterMessage(ObjectAttributeTable.ObjectAttribute)

StringAttributeTable = _reflection.GeneratedProtocolMessageType('StringAttributeTable', (_message.Message,), dict(

  StringAttribute = _reflection.GeneratedProtocolMessageType('StringAttribute', (_message.Message,), dict(
    DESCRIPTOR = _STRINGATTRIBUTETABLE_STRINGATTRIBUTE,
    __module__ = 'TSWPArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSWP.StringAttributeTable.StringAttribute)
    ))
  ,
  DESCRIPTOR = _STRINGATTRIBUTETABLE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.StringAttributeTable)
  ))
_sym_db.RegisterMessage(StringAttributeTable)
_sym_db.RegisterMessage(StringAttributeTable.StringAttribute)

ParaDataAttributeTable = _reflection.GeneratedProtocolMessageType('ParaDataAttributeTable', (_message.Message,), dict(

  ParaDataAttribute = _reflection.GeneratedProtocolMessageType('ParaDataAttribute', (_message.Message,), dict(
    DESCRIPTOR = _PARADATAATTRIBUTETABLE_PARADATAATTRIBUTE,
    __module__ = 'TSWPArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSWP.ParaDataAttributeTable.ParaDataAttribute)
    ))
  ,
  DESCRIPTOR = _PARADATAATTRIBUTETABLE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.ParaDataAttributeTable)
  ))
_sym_db.RegisterMessage(ParaDataAttributeTable)
_sym_db.RegisterMessage(ParaDataAttributeTable.ParaDataAttribute)

OverlappingFieldAttributeTable = _reflection.GeneratedProtocolMessageType('OverlappingFieldAttributeTable', (_message.Message,), dict(

  OverlappingFieldAttribute = _reflection.GeneratedProtocolMessageType('OverlappingFieldAttribute', (_message.Message,), dict(
    DESCRIPTOR = _OVERLAPPINGFIELDATTRIBUTETABLE_OVERLAPPINGFIELDATTRIBUTE,
    __module__ = 'TSWPArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSWP.OverlappingFieldAttributeTable.OverlappingFieldAttribute)
    ))
  ,
  DESCRIPTOR = _OVERLAPPINGFIELDATTRIBUTETABLE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.OverlappingFieldAttributeTable)
  ))
_sym_db.RegisterMessage(OverlappingFieldAttributeTable)
_sym_db.RegisterMessage(OverlappingFieldAttributeTable.OverlappingFieldAttribute)

StorageArchive = _reflection.GeneratedProtocolMessageType('StorageArchive', (_message.Message,), dict(
  DESCRIPTOR = _STORAGEARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.StorageArchive)
  ))
_sym_db.RegisterMessage(StorageArchive)

HighlightArchive = _reflection.GeneratedProtocolMessageType('HighlightArchive', (_message.Message,), dict(
  DESCRIPTOR = _HIGHLIGHTARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.HighlightArchive)
  ))
_sym_db.RegisterMessage(HighlightArchive)

PencilAnnotationArchive = _reflection.GeneratedProtocolMessageType('PencilAnnotationArchive', (_message.Message,), dict(
  DESCRIPTOR = _PENCILANNOTATIONARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.PencilAnnotationArchive)
  ))
_sym_db.RegisterMessage(PencilAnnotationArchive)

FontFeatureArchive = _reflection.GeneratedProtocolMessageType('FontFeatureArchive', (_message.Message,), dict(
  DESCRIPTOR = _FONTFEATUREARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.FontFeatureArchive)
  ))
_sym_db.RegisterMessage(FontFeatureArchive)

CharacterStylePropertiesArchive = _reflection.GeneratedProtocolMessageType('CharacterStylePropertiesArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARACTERSTYLEPROPERTIESARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.CharacterStylePropertiesArchive)
  ))
_sym_db.RegisterMessage(CharacterStylePropertiesArchive)

CharacterStyleArchive = _reflection.GeneratedProtocolMessageType('CharacterStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARACTERSTYLEARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.CharacterStyleArchive)
  ))
_sym_db.RegisterMessage(CharacterStyleArchive)

TabArchive = _reflection.GeneratedProtocolMessageType('TabArchive', (_message.Message,), dict(
  DESCRIPTOR = _TABARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.TabArchive)
  ))
_sym_db.RegisterMessage(TabArchive)

TabsArchive = _reflection.GeneratedProtocolMessageType('TabsArchive', (_message.Message,), dict(
  DESCRIPTOR = _TABSARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.TabsArchive)
  ))
_sym_db.RegisterMessage(TabsArchive)

LineSpacingArchive = _reflection.GeneratedProtocolMessageType('LineSpacingArchive', (_message.Message,), dict(
  DESCRIPTOR = _LINESPACINGARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.LineSpacingArchive)
  ))
_sym_db.RegisterMessage(LineSpacingArchive)

ParagraphStylePropertiesArchive = _reflection.GeneratedProtocolMessageType('ParagraphStylePropertiesArchive', (_message.Message,), dict(
  DESCRIPTOR = _PARAGRAPHSTYLEPROPERTIESARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.ParagraphStylePropertiesArchive)
  ))
_sym_db.RegisterMessage(ParagraphStylePropertiesArchive)

ParagraphStyleArchive = _reflection.GeneratedProtocolMessageType('ParagraphStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _PARAGRAPHSTYLEARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.ParagraphStyleArchive)
  ))
_sym_db.RegisterMessage(ParagraphStyleArchive)

ListStyleArchive = _reflection.GeneratedProtocolMessageType('ListStyleArchive', (_message.Message,), dict(

  LabelGeometry = _reflection.GeneratedProtocolMessageType('LabelGeometry', (_message.Message,), dict(
    DESCRIPTOR = _LISTSTYLEARCHIVE_LABELGEOMETRY,
    __module__ = 'TSWPArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSWP.ListStyleArchive.LabelGeometry)
    ))
  ,

  LabelImage = _reflection.GeneratedProtocolMessageType('LabelImage', (_message.Message,), dict(
    DESCRIPTOR = _LISTSTYLEARCHIVE_LABELIMAGE,
    __module__ = 'TSWPArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSWP.ListStyleArchive.LabelImage)
    ))
  ,
  DESCRIPTOR = _LISTSTYLEARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.ListStyleArchive)
  ))
_sym_db.RegisterMessage(ListStyleArchive)
_sym_db.RegisterMessage(ListStyleArchive.LabelGeometry)
_sym_db.RegisterMessage(ListStyleArchive.LabelImage)

TextStylePresetArchive = _reflection.GeneratedProtocolMessageType('TextStylePresetArchive', (_message.Message,), dict(
  DESCRIPTOR = _TEXTSTYLEPRESETARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.TextStylePresetArchive)
  ))
_sym_db.RegisterMessage(TextStylePresetArchive)

ColumnsArchive = _reflection.GeneratedProtocolMessageType('ColumnsArchive', (_message.Message,), dict(

  EqualColumnsArchive = _reflection.GeneratedProtocolMessageType('EqualColumnsArchive', (_message.Message,), dict(
    DESCRIPTOR = _COLUMNSARCHIVE_EQUALCOLUMNSARCHIVE,
    __module__ = 'TSWPArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSWP.ColumnsArchive.EqualColumnsArchive)
    ))
  ,

  NonEqualColumnsArchive = _reflection.GeneratedProtocolMessageType('NonEqualColumnsArchive', (_message.Message,), dict(

    GapWidthArchive = _reflection.GeneratedProtocolMessageType('GapWidthArchive', (_message.Message,), dict(
      DESCRIPTOR = _COLUMNSARCHIVE_NONEQUALCOLUMNSARCHIVE_GAPWIDTHARCHIVE,
      __module__ = 'TSWPArchives_pb2'
      # @@protoc_insertion_point(class_scope:TSWP.ColumnsArchive.NonEqualColumnsArchive.GapWidthArchive)
      ))
    ,
    DESCRIPTOR = _COLUMNSARCHIVE_NONEQUALCOLUMNSARCHIVE,
    __module__ = 'TSWPArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSWP.ColumnsArchive.NonEqualColumnsArchive)
    ))
  ,
  DESCRIPTOR = _COLUMNSARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.ColumnsArchive)
  ))
_sym_db.RegisterMessage(ColumnsArchive)
_sym_db.RegisterMessage(ColumnsArchive.EqualColumnsArchive)
_sym_db.RegisterMessage(ColumnsArchive.NonEqualColumnsArchive)
_sym_db.RegisterMessage(ColumnsArchive.NonEqualColumnsArchive.GapWidthArchive)

PaddingArchive = _reflection.GeneratedProtocolMessageType('PaddingArchive', (_message.Message,), dict(
  DESCRIPTOR = _PADDINGARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.PaddingArchive)
  ))
_sym_db.RegisterMessage(PaddingArchive)

ColumnStylePropertiesArchive = _reflection.GeneratedProtocolMessageType('ColumnStylePropertiesArchive', (_message.Message,), dict(
  DESCRIPTOR = _COLUMNSTYLEPROPERTIESARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.ColumnStylePropertiesArchive)
  ))
_sym_db.RegisterMessage(ColumnStylePropertiesArchive)

ColumnStyleArchive = _reflection.GeneratedProtocolMessageType('ColumnStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _COLUMNSTYLEARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.ColumnStyleArchive)
  ))
_sym_db.RegisterMessage(ColumnStyleArchive)

ShapeStylePropertiesArchive = _reflection.GeneratedProtocolMessageType('ShapeStylePropertiesArchive', (_message.Message,), dict(
  DESCRIPTOR = _SHAPESTYLEPROPERTIESARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.ShapeStylePropertiesArchive)
  ))
_sym_db.RegisterMessage(ShapeStylePropertiesArchive)

ShapeStyleArchive = _reflection.GeneratedProtocolMessageType('ShapeStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _SHAPESTYLEARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.ShapeStyleArchive)
  ))
_sym_db.RegisterMessage(ShapeStyleArchive)

ThemePresetsArchive = _reflection.GeneratedProtocolMessageType('ThemePresetsArchive', (_message.Message,), dict(
  DESCRIPTOR = _THEMEPRESETSARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.ThemePresetsArchive)
  ))
_sym_db.RegisterMessage(ThemePresetsArchive)

TextPresetDisplayItemArchive = _reflection.GeneratedProtocolMessageType('TextPresetDisplayItemArchive', (_message.Message,), dict(
  DESCRIPTOR = _TEXTPRESETDISPLAYITEMARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.TextPresetDisplayItemArchive)
  ))
_sym_db.RegisterMessage(TextPresetDisplayItemArchive)

TOCEntryStylePropertiesArchive = _reflection.GeneratedProtocolMessageType('TOCEntryStylePropertiesArchive', (_message.Message,), dict(
  DESCRIPTOR = _TOCENTRYSTYLEPROPERTIESARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.TOCEntryStylePropertiesArchive)
  ))
_sym_db.RegisterMessage(TOCEntryStylePropertiesArchive)

TOCEntryStyleArchive = _reflection.GeneratedProtocolMessageType('TOCEntryStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _TOCENTRYSTYLEARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.TOCEntryStyleArchive)
  ))
_sym_db.RegisterMessage(TOCEntryStyleArchive)

TOCSettingsArchive = _reflection.GeneratedProtocolMessageType('TOCSettingsArchive', (_message.Message,), dict(

  TOCEntryData = _reflection.GeneratedProtocolMessageType('TOCEntryData', (_message.Message,), dict(
    DESCRIPTOR = _TOCSETTINGSARCHIVE_TOCENTRYDATA,
    __module__ = 'TSWPArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSWP.TOCSettingsArchive.TOCEntryData)
    ))
  ,
  DESCRIPTOR = _TOCSETTINGSARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.TOCSettingsArchive)
  ))
_sym_db.RegisterMessage(TOCSettingsArchive)
_sym_db.RegisterMessage(TOCSettingsArchive.TOCEntryData)

TOCEntryInstanceArchive = _reflection.GeneratedProtocolMessageType('TOCEntryInstanceArchive', (_message.Message,), dict(
  DESCRIPTOR = _TOCENTRYINSTANCEARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.TOCEntryInstanceArchive)
  ))
_sym_db.RegisterMessage(TOCEntryInstanceArchive)

UndoTransaction = _reflection.GeneratedProtocolMessageType('UndoTransaction', (_message.Message,), dict(

  GenericTransaction = _reflection.GeneratedProtocolMessageType('GenericTransaction', (_message.Message,), dict(
    DESCRIPTOR = _UNDOTRANSACTION_GENERICTRANSACTION,
    __module__ = 'TSWPArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSWP.UndoTransaction.GenericTransaction)
    ))
  ,

  TextTransaction = _reflection.GeneratedProtocolMessageType('TextTransaction', (_message.Message,), dict(
    DESCRIPTOR = _UNDOTRANSACTION_TEXTTRANSACTION,
    __module__ = 'TSWPArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSWP.UndoTransaction.TextTransaction)
    ))
  ,

  CharIndexTransaction = _reflection.GeneratedProtocolMessageType('CharIndexTransaction', (_message.Message,), dict(
    DESCRIPTOR = _UNDOTRANSACTION_CHARINDEXTRANSACTION,
    __module__ = 'TSWPArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSWP.UndoTransaction.CharIndexTransaction)
    ))
  ,

  ReplaceCharIndexTransaction = _reflection.GeneratedProtocolMessageType('ReplaceCharIndexTransaction', (_message.Message,), dict(
    DESCRIPTOR = _UNDOTRANSACTION_REPLACECHARINDEXTRANSACTION,
    __module__ = 'TSWPArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSWP.UndoTransaction.ReplaceCharIndexTransaction)
    ))
  ,

  AttributeIndexTransaction = _reflection.GeneratedProtocolMessageType('AttributeIndexTransaction', (_message.Message,), dict(
    DESCRIPTOR = _UNDOTRANSACTION_ATTRIBUTEINDEXTRANSACTION,
    __module__ = 'TSWPArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSWP.UndoTransaction.AttributeIndexTransaction)
    ))
  ,

  InsertAttributeTransaction = _reflection.GeneratedProtocolMessageType('InsertAttributeTransaction', (_message.Message,), dict(
    DESCRIPTOR = _UNDOTRANSACTION_INSERTATTRIBUTETRANSACTION,
    __module__ = 'TSWPArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSWP.UndoTransaction.InsertAttributeTransaction)
    ))
  ,

  InsertNilTransaction = _reflection.GeneratedProtocolMessageType('InsertNilTransaction', (_message.Message,), dict(
    DESCRIPTOR = _UNDOTRANSACTION_INSERTNILTRANSACTION,
    __module__ = 'TSWPArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSWP.UndoTransaction.InsertNilTransaction)
    ))
  ,

  CharDeltaTransaction = _reflection.GeneratedProtocolMessageType('CharDeltaTransaction', (_message.Message,), dict(
    DESCRIPTOR = _UNDOTRANSACTION_CHARDELTATRANSACTION,
    __module__ = 'TSWPArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSWP.UndoTransaction.CharDeltaTransaction)
    ))
  ,

  ParagraphDataTransaction = _reflection.GeneratedProtocolMessageType('ParagraphDataTransaction', (_message.Message,), dict(
    DESCRIPTOR = _UNDOTRANSACTION_PARAGRAPHDATATRANSACTION,
    __module__ = 'TSWPArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSWP.UndoTransaction.ParagraphDataTransaction)
    ))
  ,

  ObjectDOLCTransaction = _reflection.GeneratedProtocolMessageType('ObjectDOLCTransaction', (_message.Message,), dict(
    DESCRIPTOR = _UNDOTRANSACTION_OBJECTDOLCTRANSACTION,
    __module__ = 'TSWPArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSWP.UndoTransaction.ObjectDOLCTransaction)
    ))
  ,

  CTDateTransaction = _reflection.GeneratedProtocolMessageType('CTDateTransaction', (_message.Message,), dict(
    DESCRIPTOR = _UNDOTRANSACTION_CTDATETRANSACTION,
    __module__ = 'TSWPArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSWP.UndoTransaction.CTDateTransaction)
    ))
  ,

  UnionTransaction = _reflection.GeneratedProtocolMessageType('UnionTransaction', (_message.Message,), dict(
    DESCRIPTOR = _UNDOTRANSACTION_UNIONTRANSACTION,
    __module__ = 'TSWPArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSWP.UndoTransaction.UnionTransaction)
    ))
  ,

  StorageAction = _reflection.GeneratedProtocolMessageType('StorageAction', (_message.Message,), dict(
    DESCRIPTOR = _UNDOTRANSACTION_STORAGEACTION,
    __module__ = 'TSWPArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSWP.UndoTransaction.StorageAction)
    ))
  ,

  StorageActionGroup = _reflection.GeneratedProtocolMessageType('StorageActionGroup', (_message.Message,), dict(
    DESCRIPTOR = _UNDOTRANSACTION_STORAGEACTIONGROUP,
    __module__ = 'TSWPArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSWP.UndoTransaction.StorageActionGroup)
    ))
  ,
  DESCRIPTOR = _UNDOTRANSACTION,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.UndoTransaction)
  ))
_sym_db.RegisterMessage(UndoTransaction)
_sym_db.RegisterMessage(UndoTransaction.GenericTransaction)
_sym_db.RegisterMessage(UndoTransaction.TextTransaction)
_sym_db.RegisterMessage(UndoTransaction.CharIndexTransaction)
_sym_db.RegisterMessage(UndoTransaction.ReplaceCharIndexTransaction)
_sym_db.RegisterMessage(UndoTransaction.AttributeIndexTransaction)
_sym_db.RegisterMessage(UndoTransaction.InsertAttributeTransaction)
_sym_db.RegisterMessage(UndoTransaction.InsertNilTransaction)
_sym_db.RegisterMessage(UndoTransaction.CharDeltaTransaction)
_sym_db.RegisterMessage(UndoTransaction.ParagraphDataTransaction)
_sym_db.RegisterMessage(UndoTransaction.ObjectDOLCTransaction)
_sym_db.RegisterMessage(UndoTransaction.CTDateTransaction)
_sym_db.RegisterMessage(UndoTransaction.UnionTransaction)
_sym_db.RegisterMessage(UndoTransaction.StorageAction)
_sym_db.RegisterMessage(UndoTransaction.StorageActionGroup)

UndoTransactionWrapperArchive = _reflection.GeneratedProtocolMessageType('UndoTransactionWrapperArchive', (_message.Message,), dict(
  DESCRIPTOR = _UNDOTRANSACTIONWRAPPERARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.UndoTransactionWrapperArchive)
  ))
_sym_db.RegisterMessage(UndoTransactionWrapperArchive)

ShapeInfoArchive = _reflection.GeneratedProtocolMessageType('ShapeInfoArchive', (_message.Message,), dict(
  DESCRIPTOR = _SHAPEINFOARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.ShapeInfoArchive)
  ))
_sym_db.RegisterMessage(ShapeInfoArchive)

CommentInfoArchive = _reflection.GeneratedProtocolMessageType('CommentInfoArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMENTINFOARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.CommentInfoArchive)
  ))
_sym_db.RegisterMessage(CommentInfoArchive)

TOCInfoArchive = _reflection.GeneratedProtocolMessageType('TOCInfoArchive', (_message.Message,), dict(
  DESCRIPTOR = _TOCINFOARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.TOCInfoArchive)
  ))
_sym_db.RegisterMessage(TOCInfoArchive)

TOCLayoutHintArchive = _reflection.GeneratedProtocolMessageType('TOCLayoutHintArchive', (_message.Message,), dict(
  DESCRIPTOR = _TOCLAYOUTHINTARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.TOCLayoutHintArchive)
  ))
_sym_db.RegisterMessage(TOCLayoutHintArchive)

EquationInfoArchive = _reflection.GeneratedProtocolMessageType('EquationInfoArchive', (_message.Message,), dict(
  DESCRIPTOR = _EQUATIONINFOARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.EquationInfoArchive)
  ))
_sym_db.RegisterMessage(EquationInfoArchive)

TextualAttachmentArchive = _reflection.GeneratedProtocolMessageType('TextualAttachmentArchive', (_message.Message,), dict(
  DESCRIPTOR = _TEXTUALATTACHMENTARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.TextualAttachmentArchive)
  ))
_sym_db.RegisterMessage(TextualAttachmentArchive)

TSWPTOCPageNumberAttachmentArchive = _reflection.GeneratedProtocolMessageType('TSWPTOCPageNumberAttachmentArchive', (_message.Message,), dict(
  DESCRIPTOR = _TSWPTOCPAGENUMBERATTACHMENTARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.TSWPTOCPageNumberAttachmentArchive)
  ))
_sym_db.RegisterMessage(TSWPTOCPageNumberAttachmentArchive)

UIGraphicalAttachment = _reflection.GeneratedProtocolMessageType('UIGraphicalAttachment', (_message.Message,), dict(
  DESCRIPTOR = _UIGRAPHICALATTACHMENT,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.UIGraphicalAttachment)
  ))
_sym_db.RegisterMessage(UIGraphicalAttachment)

DrawableAttachmentArchive = _reflection.GeneratedProtocolMessageType('DrawableAttachmentArchive', (_message.Message,), dict(
  DESCRIPTOR = _DRAWABLEATTACHMENTARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.DrawableAttachmentArchive)
  ))
_sym_db.RegisterMessage(DrawableAttachmentArchive)

TOCAttachmentArchive = _reflection.GeneratedProtocolMessageType('TOCAttachmentArchive', (_message.Message,), dict(
  DESCRIPTOR = _TOCATTACHMENTARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.TOCAttachmentArchive)
  ))
_sym_db.RegisterMessage(TOCAttachmentArchive)

FootnoteReferenceAttachmentArchive = _reflection.GeneratedProtocolMessageType('FootnoteReferenceAttachmentArchive', (_message.Message,), dict(
  DESCRIPTOR = _FOOTNOTEREFERENCEATTACHMENTARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.FootnoteReferenceAttachmentArchive)
  ))
_sym_db.RegisterMessage(FootnoteReferenceAttachmentArchive)

NumberAttachmentArchive = _reflection.GeneratedProtocolMessageType('NumberAttachmentArchive', (_message.Message,), dict(
  DESCRIPTOR = _NUMBERATTACHMENTARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.NumberAttachmentArchive)
  ))
_sym_db.RegisterMessage(NumberAttachmentArchive)

SmartFieldArchive = _reflection.GeneratedProtocolMessageType('SmartFieldArchive', (_message.Message,), dict(
  DESCRIPTOR = _SMARTFIELDARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.SmartFieldArchive)
  ))
_sym_db.RegisterMessage(SmartFieldArchive)

HyperlinkFieldArchive = _reflection.GeneratedProtocolMessageType('HyperlinkFieldArchive', (_message.Message,), dict(
  DESCRIPTOR = _HYPERLINKFIELDARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.HyperlinkFieldArchive)
  ))
_sym_db.RegisterMessage(HyperlinkFieldArchive)

PlaceholderSmartFieldArchive = _reflection.GeneratedProtocolMessageType('PlaceholderSmartFieldArchive', (_message.Message,), dict(
  DESCRIPTOR = _PLACEHOLDERSMARTFIELDARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.PlaceholderSmartFieldArchive)
  ))
_sym_db.RegisterMessage(PlaceholderSmartFieldArchive)

UnsupportedHyperlinkFieldArchive = _reflection.GeneratedProtocolMessageType('UnsupportedHyperlinkFieldArchive', (_message.Message,), dict(
  DESCRIPTOR = _UNSUPPORTEDHYPERLINKFIELDARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.UnsupportedHyperlinkFieldArchive)
  ))
_sym_db.RegisterMessage(UnsupportedHyperlinkFieldArchive)

BibliographySmartFieldArchive = _reflection.GeneratedProtocolMessageType('BibliographySmartFieldArchive', (_message.Message,), dict(
  DESCRIPTOR = _BIBLIOGRAPHYSMARTFIELDARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.BibliographySmartFieldArchive)
  ))
_sym_db.RegisterMessage(BibliographySmartFieldArchive)

CitationRecordArchive = _reflection.GeneratedProtocolMessageType('CitationRecordArchive', (_message.Message,), dict(
  DESCRIPTOR = _CITATIONRECORDARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.CitationRecordArchive)
  ))
_sym_db.RegisterMessage(CitationRecordArchive)

CitationSmartFieldArchive = _reflection.GeneratedProtocolMessageType('CitationSmartFieldArchive', (_message.Message,), dict(
  DESCRIPTOR = _CITATIONSMARTFIELDARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.CitationSmartFieldArchive)
  ))
_sym_db.RegisterMessage(CitationSmartFieldArchive)

DateTimeSmartFieldArchive = _reflection.GeneratedProtocolMessageType('DateTimeSmartFieldArchive', (_message.Message,), dict(
  DESCRIPTOR = _DATETIMESMARTFIELDARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.DateTimeSmartFieldArchive)
  ))
_sym_db.RegisterMessage(DateTimeSmartFieldArchive)

BookmarkFieldArchive = _reflection.GeneratedProtocolMessageType('BookmarkFieldArchive', (_message.Message,), dict(
  DESCRIPTOR = _BOOKMARKFIELDARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.BookmarkFieldArchive)
  ))
_sym_db.RegisterMessage(BookmarkFieldArchive)

FilenameSmartFieldArchive = _reflection.GeneratedProtocolMessageType('FilenameSmartFieldArchive', (_message.Message,), dict(
  DESCRIPTOR = _FILENAMESMARTFIELDARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.FilenameSmartFieldArchive)
  ))
_sym_db.RegisterMessage(FilenameSmartFieldArchive)

MergeSmartFieldArchive = _reflection.GeneratedProtocolMessageType('MergeSmartFieldArchive', (_message.Message,), dict(
  DESCRIPTOR = _MERGESMARTFIELDARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.MergeSmartFieldArchive)
  ))
_sym_db.RegisterMessage(MergeSmartFieldArchive)

TOCSmartFieldArchive = _reflection.GeneratedProtocolMessageType('TOCSmartFieldArchive', (_message.Message,), dict(

  TOCEntry = _reflection.GeneratedProtocolMessageType('TOCEntry', (_message.Message,), dict(
    DESCRIPTOR = _TOCSMARTFIELDARCHIVE_TOCENTRY,
    __module__ = 'TSWPArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSWP.TOCSmartFieldArchive.TOCEntry)
    ))
  ,
  DESCRIPTOR = _TOCSMARTFIELDARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.TOCSmartFieldArchive)
  ))
_sym_db.RegisterMessage(TOCSmartFieldArchive)
_sym_db.RegisterMessage(TOCSmartFieldArchive.TOCEntry)

RubyFieldArchive = _reflection.GeneratedProtocolMessageType('RubyFieldArchive', (_message.Message,), dict(
  DESCRIPTOR = _RUBYFIELDARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.RubyFieldArchive)
  ))
_sym_db.RegisterMessage(RubyFieldArchive)

TateChuYokoFieldArchive = _reflection.GeneratedProtocolMessageType('TateChuYokoFieldArchive', (_message.Message,), dict(
  DESCRIPTOR = _TATECHUYOKOFIELDARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.TateChuYokoFieldArchive)
  ))
_sym_db.RegisterMessage(TateChuYokoFieldArchive)

ChangeArchive = _reflection.GeneratedProtocolMessageType('ChangeArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHANGEARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.ChangeArchive)
  ))
_sym_db.RegisterMessage(ChangeArchive)

ChangeSessionArchive = _reflection.GeneratedProtocolMessageType('ChangeSessionArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHANGESESSIONARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.ChangeSessionArchive)
  ))
_sym_db.RegisterMessage(ChangeSessionArchive)

SectionPlaceholderArchive = _reflection.GeneratedProtocolMessageType('SectionPlaceholderArchive', (_message.Message,), dict(
  DESCRIPTOR = _SECTIONPLACEHOLDERARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.SectionPlaceholderArchive)
  ))
_sym_db.RegisterMessage(SectionPlaceholderArchive)

HyperlinkSelectionArchive = _reflection.GeneratedProtocolMessageType('HyperlinkSelectionArchive', (_message.Message,), dict(
  DESCRIPTOR = _HYPERLINKSELECTIONARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.HyperlinkSelectionArchive)
  ))
_sym_db.RegisterMessage(HyperlinkSelectionArchive)

FlowInfoArchive = _reflection.GeneratedProtocolMessageType('FlowInfoArchive', (_message.Message,), dict(
  DESCRIPTOR = _FLOWINFOARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.FlowInfoArchive)
  ))
_sym_db.RegisterMessage(FlowInfoArchive)

FlowInfoContainerArchive = _reflection.GeneratedProtocolMessageType('FlowInfoContainerArchive', (_message.Message,), dict(
  DESCRIPTOR = _FLOWINFOCONTAINERARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.FlowInfoContainerArchive)
  ))
_sym_db.RegisterMessage(FlowInfoContainerArchive)

DropCapArchive = _reflection.GeneratedProtocolMessageType('DropCapArchive', (_message.Message,), dict(
  DESCRIPTOR = _DROPCAPARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.DropCapArchive)
  ))
_sym_db.RegisterMessage(DropCapArchive)

DropCapStylePropertiesArchive = _reflection.GeneratedProtocolMessageType('DropCapStylePropertiesArchive', (_message.Message,), dict(
  DESCRIPTOR = _DROPCAPSTYLEPROPERTIESARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.DropCapStylePropertiesArchive)
  ))
_sym_db.RegisterMessage(DropCapStylePropertiesArchive)

DropCapStyleArchive = _reflection.GeneratedProtocolMessageType('DropCapStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _DROPCAPSTYLEARCHIVE,
  __module__ = 'TSWPArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.DropCapStyleArchive)
  ))
_sym_db.RegisterMessage(DropCapStyleArchive)

padding.message_type = _PADDINGARCHIVE
TSSArchives__pb2.CommandPropertyEntryArchive.RegisterExtension(padding)
_THEMEPRESETSARCHIVE.extensions_by_name['extension'].message_type = _THEMEPRESETSARCHIVE
TSSArchives__pb2.ThemeArchive.RegisterExtension(_THEMEPRESETSARCHIVE.extensions_by_name['extension'])
TSDArchives__pb2.ImageArchive.RegisterExtension(_EQUATIONINFOARCHIVE.extensions_by_name['equation_source_old'])
_EQUATIONINFOARCHIVE.extensions_by_name['equation_text_properties'].message_type = _CHARACTERSTYLEPROPERTIESARCHIVE
TSDArchives__pb2.ImageArchive.RegisterExtension(_EQUATIONINFOARCHIVE.extensions_by_name['equation_text_properties'])
TSDArchives__pb2.ImageArchive.RegisterExtension(_EQUATIONINFOARCHIVE.extensions_by_name['equation_depth'])
TSDArchives__pb2.ImageArchive.RegisterExtension(_EQUATIONINFOARCHIVE.extensions_by_name['equation_source_text'])

_SHAPEINFOARCHIVE.fields_by_name['deprecated_storage']._options = None
# @@protoc_insertion_point(module_scope)
