from __future__ import absolute_import
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: TSCEArchives.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import TSPMessages_pb2 as TSPMessages__pb2
from . import TSKArchives_pb2 as TSKArchives__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='TSCEArchives.proto',
  package='TSCE',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x12TSCEArchives.proto\x12\x04TSCE\x1a\x11TSPMessages.proto\x1a\x11TSKArchives.proto\"Y\n\x14\x43\x65llReferenceArchive\x12\x0e\n\x06\x63olumn\x18\x01 \x02(\r\x12\x0b\n\x03row\x18\x02 \x02(\r\x12$\n\x08table_id\x18\x03 \x02(\x0b\x32\x12.TSP.CFUUIDArchive\"a\n\x1cInternalCellReferenceArchive\x12/\n\ncoordinate\x18\x01 \x02(\x0b\x32\x1b.TSCE.CellCoordinateArchive\x12\x10\n\x08owner_id\x18\x02 \x02(\r\"\xa3\x01\n\x15RangeReferenceArchive\x12$\n\x08table_id\x18\x01 \x02(\x0b\x32\x12.TSP.CFUUIDArchive\x12\x17\n\x0ftop_left_column\x18\x02 \x02(\r\x12\x14\n\x0ctop_left_row\x18\x03 \x02(\r\x12\x1b\n\x13\x62ottom_right_column\x18\x04 \x02(\r\x12\x18\n\x10\x62ottom_right_row\x18\x05 \x02(\r\"^\n\x1dInternalRangeReferenceArchive\x12\x10\n\x08owner_id\x18\x01 \x02(\r\x12+\n\x05range\x18\x02 \x02(\x0b\x32\x1c.TSCE.RangeCoordinateArchive\"\x80\x01\n\x0fIndexSetArchive\x12\x34\n\x07\x65ntries\x18\x01 \x03(\x0b\x32#.TSCE.IndexSetArchive.IndexSetEntry\x1a\x37\n\rIndexSetEntry\x12\x13\n\x0brange_begin\x18\x01 \x02(\x05\x12\x11\n\trange_end\x18\x02 \x01(\x05\"\x9b\x01\n\x13\x43\x65llCoordSetArchive\x12=\n\x0e\x63olumn_entries\x18\x01 \x03(\x0b\x32%.TSCE.CellCoordSetArchive.ColumnEntry\x1a\x45\n\x0b\x43olumnEntry\x12\x0e\n\x06\x63olumn\x18\x01 \x02(\r\x12&\n\x07row_set\x18\x02 \x02(\x0b\x32\x15.TSCE.IndexSetArchive\"\xac\x01\n\x19InternalCellRefSetArchive\x12\x41\n\rowner_entries\x18\x01 \x03(\x0b\x32*.TSCE.InternalCellRefSetArchive.OwnerEntry\x1aL\n\nOwnerEntry\x12\x10\n\x08owner_id\x18\x01 \x02(\r\x12,\n\tcoord_set\x18\x02 \x02(\x0b\x32\x19.TSCE.CellCoordSetArchive\"<\n\rColumnRowSize\x12\x16\n\x0bnum_columns\x18\x01 \x01(\r:\x01\x31\x12\x13\n\x08num_rows\x18\x02 \x01(\r:\x01\x31\"a\n\x0f\x43\x65llRectArchive\x12+\n\x06origin\x18\x01 \x02(\x0b\x32\x1b.TSCE.CellCoordinateArchive\x12!\n\x04size\x18\x02 \x02(\x0b\x32\x13.TSCE.ColumnRowSize\"\xa8\x01\n\x11\x43\x65llRefSetArchive\x12\x39\n\rowner_entries\x18\x01 \x03(\x0b\x32\".TSCE.CellRefSetArchive.OwnerEntry\x1aX\n\nOwnerEntry\x12\x1c\n\towner_uid\x18\x01 \x02(\x0b\x32\t.TSP.UUID\x12,\n\tcoord_set\x18\x02 \x02(\x0b\x32\x19.TSCE.CellCoordSetArchive\"\x98\x01\n\x12UidCoordSetArchive\x12<\n\x0e\x63olumn_entries\x18\x01 \x03(\x0b\x32$.TSCE.UidCoordSetArchive.ColumnEntry\x1a\x44\n\x0b\x43olumnEntry\x12\x19\n\x06\x63olumn\x18\x01 \x02(\x0b\x32\t.TSP.UUID\x12\x1a\n\x07row_set\x18\x02 \x03(\x0b\x32\t.TSP.UUID\"\xad\x01\n\x14UidCellRefSetArchive\x12<\n\rowner_entries\x18\x01 \x03(\x0b\x32%.TSCE.UidCellRefSetArchive.OwnerEntry\x1aW\n\nOwnerEntry\x12\x1c\n\towner_uid\x18\x01 \x02(\x0b\x32\t.TSP.UUID\x12+\n\tcoord_set\x18\x02 \x02(\x0b\x32\x18.TSCE.UidCoordSetArchive\"\xcd\x02\n\x18ReferencesToDirtyArchive\x12\x31\n\x12to_dirty_owner_ids\x18\x01 \x01(\x0b\x32\x15.TSCE.IndexSetArchive\x12\x37\n\x0eto_dirty_cells\x18\x02 \x01(\x0b\x32\x1f.TSCE.InternalCellRefSetArchive\x12\x42\n\x19to_dirty_cells_additional\x18\x03 \x01(\x0b\x32\x1f.TSCE.InternalCellRefSetArchive\x12@\n\x13to_dirty_range_refs\x18\x04 \x03(\x0b\x32#.TSCE.InternalRangeReferenceArchive\x12?\n\x16\x63\x61lc_in_progress_cells\x18\x06 \x01(\x0b\x32\x1f.TSCE.InternalCellRefSetArchive\"\xe8\x01\n\x12\x43oordMapperArchive\x12\x39\n\x1asummary_and_label_rows_set\x18\x01 \x01(\x0b\x32\x15.TSCE.IndexSetArchive\x12\x1c\n\ttable_uid\x18\x02 \x02(\x0b\x32\t.TSP.UUID\x12\x42\n\x10\x62\x61se_to_view_map\x18\x03 \x03(\x0b\x32(.TSCE.CoordMapperArchive.BaseToViewEntry\x1a\x35\n\x0f\x42\x61seToViewEntry\x12\x10\n\x08\x62\x61se_row\x18\x01 \x02(\r\x12\x10\n\x08view_row\x18\x02 \x02(\r\"\x89\x02\n\x10ReferenceArchive\x12<\n\x0ereference_type\x18\x01 \x02(\x0e\x32$.TSCE.ReferenceArchive.ReferenceType\x12\x32\n\x0e\x63\x65ll_reference\x18\x02 \x01(\x0b\x32\x1a.TSCE.CellReferenceArchive\x12\x34\n\x0frange_reference\x18\x03 \x01(\x0b\x32\x1b.TSCE.RangeReferenceArchive\"M\n\rReferenceType\x12\x12\n\x0e\x43\x45LL_REFERENCE\x10\x01\x12\x13\n\x0fRANGE_REFERENCE\x10\x02\x12\x13\n\x0fNAME_DEPENDENCY\x10\x03\"f\n\x0b\x45\x64geArchive\x12\x0e\n\x06\x63olumn\x18\x01 \x02(\r\x12\x0b\n\x03row\x18\x02 \x02(\r\x12\x14\n\x0cis_precedent\x18\x03 \x02(\x08\x12$\n\x08owner_id\x18\x04 \x01(\x0b\x32\x12.TSP.CFUUIDArchive\"\xa4\x01\n\x0c\x45\x64gesArchive\x12!\n\x19packed_edge_without_owner\x18\t \x03(\r\x12\x1e\n\x16packed_edge_with_owner\x18\n \x03(\r\x12-\n\x11owner_id_for_edge\x18\x0b \x03(\x0b\x32\x12.TSP.CFUUIDArchive\x12\"\n\x1ainternal_owner_id_for_edge\x18\x0c \x03(\r\"\xbe\x01\n\x14\x45xpandedEdgesArchive\x12\x1f\n\x17\x65\x64ge_without_owner_rows\x18\x01 \x03(\r\x12\"\n\x1a\x65\x64ge_without_owner_columns\x18\x02 \x03(\r\x12\x1c\n\x14\x65\x64ge_with_owner_rows\x18\x03 \x03(\r\x12\x1f\n\x17\x65\x64ge_with_owner_columns\x18\x04 \x03(\r\x12\"\n\x1ainternal_owner_id_for_edge\x18\x05 \x03(\r\"\xe2\x02\n\x11\x43\x65llRecordArchive\x12\x0e\n\x06\x63olumn\x18\x01 \x02(\r\x12\x0b\n\x03row\x18\x02 \x02(\r\x12(\n dirty_self_plus_precedents_count\x18\x03 \x01(\x04\x12\x15\n\ris_in_a_cycle\x18\x04 \x01(\x08\x12#\n\x04\x65\x64ge\x18\x05 \x03(\x0b\x32\x11.TSCE.EdgeArchiveB\x02\x18\x01\x12 \n\x12\x63ontains_a_formula\x18\x06 \x01(\x08:\x04true\x12!\n\x19has_calculated_precedents\x18\x07 \x01(\x08\x12/\n#calculate_precedents_on_next_recalc\x18\x08 \x01(\x08\x42\x02\x18\x01\x12\x31\n)translate_for_excel_import_on_next_recalc\x18\n \x01(\x08\x12!\n\x05\x65\x64ges\x18\t \x01(\x0b\x32\x12.TSCE.EdgesArchive\"`\n\x17\x43\x65llDependenciesArchive\x12,\n\x0b\x63\x65ll_record\x18\x01 \x03(\x0b\x32\x17.TSCE.CellRecordArchive\x12\x17\n\x0fnum_dirty_cells\x18\x02 \x01(\r\"\xd0\x01\n\x19\x43\x65llRecordExpandedArchive\x12\x0e\n\x06\x63olumn\x18\x01 \x02(\r\x12\x0b\n\x03row\x18\x02 \x02(\r\x12(\n dirty_self_plus_precedents_count\x18\x03 \x01(\x04\x12\x15\n\ris_in_a_cycle\x18\x04 \x01(\x08\x12!\n\x19has_calculated_precedents\x18\x05 \x01(\x08\x12\x32\n\x0e\x65xpanded_edges\x18\x06 \x01(\x0b\x32\x1a.TSCE.ExpandedEdgesArchive\"W\n\x1f\x43\x65llDependenciesExpandedArchive\x12\x34\n\x0b\x63\x65ll_record\x18\x01 \x03(\x0b\x32\x1f.TSCE.CellRecordExpandedArchive\"\x9c\x01\n\x15\x43\x65llRecordTileArchive\x12\x19\n\x11internal_owner_id\x18\x01 \x02(\r\x12\x19\n\x11tile_column_begin\x18\x02 \x02(\r\x12\x16\n\x0etile_row_begin\x18\x03 \x02(\r\x12\x35\n\x0c\x63\x65ll_records\x18\x04 \x03(\x0b\x32\x1f.TSCE.CellRecordExpandedArchive\"I\n\x1c\x43\x65llDependenciesTiledArchive\x12)\n\x11\x63\x65ll_record_tiles\x18\x01 \x03(\x0b\x32\x0e.TSP.Reference\"\x84\x06\n\x1bVolatileDependenciesArchive\x12!\n\x19volatile_time_cell_column\x18\x01 \x03(\r\x12\x1e\n\x16volatile_time_cell_row\x18\x02 \x03(\r\x12#\n\x1bvolatile_random_cell_column\x18\x03 \x03(\r\x12 \n\x18volatile_random_cell_row\x18\x04 \x03(\r\x12#\n\x1bvolatile_locale_cell_column\x18\x0f \x03(\r\x12 \n\x18volatile_locale_cell_row\x18\x10 \x03(\r\x12%\n\x1dvolatile_location_cell_column\x18\x05 \x03(\r\x12\"\n\x1avolatile_location_cell_row\x18\x06 \x03(\r\x12$\n\x1cvolatile_compass_cell_column\x18\x07 \x03(\r\x12!\n\x19volatile_compass_cell_row\x18\x08 \x03(\r\x12(\n volatile_remote_data_cell_column\x18\x13 \x03(\r\x12%\n\x1dvolatile_remote_data_cell_row\x18\x14 \x03(\r\x12-\n%volatile_sheet_table_name_cell_column\x18\x11 \x03(\r\x12*\n\"volatile_sheet_table_name_cell_row\x18\x12 \x03(\r\x12)\n!calculated_dependency_cell_column\x18\t \x03(\r\x12&\n\x1e\x63\x61lculated_dependency_cell_row\x18\n \x03(\r\x12\x44\n volatile_geometry_cell_reference\x18\r \x03(\x0b\x32\x1a.TSCE.CellReferenceArchive\x12;\n\x16volatile_geometry_cell\x18\x0b \x03(\x0b\x32\x1b.TSCE.CellCoordinateArchive\"\x9a\x03\n#VolatileDependenciesExpandedArchive\x12\x36\n\x13volatile_time_cells\x18\x01 \x01(\x0b\x32\x19.TSCE.CellCoordSetArchive\x12\x38\n\x15volatile_random_cells\x18\x02 \x01(\x0b\x32\x19.TSCE.CellCoordSetArchive\x12\x38\n\x15volatile_locale_cells\x18\x03 \x01(\x0b\x32\x19.TSCE.CellCoordSetArchive\x12\x42\n\x1fvolatile_sheet_table_name_cells\x18\x04 \x01(\x0b\x32\x19.TSCE.CellCoordSetArchive\x12=\n\x1avolatile_remote_data_cells\x18\x05 \x01(\x0b\x32\x19.TSCE.CellCoordSetArchive\x12\x44\n\x1bvolatile_geometry_cell_refs\x18\x07 \x01(\x0b\x32\x1f.TSCE.InternalCellRefSetArchive\"c\n RTreeInternalNodeContentsArchive\x12\x0b\n\x03min\x18\x01 \x03(\r\x12\x0b\n\x03max\x18\x02 \x03(\r\x12%\n\x05\x63hild\x18\x03 \x02(\x0b\x32\x16.TSCE.RTreeNodeArchive\"l\n\x1cRTreeLeafNodeContentsArchive\x12\x0b\n\x03min\x18\x01 \x03(\r\x12\x0b\n\x03max\x18\x02 \x03(\r\x12\x32\n\x0e\x63\x65ll_reference\x18\x03 \x02(\x0b\x32\x1a.TSCE.CellReferenceArchive\"\xb8\x01\n\x10RTreeNodeArchive\x12\r\n\x05level\x18\x01 \x02(\r\x12\r\n\x05\x63ount\x18\x02 \x02(\r\x12\x46\n\x16internal_node_contents\x18\x03 \x03(\x0b\x32&.TSCE.RTreeInternalNodeContentsArchive\x12>\n\x12leaf_node_contents\x18\x04 \x03(\x0b\x32\".TSCE.RTreeLeafNodeContentsArchive\"\xd9\x01\n\x0cRTreeArchive\x12\x14\n\x0c\x64\x61ta_file_id\x18\x01 \x02(\r\x12\x11\n\tdata_size\x18\x02 \x02(\r\x12\x15\n\rdata_num_dims\x18\x03 \x02(\r\x12\x16\n\x0e\x64\x61ta_elem_size\x18\x04 \x02(\r\x12\x1b\n\x13\x64\x61ta_elem_real_size\x18\x05 \x02(\r\x12\x16\n\x0e\x64\x61ta_max_nodes\x18\x06 \x02(\r\x12\x16\n\x0e\x64\x61ta_min_nodes\x18\x07 \x02(\r\x12$\n\x04root\x18\x08 \x02(\x0b\x32\x16.TSCE.RTreeNodeArchive\"\xcc\x01\n\x1aRangeBackDependencyArchive\x12\x16\n\x0e\x63\x65ll_coord_row\x18\x01 \x02(\r\x12\x19\n\x11\x63\x65ll_coord_column\x18\x02 \x02(\r\x12\x34\n\x0frange_reference\x18\x03 \x01(\x0b\x32\x1b.TSCE.RangeReferenceArchive\x12\x45\n\x18internal_range_reference\x18\x04 \x01(\x0b\x32#.TSCE.InternalRangeReferenceArchive\"U\n\x18RangeDependenciesArchive\x12\x39\n\x0f\x62\x61\x63k_dependency\x18\x02 \x03(\x0b\x32 .TSCE.RangeBackDependencyArchive\"\xf3\x01\n\x1aRangePrecedentsTileArchive\x12\x13\n\x0bto_owner_id\x18\x01 \x02(\r\x12J\n\rfrom_to_range\x18\x02 \x03(\x0b\x32\x33.TSCE.RangePrecedentsTileArchive.FromToRangeArchive\x1at\n\x12\x46romToRangeArchive\x12/\n\nfrom_coord\x18\x01 \x02(\x0b\x32\x1b.TSCE.CellCoordinateArchive\x12-\n\x0erefers_to_rect\x18\x02 \x02(\x0b\x32\x15.TSCE.CellRectArchive\"N\n\x1dRangeDependenciesTiledArchive\x12-\n\x15range_precedents_tile\x18\x01 \x03(\x0b\x32\x0e.TSP.Reference\"\x95\x07\n\x1bSpanningDependenciesArchive\x12\x0e\n\x06\x63olumn\x18\x01 \x03(\r\x12\x45\n\rrange_context\x18\x02 \x03(\x0e\x32..TSCE.SpanningDependenciesArchive.RangeContext\x12(\n\x04\x63\x65ll\x18\x03 \x03(\x0b\x32\x1a.TSCE.CellReferenceArchive\x12\x43\n\x1dtotal_range_for_deleted_table\x18\x04 \x01(\x0b\x32\x1c.TSCE.RangeCoordinateArchive\x12\x42\n\x1c\x62ody_range_for_deleted_table\x18\x05 \x01(\x0b\x32\x1c.TSCE.RangeCoordinateArchive\x12\x66\n\x1freferring_column_to_local_cells\x18\x06 \x03(\x0b\x32=.TSCE.SpanningDependenciesArchive.ReferringColumnToLocalCells\x12h\n referring_column_to_remote_cells\x18\x07 \x03(\x0b\x32>.TSCE.SpanningDependenciesArchive.ReferringColumnToRemoteCells\x1a\xaa\x01\n\x1bReferringColumnToLocalCells\x12\x0e\n\x06\x63olumn\x18\x01 \x02(\r\x12\x45\n\rrange_context\x18\x02 \x02(\x0e\x32..TSCE.SpanningDependenciesArchive.RangeContext\x12\x34\n\x0f\x63\x65ll_coordinate\x18\x03 \x03(\x0b\x32\x1b.TSCE.CellCoordinateArchive\x1a\xba\x01\n\x1cReferringColumnToRemoteCells\x12\x0e\n\x06\x63olumn\x18\x01 \x02(\r\x12\x45\n\rrange_context\x18\x02 \x02(\x0e\x32..TSCE.SpanningDependenciesArchive.RangeContext\x12\x43\n\x17internal_cell_reference\x18\x03 \x03(\x0b\x32\".TSCE.InternalCellReferenceArchive\"0\n\x0cRangeContext\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x13\n\x0fINCLUDE_HEADERS\x10\x01\"\xf2\x05\n#SpanningDependenciesExpandedArchive\x12\x61\n\x15\x63oord_refers_to_spans\x18\x01 \x03(\x0b\x32\x42.TSCE.SpanningDependenciesExpandedArchive.CellCoordRefersToExtents\x12;\n\x15total_range_for_table\x18\x02 \x01(\x0b\x32\x1c.TSCE.RangeCoordinateArchive\x12:\n\x14\x62ody_range_for_table\x18\x03 \x01(\x0b\x32\x1c.TSCE.RangeCoordinateArchive\x1a\x37\n\x0b\x45xtentRange\x12\x14\n\x0c\x65xtent_begin\x18\x01 \x02(\r\x12\x12\n\nextent_end\x18\x02 \x01(\r\x1a\xc9\x01\n\x1f\x45xtentRangeWithTableWithContext\x12\x10\n\x08owner_id\x18\x01 \x02(\r\x12M\n\rrange_context\x18\x02 \x02(\x0e\x32\x36.TSCE.SpanningDependenciesExpandedArchive.RangeContext\x12\x45\n\x06ranges\x18\x03 \x03(\x0b\x32\x35.TSCE.SpanningDependenciesExpandedArchive.ExtentRange\x1a\xb7\x01\n\x18\x43\x65llCoordRefersToExtents\x12/\n\ncoordinate\x18\x01 \x02(\x0b\x32\x1b.TSCE.CellCoordinateArchive\x12j\n\x17ranges_by_table_context\x18\x02 \x03(\x0b\x32I.TSCE.SpanningDependenciesExpandedArchive.ExtentRangeWithTableWithContext\"0\n\x0cRangeContext\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x13\n\x0fINCLUDE_HEADERS\x10\x01\"[\n\x1dWholeOwnerDependenciesArchive\x12:\n\x0e\x64\x65pendent_cell\x18\x01 \x03(\x0b\x32\".TSCE.InternalCellReferenceArchive\"a\n%WholeOwnerDependenciesExpandedArchive\x12\x38\n\x0f\x64\x65pendent_cells\x18\x01 \x01(\x0b\x32\x1f.TSCE.InternalCellRefSetArchive\"\xee\x02\n\x11\x43\x65llErrorsArchive\x12\x34\n\x06\x65rrors\x18\x01 \x03(\x0b\x32$.TSCE.CellErrorsArchive.ErrorForCell\x1a\xb7\x01\n\x0c\x45rrorForCell\x12/\n\ncoordinate\x18\x01 \x02(\x0b\x32\x1b.TSCE.CellCoordinateArchive\x12\x39\n\x0c\x65rror_flavor\x18\x02 \x02(\x0e\x32#.TSCE.CellErrorsArchive.ErrorFlavor\x12;\n\x0f\x65rr_due_to_cell\x18\x03 \x01(\x0b\x32\".TSCE.InternalCellReferenceArchive\"i\n\x0b\x45rrorFlavor\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05\x45RROR\x10\x01\x12\r\n\tREF_ERROR\x10\x02\x12\x16\n\x12\x43IRCULAR_REF_ERROR\x10\x03\x12\x1e\n\x1aUNSUPPORTED_FUNCTION_ERROR\x10\x04\"\xae\x03\n\x15UuidReferencesArchive\x12\x38\n\ntable_refs\x18\x01 \x03(\x0b\x32$.TSCE.UuidReferencesArchive.TableRef\x12\x45\n\x0ftable_uuid_refs\x18\x02 \x03(\x0b\x32,.TSCE.UuidReferencesArchive.TableWithUuidRef\x1aW\n\x08TableRef\x12\x1d\n\nowner_uuid\x18\x01 \x02(\x0b\x32\t.TSP.UUID\x12,\n\tcoord_set\x18\x02 \x01(\x0b\x32\x19.TSCE.CellCoordSetArchive\x1aP\n\x07UuidRef\x12\x17\n\x04uuid\x18\x01 \x02(\x0b\x32\t.TSP.UUID\x12,\n\tcoord_set\x18\x02 \x01(\x0b\x32\x19.TSCE.CellCoordSetArchive\x1ai\n\x10TableWithUuidRef\x12\x1d\n\nowner_uuid\x18\x01 \x02(\x0b\x32\t.TSP.UUID\x12\x36\n\tuuid_refs\x18\x02 \x03(\x0b\x32#.TSCE.UuidReferencesArchive.UuidRef\"\xee\x06\n\x1f\x46ormulaOwnerDependenciesArchive\x12$\n\x11\x66ormula_owner_uid\x18\x01 \x02(\x0b\x32\t.TSP.UUID\x12!\n\x19internal_formula_owner_id\x18\x02 \x02(\r\x12\x12\n\nowner_kind\x18\x03 \x01(\r\x12@\n\x11\x63\x65ll_dependencies\x18\x04 \x01(\x0b\x32%.TSCE.CellDependenciesExpandedArchive\x12:\n\x12range_dependencies\x18\x05 \x01(\x0b\x32\x1e.TSCE.RangeDependenciesArchive\x12H\n\x15volatile_dependencies\x18\x06 \x01(\x0b\x32).TSCE.VolatileDependenciesExpandedArchive\x12O\n\x1cspanning_column_dependencies\x18\x07 \x01(\x0b\x32).TSCE.SpanningDependenciesExpandedArchive\x12L\n\x19spanning_row_dependencies\x18\x08 \x01(\x0b\x32).TSCE.SpanningDependenciesExpandedArchive\x12M\n\x18whole_owner_dependencies\x18\t \x01(\x0b\x32+.TSCE.WholeOwnerDependenciesExpandedArchive\x12,\n\x0b\x63\x65ll_errors\x18\n \x01(\x0b\x32\x17.TSCE.CellErrorsArchive\x12%\n\rformula_owner\x18\x0b \x01(\x0b\x32\x0e.TSP.Reference\x12!\n\x0e\x62\x61se_owner_uid\x18\x0c \x01(\x0b\x32\t.TSP.UUID\x12\x43\n\x17tiled_cell_dependencies\x18\r \x01(\x0b\x32\".TSCE.CellDependenciesTiledArchive\x12\x34\n\x0fuuid_references\x18\x0e \x01(\x0b\x32\x1b.TSCE.UuidReferencesArchive\x12\x45\n\x18tiled_range_dependencies\x18\x0f \x01(\x0b\x32#.TSCE.RangeDependenciesTiledArchive\"\xaa\x04\n\x17\x46ormulaOwnerInfoArchive\x12,\n\x10\x66ormula_owner_id\x18\x01 \x02(\x0b\x32\x12.TSP.CFUUIDArchive\x12\x38\n\x11\x63\x65ll_dependencies\x18\x02 \x01(\x0b\x32\x1d.TSCE.CellDependenciesArchive\x12:\n\x12range_dependencies\x18\x03 \x01(\x0b\x32\x1e.TSCE.RangeDependenciesArchive\x12@\n\x15volatile_dependencies\x18\x04 \x01(\x0b\x32!.TSCE.VolatileDependenciesArchive\x12G\n\x1cspanning_column_dependencies\x18\x05 \x01(\x0b\x32!.TSCE.SpanningDependenciesArchive\x12\x44\n\x19spanning_row_dependencies\x18\x06 \x01(\x0b\x32!.TSCE.SpanningDependenciesArchive\x12\x45\n\x18whole_owner_dependencies\x18\x08 \x01(\x0b\x32#.TSCE.WholeOwnerDependenciesArchive\x12,\n\x0b\x63\x65ll_errors\x18\t \x01(\x0b\x32\x17.TSCE.CellErrorsArchive\x12%\n\rformula_owner\x18\x07 \x01(\x0b\x32\x0e.TSP.Reference\"Q\n\x18SubFormulaOwnerIDArchive\x12!\n\x0e\x62\x61se_owner_uid\x18\x01 \x02(\x0b\x32\t.TSP.UUID\x12\x12\n\nowner_kind\x18\x02 \x01(\r\"\x99\x02\n\x11OwnerIDMapArchive\x12\x41\n\tmap_entry\x18\x01 \x03(\x0b\x32..TSCE.OwnerIDMapArchive.OwnerIDMapArchiveEntry\x12&\n\x1eunregistered_internal_owner_id\x18\x02 \x03(\r\x1a\x98\x01\n\x16OwnerIDMapArchiveEntry\x12\x19\n\x11internal_owner_id\x18\x01 \x02(\r\x12$\n\x08owner_id\x18\x02 \x02(\x0b\x32\x12.TSP.CFUUIDArchive\x12=\n\x15sub_formula_owner_uid\x18\x03 \x01(\x0b\x32\x1e.TSCE.SubFormulaOwnerIDArchive\"0\n\x14UidLookupListArchive\x12\x18\n\x05uuids\x18\x01 \x03(\x0b\x32\t.TSP.UUID\"\xcd\x02\n\x18\x44\x65pendencyTrackerArchive\x12\x39\n\x12\x66ormula_owner_info\x18\x01 \x03(\x0b\x32\x1d.TSCE.FormulaOwnerInfoArchive\x12\x32\n\ndirty_leaf\x18\x02 \x03(\x0b\x32\x1a.TSCE.CellReferenceArchiveB\x02\x18\x01\x12-\n\x0cowner_id_map\x18\x03 \x01(\x0b\x32\x17.TSCE.OwnerIDMapArchive\x12\x43\n\x13internal_dirty_leaf\x18\x04 \x03(\x0b\x32\".TSCE.InternalCellReferenceArchiveB\x02\x18\x01\x12\x1a\n\x12number_of_formulas\x18\x05 \x01(\x04\x12\x32\n\x1a\x66ormula_owner_dependencies\x18\x06 \x03(\x0b\x32\x0e.TSP.Reference\"e\n\x1aRemoteDataSpecifierArchive\x12\x16\n\x0e\x66unction_index\x18\x01 \x02(\r\x12\x0e\n\x06symbol\x18\x02 \x02(\t\x12\x11\n\tattribute\x18\x03 \x02(\r\x12\x0c\n\x04\x64\x61te\x18\x04 \x01(\x01\"\xd0\x01\n\x19RemoteDataValueMapArchive\x12\x41\n\x05\x65ntry\x18\x01 \x03(\x0b\x32\x32.TSCE.RemoteDataValueMapArchive.RemoteDataMapEntry\x1ap\n\x12RemoteDataMapEntry\x12\x33\n\tspecifier\x18\x01 \x02(\x0b\x32 .TSCE.RemoteDataSpecifierArchive\x12%\n\x05value\x18\x02 \x02(\x0b\x32\x16.TSCE.CellValueArchive\"\x96\x01\n\x0cStockArchive\x12\x0e\n\x06symbol\x18\x01 \x02(\t\x12\x0c\n\x04\x64\x61te\x18\x02 \x01(\x01\x12\x34\n\tattribute\x18\x03 \x03(\x0b\x32!.TSCE.StockArchive.AttributeEntry\x1a\x32\n\x0e\x41ttributeEntry\x12\x11\n\tattribute\x18\x01 \x02(\r\x12\r\n\x05value\x18\x02 \x02(\t\"p\n\x16RemoteDataStoreArchive\x12\x32\n\tvalue_map\x18\x01 \x02(\x0b\x32\x1f.TSCE.RemoteDataValueMapArchive\x12\"\n\x06stocks\x18\x02 \x03(\x0b\x32\x12.TSCE.StockArchive\"q\n\x18NameTrackedReferencePair\x12\x0c\n\x04name\x18\x01 \x02(\t\x12)\n\x11tracked_reference\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12\x1c\n\x14tracked_reference_id\x18\x03 \x01(\r\"\x8b\x01\n\x1eNamesByTrackedReferenceArchive\x12$\n\x08table_id\x18\x01 \x02(\x0b\x32\x12.TSP.CFUUIDArchive\x12\x43\n\x1bname_tracked_reference_pair\x18\x02 \x03(\x0b\x32\x1e.TSCE.NameTrackedReferencePair\"\xa0\x01\n\x1cNamedReferenceManagerArchive\x12)\n\x11reference_tracker\x18\x01 \x02(\x0b\x32\x0e.TSP.Reference\x12U\n#names_by_tracked_reference_by_table\x18\x02 \x03(\x0b\x32$.TSCE.NamesByTrackedReferenceArchiveB\x02\x18\x01\"\x83\x01\n\x13UuidSetStoreArchive\x12\x32\n\x07uuidSet\x18\x01 \x03(\x0b\x32!.TSCE.UuidSetStoreArchive.UuidSet\x1a\x38\n\x07UuidSet\x12\x17\n\x04uuid\x18\x01 \x03(\x0b\x32\t.TSP.UUID\x12\x14\n\x0cindex_of_set\x18\x02 \x02(\r\"\xfb\x01\n\x17UuidReferenceMapArchive\x12I\n\x12\x63\x65ll_refs_for_uuid\x18\x01 \x03(\x0b\x32-.TSCE.UuidReferenceMapArchive.CellRefsForUuid\x1a\x94\x01\n\x0f\x43\x65llRefsForUuid\x12\x17\n\x04uuid\x18\x01 \x02(\x0b\x32\t.TSP.UUID\x12\x34\n\x08\x63\x65ll_ref\x18\x02 \x03(\x0b\x32\".TSCE.InternalCellReferenceArchive\x12\x32\n\tcell_refs\x18\x03 \x01(\x0b\x32\x1f.TSCE.InternalCellRefSetArchive\"\xdc\x02\n\x15GroupByNodeMapArchive\x12K\n\x11refs_for_group_by\x18\x01 \x03(\x0b\x32\x30.TSCE.GroupByNodeMapArchive.GroupNodesForGroupBy\x1am\n\x14\x43\x65llRefsForGroupNode\x12!\n\x0egroup_node_uid\x18\x01 \x02(\x0b\x32\t.TSP.UUID\x12\x32\n\tcell_refs\x18\x03 \x01(\x0b\x32\x1f.TSCE.InternalCellRefSetArchive\x1a\x86\x01\n\x14GroupNodesForGroupBy\x12\x1f\n\x0cgroup_by_uid\x18\x01 \x02(\x0b\x32\t.TSP.UUID\x12M\n\x13refs_for_group_node\x18\x02 \x03(\x0b\x32\x30.TSCE.GroupByNodeMapArchive.CellRefsForGroupNode\"\x85\x07\n\x18\x43\x61lculationEngineArchive\x12\x16\n\x0e\x62\x61se_date_1904\x18\x01 \x01(\x08\x12:\n\x12\x64\x65pendency_tracker\x18\x02 \x02(\x0b\x32\x1e.TSCE.DependencyTrackerArchive\x12/\n\x17named_reference_manager\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12R\n\x16\x65xcel_import_date_mode\x18\x04 \x01(\x0e\x32\x32.TSCE.CalculationEngineArchive.ExcelImportDateMode\x12\'\n\x1fsaved_locale_identifier_for_4_2\x18\x05 \x01(\t\x12\x1c\n\x14\x64ocument_random_seed\x18\x06 \x01(\x04\x12\x39\n\x12uuid_reference_map\x18\x07 \x01(\x0b\x32\x1d.TSCE.UuidReferenceMapArchive\x12\x1a\n\x12\x64ocument_timestamp\x18\t \x01(\x01\x12\x19\n\x11\x64ocument_timezone\x18\n \x01(\t\x12;\n\x11table_uid_history\x18\x0b \x01(\x0b\x32 .TSCE.RewriteTableUIDInfoArchive\x12)\n\x11remote_data_store\x18\x0c \x01(\x0b\x32\x0e.TSP.Reference\x12\x33\n\x0egroup_node_map\x18\r \x01(\x0b\x32\x1b.TSCE.GroupByNodeMapArchive\x12+\n\x13header_name_manager\x18\x0e \x01(\x0b\x32\x0e.TSP.Reference\x12%\n\rrefs_to_dirty\x18\x0f \x01(\x0b\x32\x0e.TSP.Reference\x12\x1f\n\x17saved_locale_identifier\x18\x10 \x01(\t\x12\x32\n\x1f\x62\x65gin_tracking_names_legacy_nrm\x18\x11 \x03(\x0b\x32\t.TSP.UUID\x12\x30\n\x1d\x65nd_tracking_names_legacy_nrm\x18\x12 \x03(\x0b\x32\t.TSP.UUID\"_\n\x13\x45xcelImportDateMode\x12\x12\n\x0e\x44\x41TE_MODE_1900\x10\x01\x12\x19\n\x15\x44\x41TE_MODE_1900_LEGACY\x10\x02\x12\x19\n\x15\x44\x41TE_MODE_1904_LEGACY\x10\x03\"\x9d\x01\n\x1dPreserveColumnRowFlagsArchive\x12\x1d\n\x15\x62\x65gin_row_is_absolute\x18\x01 \x02(\x08\x12 \n\x18\x62\x65gin_column_is_absolute\x18\x02 \x02(\x08\x12\x1b\n\x13\x65nd_row_is_absolute\x18\x03 \x01(\x08\x12\x1e\n\x16\x65nd_column_is_absolute\x18\x04 \x01(\x08\"\xad\x03\n\x18\x43\x61tegoryReferenceArchive\x12\x1f\n\x0cgroup_by_uid\x18\x01 \x02(\x0b\x32\t.TSP.UUID\x12\x1d\n\ncolumn_uid\x18\x02 \x02(\x0b\x32\t.TSP.UUID\x12-\n\x0e\x61ggregate_type\x18\x03 \x02(\x0e\x32\x15.TSCE.CategoryAggType\x12\x13\n\x0bgroup_level\x18\x04 \x02(\x11\x12@\n\ngroup_uids\x18\x06 \x01(\x0b\x32,.TSCE.CategoryReferenceArchive.CatRefUidList\x12;\n\x0epreserve_flags\x18\x07 \x01(\x0b\x32#.TSCE.PreserveColumnRowFlagsArchive\x12\x17\n\x0frelative_column\x18\x08 \x01(\x05\x12%\n\x12relative_group_uid\x18\t \x01(\x0b\x32\t.TSP.UUID\x12%\n\x12\x61\x62solute_group_uid\x18\n \x01(\x0b\x32\t.TSP.UUID\x1a\'\n\rCatRefUidList\x12\x16\n\x03uid\x18\x01 \x03(\x0b\x32\t.TSP.UUID\"\xd2.\n\x13\x41STNodeArrayArchive\x12:\n\x08\x41ST_node\x18\x01 \x03(\x0b\x32(.TSCE.ASTNodeArrayArchive.ASTNodeArchive\x1a~\n ASTLocalCellReferenceNodeArchive\x12\x12\n\nrow_handle\x18\x01 \x02(\r\x12\x15\n\rcolumn_handle\x18\x02 \x02(\r\x12\x15\n\rrow_is_sticky\x18\x03 \x02(\r\x12\x18\n\x10\x63olumn_is_sticky\x18\x04 \x02(\r\x1a\xf9\x02\n%ASTCrossTableCellReferenceNodeArchive\x12\x12\n\nrow_handle\x18\x01 \x02(\r\x12\x15\n\rcolumn_handle\x18\x02 \x02(\r\x12\x15\n\rrow_is_sticky\x18\x03 \x02(\r\x12\x18\n\x10\x63olumn_is_sticky\x18\x04 \x02(\r\x12$\n\x08table_id\x18\x05 \x02(\x0b\x32\x12.TSP.CFUUIDArchive\x12\x31\n)AST_reference_whitespace_after_sheet_name\x18\x06 \x01(\t\x12\x32\n*AST_reference_whitespace_before_table_name\x18\x07 \x01(\t\x12\x31\n)AST_reference_whitespace_after_table_name\x18\x08 \x01(\t\x12\x34\n,AST_reference_whitespace_before_cell_address\x18\t \x01(\t\x1a>\n\x1a\x41STColumnCoordinateArchive\x12\x0e\n\x06\x63olumn\x18\x01 \x02(\x11\x12\x10\n\x08\x61\x62solute\x18\x02 \x01(\x08\x1a\x38\n\x17\x41STRowCoordinateArchive\x12\x0b\n\x03row\x18\x01 \x02(\x11\x12\x10\n\x08\x61\x62solute\x18\x02 \x01(\x08\x1a$\n\nASTUidList\x12\x16\n\x03uid\x18\x01 \x03(\x0b\x32\t.TSP.UUID\x1a\xf7\x01\n\x0b\x41STUidTract\x12\x38\n\ncolumnUids\x18\x01 \x02(\x0b\x32$.TSCE.ASTNodeArrayArchive.ASTUidList\x12\x35\n\x07rowUids\x18\x02 \x02(\x0b\x32$.TSCE.ASTNodeArrayArchive.ASTUidList\x12\x14\n\x0cis_range_ref\x18\x03 \x01(\x08\x12=\n\x07purpose\x18\x04 \x01(\x0e\x32,.TSCE.ASTNodeArrayArchive.ASTUidTractPurpose\x12\"\n\x14preserve_rectangular\x18\x05 \x01(\x08:\x04true\x1a\x8d\x01\n\rASTStickyBits\x12\x1d\n\x15\x62\x65gin_row_is_absolute\x18\x01 \x02(\x08\x12 \n\x18\x62\x65gin_column_is_absolute\x18\x02 \x02(\x08\x12\x1b\n\x13\x65nd_row_is_absolute\x18\x03 \x02(\x08\x12\x1e\n\x16\x65nd_column_is_absolute\x18\x04 \x02(\x08\x1a\x85\x01\n\x0f\x41STUidTractList\x12\x34\n\x05tract\x18\x01 \x03(\x0b\x32%.TSCE.ASTNodeArrayArchive.ASTUidTract\x12<\n\x0bsticky_bits\x18\x02 \x02(\x0b\x32\'.TSCE.ASTNodeArrayArchive.ASTStickyBits\x1a\x83\x01\n\x17\x41STUidCoordinateArchive\x12\x1d\n\ncolumn_uid\x18\x01 \x02(\x0b\x32\t.TSP.UUID\x12\x1a\n\x07row_uid\x18\x02 \x02(\x0b\x32\t.TSP.UUID\x12\x17\n\x0f\x63olumn_absolute\x18\x03 \x02(\x08\x12\x14\n\x0crow_absolute\x18\x04 \x02(\x08\x1aS\n\x1b\x41STCategoryReferenceArchive\x12\x34\n\x0c\x63\x61tegory_ref\x18\x01 \x02(\x0b\x32\x1e.TSCE.CategoryReferenceArchive\x1a\xfa\x04\n\x14\x41STColonTractArchive\x12i\n\x0frelative_column\x18\x01 \x03(\x0b\x32P.TSCE.ASTNodeArrayArchive.ASTColonTractArchive.ASTColonTractRelativeRangeArchive\x12\x66\n\x0crelative_row\x18\x02 \x03(\x0b\x32P.TSCE.ASTNodeArrayArchive.ASTColonTractArchive.ASTColonTractRelativeRangeArchive\x12i\n\x0f\x61\x62solute_column\x18\x03 \x03(\x0b\x32P.TSCE.ASTNodeArrayArchive.ASTColonTractArchive.ASTColonTractAbsoluteRangeArchive\x12\x66\n\x0c\x61\x62solute_row\x18\x04 \x03(\x0b\x32P.TSCE.ASTNodeArrayArchive.ASTColonTractArchive.ASTColonTractAbsoluteRangeArchive\x12\"\n\x14preserve_rectangular\x18\x05 \x01(\x08:\x04true\x1aK\n!ASTColonTractRelativeRangeArchive\x12\x13\n\x0brange_begin\x18\x01 \x02(\x05\x12\x11\n\trange_end\x18\x02 \x01(\x05\x1aK\n!ASTColonTractAbsoluteRangeArchive\x12\x13\n\x0brange_begin\x18\x01 \x02(\r\x12\x11\n\trange_end\x18\x02 \x01(\r\x1a\x9e\x02\n&ASTCrossTableReferenceExtraInfoArchive\x12$\n\x08table_id\x18\x01 \x02(\x0b\x32\x12.TSP.CFUUIDArchive\x12\x31\n)AST_reference_whitespace_after_sheet_name\x18\x02 \x01(\t\x12\x32\n*AST_reference_whitespace_before_table_name\x18\x03 \x01(\t\x12\x31\n)AST_reference_whitespace_after_table_name\x18\x04 \x01(\t\x12\x34\n,AST_reference_whitespace_before_cell_address\x18\x05 \x01(\t\x1a\xbe\x01\n\x14\x41STLetNodeWhitespace\x12$\n\x1c\x41ST_let_whitespace_after_let\x18\x01 \x01(\t\x12+\n#AST_let_whitespace_after_identifier\x18\x02 \x01(\t\x12\'\n\x1f\x41ST_let_whitespace_after_equals\x18\x03 \x01(\t\x12*\n\"AST_let_whitespace_after_delimiter\x18\x04 \x01(\t\x1a\xbc\x10\n\x0e\x41STNodeArchive\x12<\n\rAST_node_type\x18\x01 \x02(\x0e\x32%.TSCE.ASTNodeArrayArchive.ASTNodeType\x12\x1f\n\x17\x41ST_function_node_index\x18\x02 \x01(\r\x12!\n\x19\x41ST_function_node_numArgs\x18\x03 \x01(\r\x12\x1e\n\x16\x41ST_number_node_number\x18\x04 \x01(\x01\x12 \n\x18\x41ST_boolean_node_boolean\x18\x05 \x01(\x08\x12\x1e\n\x16\x41ST_string_node_string\x18\x06 \x01(\t\x12\x1d\n\x15\x41ST_date_node_dateNum\x18\x07 \x01(\x01\x12*\n\"AST_date_node_suppress_date_format\x18\x13 \x01(\x08\x12*\n\"AST_date_node_suppress_time_format\x18\x14 \x01(\x08\x12&\n\x1e\x41ST_date_node_date_time_format\x18\x15 \x01(\t\x12!\n\x19\x41ST_duration_node_unitNum\x18\x08 \x01(\x01\x12\x1e\n\x16\x41ST_duration_node_unit\x18\t \x01(\x05\x12\x1f\n\x17\x41ST_duration_node_style\x18\x16 \x01(\r\x12/\n\'AST_duration_node_duration_unit_largest\x18\x17 \x01(\r\x12\x30\n(AST_duration_node_duration_unit_smallest\x18\x18 \x01(\r\x12-\n%AST_duration_node_use_automatic_units\x18\x1d \x01(\x08\x12\x1e\n\x16\x41ST_token_node_boolean\x18\n \x01(\x08\x12\x1d\n\x15\x41ST_array_node_numCol\x18\x0b \x01(\r\x12\x1d\n\x15\x41ST_array_node_numRow\x18\x0c \x01(\r\x12\x1d\n\x15\x41ST_list_node_numArgs\x18\r \x01(\r\x12\x37\n\x14\x41ST_thunk_node_array\x18\x0e \x01(\x0b\x32\x19.TSCE.ASTNodeArrayArchive\x12k\n\'AST_local_cell_reference_node_reference\x18\x0f \x01(\x0b\x32:.TSCE.ASTNodeArrayArchive.ASTLocalCellReferenceNodeArchive\x12v\n-AST_cross_table_cell_reference_node_reference\x18\x10 \x01(\x0b\x32?.TSCE.ASTNodeArrayArchive.ASTCrossTableCellReferenceNodeArchive\x12(\n AST_unknown_function_node_string\x18\x11 \x01(\t\x12)\n!AST_unknown_function_node_numArgs\x18\x12 \x01(\r\x12\x16\n\x0e\x41ST_whitespace\x18\x19 \x01(\t\x12H\n\nAST_column\x18\x1a \x01(\x0b\x32\x34.TSCE.ASTNodeArrayArchive.ASTColumnCoordinateArchive\x12\x42\n\x07\x41ST_row\x18\x1b \x01(\x0b\x32\x31.TSCE.ASTNodeArrayArchive.ASTRowCoordinateArchive\x12n\n$AST_cross_table_reference_extra_info\x18\x1c \x01(\x0b\x32@.TSCE.ASTNodeArrayArchive.ASTCrossTableReferenceExtraInfoArchive\x12M\n\x12\x41ST_uid_coordinate\x18\x1e \x01(\x0b\x32\x31.TSCE.ASTNodeArrayArchive.ASTUidCoordinateArchive\x12@\n\x0f\x41ST_sticky_bits\x18! \x01(\x0b\x32\'.TSCE.ASTNodeArrayArchive.ASTStickyBits\x12G\n\x16\x41ST_frozen_sticky_bits\x18) \x01(\x0b\x32\'.TSCE.ASTNodeArrayArchive.ASTStickyBits\x12\x1a\n\x12\x41ST_let_identifier\x18\" \x01(\t\x12-\n\nAST_let_e2\x18# \x01(\x0b\x32\x19.TSCE.ASTNodeArrayArchive\x12J\n\x12\x41ST_let_whitespace\x18$ \x01(\x0b\x32..TSCE.ASTNodeArrayArchive.ASTLetNodeWhitespace\x12\x12\n\nAST_symbol\x18% \x01(\r\x12\x41\n\x0e\x41ST_tract_list\x18& \x01(\x0b\x32).TSCE.ASTNodeArrayArchive.ASTUidTractList\x12O\n\x10\x41ST_category_ref\x18\' \x01(\x0b\x32\x35.TSCE.ASTNodeArrayArchive.ASTCategoryReferenceArchive\x12G\n\x0f\x41ST_colon_tract\x18( \x01(\x0b\x32..TSCE.ASTNodeArrayArchive.ASTColonTractArchive\x12#\n\x1b\x41ST_number_node_decimal_low\x18* \x01(\x04\x12$\n\x1c\x41ST_number_node_decimal_high\x18+ \x01(\x04\"\xa9\x08\n\x0b\x41STNodeType\x12\x11\n\rADDITION_NODE\x10\x01\x12\x14\n\x10SUBTRACTION_NODE\x10\x02\x12\x17\n\x13MULTIPLICATION_NODE\x10\x03\x12\x11\n\rDIVISION_NODE\x10\x04\x12\x0e\n\nPOWER_NODE\x10\x05\x12\x16\n\x12\x43ONCATENATION_NODE\x10\x06\x12\x15\n\x11GREATER_THAN_NODE\x10\x07\x12!\n\x1dGREATER_THAN_OR_EQUAL_TO_NODE\x10\x08\x12\x12\n\x0eLESS_THAN_NODE\x10\t\x12\x1e\n\x1aLESS_THAN_OR_EQUAL_TO_NODE\x10\n\x12\x11\n\rEQUAL_TO_NODE\x10\x0b\x12\x15\n\x11NOT_EQUAL_TO_NODE\x10\x0c\x12\x11\n\rNEGATION_NODE\x10\r\x12\x12\n\x0ePLUS_SIGN_NODE\x10\x0e\x12\x10\n\x0cPERCENT_NODE\x10\x0f\x12\x11\n\rFUNCTION_NODE\x10\x10\x12\x0f\n\x0bNUMBER_NODE\x10\x11\x12\x10\n\x0c\x42OOLEAN_NODE\x10\x12\x12\x0f\n\x0bSTRING_NODE\x10\x13\x12\r\n\tDATE_NODE\x10\x14\x12\x11\n\rDURATION_NODE\x10\x15\x12\x17\n\x13\x45MPTY_ARGUMENT_NODE\x10\x16\x12\x0e\n\nTOKEN_NODE\x10\x17\x12\x0e\n\nARRAY_NODE\x10\x18\x12\r\n\tLIST_NODE\x10\x19\x12\x0e\n\nTHUNK_NODE\x10\x1a\x12\x1d\n\x19LOCAL_CELL_REFERENCE_NODE\x10\x1b\x12#\n\x1f\x43ROSS_TABLE_CELL_REFERENCE_NODE\x10\x1c\x12\x0e\n\nCOLON_NODE\x10\x1d\x12\x18\n\x14REFERENCE_ERROR_NODE\x10\x1e\x12\x19\n\x15UNKNOWN_FUNCTION_NODE\x10\x1f\x12\x1a\n\x16\x41PPEND_WHITESPACE_NODE\x10 \x12\x1b\n\x17PREPEND_WHITESPACE_NODE\x10!\x12\x1d\n\x19\x42\x45GIN_EMBEDDED_NODE_ARRAY\x10\"\x12\x12\n\x0e\x45ND_THUNK_NODE\x10#\x12\x17\n\x13\x43\x45LL_REFERENCE_NODE\x10$\x12\x18\n\x14\x43OLON_NODE_WITH_UIDS\x10-\x12\x1d\n\x19REFERENCE_ERROR_WITH_UIDS\x10.\x12\x16\n\x12UID_REFERENCE_NODE\x10\x30\x12\x0c\n\x08LET_NODE\x10\x34\x12\x10\n\x0cLET_VAR_NODE\x10\x35\x12\x10\n\x0cLET_END_NODE\x10\x36\x12\x18\n\x14LINKED_CELL_REF_NODE\x10?\x12\x1a\n\x16LINKED_COLUMN_REF_NODE\x10@\x12\x17\n\x13LINKED_ROW_REF_NODE\x10\x41\x12\x15\n\x11\x43\x41TEGORY_REF_NODE\x10\x42\x12\x14\n\x10\x43OLON_TRACT_NODE\x10\x43\"\xab\x01\n\x12\x41STUidTractPurpose\x12\x11\n\rUIDS_INCLUDED\x10\x00\x12\x11\n\rUIDS_PREMERGE\x10\x01\x12\x16\n\x12UIDS_PREMOVEREGION\x10\x02\x12\x11\n\rUIDS_EXCLUDED\x10\x03\x12\x0f\n\x0bUIDS_ACTIVE\x10\x04\x12\x19\n\x15UIDS_PREMERGE_TOPLEFT\x10\x05\x12\x18\n\x14UIDS_REMOVED_BY_MOVE\x10\x06\"\xc1\x01\n\x1e\x46ormulaTranslationFlagsArchive\x12 \n\x18\x65xcel_import_translation\x18\x01 \x01(\x08\x12\x33\n+number_to_date_coercion_removal_translation\x18\x02 \x01(\x08\x12$\n\x1c\x63ontains_uid_form_references\x18\x03 \x01(\x08\x12\"\n\x1a\x63ontains_frozen_references\x18\x04 \x01(\x08\"\xd2\x02\n\x0e\x46ormulaArchive\x12\x31\n\x0e\x41ST_node_array\x18\x01 \x02(\x0b\x32\x19.TSCE.ASTNodeArrayArchive\x12\x13\n\x0bhost_column\x18\x02 \x01(\r\x12\x10\n\x08host_row\x18\x03 \x01(\r\x12\x1f\n\x17host_column_is_negative\x18\x04 \x01(\x08\x12\x1c\n\x14host_row_is_negative\x18\x05 \x01(\x08\x12?\n\x11translation_flags\x18\x06 \x01(\x0b\x32$.TSCE.FormulaTranslationFlagsArchive\x12!\n\x0ehost_table_uid\x18\x07 \x01(\x0b\x32\t.TSP.UUID\x12\"\n\x0fhost_column_uid\x18\x08 \x01(\x0b\x32\t.TSP.UUID\x12\x1f\n\x0chost_row_uid\x18\t \x01(\x0b\x32\t.TSP.UUID\"I\n\x0e\x46unctorArchive\x12%\n\x07\x66ormula\x18\x01 \x02(\x0b\x32\x14.TSCE.FormulaArchive\x12\x10\n\x08num_args\x18\x02 \x02(\r\"\xb9\x03\n\x13\x46ormatStructArchive\x12\x13\n\x0b\x66ormat_type\x18\x01 \x02(\r\x12\x16\n\x0e\x64\x65\x63imal_places\x18\x02 \x01(\r\x12\x15\n\rcurrency_code\x18\x03 \x01(\t\x12\x16\n\x0enegative_style\x18\x04 \x01(\r\x12 \n\x18show_thousands_separator\x18\x05 \x01(\x08\x12\x1c\n\x14use_accounting_style\x18\x06 \x01(\x08\x12\x16\n\x0e\x64uration_style\x18\x07 \x01(\r\x12\x0c\n\x04\x62\x61se\x18\x08 \x01(\r\x12\x13\n\x0b\x62\x61se_places\x18\t \x01(\r\x12\x1b\n\x13\x62\x61se_use_minus_sign\x18\n \x01(\x08\x12\x19\n\x11\x66raction_accuracy\x18\x0b \x01(\r\x12\x1c\n\x14suppress_date_format\x18\x0c \x01(\x08\x12\x1c\n\x14suppress_time_format\x18\r \x01(\x08\x12\x18\n\x10\x64\x61te_time_format\x18\x0e \x01(\t\x12\x1d\n\x15\x64uration_unit_largest\x18\x0f \x01(\r\x12\x1e\n\x16\x64uration_unit_smallest\x18\x10 \x01(\r\"~\n\x16RangeCoordinateArchive\x12\x17\n\x0ftop_left_column\x18\x01 \x02(\r\x12\x14\n\x0ctop_left_row\x18\x02 \x02(\r\x12\x1b\n\x13\x62ottom_right_column\x18\x03 \x02(\r\x12\x18\n\x10\x62ottom_right_row\x18\x04 \x02(\r\"\x81\x01\n\x19TableTransposeInfoArchive\x12\x1d\n\x15number_of_footer_rows\x18\x03 \x02(\r\x12\x45\n\x1f\x62ody_range_for_transposed_table\x18\x04 \x02(\x0b\x32\x1c.TSCE.RangeCoordinateArchive\"c\n\x17MergeOriginMovedArchive\x12\x12\n\nsrc_column\x18\x01 \x03(\r\x12\x0f\n\x07src_row\x18\x02 \x03(\r\x12\x12\n\ndst_column\x18\x03 \x03(\r\x12\x0f\n\x07\x64st_row\x18\x04 \x03(\r\"\xcb\x07\n\x15OwnerUIDMapperArchive\x12\x1c\n\ttable_uid\x18\x01 \x02(\x0b\x32\t.TSP.UUID\x12!\n\x0enext_table_uid\x18\x02 \x02(\x0b\x32\t.TSP.UUID\x12\x32\n\x1fhidden_state_for_rows_owner_uid\x18\x03 \x02(\x0b\x32\t.TSP.UUID\x12\x37\n$next_hidden_state_for_rows_owner_uid\x18\x04 \x02(\x0b\x32\t.TSP.UUID\x12\x35\n\"hidden_state_for_columns_owner_uid\x18\x05 \x02(\x0b\x32\t.TSP.UUID\x12:\n\'next_hidden_state_for_columns_owner_uid\x18\x06 \x02(\x0b\x32\t.TSP.UUID\x12.\n\x1b\x63onditional_style_owner_uid\x18\x07 \x02(\x0b\x32\t.TSP.UUID\x12\x33\n next_conditional_style_owner_uid\x18\x08 \x02(\x0b\x32\t.TSP.UUID\x12\x38\n%sort_rule_reference_tracker_owner_uid\x18\t \x02(\x0b\x32\t.TSP.UUID\x12=\n*next_sort_rule_reference_tracker_owner_uid\x18\n \x02(\x0b\x32\t.TSP.UUID\x12\"\n\x0fmerge_owner_uid\x18\x0b \x02(\x0b\x32\t.TSP.UUID\x12\'\n\x14next_merge_owner_uid\x18\x0c \x02(\x0b\x32\t.TSP.UUID\x12%\n\x12\x63\x61tegory_owner_uid\x18\r \x02(\x0b\x32\t.TSP.UUID\x12*\n\x17next_category_owner_uid\x18\x0e \x02(\x0b\x32\t.TSP.UUID\x12\x30\n\x1d\x63\x61tegory_aggregates_owner_uid\x18\x0f \x02(\x0b\x32\t.TSP.UUID\x12\x35\n\"next_category_aggregates_owner_uid\x18\x10 \x02(\x0b\x32\t.TSP.UUID\x12\x1f\n\x0cgroup_by_uid\x18\x11 \x02(\x0b\x32\t.TSP.UUID\x12$\n\x11next_group_by_uid\x18\x12 \x02(\x0b\x32\t.TSP.UUID\x12.\n\x1bpencil_annotation_owner_uid\x18\x13 \x02(\x0b\x32\t.TSP.UUID\x12\x33\n next_pencil_annotation_owner_uid\x18\x14 \x02(\x0b\x32\t.TSP.UUID\"\xcd\x01\n\x1aRewriteTableUIDInfoArchive\x12O\n\rtable_uid_map\x18\x01 \x03(\x0b\x32\x38.TSCE.RewriteTableUIDInfoArchive.TableUIDMapEntryArchive\x1a^\n\x17TableUIDMapEntryArchive\x12!\n\x0eprev_table_uid\x18\x01 \x02(\x0b\x32\t.TSP.UUID\x12 \n\rnew_table_uid\x18\x02 \x02(\x0b\x32\t.TSP.UUID\"\xe7\x04\n\x14GroupByChangeArchive\x12:\n\x0b\x63hange_type\x18\x01 \x02(\x0e\x32%.TSCE.GroupByChangeArchive.ChangeType\x12\x1f\n\x0cgroup_by_uid\x18\x02 \x02(\x0b\x32\t.TSP.UUID\x12\x16\n\x0eprevious_level\x18\x03 \x01(\r\x12\x15\n\rupdated_level\x18\x04 \x01(\r\x12\x34\n\x17previous_to_updated_map\x18\x05 \x01(\x0b\x32\x13.TSP.UUIDMapArchive\x12\x34\n\x17updated_to_previous_map\x18\x06 \x01(\x0b\x32\x13.TSP.UUIDMapArchive\x12%\n\x12removed_group_uids\x18\x07 \x03(\x0b\x32\t.TSP.UUID\x12W\n\x17grouping_column_changes\x18\x08 \x03(\x0b\x32\x36.TSCE.GroupByChangeArchive.GroupingColumnChangeArchive\x1a\x43\n\x1bGroupingColumnChangeArchive\x12\x11\n\told_level\x18\x01 \x02(\r\x12\x11\n\tnew_level\x18\x02 \x02(\r\"\x91\x01\n\nChangeType\x12\x08\n\x04NONE\x10\x00\x12\x16\n\x12GROUP_VALUE_CHANGE\x10\x01\x12\x1b\n\x17GROUP_DEFINITION_CHANGE\x10\x02\x12\x16\n\x12REMOVE_GROUP_LEVEL\x10\x03\x12\x13\n\x0f\x41\x44\x44_GROUP_LEVEL\x10\x04\x12\x0b\n\x07PROMOTE\x10\x05\x12\n\n\x06\x44\x45MOTE\x10\x06\"r\n\x1eRewriteGroupNodeUIDInfoArchive\x12\x1f\n\x0cgroup_by_uid\x18\x01 \x01(\x0b\x32\t.TSP.UUID\x12/\n\x12group_node_uid_map\x18\x02 \x02(\x0b\x32\x13.TSP.UUIDMapArchive\"\x8e\x01\n\x12IndexedUidsArchive\x12\x31\n\x04uids\x18\x01 \x03(\x0b\x32#.TSCE.IndexedUidsArchive.IndexedUid\x1a\x45\n\nIndexedUid\x12 \n\ruid_for_index\x18\x01 \x02(\x0b\x32\t.TSP.UUID\x12\x15\n\rindex_for_uid\x18\x02 \x02(\r\"w\n\x18RewriteRangeEntryArchive\x12\x16\n\x0erange_location\x18\x01 \x02(\r\x12\x14\n\x0crange_length\x18\x02 \x02(\r\x12\x1d\n\nrange_uids\x18\x03 \x03(\x0b\x32\t.TSP.UUID\x12\x0e\n\x06offset\x18\x04 \x02(\r\"\xf2\x02\n\x1b\x43olumnOrRowUuidsInfoArchive\x12\x0f\n\x07is_rows\x18\x01 \x02(\x08\x12\x1c\n\ttable_uid\x18\x02 \x02(\x0b\x32\t.TSP.UUID\x12\'\n\x14\x63ond_style_owner_uid\x18\x03 \x02(\x0b\x32\t.TSP.UUID\x12\x1f\n\x0cgroup_by_uid\x18\x04 \x02(\x0b\x32\t.TSP.UUID\x12&\n\x04uids\x18\x05 \x02(\x0b\x32\x18.TSCE.IndexedUidsArchive\x12\x35\n\rrange_entries\x18\x06 \x03(\x0b\x32\x1e.TSCE.RewriteRangeEntryArchive\x12\x31\n\x0btable_range\x18\x07 \x02(\x0b\x32\x1c.TSCE.RangeCoordinateArchive\x12 \n\rinsert_at_uid\x18\x08 \x01(\x0b\x32\t.TSP.UUID\x12&\n\x13insert_opposite_uid\x18\t \x01(\x0b\x32\t.TSP.UUID\"\x8c\x01\n\x11RegionInfoArchive\x12\x1c\n\ttable_uid\x18\x01 \x02(\x0b\x32\t.TSP.UUID\x12-\n\x0b\x63olumn_uids\x18\x02 \x02(\x0b\x32\x18.TSCE.IndexedUidsArchive\x12*\n\x08row_uids\x18\x03 \x02(\x0b\x32\x18.TSCE.IndexedUidsArchive\"\xfa\x01\n\x16RegionMovedInfoArchive\x12+\n\nsrc_region\x18\x01 \x02(\x0b\x32\x17.TSCE.RegionInfoArchive\x12+\n\ndst_region\x18\x02 \x02(\x0b\x32\x17.TSCE.RegionInfoArchive\x12\x11\n\tspan_rows\x18\x03 \x01(\x08\x12\x14\n\x0cspan_columns\x18\x04 \x01(\x08\x12\x34\n\x13original_src_region\x18\x05 \x01(\x0b\x32\x17.TSCE.RegionInfoArchive\x12\'\n\x14\x66inal_dest_table_uid\x18\x06 \x01(\x0b\x32\t.TSP.UUID\"=\n\x12MergeSourceArchive\x12\x14\n\x0c\x63oord_column\x18\x01 \x02(\r\x12\x11\n\tcoord_row\x18\x02 \x02(\r\"\xdb\t\n\x19\x46ormulaRewriteSpecArchive\x12\x41\n\x0crewrite_type\x18\x01 \x02(\x0e\x32+.TSCE.FormulaRewriteSpecArchive.RewriteType\x12\x1c\n\ttable_uid\x18\x02 \x01(\x0b\x32\t.TSP.UUID\x12\'\n\x14\x63ond_style_owner_uid\x18\x03 \x01(\x0b\x32\t.TSP.UUID\x12\x1f\n\x0cgroup_by_uid\x18\x04 \x01(\x0b\x32\t.TSP.UUID\x12\x43\n\x18\x63olumn_or_row_uuids_info\x18\x05 \x01(\x0b\x32!.TSCE.ColumnOrRowUuidsInfoArchive\x12G\n\x1c\x61ux_column_or_row_uuids_info\x18\x06 \x01(\x0b\x32!.TSCE.ColumnOrRowUuidsInfoArchive\x12\x37\n\x11region_moved_info\x18\x07 \x01(\x0b\x32\x1c.TSCE.RegionMovedInfoArchive\x12,\n\x0bregion_info\x18\x08 \x01(\x0b\x32\x17.TSCE.RegionInfoArchive\x12?\n\x15rewrite_table_id_info\x18\t \x01(\x0b\x32 .TSCE.RewriteTableUIDInfoArchive\x12>\n\x15transposed_table_info\x18\n \x01(\x0b\x32\x1f.TSCE.TableTransposeInfoArchive\x12>\n\x17merge_origin_moved_info\x18\x0b \x01(\x0b\x32\x1d.TSCE.MergeOriginMovedArchive\x12.\n\x0cmerge_source\x18\x0c \x01(\x0b\x32\x18.TSCE.MergeSourceArchive\x12=\n\x0fgroup_node_info\x18\r \x01(\x0b\x32$.TSCE.RewriteGroupNodeUIDInfoArchive\x12\x32\n\x0egroupby_change\x18\x0e \x01(\x0b\x32\x1a.TSCE.GroupByChangeArchive\x12\x12\n\nis_inverse\x18\x0f \x01(\x08\"\xa5\x03\n\x0bRewriteType\x12\x10\n\x0c\x44\x45LETE_OWNER\x10\x04\x12\x13\n\x0fTRANSPOSE_TABLE\x10\x07\x12\x1a\n\x16REMOVE_COLUMNS_OR_ROWS\x10\x08\x12\x1a\n\x16INSERT_COLUMNS_OR_ROWS\x10\t\x12\x18\n\x14MOVE_COLUMNS_OR_ROWS\x10\n\x12\x0f\n\x0bMOVE_REGION\x10\x0b\x12\r\n\tSORT_ROWS\x10\x0c\x12\x0f\n\x0bMERGE_CELLS\x10\r\x12\x14\n\x10UNDO_MERGE_CELLS\x10\x0e\x12\x19\n\x15TABLE_ID_REASSIGNMENT\x10\x0f\x12\x10\n\x0cINSERT_OWNER\x10\x10\x12\x16\n\x12MERGE_ORIGIN_MOVED\x10\x11\x12\x10\n\x0cREORDER_ROWS\x10\x12\x12\x1f\n\x1bGROUP_NODE_UID_REASSIGNMENT\x10\x13\x12\x1a\n\x16\x42\x41SE_TO_CHROME_REWRITE\x10\x14\x12\x1a\n\x16\x43HROME_TO_BASE_REWRITE\x10\x15\x12\x15\n\x11GROUP_NODE_CHANGE\x10\x16\x12\x0f\n\x0bPASTED_AREA\x10\x17\"3\n\x13HauntedOwnerArchive\x12\x1c\n\towner_uid\x18\x01 \x02(\x0b\x32\t.TSP.UUID\"H\n\x15\x43\x65llCoordinateArchive\x12\x12\n\npackedData\x18\x01 \x01(\x07\x12\x0e\n\x06\x63olumn\x18\x02 \x01(\r\x12\x0b\n\x03row\x18\x03 \x01(\r\"N\n\x1b\x43\x65llCoordinateVectorArchive\x12/\n\ncell_coord\x18\x01 \x03(\x0b\x32\x1b.TSCE.CellCoordinateArchive\"p\n ExpandedCellRefObjectPairArchive\x12,\n\x08\x63\x65ll_ref\x18\x01 \x02(\x0b\x32\x1a.TSCE.CellReferenceArchive\x12\x1e\n\x06object\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\"g\n\x1f\x45xpandedCellRefObjectMapArchive\x12\x44\n\x14\x63\x65ll_ref_object_pair\x18\x01 \x03(\x0b\x32&.TSCE.ExpandedCellRefObjectPairArchive\"|\n\x15\x46ormulaAtCoordArchive\x12\x0e\n\x06\x63olumn\x18\x01 \x02(\r\x12\x0b\n\x03row\x18\x02 \x02(\r\x12%\n\x07\x66ormula\x18\x03 \x01(\x0b\x32\x14.TSCE.FormulaArchive\x12\x1f\n\x17repeat_previous_formula\x18\x04 \x01(\x08\"\x8b\x01\n\x1f\x46ormulaCoordPairsByOwnerArchive\x12\x12\n\nowner_kind\x18\x01 \x02(\r\x12\x1c\n\towner_uid\x18\x02 \x01(\x0b\x32\t.TSP.UUID\x12\x36\n\x11\x66ormula_at_coords\x18\x03 \x03(\x0b\x32\x1b.TSCE.FormulaAtCoordArchive\"[\n\x16\x46ormulasForUndoArchive\x12\x41\n\x12\x66ormulas_for_owner\x18\x01 \x03(\x0b\x32%.TSCE.FormulaCoordPairsByOwnerArchive\"q\n\x1c\x46ormulaRewriteCommandArchive\x12-\n\x15table_rewrite_command\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\x12\"\n\x05super\x18\x02 \x01(\x0b\x32\x13.TSK.CommandArchive\"\xc5\x01\n\"ExtendTableIDHistoryCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x35\n\x0crewrite_spec\x18\x02 \x02(\x0b\x32\x1f.TSCE.FormulaRewriteSpecArchive\x12\x44\n\x1atable_uid_history_rollback\x18\x03 \x01(\x0b\x32 .TSCE.RewriteTableUIDInfoArchive\"^\n!NumberTrackedReferencePairArchive\x12\x0e\n\x06number\x18\x01 \x02(\r\x12)\n\x11tracked_reference\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\"t\n\"NumberToTrackedReferenceMapArchive\x12N\n\x1dnumber_tracked_reference_pair\x18\x01 \x03(\x0b\x32\'.TSCE.NumberTrackedReferencePairArchive\"\xb3\x02\n&TrackedReferencesRewriteCommandArchive\x12U\n\x1freferences_in_reference_tracker\x18\x01 \x01(\x0b\x32(.TSCE.NumberToTrackedReferenceMapArchiveB\x02\x18\x01\x12W\n!original_tracked_reference_copies\x18\x02 \x01(\x0b\x32(.TSCE.NumberToTrackedReferenceMapArchiveB\x02\x18\x01\x12\x35\n\x0crewrite_spec\x18\x03 \x01(\x0b\x32\x1f.TSCE.FormulaRewriteSpecArchive\x12\"\n\x05super\x18\x04 \x02(\x0b\x32\x13.TSK.CommandArchive\"U\n\x17TrackedReferenceArchive\x12&\n\x03\x61st\x18\x01 \x02(\x0b\x32\x19.TSCE.ASTNodeArrayArchive\x12\x12\n\nformula_id\x18\x02 \x02(\r\"v\n\x1f\x45xpandedTrackedReferenceArchive\x12&\n\x03\x61st\x18\x01 \x02(\x0b\x32\x19.TSCE.ASTNodeArrayArchive\x12\x16\n\x0e\x66ormula_column\x18\x02 \x02(\r\x12\x13\n\x0b\x66ormula_row\x18\x03 \x02(\r\"\x83\x02\n\x17ReferenceTrackerArchive\x12 \n\x04uuid\x18\x01 \x02(\x0b\x32\x12.TSP.CFUUIDArchive\x12-\n\x11tracked_reference\x18\x02 \x03(\x0b\x32\x0e.TSP.ReferenceB\x02\x18\x01\x12\x42\n\x1b\x63ontained_tracked_reference\x18\x03 \x03(\x0b\x32\x1d.TSCE.TrackedReferenceArchive\x12S\n$contained_expanded_tracked_reference\x18\x04 \x03(\x0b\x32%.TSCE.ExpandedTrackedReferenceArchive\"n\n\x17\x42ooleanCellValueArchive\x12\r\n\x05value\x18\x01 \x02(\x08\x12(\n\x06\x66ormat\x18\x02 \x01(\x0b\x32\x18.TSK.FormatStructArchive\x12\x1a\n\x12\x66ormat_is_explicit\x18\x03 \x01(\x08\"\x8b\x01\n\x14\x44\x61teCellValueArchive\x12\r\n\x05value\x18\x01 \x02(\x01\x12(\n\x06\x66ormat\x18\x02 \x02(\x0b\x32\x18.TSK.FormatStructArchive\x12\x1e\n\x12\x66ormat_is_implicit\x18\x03 \x01(\x08\x42\x02\x18\x01\x12\x1a\n\x12\x66ormat_is_explicit\x18\x04 \x01(\x08\"\xe3\x01\n\x16NumberCellValueArchive\x12\r\n\x05value\x18\x01 \x01(\x01\x12\x12\n\nunit_index\x18\x02 \x01(\x05\x12\x15\n\rcurrency_code\x18\x05 \x01(\t\x12(\n\x06\x66ormat\x18\x03 \x02(\x0b\x32\x18.TSK.FormatStructArchive\x12\x1e\n\x12\x66ormat_is_implicit\x18\x04 \x01(\x08\x42\x02\x18\x01\x12\x1a\n\x12\x66ormat_is_explicit\x18\x06 \x01(\x08\x12\x13\n\x0b\x64\x65\x63imal_low\x18\x07 \x01(\x04\x12\x14\n\x0c\x64\x65\x63imal_high\x18\x08 \x01(\x04\"\xc0\x01\n\x16StringCellValueArchive\x12\r\n\x05value\x18\x01 \x02(\t\x12(\n\x06\x66ormat\x18\x02 \x02(\x0b\x32\x18.TSK.FormatStructArchive\x12\x1e\n\x12\x66ormat_is_implicit\x18\x03 \x01(\x08\x42\x02\x18\x01\x12\x1a\n\x12\x66ormat_is_explicit\x18\x04 \x01(\x08\x12\x10\n\x08is_regex\x18\x05 \x01(\x08\x12\x1f\n\x17is_case_sensitive_regex\x18\x06 \x01(\x08\"\xcd\x03\n\x15\x45rrorCellValueArchive\x12\x39\n\nerror_type\x18\x01 \x02(\x0e\x32%.TSCE.ErrorCellValueArchive.ErrorType\x12\x16\n\x0e\x65xtra_info_int\x18\x03 \x01(\x05\x12\x19\n\x11\x65xtra_info_string\x18\x04 \x01(\t\x12\x19\n\x11\x65xtra_info_double\x18\x05 \x01(\x01\"\xaa\x02\n\tErrorType\x12\x10\n\x0cUnknownError\x10\x01\x12\x1d\n\x19InvalidLiveStockAttribute\x10o\x12 \n\x1cInvalidLiveCurrencyAttribute\x10p\x12#\n\x1fInvalidHistoricalStockAttribute\x10q\x12&\n\"InvalidHistoricalCurrencyAttribute\x10r\x12\x19\n\x15InvalidHistoricalDate\x10s\x12\x18\n\x14NoTradingInformation\x10t\x12\x14\n\x10InvalidStockCode\x10u\x12\x17\n\x13InvalidCurrencyPair\x10v\x12\x19\n\x15RemoteDataServerError\x10w\"\xb3\x03\n\x10\x43\x65llValueArchive\x12=\n\x0f\x63\x65ll_value_type\x18\x01 \x02(\x0e\x32$.TSCE.CellValueArchive.CellValueType\x12\x34\n\rboolean_value\x18\x02 \x01(\x0b\x32\x1d.TSCE.BooleanCellValueArchive\x12.\n\ndate_value\x18\x03 \x01(\x0b\x32\x1a.TSCE.DateCellValueArchive\x12\x32\n\x0cnumber_value\x18\x04 \x01(\x0b\x32\x1c.TSCE.NumberCellValueArchive\x12\x32\n\x0cstring_value\x18\x05 \x01(\x0b\x32\x1c.TSCE.StringCellValueArchive\x12\x30\n\x0b\x65rror_value\x18\x06 \x01(\x0b\x32\x1b.TSCE.ErrorCellValueArchive\"`\n\rCellValueType\x12\x0c\n\x08NIL_TYPE\x10\x01\x12\x10\n\x0c\x42OOLEAN_TYPE\x10\x02\x12\r\n\tDATE_TYPE\x10\x03\x12\x0f\n\x0bNUMBER_TYPE\x10\x04\x12\x0f\n\x0bSTRING_TYPE\x10\x05*\xf6\x01\n\x0f\x43\x61tegoryAggType\x12\r\n\tAGGR_NONE\x10\x00\x12\x0e\n\nAGGR_COUNT\x10\x01\x12\x0e\n\nAGGR_TOTAL\x10\x02\x12\x0c\n\x08\x41GGR_AVG\x10\x03\x12\x0c\n\x08\x41GGR_MIN\x10\x04\x12\x0c\n\x08\x41GGR_MAX\x10\x05\x12!\n\x1d\x41GGR_CHARTGROUPVALUEHIERARCHY\x10\x07\x12\x1c\n\x18\x41GGR_GROUPVALUEHIERARCHY\x10\x08\x12\x13\n\x0f\x41GGR_GROUPVALUE\x10\t\x12\x11\n\rAGGR_BODYROWS\x10\n\x12\x11\n\rAGGR_INDIRECT\x10\x0b\x12\x0e\n\nAGGR_LABEL\x10\x0c')
  ,
  dependencies=[TSPMessages__pb2.DESCRIPTOR,TSKArchives__pb2.DESCRIPTOR,])

_CATEGORYAGGTYPE = _descriptor.EnumDescriptor(
  name='CategoryAggType',
  full_name='TSCE.CategoryAggType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AGGR_NONE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGGR_COUNT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGGR_TOTAL', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGGR_AVG', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGGR_MIN', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGGR_MAX', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGGR_CHARTGROUPVALUEHIERARCHY', index=6, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGGR_GROUPVALUEHIERARCHY', index=7, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGGR_GROUPVALUE', index=8, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGGR_BODYROWS', index=9, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGGR_INDIRECT', index=10, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGGR_LABEL', index=11, number=12,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=29788,
  serialized_end=30034,
)
_sym_db.RegisterEnumDescriptor(_CATEGORYAGGTYPE)

CategoryAggType = enum_type_wrapper.EnumTypeWrapper(_CATEGORYAGGTYPE)
AGGR_NONE = 0
AGGR_COUNT = 1
AGGR_TOTAL = 2
AGGR_AVG = 3
AGGR_MIN = 4
AGGR_MAX = 5
AGGR_CHARTGROUPVALUEHIERARCHY = 7
AGGR_GROUPVALUEHIERARCHY = 8
AGGR_GROUPVALUE = 9
AGGR_BODYROWS = 10
AGGR_INDIRECT = 11
AGGR_LABEL = 12


_REFERENCEARCHIVE_REFERENCETYPE = _descriptor.EnumDescriptor(
  name='ReferenceType',
  full_name='TSCE.ReferenceArchive.ReferenceType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CELL_REFERENCE', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RANGE_REFERENCE', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NAME_DEPENDENCY', index=2, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2405,
  serialized_end=2482,
)
_sym_db.RegisterEnumDescriptor(_REFERENCEARCHIVE_REFERENCETYPE)

_SPANNINGDEPENDENCIESARCHIVE_RANGECONTEXT = _descriptor.EnumDescriptor(
  name='RangeContext',
  full_name='TSCE.SpanningDependenciesArchive.RangeContext',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DEFAULT', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INCLUDE_HEADERS', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7233,
  serialized_end=7281,
)
_sym_db.RegisterEnumDescriptor(_SPANNINGDEPENDENCIESARCHIVE_RANGECONTEXT)

_SPANNINGDEPENDENCIESEXPANDEDARCHIVE_RANGECONTEXT = _descriptor.EnumDescriptor(
  name='RangeContext',
  full_name='TSCE.SpanningDependenciesExpandedArchive.RangeContext',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DEFAULT', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INCLUDE_HEADERS', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7233,
  serialized_end=7281,
)
_sym_db.RegisterEnumDescriptor(_SPANNINGDEPENDENCIESEXPANDEDARCHIVE_RANGECONTEXT)

_CELLERRORSARCHIVE_ERRORFLAVOR = _descriptor.EnumDescriptor(
  name='ErrorFlavor',
  full_name='TSCE.CellErrorsArchive.ErrorFlavor',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REF_ERROR', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CIRCULAR_REF_ERROR', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNSUPPORTED_FUNCTION_ERROR', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8494,
  serialized_end=8599,
)
_sym_db.RegisterEnumDescriptor(_CELLERRORSARCHIVE_ERRORFLAVOR)

_CALCULATIONENGINEARCHIVE_EXCELIMPORTDATEMODE = _descriptor.EnumDescriptor(
  name='ExcelImportDateMode',
  full_name='TSCE.CalculationEngineArchive.ExcelImportDateMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DATE_MODE_1900', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DATE_MODE_1900_LEGACY', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DATE_MODE_1904_LEGACY', index=2, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=13772,
  serialized_end=13867,
)
_sym_db.RegisterEnumDescriptor(_CALCULATIONENGINEARCHIVE_EXCELIMPORTDATEMODE)

_ASTNODEARRAYARCHIVE_ASTNODETYPE = _descriptor.EnumDescriptor(
  name='ASTNodeType',
  full_name='TSCE.ASTNodeArrayArchive.ASTNodeType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ADDITION_NODE', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUBTRACTION_NODE', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MULTIPLICATION_NODE', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DIVISION_NODE', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='POWER_NODE', index=4, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONCATENATION_NODE', index=5, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GREATER_THAN_NODE', index=6, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GREATER_THAN_OR_EQUAL_TO_NODE', index=7, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LESS_THAN_NODE', index=8, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LESS_THAN_OR_EQUAL_TO_NODE', index=9, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EQUAL_TO_NODE', index=10, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_EQUAL_TO_NODE', index=11, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NEGATION_NODE', index=12, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PLUS_SIGN_NODE', index=13, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PERCENT_NODE', index=14, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FUNCTION_NODE', index=15, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NUMBER_NODE', index=16, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BOOLEAN_NODE', index=17, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STRING_NODE', index=18, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DATE_NODE', index=19, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DURATION_NODE', index=20, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EMPTY_ARGUMENT_NODE', index=21, number=22,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOKEN_NODE', index=22, number=23,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ARRAY_NODE', index=23, number=24,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LIST_NODE', index=24, number=25,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='THUNK_NODE', index=25, number=26,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOCAL_CELL_REFERENCE_NODE', index=26, number=27,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CROSS_TABLE_CELL_REFERENCE_NODE', index=27, number=28,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COLON_NODE', index=28, number=29,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REFERENCE_ERROR_NODE', index=29, number=30,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_FUNCTION_NODE', index=30, number=31,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='APPEND_WHITESPACE_NODE', index=31, number=32,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PREPEND_WHITESPACE_NODE', index=32, number=33,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BEGIN_EMBEDDED_NODE_ARRAY', index=33, number=34,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='END_THUNK_NODE', index=34, number=35,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CELL_REFERENCE_NODE', index=35, number=36,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COLON_NODE_WITH_UIDS', index=36, number=45,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REFERENCE_ERROR_WITH_UIDS', index=37, number=46,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UID_REFERENCE_NODE', index=38, number=48,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LET_NODE', index=39, number=52,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LET_VAR_NODE', index=40, number=53,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LET_END_NODE', index=41, number=54,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LINKED_CELL_REF_NODE', index=42, number=63,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LINKED_COLUMN_REF_NODE', index=43, number=64,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LINKED_ROW_REF_NODE', index=44, number=65,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CATEGORY_REF_NODE', index=45, number=66,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COLON_TRACT_NODE', index=46, number=67,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=19193,
  serialized_end=20258,
)
_sym_db.RegisterEnumDescriptor(_ASTNODEARRAYARCHIVE_ASTNODETYPE)

_ASTNODEARRAYARCHIVE_ASTUIDTRACTPURPOSE = _descriptor.EnumDescriptor(
  name='ASTUidTractPurpose',
  full_name='TSCE.ASTNodeArrayArchive.ASTUidTractPurpose',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UIDS_INCLUDED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UIDS_PREMERGE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UIDS_PREMOVEREGION', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UIDS_EXCLUDED', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UIDS_ACTIVE', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UIDS_PREMERGE_TOPLEFT', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UIDS_REMOVED_BY_MOVE', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=20261,
  serialized_end=20432,
)
_sym_db.RegisterEnumDescriptor(_ASTNODEARRAYARCHIVE_ASTUIDTRACTPURPOSE)

_GROUPBYCHANGEARCHIVE_CHANGETYPE = _descriptor.EnumDescriptor(
  name='ChangeType',
  full_name='TSCE.GroupByChangeArchive.ChangeType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GROUP_VALUE_CHANGE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GROUP_DEFINITION_CHANGE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REMOVE_GROUP_LEVEL', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADD_GROUP_LEVEL', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROMOTE', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEMOTE', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=23504,
  serialized_end=23649,
)
_sym_db.RegisterEnumDescriptor(_GROUPBYCHANGEARCHIVE_CHANGETYPE)

_FORMULAREWRITESPECARCHIVE_REWRITETYPE = _descriptor.EnumDescriptor(
  name='RewriteType',
  full_name='TSCE.FormulaRewriteSpecArchive.RewriteType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DELETE_OWNER', index=0, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRANSPOSE_TABLE', index=1, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REMOVE_COLUMNS_OR_ROWS', index=2, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INSERT_COLUMNS_OR_ROWS', index=3, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MOVE_COLUMNS_OR_ROWS', index=4, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MOVE_REGION', index=5, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SORT_ROWS', index=6, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MERGE_CELLS', index=7, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNDO_MERGE_CELLS', index=8, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TABLE_ID_REASSIGNMENT', index=9, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INSERT_OWNER', index=10, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MERGE_ORIGIN_MOVED', index=11, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REORDER_ROWS', index=12, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GROUP_NODE_UID_REASSIGNMENT', index=13, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BASE_TO_CHROME_REWRITE', index=14, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHROME_TO_BASE_REWRITE', index=15, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GROUP_NODE_CHANGE', index=16, number=22,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PASTED_AREA', index=17, number=23,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=25688,
  serialized_end=26109,
)
_sym_db.RegisterEnumDescriptor(_FORMULAREWRITESPECARCHIVE_REWRITETYPE)

_ERRORCELLVALUEARCHIVE_ERRORTYPE = _descriptor.EnumDescriptor(
  name='ErrorType',
  full_name='TSCE.ErrorCellValueArchive.ErrorType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UnknownError', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InvalidLiveStockAttribute', index=1, number=111,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InvalidLiveCurrencyAttribute', index=2, number=112,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InvalidHistoricalStockAttribute', index=3, number=113,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InvalidHistoricalCurrencyAttribute', index=4, number=114,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InvalidHistoricalDate', index=5, number=115,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NoTradingInformation', index=6, number=116,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InvalidStockCode', index=7, number=117,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InvalidCurrencyPair', index=8, number=118,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RemoteDataServerError', index=9, number=119,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=29049,
  serialized_end=29347,
)
_sym_db.RegisterEnumDescriptor(_ERRORCELLVALUEARCHIVE_ERRORTYPE)

_CELLVALUEARCHIVE_CELLVALUETYPE = _descriptor.EnumDescriptor(
  name='CellValueType',
  full_name='TSCE.CellValueArchive.CellValueType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NIL_TYPE', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BOOLEAN_TYPE', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DATE_TYPE', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NUMBER_TYPE', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STRING_TYPE', index=4, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=29689,
  serialized_end=29785,
)
_sym_db.RegisterEnumDescriptor(_CELLVALUEARCHIVE_CELLVALUETYPE)


_CELLREFERENCEARCHIVE = _descriptor.Descriptor(
  name='CellReferenceArchive',
  full_name='TSCE.CellReferenceArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='column', full_name='TSCE.CellReferenceArchive.column', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row', full_name='TSCE.CellReferenceArchive.row', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_id', full_name='TSCE.CellReferenceArchive.table_id', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=66,
  serialized_end=155,
)


_INTERNALCELLREFERENCEARCHIVE = _descriptor.Descriptor(
  name='InternalCellReferenceArchive',
  full_name='TSCE.InternalCellReferenceArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='coordinate', full_name='TSCE.InternalCellReferenceArchive.coordinate', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner_id', full_name='TSCE.InternalCellReferenceArchive.owner_id', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=157,
  serialized_end=254,
)


_RANGEREFERENCEARCHIVE = _descriptor.Descriptor(
  name='RangeReferenceArchive',
  full_name='TSCE.RangeReferenceArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='table_id', full_name='TSCE.RangeReferenceArchive.table_id', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='top_left_column', full_name='TSCE.RangeReferenceArchive.top_left_column', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='top_left_row', full_name='TSCE.RangeReferenceArchive.top_left_row', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bottom_right_column', full_name='TSCE.RangeReferenceArchive.bottom_right_column', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bottom_right_row', full_name='TSCE.RangeReferenceArchive.bottom_right_row', index=4,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=257,
  serialized_end=420,
)


_INTERNALRANGEREFERENCEARCHIVE = _descriptor.Descriptor(
  name='InternalRangeReferenceArchive',
  full_name='TSCE.InternalRangeReferenceArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner_id', full_name='TSCE.InternalRangeReferenceArchive.owner_id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range', full_name='TSCE.InternalRangeReferenceArchive.range', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=422,
  serialized_end=516,
)


_INDEXSETARCHIVE_INDEXSETENTRY = _descriptor.Descriptor(
  name='IndexSetEntry',
  full_name='TSCE.IndexSetArchive.IndexSetEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='range_begin', full_name='TSCE.IndexSetArchive.IndexSetEntry.range_begin', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range_end', full_name='TSCE.IndexSetArchive.IndexSetEntry.range_end', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=592,
  serialized_end=647,
)

_INDEXSETARCHIVE = _descriptor.Descriptor(
  name='IndexSetArchive',
  full_name='TSCE.IndexSetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='TSCE.IndexSetArchive.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_INDEXSETARCHIVE_INDEXSETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=519,
  serialized_end=647,
)


_CELLCOORDSETARCHIVE_COLUMNENTRY = _descriptor.Descriptor(
  name='ColumnEntry',
  full_name='TSCE.CellCoordSetArchive.ColumnEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='column', full_name='TSCE.CellCoordSetArchive.ColumnEntry.column', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row_set', full_name='TSCE.CellCoordSetArchive.ColumnEntry.row_set', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=736,
  serialized_end=805,
)

_CELLCOORDSETARCHIVE = _descriptor.Descriptor(
  name='CellCoordSetArchive',
  full_name='TSCE.CellCoordSetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='column_entries', full_name='TSCE.CellCoordSetArchive.column_entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CELLCOORDSETARCHIVE_COLUMNENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=650,
  serialized_end=805,
)


_INTERNALCELLREFSETARCHIVE_OWNERENTRY = _descriptor.Descriptor(
  name='OwnerEntry',
  full_name='TSCE.InternalCellRefSetArchive.OwnerEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner_id', full_name='TSCE.InternalCellRefSetArchive.OwnerEntry.owner_id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='coord_set', full_name='TSCE.InternalCellRefSetArchive.OwnerEntry.coord_set', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=904,
  serialized_end=980,
)

_INTERNALCELLREFSETARCHIVE = _descriptor.Descriptor(
  name='InternalCellRefSetArchive',
  full_name='TSCE.InternalCellRefSetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner_entries', full_name='TSCE.InternalCellRefSetArchive.owner_entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_INTERNALCELLREFSETARCHIVE_OWNERENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=808,
  serialized_end=980,
)


_COLUMNROWSIZE = _descriptor.Descriptor(
  name='ColumnRowSize',
  full_name='TSCE.ColumnRowSize',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='num_columns', full_name='TSCE.ColumnRowSize.num_columns', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_rows', full_name='TSCE.ColumnRowSize.num_rows', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=982,
  serialized_end=1042,
)


_CELLRECTARCHIVE = _descriptor.Descriptor(
  name='CellRectArchive',
  full_name='TSCE.CellRectArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='origin', full_name='TSCE.CellRectArchive.origin', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='TSCE.CellRectArchive.size', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1044,
  serialized_end=1141,
)


_CELLREFSETARCHIVE_OWNERENTRY = _descriptor.Descriptor(
  name='OwnerEntry',
  full_name='TSCE.CellRefSetArchive.OwnerEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner_uid', full_name='TSCE.CellRefSetArchive.OwnerEntry.owner_uid', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='coord_set', full_name='TSCE.CellRefSetArchive.OwnerEntry.coord_set', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1224,
  serialized_end=1312,
)

_CELLREFSETARCHIVE = _descriptor.Descriptor(
  name='CellRefSetArchive',
  full_name='TSCE.CellRefSetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner_entries', full_name='TSCE.CellRefSetArchive.owner_entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CELLREFSETARCHIVE_OWNERENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1144,
  serialized_end=1312,
)


_UIDCOORDSETARCHIVE_COLUMNENTRY = _descriptor.Descriptor(
  name='ColumnEntry',
  full_name='TSCE.UidCoordSetArchive.ColumnEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='column', full_name='TSCE.UidCoordSetArchive.ColumnEntry.column', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row_set', full_name='TSCE.UidCoordSetArchive.ColumnEntry.row_set', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1399,
  serialized_end=1467,
)

_UIDCOORDSETARCHIVE = _descriptor.Descriptor(
  name='UidCoordSetArchive',
  full_name='TSCE.UidCoordSetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='column_entries', full_name='TSCE.UidCoordSetArchive.column_entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_UIDCOORDSETARCHIVE_COLUMNENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1315,
  serialized_end=1467,
)


_UIDCELLREFSETARCHIVE_OWNERENTRY = _descriptor.Descriptor(
  name='OwnerEntry',
  full_name='TSCE.UidCellRefSetArchive.OwnerEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner_uid', full_name='TSCE.UidCellRefSetArchive.OwnerEntry.owner_uid', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='coord_set', full_name='TSCE.UidCellRefSetArchive.OwnerEntry.coord_set', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1556,
  serialized_end=1643,
)

_UIDCELLREFSETARCHIVE = _descriptor.Descriptor(
  name='UidCellRefSetArchive',
  full_name='TSCE.UidCellRefSetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner_entries', full_name='TSCE.UidCellRefSetArchive.owner_entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_UIDCELLREFSETARCHIVE_OWNERENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1470,
  serialized_end=1643,
)


_REFERENCESTODIRTYARCHIVE = _descriptor.Descriptor(
  name='ReferencesToDirtyArchive',
  full_name='TSCE.ReferencesToDirtyArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='to_dirty_owner_ids', full_name='TSCE.ReferencesToDirtyArchive.to_dirty_owner_ids', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='to_dirty_cells', full_name='TSCE.ReferencesToDirtyArchive.to_dirty_cells', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='to_dirty_cells_additional', full_name='TSCE.ReferencesToDirtyArchive.to_dirty_cells_additional', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='to_dirty_range_refs', full_name='TSCE.ReferencesToDirtyArchive.to_dirty_range_refs', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='calc_in_progress_cells', full_name='TSCE.ReferencesToDirtyArchive.calc_in_progress_cells', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1646,
  serialized_end=1979,
)


_COORDMAPPERARCHIVE_BASETOVIEWENTRY = _descriptor.Descriptor(
  name='BaseToViewEntry',
  full_name='TSCE.CoordMapperArchive.BaseToViewEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base_row', full_name='TSCE.CoordMapperArchive.BaseToViewEntry.base_row', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='view_row', full_name='TSCE.CoordMapperArchive.BaseToViewEntry.view_row', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2161,
  serialized_end=2214,
)

_COORDMAPPERARCHIVE = _descriptor.Descriptor(
  name='CoordMapperArchive',
  full_name='TSCE.CoordMapperArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='summary_and_label_rows_set', full_name='TSCE.CoordMapperArchive.summary_and_label_rows_set', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_uid', full_name='TSCE.CoordMapperArchive.table_uid', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='base_to_view_map', full_name='TSCE.CoordMapperArchive.base_to_view_map', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_COORDMAPPERARCHIVE_BASETOVIEWENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1982,
  serialized_end=2214,
)


_REFERENCEARCHIVE = _descriptor.Descriptor(
  name='ReferenceArchive',
  full_name='TSCE.ReferenceArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='reference_type', full_name='TSCE.ReferenceArchive.reference_type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_reference', full_name='TSCE.ReferenceArchive.cell_reference', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range_reference', full_name='TSCE.ReferenceArchive.range_reference', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _REFERENCEARCHIVE_REFERENCETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2217,
  serialized_end=2482,
)


_EDGEARCHIVE = _descriptor.Descriptor(
  name='EdgeArchive',
  full_name='TSCE.EdgeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='column', full_name='TSCE.EdgeArchive.column', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row', full_name='TSCE.EdgeArchive.row', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_precedent', full_name='TSCE.EdgeArchive.is_precedent', index=2,
      number=3, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner_id', full_name='TSCE.EdgeArchive.owner_id', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2484,
  serialized_end=2586,
)


_EDGESARCHIVE = _descriptor.Descriptor(
  name='EdgesArchive',
  full_name='TSCE.EdgesArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='packed_edge_without_owner', full_name='TSCE.EdgesArchive.packed_edge_without_owner', index=0,
      number=9, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='packed_edge_with_owner', full_name='TSCE.EdgesArchive.packed_edge_with_owner', index=1,
      number=10, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner_id_for_edge', full_name='TSCE.EdgesArchive.owner_id_for_edge', index=2,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='internal_owner_id_for_edge', full_name='TSCE.EdgesArchive.internal_owner_id_for_edge', index=3,
      number=12, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2589,
  serialized_end=2753,
)


_EXPANDEDEDGESARCHIVE = _descriptor.Descriptor(
  name='ExpandedEdgesArchive',
  full_name='TSCE.ExpandedEdgesArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='edge_without_owner_rows', full_name='TSCE.ExpandedEdgesArchive.edge_without_owner_rows', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='edge_without_owner_columns', full_name='TSCE.ExpandedEdgesArchive.edge_without_owner_columns', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='edge_with_owner_rows', full_name='TSCE.ExpandedEdgesArchive.edge_with_owner_rows', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='edge_with_owner_columns', full_name='TSCE.ExpandedEdgesArchive.edge_with_owner_columns', index=3,
      number=4, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='internal_owner_id_for_edge', full_name='TSCE.ExpandedEdgesArchive.internal_owner_id_for_edge', index=4,
      number=5, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2756,
  serialized_end=2946,
)


_CELLRECORDARCHIVE = _descriptor.Descriptor(
  name='CellRecordArchive',
  full_name='TSCE.CellRecordArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='column', full_name='TSCE.CellRecordArchive.column', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row', full_name='TSCE.CellRecordArchive.row', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dirty_self_plus_precedents_count', full_name='TSCE.CellRecordArchive.dirty_self_plus_precedents_count', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_in_a_cycle', full_name='TSCE.CellRecordArchive.is_in_a_cycle', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='edge', full_name='TSCE.CellRecordArchive.edge', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='contains_a_formula', full_name='TSCE.CellRecordArchive.contains_a_formula', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='has_calculated_precedents', full_name='TSCE.CellRecordArchive.has_calculated_precedents', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='calculate_precedents_on_next_recalc', full_name='TSCE.CellRecordArchive.calculate_precedents_on_next_recalc', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='translate_for_excel_import_on_next_recalc', full_name='TSCE.CellRecordArchive.translate_for_excel_import_on_next_recalc', index=8,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='edges', full_name='TSCE.CellRecordArchive.edges', index=9,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2949,
  serialized_end=3303,
)


_CELLDEPENDENCIESARCHIVE = _descriptor.Descriptor(
  name='CellDependenciesArchive',
  full_name='TSCE.CellDependenciesArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cell_record', full_name='TSCE.CellDependenciesArchive.cell_record', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_dirty_cells', full_name='TSCE.CellDependenciesArchive.num_dirty_cells', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3305,
  serialized_end=3401,
)


_CELLRECORDEXPANDEDARCHIVE = _descriptor.Descriptor(
  name='CellRecordExpandedArchive',
  full_name='TSCE.CellRecordExpandedArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='column', full_name='TSCE.CellRecordExpandedArchive.column', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row', full_name='TSCE.CellRecordExpandedArchive.row', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dirty_self_plus_precedents_count', full_name='TSCE.CellRecordExpandedArchive.dirty_self_plus_precedents_count', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_in_a_cycle', full_name='TSCE.CellRecordExpandedArchive.is_in_a_cycle', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='has_calculated_precedents', full_name='TSCE.CellRecordExpandedArchive.has_calculated_precedents', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expanded_edges', full_name='TSCE.CellRecordExpandedArchive.expanded_edges', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3404,
  serialized_end=3612,
)


_CELLDEPENDENCIESEXPANDEDARCHIVE = _descriptor.Descriptor(
  name='CellDependenciesExpandedArchive',
  full_name='TSCE.CellDependenciesExpandedArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cell_record', full_name='TSCE.CellDependenciesExpandedArchive.cell_record', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3614,
  serialized_end=3701,
)


_CELLRECORDTILEARCHIVE = _descriptor.Descriptor(
  name='CellRecordTileArchive',
  full_name='TSCE.CellRecordTileArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='internal_owner_id', full_name='TSCE.CellRecordTileArchive.internal_owner_id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tile_column_begin', full_name='TSCE.CellRecordTileArchive.tile_column_begin', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tile_row_begin', full_name='TSCE.CellRecordTileArchive.tile_row_begin', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_records', full_name='TSCE.CellRecordTileArchive.cell_records', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3704,
  serialized_end=3860,
)


_CELLDEPENDENCIESTILEDARCHIVE = _descriptor.Descriptor(
  name='CellDependenciesTiledArchive',
  full_name='TSCE.CellDependenciesTiledArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cell_record_tiles', full_name='TSCE.CellDependenciesTiledArchive.cell_record_tiles', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3862,
  serialized_end=3935,
)


_VOLATILEDEPENDENCIESARCHIVE = _descriptor.Descriptor(
  name='VolatileDependenciesArchive',
  full_name='TSCE.VolatileDependenciesArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='volatile_time_cell_column', full_name='TSCE.VolatileDependenciesArchive.volatile_time_cell_column', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volatile_time_cell_row', full_name='TSCE.VolatileDependenciesArchive.volatile_time_cell_row', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volatile_random_cell_column', full_name='TSCE.VolatileDependenciesArchive.volatile_random_cell_column', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volatile_random_cell_row', full_name='TSCE.VolatileDependenciesArchive.volatile_random_cell_row', index=3,
      number=4, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volatile_locale_cell_column', full_name='TSCE.VolatileDependenciesArchive.volatile_locale_cell_column', index=4,
      number=15, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volatile_locale_cell_row', full_name='TSCE.VolatileDependenciesArchive.volatile_locale_cell_row', index=5,
      number=16, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volatile_location_cell_column', full_name='TSCE.VolatileDependenciesArchive.volatile_location_cell_column', index=6,
      number=5, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volatile_location_cell_row', full_name='TSCE.VolatileDependenciesArchive.volatile_location_cell_row', index=7,
      number=6, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volatile_compass_cell_column', full_name='TSCE.VolatileDependenciesArchive.volatile_compass_cell_column', index=8,
      number=7, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volatile_compass_cell_row', full_name='TSCE.VolatileDependenciesArchive.volatile_compass_cell_row', index=9,
      number=8, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volatile_remote_data_cell_column', full_name='TSCE.VolatileDependenciesArchive.volatile_remote_data_cell_column', index=10,
      number=19, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volatile_remote_data_cell_row', full_name='TSCE.VolatileDependenciesArchive.volatile_remote_data_cell_row', index=11,
      number=20, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volatile_sheet_table_name_cell_column', full_name='TSCE.VolatileDependenciesArchive.volatile_sheet_table_name_cell_column', index=12,
      number=17, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volatile_sheet_table_name_cell_row', full_name='TSCE.VolatileDependenciesArchive.volatile_sheet_table_name_cell_row', index=13,
      number=18, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='calculated_dependency_cell_column', full_name='TSCE.VolatileDependenciesArchive.calculated_dependency_cell_column', index=14,
      number=9, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='calculated_dependency_cell_row', full_name='TSCE.VolatileDependenciesArchive.calculated_dependency_cell_row', index=15,
      number=10, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volatile_geometry_cell_reference', full_name='TSCE.VolatileDependenciesArchive.volatile_geometry_cell_reference', index=16,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volatile_geometry_cell', full_name='TSCE.VolatileDependenciesArchive.volatile_geometry_cell', index=17,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3938,
  serialized_end=4710,
)


_VOLATILEDEPENDENCIESEXPANDEDARCHIVE = _descriptor.Descriptor(
  name='VolatileDependenciesExpandedArchive',
  full_name='TSCE.VolatileDependenciesExpandedArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='volatile_time_cells', full_name='TSCE.VolatileDependenciesExpandedArchive.volatile_time_cells', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volatile_random_cells', full_name='TSCE.VolatileDependenciesExpandedArchive.volatile_random_cells', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volatile_locale_cells', full_name='TSCE.VolatileDependenciesExpandedArchive.volatile_locale_cells', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volatile_sheet_table_name_cells', full_name='TSCE.VolatileDependenciesExpandedArchive.volatile_sheet_table_name_cells', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volatile_remote_data_cells', full_name='TSCE.VolatileDependenciesExpandedArchive.volatile_remote_data_cells', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volatile_geometry_cell_refs', full_name='TSCE.VolatileDependenciesExpandedArchive.volatile_geometry_cell_refs', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4713,
  serialized_end=5123,
)


_RTREEINTERNALNODECONTENTSARCHIVE = _descriptor.Descriptor(
  name='RTreeInternalNodeContentsArchive',
  full_name='TSCE.RTreeInternalNodeContentsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='min', full_name='TSCE.RTreeInternalNodeContentsArchive.min', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max', full_name='TSCE.RTreeInternalNodeContentsArchive.max', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='child', full_name='TSCE.RTreeInternalNodeContentsArchive.child', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5125,
  serialized_end=5224,
)


_RTREELEAFNODECONTENTSARCHIVE = _descriptor.Descriptor(
  name='RTreeLeafNodeContentsArchive',
  full_name='TSCE.RTreeLeafNodeContentsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='min', full_name='TSCE.RTreeLeafNodeContentsArchive.min', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max', full_name='TSCE.RTreeLeafNodeContentsArchive.max', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_reference', full_name='TSCE.RTreeLeafNodeContentsArchive.cell_reference', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5226,
  serialized_end=5334,
)


_RTREENODEARCHIVE = _descriptor.Descriptor(
  name='RTreeNodeArchive',
  full_name='TSCE.RTreeNodeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='level', full_name='TSCE.RTreeNodeArchive.level', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='count', full_name='TSCE.RTreeNodeArchive.count', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='internal_node_contents', full_name='TSCE.RTreeNodeArchive.internal_node_contents', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='leaf_node_contents', full_name='TSCE.RTreeNodeArchive.leaf_node_contents', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5337,
  serialized_end=5521,
)


_RTREEARCHIVE = _descriptor.Descriptor(
  name='RTreeArchive',
  full_name='TSCE.RTreeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_file_id', full_name='TSCE.RTreeArchive.data_file_id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_size', full_name='TSCE.RTreeArchive.data_size', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_num_dims', full_name='TSCE.RTreeArchive.data_num_dims', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_elem_size', full_name='TSCE.RTreeArchive.data_elem_size', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_elem_real_size', full_name='TSCE.RTreeArchive.data_elem_real_size', index=4,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_max_nodes', full_name='TSCE.RTreeArchive.data_max_nodes', index=5,
      number=6, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_min_nodes', full_name='TSCE.RTreeArchive.data_min_nodes', index=6,
      number=7, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='root', full_name='TSCE.RTreeArchive.root', index=7,
      number=8, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5524,
  serialized_end=5741,
)


_RANGEBACKDEPENDENCYARCHIVE = _descriptor.Descriptor(
  name='RangeBackDependencyArchive',
  full_name='TSCE.RangeBackDependencyArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cell_coord_row', full_name='TSCE.RangeBackDependencyArchive.cell_coord_row', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_coord_column', full_name='TSCE.RangeBackDependencyArchive.cell_coord_column', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range_reference', full_name='TSCE.RangeBackDependencyArchive.range_reference', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='internal_range_reference', full_name='TSCE.RangeBackDependencyArchive.internal_range_reference', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5744,
  serialized_end=5948,
)


_RANGEDEPENDENCIESARCHIVE = _descriptor.Descriptor(
  name='RangeDependenciesArchive',
  full_name='TSCE.RangeDependenciesArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='back_dependency', full_name='TSCE.RangeDependenciesArchive.back_dependency', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5950,
  serialized_end=6035,
)


_RANGEPRECEDENTSTILEARCHIVE_FROMTORANGEARCHIVE = _descriptor.Descriptor(
  name='FromToRangeArchive',
  full_name='TSCE.RangePrecedentsTileArchive.FromToRangeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='from_coord', full_name='TSCE.RangePrecedentsTileArchive.FromToRangeArchive.from_coord', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='refers_to_rect', full_name='TSCE.RangePrecedentsTileArchive.FromToRangeArchive.refers_to_rect', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6165,
  serialized_end=6281,
)

_RANGEPRECEDENTSTILEARCHIVE = _descriptor.Descriptor(
  name='RangePrecedentsTileArchive',
  full_name='TSCE.RangePrecedentsTileArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='to_owner_id', full_name='TSCE.RangePrecedentsTileArchive.to_owner_id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='from_to_range', full_name='TSCE.RangePrecedentsTileArchive.from_to_range', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_RANGEPRECEDENTSTILEARCHIVE_FROMTORANGEARCHIVE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6038,
  serialized_end=6281,
)


_RANGEDEPENDENCIESTILEDARCHIVE = _descriptor.Descriptor(
  name='RangeDependenciesTiledArchive',
  full_name='TSCE.RangeDependenciesTiledArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='range_precedents_tile', full_name='TSCE.RangeDependenciesTiledArchive.range_precedents_tile', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6283,
  serialized_end=6361,
)


_SPANNINGDEPENDENCIESARCHIVE_REFERRINGCOLUMNTOLOCALCELLS = _descriptor.Descriptor(
  name='ReferringColumnToLocalCells',
  full_name='TSCE.SpanningDependenciesArchive.ReferringColumnToLocalCells',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='column', full_name='TSCE.SpanningDependenciesArchive.ReferringColumnToLocalCells.column', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range_context', full_name='TSCE.SpanningDependenciesArchive.ReferringColumnToLocalCells.range_context', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_coordinate', full_name='TSCE.SpanningDependenciesArchive.ReferringColumnToLocalCells.cell_coordinate', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6872,
  serialized_end=7042,
)

_SPANNINGDEPENDENCIESARCHIVE_REFERRINGCOLUMNTOREMOTECELLS = _descriptor.Descriptor(
  name='ReferringColumnToRemoteCells',
  full_name='TSCE.SpanningDependenciesArchive.ReferringColumnToRemoteCells',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='column', full_name='TSCE.SpanningDependenciesArchive.ReferringColumnToRemoteCells.column', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range_context', full_name='TSCE.SpanningDependenciesArchive.ReferringColumnToRemoteCells.range_context', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='internal_cell_reference', full_name='TSCE.SpanningDependenciesArchive.ReferringColumnToRemoteCells.internal_cell_reference', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7045,
  serialized_end=7231,
)

_SPANNINGDEPENDENCIESARCHIVE = _descriptor.Descriptor(
  name='SpanningDependenciesArchive',
  full_name='TSCE.SpanningDependenciesArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='column', full_name='TSCE.SpanningDependenciesArchive.column', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range_context', full_name='TSCE.SpanningDependenciesArchive.range_context', index=1,
      number=2, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell', full_name='TSCE.SpanningDependenciesArchive.cell', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_range_for_deleted_table', full_name='TSCE.SpanningDependenciesArchive.total_range_for_deleted_table', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='body_range_for_deleted_table', full_name='TSCE.SpanningDependenciesArchive.body_range_for_deleted_table', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='referring_column_to_local_cells', full_name='TSCE.SpanningDependenciesArchive.referring_column_to_local_cells', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='referring_column_to_remote_cells', full_name='TSCE.SpanningDependenciesArchive.referring_column_to_remote_cells', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SPANNINGDEPENDENCIESARCHIVE_REFERRINGCOLUMNTOLOCALCELLS, _SPANNINGDEPENDENCIESARCHIVE_REFERRINGCOLUMNTOREMOTECELLS, ],
  enum_types=[
    _SPANNINGDEPENDENCIESARCHIVE_RANGECONTEXT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6364,
  serialized_end=7281,
)


_SPANNINGDEPENDENCIESEXPANDEDARCHIVE_EXTENTRANGE = _descriptor.Descriptor(
  name='ExtentRange',
  full_name='TSCE.SpanningDependenciesExpandedArchive.ExtentRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='extent_begin', full_name='TSCE.SpanningDependenciesExpandedArchive.ExtentRange.extent_begin', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extent_end', full_name='TSCE.SpanningDependenciesExpandedArchive.ExtentRange.extent_end', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7543,
  serialized_end=7598,
)

_SPANNINGDEPENDENCIESEXPANDEDARCHIVE_EXTENTRANGEWITHTABLEWITHCONTEXT = _descriptor.Descriptor(
  name='ExtentRangeWithTableWithContext',
  full_name='TSCE.SpanningDependenciesExpandedArchive.ExtentRangeWithTableWithContext',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner_id', full_name='TSCE.SpanningDependenciesExpandedArchive.ExtentRangeWithTableWithContext.owner_id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range_context', full_name='TSCE.SpanningDependenciesExpandedArchive.ExtentRangeWithTableWithContext.range_context', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ranges', full_name='TSCE.SpanningDependenciesExpandedArchive.ExtentRangeWithTableWithContext.ranges', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7601,
  serialized_end=7802,
)

_SPANNINGDEPENDENCIESEXPANDEDARCHIVE_CELLCOORDREFERSTOEXTENTS = _descriptor.Descriptor(
  name='CellCoordRefersToExtents',
  full_name='TSCE.SpanningDependenciesExpandedArchive.CellCoordRefersToExtents',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='coordinate', full_name='TSCE.SpanningDependenciesExpandedArchive.CellCoordRefersToExtents.coordinate', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ranges_by_table_context', full_name='TSCE.SpanningDependenciesExpandedArchive.CellCoordRefersToExtents.ranges_by_table_context', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7805,
  serialized_end=7988,
)

_SPANNINGDEPENDENCIESEXPANDEDARCHIVE = _descriptor.Descriptor(
  name='SpanningDependenciesExpandedArchive',
  full_name='TSCE.SpanningDependenciesExpandedArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='coord_refers_to_spans', full_name='TSCE.SpanningDependenciesExpandedArchive.coord_refers_to_spans', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_range_for_table', full_name='TSCE.SpanningDependenciesExpandedArchive.total_range_for_table', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='body_range_for_table', full_name='TSCE.SpanningDependenciesExpandedArchive.body_range_for_table', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SPANNINGDEPENDENCIESEXPANDEDARCHIVE_EXTENTRANGE, _SPANNINGDEPENDENCIESEXPANDEDARCHIVE_EXTENTRANGEWITHTABLEWITHCONTEXT, _SPANNINGDEPENDENCIESEXPANDEDARCHIVE_CELLCOORDREFERSTOEXTENTS, ],
  enum_types=[
    _SPANNINGDEPENDENCIESEXPANDEDARCHIVE_RANGECONTEXT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7284,
  serialized_end=8038,
)


_WHOLEOWNERDEPENDENCIESARCHIVE = _descriptor.Descriptor(
  name='WholeOwnerDependenciesArchive',
  full_name='TSCE.WholeOwnerDependenciesArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dependent_cell', full_name='TSCE.WholeOwnerDependenciesArchive.dependent_cell', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8040,
  serialized_end=8131,
)


_WHOLEOWNERDEPENDENCIESEXPANDEDARCHIVE = _descriptor.Descriptor(
  name='WholeOwnerDependenciesExpandedArchive',
  full_name='TSCE.WholeOwnerDependenciesExpandedArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dependent_cells', full_name='TSCE.WholeOwnerDependenciesExpandedArchive.dependent_cells', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8133,
  serialized_end=8230,
)


_CELLERRORSARCHIVE_ERRORFORCELL = _descriptor.Descriptor(
  name='ErrorForCell',
  full_name='TSCE.CellErrorsArchive.ErrorForCell',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='coordinate', full_name='TSCE.CellErrorsArchive.ErrorForCell.coordinate', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error_flavor', full_name='TSCE.CellErrorsArchive.ErrorForCell.error_flavor', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='err_due_to_cell', full_name='TSCE.CellErrorsArchive.ErrorForCell.err_due_to_cell', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8309,
  serialized_end=8492,
)

_CELLERRORSARCHIVE = _descriptor.Descriptor(
  name='CellErrorsArchive',
  full_name='TSCE.CellErrorsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='errors', full_name='TSCE.CellErrorsArchive.errors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CELLERRORSARCHIVE_ERRORFORCELL, ],
  enum_types=[
    _CELLERRORSARCHIVE_ERRORFLAVOR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8233,
  serialized_end=8599,
)


_UUIDREFERENCESARCHIVE_TABLEREF = _descriptor.Descriptor(
  name='TableRef',
  full_name='TSCE.UuidReferencesArchive.TableRef',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner_uuid', full_name='TSCE.UuidReferencesArchive.TableRef.owner_uuid', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='coord_set', full_name='TSCE.UuidReferencesArchive.TableRef.coord_set', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8756,
  serialized_end=8843,
)

_UUIDREFERENCESARCHIVE_UUIDREF = _descriptor.Descriptor(
  name='UuidRef',
  full_name='TSCE.UuidReferencesArchive.UuidRef',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='TSCE.UuidReferencesArchive.UuidRef.uuid', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='coord_set', full_name='TSCE.UuidReferencesArchive.UuidRef.coord_set', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8845,
  serialized_end=8925,
)

_UUIDREFERENCESARCHIVE_TABLEWITHUUIDREF = _descriptor.Descriptor(
  name='TableWithUuidRef',
  full_name='TSCE.UuidReferencesArchive.TableWithUuidRef',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner_uuid', full_name='TSCE.UuidReferencesArchive.TableWithUuidRef.owner_uuid', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uuid_refs', full_name='TSCE.UuidReferencesArchive.TableWithUuidRef.uuid_refs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8927,
  serialized_end=9032,
)

_UUIDREFERENCESARCHIVE = _descriptor.Descriptor(
  name='UuidReferencesArchive',
  full_name='TSCE.UuidReferencesArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='table_refs', full_name='TSCE.UuidReferencesArchive.table_refs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_uuid_refs', full_name='TSCE.UuidReferencesArchive.table_uuid_refs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_UUIDREFERENCESARCHIVE_TABLEREF, _UUIDREFERENCESARCHIVE_UUIDREF, _UUIDREFERENCESARCHIVE_TABLEWITHUUIDREF, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8602,
  serialized_end=9032,
)


_FORMULAOWNERDEPENDENCIESARCHIVE = _descriptor.Descriptor(
  name='FormulaOwnerDependenciesArchive',
  full_name='TSCE.FormulaOwnerDependenciesArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='formula_owner_uid', full_name='TSCE.FormulaOwnerDependenciesArchive.formula_owner_uid', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='internal_formula_owner_id', full_name='TSCE.FormulaOwnerDependenciesArchive.internal_formula_owner_id', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner_kind', full_name='TSCE.FormulaOwnerDependenciesArchive.owner_kind', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_dependencies', full_name='TSCE.FormulaOwnerDependenciesArchive.cell_dependencies', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range_dependencies', full_name='TSCE.FormulaOwnerDependenciesArchive.range_dependencies', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volatile_dependencies', full_name='TSCE.FormulaOwnerDependenciesArchive.volatile_dependencies', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spanning_column_dependencies', full_name='TSCE.FormulaOwnerDependenciesArchive.spanning_column_dependencies', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spanning_row_dependencies', full_name='TSCE.FormulaOwnerDependenciesArchive.spanning_row_dependencies', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='whole_owner_dependencies', full_name='TSCE.FormulaOwnerDependenciesArchive.whole_owner_dependencies', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_errors', full_name='TSCE.FormulaOwnerDependenciesArchive.cell_errors', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formula_owner', full_name='TSCE.FormulaOwnerDependenciesArchive.formula_owner', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='base_owner_uid', full_name='TSCE.FormulaOwnerDependenciesArchive.base_owner_uid', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tiled_cell_dependencies', full_name='TSCE.FormulaOwnerDependenciesArchive.tiled_cell_dependencies', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uuid_references', full_name='TSCE.FormulaOwnerDependenciesArchive.uuid_references', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tiled_range_dependencies', full_name='TSCE.FormulaOwnerDependenciesArchive.tiled_range_dependencies', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9035,
  serialized_end=9913,
)


_FORMULAOWNERINFOARCHIVE = _descriptor.Descriptor(
  name='FormulaOwnerInfoArchive',
  full_name='TSCE.FormulaOwnerInfoArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='formula_owner_id', full_name='TSCE.FormulaOwnerInfoArchive.formula_owner_id', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_dependencies', full_name='TSCE.FormulaOwnerInfoArchive.cell_dependencies', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range_dependencies', full_name='TSCE.FormulaOwnerInfoArchive.range_dependencies', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volatile_dependencies', full_name='TSCE.FormulaOwnerInfoArchive.volatile_dependencies', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spanning_column_dependencies', full_name='TSCE.FormulaOwnerInfoArchive.spanning_column_dependencies', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spanning_row_dependencies', full_name='TSCE.FormulaOwnerInfoArchive.spanning_row_dependencies', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='whole_owner_dependencies', full_name='TSCE.FormulaOwnerInfoArchive.whole_owner_dependencies', index=6,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_errors', full_name='TSCE.FormulaOwnerInfoArchive.cell_errors', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formula_owner', full_name='TSCE.FormulaOwnerInfoArchive.formula_owner', index=8,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9916,
  serialized_end=10470,
)


_SUBFORMULAOWNERIDARCHIVE = _descriptor.Descriptor(
  name='SubFormulaOwnerIDArchive',
  full_name='TSCE.SubFormulaOwnerIDArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base_owner_uid', full_name='TSCE.SubFormulaOwnerIDArchive.base_owner_uid', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner_kind', full_name='TSCE.SubFormulaOwnerIDArchive.owner_kind', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10472,
  serialized_end=10553,
)


_OWNERIDMAPARCHIVE_OWNERIDMAPARCHIVEENTRY = _descriptor.Descriptor(
  name='OwnerIDMapArchiveEntry',
  full_name='TSCE.OwnerIDMapArchive.OwnerIDMapArchiveEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='internal_owner_id', full_name='TSCE.OwnerIDMapArchive.OwnerIDMapArchiveEntry.internal_owner_id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner_id', full_name='TSCE.OwnerIDMapArchive.OwnerIDMapArchiveEntry.owner_id', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sub_formula_owner_uid', full_name='TSCE.OwnerIDMapArchive.OwnerIDMapArchiveEntry.sub_formula_owner_uid', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10685,
  serialized_end=10837,
)

_OWNERIDMAPARCHIVE = _descriptor.Descriptor(
  name='OwnerIDMapArchive',
  full_name='TSCE.OwnerIDMapArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='map_entry', full_name='TSCE.OwnerIDMapArchive.map_entry', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unregistered_internal_owner_id', full_name='TSCE.OwnerIDMapArchive.unregistered_internal_owner_id', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_OWNERIDMAPARCHIVE_OWNERIDMAPARCHIVEENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10556,
  serialized_end=10837,
)


_UIDLOOKUPLISTARCHIVE = _descriptor.Descriptor(
  name='UidLookupListArchive',
  full_name='TSCE.UidLookupListArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuids', full_name='TSCE.UidLookupListArchive.uuids', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10839,
  serialized_end=10887,
)


_DEPENDENCYTRACKERARCHIVE = _descriptor.Descriptor(
  name='DependencyTrackerArchive',
  full_name='TSCE.DependencyTrackerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='formula_owner_info', full_name='TSCE.DependencyTrackerArchive.formula_owner_info', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dirty_leaf', full_name='TSCE.DependencyTrackerArchive.dirty_leaf', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner_id_map', full_name='TSCE.DependencyTrackerArchive.owner_id_map', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='internal_dirty_leaf', full_name='TSCE.DependencyTrackerArchive.internal_dirty_leaf', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='number_of_formulas', full_name='TSCE.DependencyTrackerArchive.number_of_formulas', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formula_owner_dependencies', full_name='TSCE.DependencyTrackerArchive.formula_owner_dependencies', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10890,
  serialized_end=11223,
)


_REMOTEDATASPECIFIERARCHIVE = _descriptor.Descriptor(
  name='RemoteDataSpecifierArchive',
  full_name='TSCE.RemoteDataSpecifierArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='function_index', full_name='TSCE.RemoteDataSpecifierArchive.function_index', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='TSCE.RemoteDataSpecifierArchive.symbol', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attribute', full_name='TSCE.RemoteDataSpecifierArchive.attribute', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='TSCE.RemoteDataSpecifierArchive.date', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11225,
  serialized_end=11326,
)


_REMOTEDATAVALUEMAPARCHIVE_REMOTEDATAMAPENTRY = _descriptor.Descriptor(
  name='RemoteDataMapEntry',
  full_name='TSCE.RemoteDataValueMapArchive.RemoteDataMapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='specifier', full_name='TSCE.RemoteDataValueMapArchive.RemoteDataMapEntry.specifier', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='TSCE.RemoteDataValueMapArchive.RemoteDataMapEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11425,
  serialized_end=11537,
)

_REMOTEDATAVALUEMAPARCHIVE = _descriptor.Descriptor(
  name='RemoteDataValueMapArchive',
  full_name='TSCE.RemoteDataValueMapArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entry', full_name='TSCE.RemoteDataValueMapArchive.entry', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_REMOTEDATAVALUEMAPARCHIVE_REMOTEDATAMAPENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11329,
  serialized_end=11537,
)


_STOCKARCHIVE_ATTRIBUTEENTRY = _descriptor.Descriptor(
  name='AttributeEntry',
  full_name='TSCE.StockArchive.AttributeEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='attribute', full_name='TSCE.StockArchive.AttributeEntry.attribute', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='TSCE.StockArchive.AttributeEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11640,
  serialized_end=11690,
)

_STOCKARCHIVE = _descriptor.Descriptor(
  name='StockArchive',
  full_name='TSCE.StockArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbol', full_name='TSCE.StockArchive.symbol', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='TSCE.StockArchive.date', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attribute', full_name='TSCE.StockArchive.attribute', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_STOCKARCHIVE_ATTRIBUTEENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11540,
  serialized_end=11690,
)


_REMOTEDATASTOREARCHIVE = _descriptor.Descriptor(
  name='RemoteDataStoreArchive',
  full_name='TSCE.RemoteDataStoreArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value_map', full_name='TSCE.RemoteDataStoreArchive.value_map', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stocks', full_name='TSCE.RemoteDataStoreArchive.stocks', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11692,
  serialized_end=11804,
)


_NAMETRACKEDREFERENCEPAIR = _descriptor.Descriptor(
  name='NameTrackedReferencePair',
  full_name='TSCE.NameTrackedReferencePair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='TSCE.NameTrackedReferencePair.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tracked_reference', full_name='TSCE.NameTrackedReferencePair.tracked_reference', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tracked_reference_id', full_name='TSCE.NameTrackedReferencePair.tracked_reference_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11806,
  serialized_end=11919,
)


_NAMESBYTRACKEDREFERENCEARCHIVE = _descriptor.Descriptor(
  name='NamesByTrackedReferenceArchive',
  full_name='TSCE.NamesByTrackedReferenceArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='table_id', full_name='TSCE.NamesByTrackedReferenceArchive.table_id', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name_tracked_reference_pair', full_name='TSCE.NamesByTrackedReferenceArchive.name_tracked_reference_pair', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11922,
  serialized_end=12061,
)


_NAMEDREFERENCEMANAGERARCHIVE = _descriptor.Descriptor(
  name='NamedReferenceManagerArchive',
  full_name='TSCE.NamedReferenceManagerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='reference_tracker', full_name='TSCE.NamedReferenceManagerArchive.reference_tracker', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='names_by_tracked_reference_by_table', full_name='TSCE.NamedReferenceManagerArchive.names_by_tracked_reference_by_table', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12064,
  serialized_end=12224,
)


_UUIDSETSTOREARCHIVE_UUIDSET = _descriptor.Descriptor(
  name='UuidSet',
  full_name='TSCE.UuidSetStoreArchive.UuidSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='TSCE.UuidSetStoreArchive.UuidSet.uuid', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='index_of_set', full_name='TSCE.UuidSetStoreArchive.UuidSet.index_of_set', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12302,
  serialized_end=12358,
)

_UUIDSETSTOREARCHIVE = _descriptor.Descriptor(
  name='UuidSetStoreArchive',
  full_name='TSCE.UuidSetStoreArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuidSet', full_name='TSCE.UuidSetStoreArchive.uuidSet', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_UUIDSETSTOREARCHIVE_UUIDSET, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12227,
  serialized_end=12358,
)


_UUIDREFERENCEMAPARCHIVE_CELLREFSFORUUID = _descriptor.Descriptor(
  name='CellRefsForUuid',
  full_name='TSCE.UuidReferenceMapArchive.CellRefsForUuid',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='TSCE.UuidReferenceMapArchive.CellRefsForUuid.uuid', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_ref', full_name='TSCE.UuidReferenceMapArchive.CellRefsForUuid.cell_ref', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_refs', full_name='TSCE.UuidReferenceMapArchive.CellRefsForUuid.cell_refs', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12464,
  serialized_end=12612,
)

_UUIDREFERENCEMAPARCHIVE = _descriptor.Descriptor(
  name='UuidReferenceMapArchive',
  full_name='TSCE.UuidReferenceMapArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cell_refs_for_uuid', full_name='TSCE.UuidReferenceMapArchive.cell_refs_for_uuid', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_UUIDREFERENCEMAPARCHIVE_CELLREFSFORUUID, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12361,
  serialized_end=12612,
)


_GROUPBYNODEMAPARCHIVE_CELLREFSFORGROUPNODE = _descriptor.Descriptor(
  name='CellRefsForGroupNode',
  full_name='TSCE.GroupByNodeMapArchive.CellRefsForGroupNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_node_uid', full_name='TSCE.GroupByNodeMapArchive.CellRefsForGroupNode.group_node_uid', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_refs', full_name='TSCE.GroupByNodeMapArchive.CellRefsForGroupNode.cell_refs', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12717,
  serialized_end=12826,
)

_GROUPBYNODEMAPARCHIVE_GROUPNODESFORGROUPBY = _descriptor.Descriptor(
  name='GroupNodesForGroupBy',
  full_name='TSCE.GroupByNodeMapArchive.GroupNodesForGroupBy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_by_uid', full_name='TSCE.GroupByNodeMapArchive.GroupNodesForGroupBy.group_by_uid', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='refs_for_group_node', full_name='TSCE.GroupByNodeMapArchive.GroupNodesForGroupBy.refs_for_group_node', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12829,
  serialized_end=12963,
)

_GROUPBYNODEMAPARCHIVE = _descriptor.Descriptor(
  name='GroupByNodeMapArchive',
  full_name='TSCE.GroupByNodeMapArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='refs_for_group_by', full_name='TSCE.GroupByNodeMapArchive.refs_for_group_by', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_GROUPBYNODEMAPARCHIVE_CELLREFSFORGROUPNODE, _GROUPBYNODEMAPARCHIVE_GROUPNODESFORGROUPBY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12615,
  serialized_end=12963,
)


_CALCULATIONENGINEARCHIVE = _descriptor.Descriptor(
  name='CalculationEngineArchive',
  full_name='TSCE.CalculationEngineArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base_date_1904', full_name='TSCE.CalculationEngineArchive.base_date_1904', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dependency_tracker', full_name='TSCE.CalculationEngineArchive.dependency_tracker', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='named_reference_manager', full_name='TSCE.CalculationEngineArchive.named_reference_manager', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='excel_import_date_mode', full_name='TSCE.CalculationEngineArchive.excel_import_date_mode', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='saved_locale_identifier_for_4_2', full_name='TSCE.CalculationEngineArchive.saved_locale_identifier_for_4_2', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='document_random_seed', full_name='TSCE.CalculationEngineArchive.document_random_seed', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uuid_reference_map', full_name='TSCE.CalculationEngineArchive.uuid_reference_map', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='document_timestamp', full_name='TSCE.CalculationEngineArchive.document_timestamp', index=7,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='document_timezone', full_name='TSCE.CalculationEngineArchive.document_timezone', index=8,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_uid_history', full_name='TSCE.CalculationEngineArchive.table_uid_history', index=9,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remote_data_store', full_name='TSCE.CalculationEngineArchive.remote_data_store', index=10,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group_node_map', full_name='TSCE.CalculationEngineArchive.group_node_map', index=11,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_name_manager', full_name='TSCE.CalculationEngineArchive.header_name_manager', index=12,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='refs_to_dirty', full_name='TSCE.CalculationEngineArchive.refs_to_dirty', index=13,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='saved_locale_identifier', full_name='TSCE.CalculationEngineArchive.saved_locale_identifier', index=14,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='begin_tracking_names_legacy_nrm', full_name='TSCE.CalculationEngineArchive.begin_tracking_names_legacy_nrm', index=15,
      number=17, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_tracking_names_legacy_nrm', full_name='TSCE.CalculationEngineArchive.end_tracking_names_legacy_nrm', index=16,
      number=18, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CALCULATIONENGINEARCHIVE_EXCELIMPORTDATEMODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12966,
  serialized_end=13867,
)


_PRESERVECOLUMNROWFLAGSARCHIVE = _descriptor.Descriptor(
  name='PreserveColumnRowFlagsArchive',
  full_name='TSCE.PreserveColumnRowFlagsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='begin_row_is_absolute', full_name='TSCE.PreserveColumnRowFlagsArchive.begin_row_is_absolute', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='begin_column_is_absolute', full_name='TSCE.PreserveColumnRowFlagsArchive.begin_column_is_absolute', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_row_is_absolute', full_name='TSCE.PreserveColumnRowFlagsArchive.end_row_is_absolute', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_column_is_absolute', full_name='TSCE.PreserveColumnRowFlagsArchive.end_column_is_absolute', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13870,
  serialized_end=14027,
)


_CATEGORYREFERENCEARCHIVE_CATREFUIDLIST = _descriptor.Descriptor(
  name='CatRefUidList',
  full_name='TSCE.CategoryReferenceArchive.CatRefUidList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='TSCE.CategoryReferenceArchive.CatRefUidList.uid', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14420,
  serialized_end=14459,
)

_CATEGORYREFERENCEARCHIVE = _descriptor.Descriptor(
  name='CategoryReferenceArchive',
  full_name='TSCE.CategoryReferenceArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_by_uid', full_name='TSCE.CategoryReferenceArchive.group_by_uid', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column_uid', full_name='TSCE.CategoryReferenceArchive.column_uid', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aggregate_type', full_name='TSCE.CategoryReferenceArchive.aggregate_type', index=2,
      number=3, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group_level', full_name='TSCE.CategoryReferenceArchive.group_level', index=3,
      number=4, type=17, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group_uids', full_name='TSCE.CategoryReferenceArchive.group_uids', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preserve_flags', full_name='TSCE.CategoryReferenceArchive.preserve_flags', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='relative_column', full_name='TSCE.CategoryReferenceArchive.relative_column', index=6,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='relative_group_uid', full_name='TSCE.CategoryReferenceArchive.relative_group_uid', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='absolute_group_uid', full_name='TSCE.CategoryReferenceArchive.absolute_group_uid', index=8,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CATEGORYREFERENCEARCHIVE_CATREFUIDLIST, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14030,
  serialized_end=14459,
)


_ASTNODEARRAYARCHIVE_ASTLOCALCELLREFERENCENODEARCHIVE = _descriptor.Descriptor(
  name='ASTLocalCellReferenceNodeArchive',
  full_name='TSCE.ASTNodeArrayArchive.ASTLocalCellReferenceNodeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='row_handle', full_name='TSCE.ASTNodeArrayArchive.ASTLocalCellReferenceNodeArchive.row_handle', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column_handle', full_name='TSCE.ASTNodeArrayArchive.ASTLocalCellReferenceNodeArchive.column_handle', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row_is_sticky', full_name='TSCE.ASTNodeArrayArchive.ASTLocalCellReferenceNodeArchive.row_is_sticky', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column_is_sticky', full_name='TSCE.ASTNodeArrayArchive.ASTLocalCellReferenceNodeArchive.column_is_sticky', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14545,
  serialized_end=14671,
)

_ASTNODEARRAYARCHIVE_ASTCROSSTABLECELLREFERENCENODEARCHIVE = _descriptor.Descriptor(
  name='ASTCrossTableCellReferenceNodeArchive',
  full_name='TSCE.ASTNodeArrayArchive.ASTCrossTableCellReferenceNodeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='row_handle', full_name='TSCE.ASTNodeArrayArchive.ASTCrossTableCellReferenceNodeArchive.row_handle', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column_handle', full_name='TSCE.ASTNodeArrayArchive.ASTCrossTableCellReferenceNodeArchive.column_handle', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row_is_sticky', full_name='TSCE.ASTNodeArrayArchive.ASTCrossTableCellReferenceNodeArchive.row_is_sticky', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column_is_sticky', full_name='TSCE.ASTNodeArrayArchive.ASTCrossTableCellReferenceNodeArchive.column_is_sticky', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_id', full_name='TSCE.ASTNodeArrayArchive.ASTCrossTableCellReferenceNodeArchive.table_id', index=4,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_reference_whitespace_after_sheet_name', full_name='TSCE.ASTNodeArrayArchive.ASTCrossTableCellReferenceNodeArchive.AST_reference_whitespace_after_sheet_name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_reference_whitespace_before_table_name', full_name='TSCE.ASTNodeArrayArchive.ASTCrossTableCellReferenceNodeArchive.AST_reference_whitespace_before_table_name', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_reference_whitespace_after_table_name', full_name='TSCE.ASTNodeArrayArchive.ASTCrossTableCellReferenceNodeArchive.AST_reference_whitespace_after_table_name', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_reference_whitespace_before_cell_address', full_name='TSCE.ASTNodeArrayArchive.ASTCrossTableCellReferenceNodeArchive.AST_reference_whitespace_before_cell_address', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14674,
  serialized_end=15051,
)

_ASTNODEARRAYARCHIVE_ASTCOLUMNCOORDINATEARCHIVE = _descriptor.Descriptor(
  name='ASTColumnCoordinateArchive',
  full_name='TSCE.ASTNodeArrayArchive.ASTColumnCoordinateArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='column', full_name='TSCE.ASTNodeArrayArchive.ASTColumnCoordinateArchive.column', index=0,
      number=1, type=17, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='absolute', full_name='TSCE.ASTNodeArrayArchive.ASTColumnCoordinateArchive.absolute', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15053,
  serialized_end=15115,
)

_ASTNODEARRAYARCHIVE_ASTROWCOORDINATEARCHIVE = _descriptor.Descriptor(
  name='ASTRowCoordinateArchive',
  full_name='TSCE.ASTNodeArrayArchive.ASTRowCoordinateArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='row', full_name='TSCE.ASTNodeArrayArchive.ASTRowCoordinateArchive.row', index=0,
      number=1, type=17, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='absolute', full_name='TSCE.ASTNodeArrayArchive.ASTRowCoordinateArchive.absolute', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15117,
  serialized_end=15173,
)

_ASTNODEARRAYARCHIVE_ASTUIDLIST = _descriptor.Descriptor(
  name='ASTUidList',
  full_name='TSCE.ASTNodeArrayArchive.ASTUidList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='TSCE.ASTNodeArrayArchive.ASTUidList.uid', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15175,
  serialized_end=15211,
)

_ASTNODEARRAYARCHIVE_ASTUIDTRACT = _descriptor.Descriptor(
  name='ASTUidTract',
  full_name='TSCE.ASTNodeArrayArchive.ASTUidTract',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='columnUids', full_name='TSCE.ASTNodeArrayArchive.ASTUidTract.columnUids', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rowUids', full_name='TSCE.ASTNodeArrayArchive.ASTUidTract.rowUids', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_range_ref', full_name='TSCE.ASTNodeArrayArchive.ASTUidTract.is_range_ref', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='purpose', full_name='TSCE.ASTNodeArrayArchive.ASTUidTract.purpose', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preserve_rectangular', full_name='TSCE.ASTNodeArrayArchive.ASTUidTract.preserve_rectangular', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15214,
  serialized_end=15461,
)

_ASTNODEARRAYARCHIVE_ASTSTICKYBITS = _descriptor.Descriptor(
  name='ASTStickyBits',
  full_name='TSCE.ASTNodeArrayArchive.ASTStickyBits',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='begin_row_is_absolute', full_name='TSCE.ASTNodeArrayArchive.ASTStickyBits.begin_row_is_absolute', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='begin_column_is_absolute', full_name='TSCE.ASTNodeArrayArchive.ASTStickyBits.begin_column_is_absolute', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_row_is_absolute', full_name='TSCE.ASTNodeArrayArchive.ASTStickyBits.end_row_is_absolute', index=2,
      number=3, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_column_is_absolute', full_name='TSCE.ASTNodeArrayArchive.ASTStickyBits.end_column_is_absolute', index=3,
      number=4, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15464,
  serialized_end=15605,
)

_ASTNODEARRAYARCHIVE_ASTUIDTRACTLIST = _descriptor.Descriptor(
  name='ASTUidTractList',
  full_name='TSCE.ASTNodeArrayArchive.ASTUidTractList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tract', full_name='TSCE.ASTNodeArrayArchive.ASTUidTractList.tract', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sticky_bits', full_name='TSCE.ASTNodeArrayArchive.ASTUidTractList.sticky_bits', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15608,
  serialized_end=15741,
)

_ASTNODEARRAYARCHIVE_ASTUIDCOORDINATEARCHIVE = _descriptor.Descriptor(
  name='ASTUidCoordinateArchive',
  full_name='TSCE.ASTNodeArrayArchive.ASTUidCoordinateArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='column_uid', full_name='TSCE.ASTNodeArrayArchive.ASTUidCoordinateArchive.column_uid', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row_uid', full_name='TSCE.ASTNodeArrayArchive.ASTUidCoordinateArchive.row_uid', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column_absolute', full_name='TSCE.ASTNodeArrayArchive.ASTUidCoordinateArchive.column_absolute', index=2,
      number=3, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row_absolute', full_name='TSCE.ASTNodeArrayArchive.ASTUidCoordinateArchive.row_absolute', index=3,
      number=4, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15744,
  serialized_end=15875,
)

_ASTNODEARRAYARCHIVE_ASTCATEGORYREFERENCEARCHIVE = _descriptor.Descriptor(
  name='ASTCategoryReferenceArchive',
  full_name='TSCE.ASTNodeArrayArchive.ASTCategoryReferenceArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='category_ref', full_name='TSCE.ASTNodeArrayArchive.ASTCategoryReferenceArchive.category_ref', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15877,
  serialized_end=15960,
)

_ASTNODEARRAYARCHIVE_ASTCOLONTRACTARCHIVE_ASTCOLONTRACTRELATIVERANGEARCHIVE = _descriptor.Descriptor(
  name='ASTColonTractRelativeRangeArchive',
  full_name='TSCE.ASTNodeArrayArchive.ASTColonTractArchive.ASTColonTractRelativeRangeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='range_begin', full_name='TSCE.ASTNodeArrayArchive.ASTColonTractArchive.ASTColonTractRelativeRangeArchive.range_begin', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range_end', full_name='TSCE.ASTNodeArrayArchive.ASTColonTractArchive.ASTColonTractRelativeRangeArchive.range_end', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16445,
  serialized_end=16520,
)

_ASTNODEARRAYARCHIVE_ASTCOLONTRACTARCHIVE_ASTCOLONTRACTABSOLUTERANGEARCHIVE = _descriptor.Descriptor(
  name='ASTColonTractAbsoluteRangeArchive',
  full_name='TSCE.ASTNodeArrayArchive.ASTColonTractArchive.ASTColonTractAbsoluteRangeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='range_begin', full_name='TSCE.ASTNodeArrayArchive.ASTColonTractArchive.ASTColonTractAbsoluteRangeArchive.range_begin', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range_end', full_name='TSCE.ASTNodeArrayArchive.ASTColonTractArchive.ASTColonTractAbsoluteRangeArchive.range_end', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16522,
  serialized_end=16597,
)

_ASTNODEARRAYARCHIVE_ASTCOLONTRACTARCHIVE = _descriptor.Descriptor(
  name='ASTColonTractArchive',
  full_name='TSCE.ASTNodeArrayArchive.ASTColonTractArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='relative_column', full_name='TSCE.ASTNodeArrayArchive.ASTColonTractArchive.relative_column', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='relative_row', full_name='TSCE.ASTNodeArrayArchive.ASTColonTractArchive.relative_row', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='absolute_column', full_name='TSCE.ASTNodeArrayArchive.ASTColonTractArchive.absolute_column', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='absolute_row', full_name='TSCE.ASTNodeArrayArchive.ASTColonTractArchive.absolute_row', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preserve_rectangular', full_name='TSCE.ASTNodeArrayArchive.ASTColonTractArchive.preserve_rectangular', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_ASTNODEARRAYARCHIVE_ASTCOLONTRACTARCHIVE_ASTCOLONTRACTRELATIVERANGEARCHIVE, _ASTNODEARRAYARCHIVE_ASTCOLONTRACTARCHIVE_ASTCOLONTRACTABSOLUTERANGEARCHIVE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15963,
  serialized_end=16597,
)

_ASTNODEARRAYARCHIVE_ASTCROSSTABLEREFERENCEEXTRAINFOARCHIVE = _descriptor.Descriptor(
  name='ASTCrossTableReferenceExtraInfoArchive',
  full_name='TSCE.ASTNodeArrayArchive.ASTCrossTableReferenceExtraInfoArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='table_id', full_name='TSCE.ASTNodeArrayArchive.ASTCrossTableReferenceExtraInfoArchive.table_id', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_reference_whitespace_after_sheet_name', full_name='TSCE.ASTNodeArrayArchive.ASTCrossTableReferenceExtraInfoArchive.AST_reference_whitespace_after_sheet_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_reference_whitespace_before_table_name', full_name='TSCE.ASTNodeArrayArchive.ASTCrossTableReferenceExtraInfoArchive.AST_reference_whitespace_before_table_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_reference_whitespace_after_table_name', full_name='TSCE.ASTNodeArrayArchive.ASTCrossTableReferenceExtraInfoArchive.AST_reference_whitespace_after_table_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_reference_whitespace_before_cell_address', full_name='TSCE.ASTNodeArrayArchive.ASTCrossTableReferenceExtraInfoArchive.AST_reference_whitespace_before_cell_address', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16600,
  serialized_end=16886,
)

_ASTNODEARRAYARCHIVE_ASTLETNODEWHITESPACE = _descriptor.Descriptor(
  name='ASTLetNodeWhitespace',
  full_name='TSCE.ASTNodeArrayArchive.ASTLetNodeWhitespace',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='AST_let_whitespace_after_let', full_name='TSCE.ASTNodeArrayArchive.ASTLetNodeWhitespace.AST_let_whitespace_after_let', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_let_whitespace_after_identifier', full_name='TSCE.ASTNodeArrayArchive.ASTLetNodeWhitespace.AST_let_whitespace_after_identifier', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_let_whitespace_after_equals', full_name='TSCE.ASTNodeArrayArchive.ASTLetNodeWhitespace.AST_let_whitespace_after_equals', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_let_whitespace_after_delimiter', full_name='TSCE.ASTNodeArrayArchive.ASTLetNodeWhitespace.AST_let_whitespace_after_delimiter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16889,
  serialized_end=17079,
)

_ASTNODEARRAYARCHIVE_ASTNODEARCHIVE = _descriptor.Descriptor(
  name='ASTNodeArchive',
  full_name='TSCE.ASTNodeArrayArchive.ASTNodeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='AST_node_type', full_name='TSCE.ASTNodeArrayArchive.ASTNodeArchive.AST_node_type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_function_node_index', full_name='TSCE.ASTNodeArrayArchive.ASTNodeArchive.AST_function_node_index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_function_node_numArgs', full_name='TSCE.ASTNodeArrayArchive.ASTNodeArchive.AST_function_node_numArgs', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_number_node_number', full_name='TSCE.ASTNodeArrayArchive.ASTNodeArchive.AST_number_node_number', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_boolean_node_boolean', full_name='TSCE.ASTNodeArrayArchive.ASTNodeArchive.AST_boolean_node_boolean', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_string_node_string', full_name='TSCE.ASTNodeArrayArchive.ASTNodeArchive.AST_string_node_string', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_date_node_dateNum', full_name='TSCE.ASTNodeArrayArchive.ASTNodeArchive.AST_date_node_dateNum', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_date_node_suppress_date_format', full_name='TSCE.ASTNodeArrayArchive.ASTNodeArchive.AST_date_node_suppress_date_format', index=7,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_date_node_suppress_time_format', full_name='TSCE.ASTNodeArrayArchive.ASTNodeArchive.AST_date_node_suppress_time_format', index=8,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_date_node_date_time_format', full_name='TSCE.ASTNodeArrayArchive.ASTNodeArchive.AST_date_node_date_time_format', index=9,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_duration_node_unitNum', full_name='TSCE.ASTNodeArrayArchive.ASTNodeArchive.AST_duration_node_unitNum', index=10,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_duration_node_unit', full_name='TSCE.ASTNodeArrayArchive.ASTNodeArchive.AST_duration_node_unit', index=11,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_duration_node_style', full_name='TSCE.ASTNodeArrayArchive.ASTNodeArchive.AST_duration_node_style', index=12,
      number=22, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_duration_node_duration_unit_largest', full_name='TSCE.ASTNodeArrayArchive.ASTNodeArchive.AST_duration_node_duration_unit_largest', index=13,
      number=23, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_duration_node_duration_unit_smallest', full_name='TSCE.ASTNodeArrayArchive.ASTNodeArchive.AST_duration_node_duration_unit_smallest', index=14,
      number=24, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_duration_node_use_automatic_units', full_name='TSCE.ASTNodeArrayArchive.ASTNodeArchive.AST_duration_node_use_automatic_units', index=15,
      number=29, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_token_node_boolean', full_name='TSCE.ASTNodeArrayArchive.ASTNodeArchive.AST_token_node_boolean', index=16,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_array_node_numCol', full_name='TSCE.ASTNodeArrayArchive.ASTNodeArchive.AST_array_node_numCol', index=17,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_array_node_numRow', full_name='TSCE.ASTNodeArrayArchive.ASTNodeArchive.AST_array_node_numRow', index=18,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_list_node_numArgs', full_name='TSCE.ASTNodeArrayArchive.ASTNodeArchive.AST_list_node_numArgs', index=19,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_thunk_node_array', full_name='TSCE.ASTNodeArrayArchive.ASTNodeArchive.AST_thunk_node_array', index=20,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_local_cell_reference_node_reference', full_name='TSCE.ASTNodeArrayArchive.ASTNodeArchive.AST_local_cell_reference_node_reference', index=21,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_cross_table_cell_reference_node_reference', full_name='TSCE.ASTNodeArrayArchive.ASTNodeArchive.AST_cross_table_cell_reference_node_reference', index=22,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_unknown_function_node_string', full_name='TSCE.ASTNodeArrayArchive.ASTNodeArchive.AST_unknown_function_node_string', index=23,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_unknown_function_node_numArgs', full_name='TSCE.ASTNodeArrayArchive.ASTNodeArchive.AST_unknown_function_node_numArgs', index=24,
      number=18, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_whitespace', full_name='TSCE.ASTNodeArrayArchive.ASTNodeArchive.AST_whitespace', index=25,
      number=25, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_column', full_name='TSCE.ASTNodeArrayArchive.ASTNodeArchive.AST_column', index=26,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_row', full_name='TSCE.ASTNodeArrayArchive.ASTNodeArchive.AST_row', index=27,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_cross_table_reference_extra_info', full_name='TSCE.ASTNodeArrayArchive.ASTNodeArchive.AST_cross_table_reference_extra_info', index=28,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_uid_coordinate', full_name='TSCE.ASTNodeArrayArchive.ASTNodeArchive.AST_uid_coordinate', index=29,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_sticky_bits', full_name='TSCE.ASTNodeArrayArchive.ASTNodeArchive.AST_sticky_bits', index=30,
      number=33, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_frozen_sticky_bits', full_name='TSCE.ASTNodeArrayArchive.ASTNodeArchive.AST_frozen_sticky_bits', index=31,
      number=41, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_let_identifier', full_name='TSCE.ASTNodeArrayArchive.ASTNodeArchive.AST_let_identifier', index=32,
      number=34, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_let_e2', full_name='TSCE.ASTNodeArrayArchive.ASTNodeArchive.AST_let_e2', index=33,
      number=35, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_let_whitespace', full_name='TSCE.ASTNodeArrayArchive.ASTNodeArchive.AST_let_whitespace', index=34,
      number=36, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_symbol', full_name='TSCE.ASTNodeArrayArchive.ASTNodeArchive.AST_symbol', index=35,
      number=37, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_tract_list', full_name='TSCE.ASTNodeArrayArchive.ASTNodeArchive.AST_tract_list', index=36,
      number=38, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_category_ref', full_name='TSCE.ASTNodeArrayArchive.ASTNodeArchive.AST_category_ref', index=37,
      number=39, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_colon_tract', full_name='TSCE.ASTNodeArrayArchive.ASTNodeArchive.AST_colon_tract', index=38,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_number_node_decimal_low', full_name='TSCE.ASTNodeArrayArchive.ASTNodeArchive.AST_number_node_decimal_low', index=39,
      number=42, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AST_number_node_decimal_high', full_name='TSCE.ASTNodeArrayArchive.ASTNodeArchive.AST_number_node_decimal_high', index=40,
      number=43, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17082,
  serialized_end=19190,
)

_ASTNODEARRAYARCHIVE = _descriptor.Descriptor(
  name='ASTNodeArrayArchive',
  full_name='TSCE.ASTNodeArrayArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='AST_node', full_name='TSCE.ASTNodeArrayArchive.AST_node', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_ASTNODEARRAYARCHIVE_ASTLOCALCELLREFERENCENODEARCHIVE, _ASTNODEARRAYARCHIVE_ASTCROSSTABLECELLREFERENCENODEARCHIVE, _ASTNODEARRAYARCHIVE_ASTCOLUMNCOORDINATEARCHIVE, _ASTNODEARRAYARCHIVE_ASTROWCOORDINATEARCHIVE, _ASTNODEARRAYARCHIVE_ASTUIDLIST, _ASTNODEARRAYARCHIVE_ASTUIDTRACT, _ASTNODEARRAYARCHIVE_ASTSTICKYBITS, _ASTNODEARRAYARCHIVE_ASTUIDTRACTLIST, _ASTNODEARRAYARCHIVE_ASTUIDCOORDINATEARCHIVE, _ASTNODEARRAYARCHIVE_ASTCATEGORYREFERENCEARCHIVE, _ASTNODEARRAYARCHIVE_ASTCOLONTRACTARCHIVE, _ASTNODEARRAYARCHIVE_ASTCROSSTABLEREFERENCEEXTRAINFOARCHIVE, _ASTNODEARRAYARCHIVE_ASTLETNODEWHITESPACE, _ASTNODEARRAYARCHIVE_ASTNODEARCHIVE, ],
  enum_types=[
    _ASTNODEARRAYARCHIVE_ASTNODETYPE,
    _ASTNODEARRAYARCHIVE_ASTUIDTRACTPURPOSE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14462,
  serialized_end=20432,
)


_FORMULATRANSLATIONFLAGSARCHIVE = _descriptor.Descriptor(
  name='FormulaTranslationFlagsArchive',
  full_name='TSCE.FormulaTranslationFlagsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='excel_import_translation', full_name='TSCE.FormulaTranslationFlagsArchive.excel_import_translation', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='number_to_date_coercion_removal_translation', full_name='TSCE.FormulaTranslationFlagsArchive.number_to_date_coercion_removal_translation', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='contains_uid_form_references', full_name='TSCE.FormulaTranslationFlagsArchive.contains_uid_form_references', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='contains_frozen_references', full_name='TSCE.FormulaTranslationFlagsArchive.contains_frozen_references', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20435,
  serialized_end=20628,
)


_FORMULAARCHIVE = _descriptor.Descriptor(
  name='FormulaArchive',
  full_name='TSCE.FormulaArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='AST_node_array', full_name='TSCE.FormulaArchive.AST_node_array', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='host_column', full_name='TSCE.FormulaArchive.host_column', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='host_row', full_name='TSCE.FormulaArchive.host_row', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='host_column_is_negative', full_name='TSCE.FormulaArchive.host_column_is_negative', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='host_row_is_negative', full_name='TSCE.FormulaArchive.host_row_is_negative', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='translation_flags', full_name='TSCE.FormulaArchive.translation_flags', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='host_table_uid', full_name='TSCE.FormulaArchive.host_table_uid', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='host_column_uid', full_name='TSCE.FormulaArchive.host_column_uid', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='host_row_uid', full_name='TSCE.FormulaArchive.host_row_uid', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20631,
  serialized_end=20969,
)


_FUNCTORARCHIVE = _descriptor.Descriptor(
  name='FunctorArchive',
  full_name='TSCE.FunctorArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='formula', full_name='TSCE.FunctorArchive.formula', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_args', full_name='TSCE.FunctorArchive.num_args', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20971,
  serialized_end=21044,
)


_FORMATSTRUCTARCHIVE = _descriptor.Descriptor(
  name='FormatStructArchive',
  full_name='TSCE.FormatStructArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='format_type', full_name='TSCE.FormatStructArchive.format_type', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='decimal_places', full_name='TSCE.FormatStructArchive.decimal_places', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency_code', full_name='TSCE.FormatStructArchive.currency_code', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='negative_style', full_name='TSCE.FormatStructArchive.negative_style', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='show_thousands_separator', full_name='TSCE.FormatStructArchive.show_thousands_separator', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_accounting_style', full_name='TSCE.FormatStructArchive.use_accounting_style', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration_style', full_name='TSCE.FormatStructArchive.duration_style', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='base', full_name='TSCE.FormatStructArchive.base', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='base_places', full_name='TSCE.FormatStructArchive.base_places', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='base_use_minus_sign', full_name='TSCE.FormatStructArchive.base_use_minus_sign', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fraction_accuracy', full_name='TSCE.FormatStructArchive.fraction_accuracy', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='suppress_date_format', full_name='TSCE.FormatStructArchive.suppress_date_format', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='suppress_time_format', full_name='TSCE.FormatStructArchive.suppress_time_format', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date_time_format', full_name='TSCE.FormatStructArchive.date_time_format', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration_unit_largest', full_name='TSCE.FormatStructArchive.duration_unit_largest', index=14,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration_unit_smallest', full_name='TSCE.FormatStructArchive.duration_unit_smallest', index=15,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21047,
  serialized_end=21488,
)


_RANGECOORDINATEARCHIVE = _descriptor.Descriptor(
  name='RangeCoordinateArchive',
  full_name='TSCE.RangeCoordinateArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='top_left_column', full_name='TSCE.RangeCoordinateArchive.top_left_column', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='top_left_row', full_name='TSCE.RangeCoordinateArchive.top_left_row', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bottom_right_column', full_name='TSCE.RangeCoordinateArchive.bottom_right_column', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bottom_right_row', full_name='TSCE.RangeCoordinateArchive.bottom_right_row', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21490,
  serialized_end=21616,
)


_TABLETRANSPOSEINFOARCHIVE = _descriptor.Descriptor(
  name='TableTransposeInfoArchive',
  full_name='TSCE.TableTransposeInfoArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='number_of_footer_rows', full_name='TSCE.TableTransposeInfoArchive.number_of_footer_rows', index=0,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='body_range_for_transposed_table', full_name='TSCE.TableTransposeInfoArchive.body_range_for_transposed_table', index=1,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21619,
  serialized_end=21748,
)


_MERGEORIGINMOVEDARCHIVE = _descriptor.Descriptor(
  name='MergeOriginMovedArchive',
  full_name='TSCE.MergeOriginMovedArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='src_column', full_name='TSCE.MergeOriginMovedArchive.src_column', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='src_row', full_name='TSCE.MergeOriginMovedArchive.src_row', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dst_column', full_name='TSCE.MergeOriginMovedArchive.dst_column', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dst_row', full_name='TSCE.MergeOriginMovedArchive.dst_row', index=3,
      number=4, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21750,
  serialized_end=21849,
)


_OWNERUIDMAPPERARCHIVE = _descriptor.Descriptor(
  name='OwnerUIDMapperArchive',
  full_name='TSCE.OwnerUIDMapperArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='table_uid', full_name='TSCE.OwnerUIDMapperArchive.table_uid', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next_table_uid', full_name='TSCE.OwnerUIDMapperArchive.next_table_uid', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hidden_state_for_rows_owner_uid', full_name='TSCE.OwnerUIDMapperArchive.hidden_state_for_rows_owner_uid', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next_hidden_state_for_rows_owner_uid', full_name='TSCE.OwnerUIDMapperArchive.next_hidden_state_for_rows_owner_uid', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hidden_state_for_columns_owner_uid', full_name='TSCE.OwnerUIDMapperArchive.hidden_state_for_columns_owner_uid', index=4,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next_hidden_state_for_columns_owner_uid', full_name='TSCE.OwnerUIDMapperArchive.next_hidden_state_for_columns_owner_uid', index=5,
      number=6, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conditional_style_owner_uid', full_name='TSCE.OwnerUIDMapperArchive.conditional_style_owner_uid', index=6,
      number=7, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next_conditional_style_owner_uid', full_name='TSCE.OwnerUIDMapperArchive.next_conditional_style_owner_uid', index=7,
      number=8, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sort_rule_reference_tracker_owner_uid', full_name='TSCE.OwnerUIDMapperArchive.sort_rule_reference_tracker_owner_uid', index=8,
      number=9, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next_sort_rule_reference_tracker_owner_uid', full_name='TSCE.OwnerUIDMapperArchive.next_sort_rule_reference_tracker_owner_uid', index=9,
      number=10, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='merge_owner_uid', full_name='TSCE.OwnerUIDMapperArchive.merge_owner_uid', index=10,
      number=11, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next_merge_owner_uid', full_name='TSCE.OwnerUIDMapperArchive.next_merge_owner_uid', index=11,
      number=12, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_owner_uid', full_name='TSCE.OwnerUIDMapperArchive.category_owner_uid', index=12,
      number=13, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next_category_owner_uid', full_name='TSCE.OwnerUIDMapperArchive.next_category_owner_uid', index=13,
      number=14, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_aggregates_owner_uid', full_name='TSCE.OwnerUIDMapperArchive.category_aggregates_owner_uid', index=14,
      number=15, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next_category_aggregates_owner_uid', full_name='TSCE.OwnerUIDMapperArchive.next_category_aggregates_owner_uid', index=15,
      number=16, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group_by_uid', full_name='TSCE.OwnerUIDMapperArchive.group_by_uid', index=16,
      number=17, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next_group_by_uid', full_name='TSCE.OwnerUIDMapperArchive.next_group_by_uid', index=17,
      number=18, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pencil_annotation_owner_uid', full_name='TSCE.OwnerUIDMapperArchive.pencil_annotation_owner_uid', index=18,
      number=19, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next_pencil_annotation_owner_uid', full_name='TSCE.OwnerUIDMapperArchive.next_pencil_annotation_owner_uid', index=19,
      number=20, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21852,
  serialized_end=22823,
)


_REWRITETABLEUIDINFOARCHIVE_TABLEUIDMAPENTRYARCHIVE = _descriptor.Descriptor(
  name='TableUIDMapEntryArchive',
  full_name='TSCE.RewriteTableUIDInfoArchive.TableUIDMapEntryArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='prev_table_uid', full_name='TSCE.RewriteTableUIDInfoArchive.TableUIDMapEntryArchive.prev_table_uid', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_table_uid', full_name='TSCE.RewriteTableUIDInfoArchive.TableUIDMapEntryArchive.new_table_uid', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22937,
  serialized_end=23031,
)

_REWRITETABLEUIDINFOARCHIVE = _descriptor.Descriptor(
  name='RewriteTableUIDInfoArchive',
  full_name='TSCE.RewriteTableUIDInfoArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='table_uid_map', full_name='TSCE.RewriteTableUIDInfoArchive.table_uid_map', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_REWRITETABLEUIDINFOARCHIVE_TABLEUIDMAPENTRYARCHIVE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22826,
  serialized_end=23031,
)


_GROUPBYCHANGEARCHIVE_GROUPINGCOLUMNCHANGEARCHIVE = _descriptor.Descriptor(
  name='GroupingColumnChangeArchive',
  full_name='TSCE.GroupByChangeArchive.GroupingColumnChangeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='old_level', full_name='TSCE.GroupByChangeArchive.GroupingColumnChangeArchive.old_level', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_level', full_name='TSCE.GroupByChangeArchive.GroupingColumnChangeArchive.new_level', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23434,
  serialized_end=23501,
)

_GROUPBYCHANGEARCHIVE = _descriptor.Descriptor(
  name='GroupByChangeArchive',
  full_name='TSCE.GroupByChangeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='TSCE.GroupByChangeArchive.change_type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group_by_uid', full_name='TSCE.GroupByChangeArchive.group_by_uid', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='previous_level', full_name='TSCE.GroupByChangeArchive.previous_level', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updated_level', full_name='TSCE.GroupByChangeArchive.updated_level', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='previous_to_updated_map', full_name='TSCE.GroupByChangeArchive.previous_to_updated_map', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updated_to_previous_map', full_name='TSCE.GroupByChangeArchive.updated_to_previous_map', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='removed_group_uids', full_name='TSCE.GroupByChangeArchive.removed_group_uids', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='grouping_column_changes', full_name='TSCE.GroupByChangeArchive.grouping_column_changes', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_GROUPBYCHANGEARCHIVE_GROUPINGCOLUMNCHANGEARCHIVE, ],
  enum_types=[
    _GROUPBYCHANGEARCHIVE_CHANGETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23034,
  serialized_end=23649,
)


_REWRITEGROUPNODEUIDINFOARCHIVE = _descriptor.Descriptor(
  name='RewriteGroupNodeUIDInfoArchive',
  full_name='TSCE.RewriteGroupNodeUIDInfoArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_by_uid', full_name='TSCE.RewriteGroupNodeUIDInfoArchive.group_by_uid', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group_node_uid_map', full_name='TSCE.RewriteGroupNodeUIDInfoArchive.group_node_uid_map', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23651,
  serialized_end=23765,
)


_INDEXEDUIDSARCHIVE_INDEXEDUID = _descriptor.Descriptor(
  name='IndexedUid',
  full_name='TSCE.IndexedUidsArchive.IndexedUid',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid_for_index', full_name='TSCE.IndexedUidsArchive.IndexedUid.uid_for_index', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='index_for_uid', full_name='TSCE.IndexedUidsArchive.IndexedUid.index_for_uid', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23841,
  serialized_end=23910,
)

_INDEXEDUIDSARCHIVE = _descriptor.Descriptor(
  name='IndexedUidsArchive',
  full_name='TSCE.IndexedUidsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uids', full_name='TSCE.IndexedUidsArchive.uids', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_INDEXEDUIDSARCHIVE_INDEXEDUID, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23768,
  serialized_end=23910,
)


_REWRITERANGEENTRYARCHIVE = _descriptor.Descriptor(
  name='RewriteRangeEntryArchive',
  full_name='TSCE.RewriteRangeEntryArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='range_location', full_name='TSCE.RewriteRangeEntryArchive.range_location', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range_length', full_name='TSCE.RewriteRangeEntryArchive.range_length', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range_uids', full_name='TSCE.RewriteRangeEntryArchive.range_uids', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offset', full_name='TSCE.RewriteRangeEntryArchive.offset', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23912,
  serialized_end=24031,
)


_COLUMNORROWUUIDSINFOARCHIVE = _descriptor.Descriptor(
  name='ColumnOrRowUuidsInfoArchive',
  full_name='TSCE.ColumnOrRowUuidsInfoArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_rows', full_name='TSCE.ColumnOrRowUuidsInfoArchive.is_rows', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_uid', full_name='TSCE.ColumnOrRowUuidsInfoArchive.table_uid', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cond_style_owner_uid', full_name='TSCE.ColumnOrRowUuidsInfoArchive.cond_style_owner_uid', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group_by_uid', full_name='TSCE.ColumnOrRowUuidsInfoArchive.group_by_uid', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uids', full_name='TSCE.ColumnOrRowUuidsInfoArchive.uids', index=4,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range_entries', full_name='TSCE.ColumnOrRowUuidsInfoArchive.range_entries', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_range', full_name='TSCE.ColumnOrRowUuidsInfoArchive.table_range', index=6,
      number=7, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='insert_at_uid', full_name='TSCE.ColumnOrRowUuidsInfoArchive.insert_at_uid', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='insert_opposite_uid', full_name='TSCE.ColumnOrRowUuidsInfoArchive.insert_opposite_uid', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24034,
  serialized_end=24404,
)


_REGIONINFOARCHIVE = _descriptor.Descriptor(
  name='RegionInfoArchive',
  full_name='TSCE.RegionInfoArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='table_uid', full_name='TSCE.RegionInfoArchive.table_uid', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column_uids', full_name='TSCE.RegionInfoArchive.column_uids', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row_uids', full_name='TSCE.RegionInfoArchive.row_uids', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24407,
  serialized_end=24547,
)


_REGIONMOVEDINFOARCHIVE = _descriptor.Descriptor(
  name='RegionMovedInfoArchive',
  full_name='TSCE.RegionMovedInfoArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='src_region', full_name='TSCE.RegionMovedInfoArchive.src_region', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dst_region', full_name='TSCE.RegionMovedInfoArchive.dst_region', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='span_rows', full_name='TSCE.RegionMovedInfoArchive.span_rows', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='span_columns', full_name='TSCE.RegionMovedInfoArchive.span_columns', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='original_src_region', full_name='TSCE.RegionMovedInfoArchive.original_src_region', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='final_dest_table_uid', full_name='TSCE.RegionMovedInfoArchive.final_dest_table_uid', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24550,
  serialized_end=24800,
)


_MERGESOURCEARCHIVE = _descriptor.Descriptor(
  name='MergeSourceArchive',
  full_name='TSCE.MergeSourceArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='coord_column', full_name='TSCE.MergeSourceArchive.coord_column', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='coord_row', full_name='TSCE.MergeSourceArchive.coord_row', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24802,
  serialized_end=24863,
)


_FORMULAREWRITESPECARCHIVE = _descriptor.Descriptor(
  name='FormulaRewriteSpecArchive',
  full_name='TSCE.FormulaRewriteSpecArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rewrite_type', full_name='TSCE.FormulaRewriteSpecArchive.rewrite_type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=4,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_uid', full_name='TSCE.FormulaRewriteSpecArchive.table_uid', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cond_style_owner_uid', full_name='TSCE.FormulaRewriteSpecArchive.cond_style_owner_uid', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group_by_uid', full_name='TSCE.FormulaRewriteSpecArchive.group_by_uid', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column_or_row_uuids_info', full_name='TSCE.FormulaRewriteSpecArchive.column_or_row_uuids_info', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aux_column_or_row_uuids_info', full_name='TSCE.FormulaRewriteSpecArchive.aux_column_or_row_uuids_info', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='region_moved_info', full_name='TSCE.FormulaRewriteSpecArchive.region_moved_info', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='region_info', full_name='TSCE.FormulaRewriteSpecArchive.region_info', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rewrite_table_id_info', full_name='TSCE.FormulaRewriteSpecArchive.rewrite_table_id_info', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transposed_table_info', full_name='TSCE.FormulaRewriteSpecArchive.transposed_table_info', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='merge_origin_moved_info', full_name='TSCE.FormulaRewriteSpecArchive.merge_origin_moved_info', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='merge_source', full_name='TSCE.FormulaRewriteSpecArchive.merge_source', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group_node_info', full_name='TSCE.FormulaRewriteSpecArchive.group_node_info', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='groupby_change', full_name='TSCE.FormulaRewriteSpecArchive.groupby_change', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_inverse', full_name='TSCE.FormulaRewriteSpecArchive.is_inverse', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FORMULAREWRITESPECARCHIVE_REWRITETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24866,
  serialized_end=26109,
)


_HAUNTEDOWNERARCHIVE = _descriptor.Descriptor(
  name='HauntedOwnerArchive',
  full_name='TSCE.HauntedOwnerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner_uid', full_name='TSCE.HauntedOwnerArchive.owner_uid', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26111,
  serialized_end=26162,
)


_CELLCOORDINATEARCHIVE = _descriptor.Descriptor(
  name='CellCoordinateArchive',
  full_name='TSCE.CellCoordinateArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='packedData', full_name='TSCE.CellCoordinateArchive.packedData', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column', full_name='TSCE.CellCoordinateArchive.column', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row', full_name='TSCE.CellCoordinateArchive.row', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26164,
  serialized_end=26236,
)


_CELLCOORDINATEVECTORARCHIVE = _descriptor.Descriptor(
  name='CellCoordinateVectorArchive',
  full_name='TSCE.CellCoordinateVectorArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cell_coord', full_name='TSCE.CellCoordinateVectorArchive.cell_coord', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26238,
  serialized_end=26316,
)


_EXPANDEDCELLREFOBJECTPAIRARCHIVE = _descriptor.Descriptor(
  name='ExpandedCellRefObjectPairArchive',
  full_name='TSCE.ExpandedCellRefObjectPairArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cell_ref', full_name='TSCE.ExpandedCellRefObjectPairArchive.cell_ref', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='object', full_name='TSCE.ExpandedCellRefObjectPairArchive.object', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26318,
  serialized_end=26430,
)


_EXPANDEDCELLREFOBJECTMAPARCHIVE = _descriptor.Descriptor(
  name='ExpandedCellRefObjectMapArchive',
  full_name='TSCE.ExpandedCellRefObjectMapArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cell_ref_object_pair', full_name='TSCE.ExpandedCellRefObjectMapArchive.cell_ref_object_pair', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26432,
  serialized_end=26535,
)


_FORMULAATCOORDARCHIVE = _descriptor.Descriptor(
  name='FormulaAtCoordArchive',
  full_name='TSCE.FormulaAtCoordArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='column', full_name='TSCE.FormulaAtCoordArchive.column', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row', full_name='TSCE.FormulaAtCoordArchive.row', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formula', full_name='TSCE.FormulaAtCoordArchive.formula', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repeat_previous_formula', full_name='TSCE.FormulaAtCoordArchive.repeat_previous_formula', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26537,
  serialized_end=26661,
)


_FORMULACOORDPAIRSBYOWNERARCHIVE = _descriptor.Descriptor(
  name='FormulaCoordPairsByOwnerArchive',
  full_name='TSCE.FormulaCoordPairsByOwnerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner_kind', full_name='TSCE.FormulaCoordPairsByOwnerArchive.owner_kind', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner_uid', full_name='TSCE.FormulaCoordPairsByOwnerArchive.owner_uid', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formula_at_coords', full_name='TSCE.FormulaCoordPairsByOwnerArchive.formula_at_coords', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26664,
  serialized_end=26803,
)


_FORMULASFORUNDOARCHIVE = _descriptor.Descriptor(
  name='FormulasForUndoArchive',
  full_name='TSCE.FormulasForUndoArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='formulas_for_owner', full_name='TSCE.FormulasForUndoArchive.formulas_for_owner', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26805,
  serialized_end=26896,
)


_FORMULAREWRITECOMMANDARCHIVE = _descriptor.Descriptor(
  name='FormulaRewriteCommandArchive',
  full_name='TSCE.FormulaRewriteCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='table_rewrite_command', full_name='TSCE.FormulaRewriteCommandArchive.table_rewrite_command', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCE.FormulaRewriteCommandArchive.super', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26898,
  serialized_end=27011,
)


_EXTENDTABLEIDHISTORYCOMMANDARCHIVE = _descriptor.Descriptor(
  name='ExtendTableIDHistoryCommandArchive',
  full_name='TSCE.ExtendTableIDHistoryCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCE.ExtendTableIDHistoryCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rewrite_spec', full_name='TSCE.ExtendTableIDHistoryCommandArchive.rewrite_spec', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_uid_history_rollback', full_name='TSCE.ExtendTableIDHistoryCommandArchive.table_uid_history_rollback', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27014,
  serialized_end=27211,
)


_NUMBERTRACKEDREFERENCEPAIRARCHIVE = _descriptor.Descriptor(
  name='NumberTrackedReferencePairArchive',
  full_name='TSCE.NumberTrackedReferencePairArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='number', full_name='TSCE.NumberTrackedReferencePairArchive.number', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tracked_reference', full_name='TSCE.NumberTrackedReferencePairArchive.tracked_reference', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27213,
  serialized_end=27307,
)


_NUMBERTOTRACKEDREFERENCEMAPARCHIVE = _descriptor.Descriptor(
  name='NumberToTrackedReferenceMapArchive',
  full_name='TSCE.NumberToTrackedReferenceMapArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='number_tracked_reference_pair', full_name='TSCE.NumberToTrackedReferenceMapArchive.number_tracked_reference_pair', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27309,
  serialized_end=27425,
)


_TRACKEDREFERENCESREWRITECOMMANDARCHIVE = _descriptor.Descriptor(
  name='TrackedReferencesRewriteCommandArchive',
  full_name='TSCE.TrackedReferencesRewriteCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='references_in_reference_tracker', full_name='TSCE.TrackedReferencesRewriteCommandArchive.references_in_reference_tracker', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='original_tracked_reference_copies', full_name='TSCE.TrackedReferencesRewriteCommandArchive.original_tracked_reference_copies', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rewrite_spec', full_name='TSCE.TrackedReferencesRewriteCommandArchive.rewrite_spec', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCE.TrackedReferencesRewriteCommandArchive.super', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27428,
  serialized_end=27735,
)


_TRACKEDREFERENCEARCHIVE = _descriptor.Descriptor(
  name='TrackedReferenceArchive',
  full_name='TSCE.TrackedReferenceArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ast', full_name='TSCE.TrackedReferenceArchive.ast', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formula_id', full_name='TSCE.TrackedReferenceArchive.formula_id', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27737,
  serialized_end=27822,
)


_EXPANDEDTRACKEDREFERENCEARCHIVE = _descriptor.Descriptor(
  name='ExpandedTrackedReferenceArchive',
  full_name='TSCE.ExpandedTrackedReferenceArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ast', full_name='TSCE.ExpandedTrackedReferenceArchive.ast', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formula_column', full_name='TSCE.ExpandedTrackedReferenceArchive.formula_column', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formula_row', full_name='TSCE.ExpandedTrackedReferenceArchive.formula_row', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27824,
  serialized_end=27942,
)


_REFERENCETRACKERARCHIVE = _descriptor.Descriptor(
  name='ReferenceTrackerArchive',
  full_name='TSCE.ReferenceTrackerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='TSCE.ReferenceTrackerArchive.uuid', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tracked_reference', full_name='TSCE.ReferenceTrackerArchive.tracked_reference', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='contained_tracked_reference', full_name='TSCE.ReferenceTrackerArchive.contained_tracked_reference', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='contained_expanded_tracked_reference', full_name='TSCE.ReferenceTrackerArchive.contained_expanded_tracked_reference', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27945,
  serialized_end=28204,
)


_BOOLEANCELLVALUEARCHIVE = _descriptor.Descriptor(
  name='BooleanCellValueArchive',
  full_name='TSCE.BooleanCellValueArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='TSCE.BooleanCellValueArchive.value', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='format', full_name='TSCE.BooleanCellValueArchive.format', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='format_is_explicit', full_name='TSCE.BooleanCellValueArchive.format_is_explicit', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28206,
  serialized_end=28316,
)


_DATECELLVALUEARCHIVE = _descriptor.Descriptor(
  name='DateCellValueArchive',
  full_name='TSCE.DateCellValueArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='TSCE.DateCellValueArchive.value', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='format', full_name='TSCE.DateCellValueArchive.format', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='format_is_implicit', full_name='TSCE.DateCellValueArchive.format_is_implicit', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='format_is_explicit', full_name='TSCE.DateCellValueArchive.format_is_explicit', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28319,
  serialized_end=28458,
)


_NUMBERCELLVALUEARCHIVE = _descriptor.Descriptor(
  name='NumberCellValueArchive',
  full_name='TSCE.NumberCellValueArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='TSCE.NumberCellValueArchive.value', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unit_index', full_name='TSCE.NumberCellValueArchive.unit_index', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency_code', full_name='TSCE.NumberCellValueArchive.currency_code', index=2,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='format', full_name='TSCE.NumberCellValueArchive.format', index=3,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='format_is_implicit', full_name='TSCE.NumberCellValueArchive.format_is_implicit', index=4,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='format_is_explicit', full_name='TSCE.NumberCellValueArchive.format_is_explicit', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='decimal_low', full_name='TSCE.NumberCellValueArchive.decimal_low', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='decimal_high', full_name='TSCE.NumberCellValueArchive.decimal_high', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28461,
  serialized_end=28688,
)


_STRINGCELLVALUEARCHIVE = _descriptor.Descriptor(
  name='StringCellValueArchive',
  full_name='TSCE.StringCellValueArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='TSCE.StringCellValueArchive.value', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='format', full_name='TSCE.StringCellValueArchive.format', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='format_is_implicit', full_name='TSCE.StringCellValueArchive.format_is_implicit', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='format_is_explicit', full_name='TSCE.StringCellValueArchive.format_is_explicit', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_regex', full_name='TSCE.StringCellValueArchive.is_regex', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_case_sensitive_regex', full_name='TSCE.StringCellValueArchive.is_case_sensitive_regex', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28691,
  serialized_end=28883,
)


_ERRORCELLVALUEARCHIVE = _descriptor.Descriptor(
  name='ErrorCellValueArchive',
  full_name='TSCE.ErrorCellValueArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error_type', full_name='TSCE.ErrorCellValueArchive.error_type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extra_info_int', full_name='TSCE.ErrorCellValueArchive.extra_info_int', index=1,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extra_info_string', full_name='TSCE.ErrorCellValueArchive.extra_info_string', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extra_info_double', full_name='TSCE.ErrorCellValueArchive.extra_info_double', index=3,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ERRORCELLVALUEARCHIVE_ERRORTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28886,
  serialized_end=29347,
)


_CELLVALUEARCHIVE = _descriptor.Descriptor(
  name='CellValueArchive',
  full_name='TSCE.CellValueArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cell_value_type', full_name='TSCE.CellValueArchive.cell_value_type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='boolean_value', full_name='TSCE.CellValueArchive.boolean_value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date_value', full_name='TSCE.CellValueArchive.date_value', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='number_value', full_name='TSCE.CellValueArchive.number_value', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='string_value', full_name='TSCE.CellValueArchive.string_value', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error_value', full_name='TSCE.CellValueArchive.error_value', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CELLVALUEARCHIVE_CELLVALUETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29350,
  serialized_end=29785,
)

_CELLREFERENCEARCHIVE.fields_by_name['table_id'].message_type = TSPMessages__pb2._CFUUIDARCHIVE
_INTERNALCELLREFERENCEARCHIVE.fields_by_name['coordinate'].message_type = _CELLCOORDINATEARCHIVE
_RANGEREFERENCEARCHIVE.fields_by_name['table_id'].message_type = TSPMessages__pb2._CFUUIDARCHIVE
_INTERNALRANGEREFERENCEARCHIVE.fields_by_name['range'].message_type = _RANGECOORDINATEARCHIVE
_INDEXSETARCHIVE_INDEXSETENTRY.containing_type = _INDEXSETARCHIVE
_INDEXSETARCHIVE.fields_by_name['entries'].message_type = _INDEXSETARCHIVE_INDEXSETENTRY
_CELLCOORDSETARCHIVE_COLUMNENTRY.fields_by_name['row_set'].message_type = _INDEXSETARCHIVE
_CELLCOORDSETARCHIVE_COLUMNENTRY.containing_type = _CELLCOORDSETARCHIVE
_CELLCOORDSETARCHIVE.fields_by_name['column_entries'].message_type = _CELLCOORDSETARCHIVE_COLUMNENTRY
_INTERNALCELLREFSETARCHIVE_OWNERENTRY.fields_by_name['coord_set'].message_type = _CELLCOORDSETARCHIVE
_INTERNALCELLREFSETARCHIVE_OWNERENTRY.containing_type = _INTERNALCELLREFSETARCHIVE
_INTERNALCELLREFSETARCHIVE.fields_by_name['owner_entries'].message_type = _INTERNALCELLREFSETARCHIVE_OWNERENTRY
_CELLRECTARCHIVE.fields_by_name['origin'].message_type = _CELLCOORDINATEARCHIVE
_CELLRECTARCHIVE.fields_by_name['size'].message_type = _COLUMNROWSIZE
_CELLREFSETARCHIVE_OWNERENTRY.fields_by_name['owner_uid'].message_type = TSPMessages__pb2._UUID
_CELLREFSETARCHIVE_OWNERENTRY.fields_by_name['coord_set'].message_type = _CELLCOORDSETARCHIVE
_CELLREFSETARCHIVE_OWNERENTRY.containing_type = _CELLREFSETARCHIVE
_CELLREFSETARCHIVE.fields_by_name['owner_entries'].message_type = _CELLREFSETARCHIVE_OWNERENTRY
_UIDCOORDSETARCHIVE_COLUMNENTRY.fields_by_name['column'].message_type = TSPMessages__pb2._UUID
_UIDCOORDSETARCHIVE_COLUMNENTRY.fields_by_name['row_set'].message_type = TSPMessages__pb2._UUID
_UIDCOORDSETARCHIVE_COLUMNENTRY.containing_type = _UIDCOORDSETARCHIVE
_UIDCOORDSETARCHIVE.fields_by_name['column_entries'].message_type = _UIDCOORDSETARCHIVE_COLUMNENTRY
_UIDCELLREFSETARCHIVE_OWNERENTRY.fields_by_name['owner_uid'].message_type = TSPMessages__pb2._UUID
_UIDCELLREFSETARCHIVE_OWNERENTRY.fields_by_name['coord_set'].message_type = _UIDCOORDSETARCHIVE
_UIDCELLREFSETARCHIVE_OWNERENTRY.containing_type = _UIDCELLREFSETARCHIVE
_UIDCELLREFSETARCHIVE.fields_by_name['owner_entries'].message_type = _UIDCELLREFSETARCHIVE_OWNERENTRY
_REFERENCESTODIRTYARCHIVE.fields_by_name['to_dirty_owner_ids'].message_type = _INDEXSETARCHIVE
_REFERENCESTODIRTYARCHIVE.fields_by_name['to_dirty_cells'].message_type = _INTERNALCELLREFSETARCHIVE
_REFERENCESTODIRTYARCHIVE.fields_by_name['to_dirty_cells_additional'].message_type = _INTERNALCELLREFSETARCHIVE
_REFERENCESTODIRTYARCHIVE.fields_by_name['to_dirty_range_refs'].message_type = _INTERNALRANGEREFERENCEARCHIVE
_REFERENCESTODIRTYARCHIVE.fields_by_name['calc_in_progress_cells'].message_type = _INTERNALCELLREFSETARCHIVE
_COORDMAPPERARCHIVE_BASETOVIEWENTRY.containing_type = _COORDMAPPERARCHIVE
_COORDMAPPERARCHIVE.fields_by_name['summary_and_label_rows_set'].message_type = _INDEXSETARCHIVE
_COORDMAPPERARCHIVE.fields_by_name['table_uid'].message_type = TSPMessages__pb2._UUID
_COORDMAPPERARCHIVE.fields_by_name['base_to_view_map'].message_type = _COORDMAPPERARCHIVE_BASETOVIEWENTRY
_REFERENCEARCHIVE.fields_by_name['reference_type'].enum_type = _REFERENCEARCHIVE_REFERENCETYPE
_REFERENCEARCHIVE.fields_by_name['cell_reference'].message_type = _CELLREFERENCEARCHIVE
_REFERENCEARCHIVE.fields_by_name['range_reference'].message_type = _RANGEREFERENCEARCHIVE
_REFERENCEARCHIVE_REFERENCETYPE.containing_type = _REFERENCEARCHIVE
_EDGEARCHIVE.fields_by_name['owner_id'].message_type = TSPMessages__pb2._CFUUIDARCHIVE
_EDGESARCHIVE.fields_by_name['owner_id_for_edge'].message_type = TSPMessages__pb2._CFUUIDARCHIVE
_CELLRECORDARCHIVE.fields_by_name['edge'].message_type = _EDGEARCHIVE
_CELLRECORDARCHIVE.fields_by_name['edges'].message_type = _EDGESARCHIVE
_CELLDEPENDENCIESARCHIVE.fields_by_name['cell_record'].message_type = _CELLRECORDARCHIVE
_CELLRECORDEXPANDEDARCHIVE.fields_by_name['expanded_edges'].message_type = _EXPANDEDEDGESARCHIVE
_CELLDEPENDENCIESEXPANDEDARCHIVE.fields_by_name['cell_record'].message_type = _CELLRECORDEXPANDEDARCHIVE
_CELLRECORDTILEARCHIVE.fields_by_name['cell_records'].message_type = _CELLRECORDEXPANDEDARCHIVE
_CELLDEPENDENCIESTILEDARCHIVE.fields_by_name['cell_record_tiles'].message_type = TSPMessages__pb2._REFERENCE
_VOLATILEDEPENDENCIESARCHIVE.fields_by_name['volatile_geometry_cell_reference'].message_type = _CELLREFERENCEARCHIVE
_VOLATILEDEPENDENCIESARCHIVE.fields_by_name['volatile_geometry_cell'].message_type = _CELLCOORDINATEARCHIVE
_VOLATILEDEPENDENCIESEXPANDEDARCHIVE.fields_by_name['volatile_time_cells'].message_type = _CELLCOORDSETARCHIVE
_VOLATILEDEPENDENCIESEXPANDEDARCHIVE.fields_by_name['volatile_random_cells'].message_type = _CELLCOORDSETARCHIVE
_VOLATILEDEPENDENCIESEXPANDEDARCHIVE.fields_by_name['volatile_locale_cells'].message_type = _CELLCOORDSETARCHIVE
_VOLATILEDEPENDENCIESEXPANDEDARCHIVE.fields_by_name['volatile_sheet_table_name_cells'].message_type = _CELLCOORDSETARCHIVE
_VOLATILEDEPENDENCIESEXPANDEDARCHIVE.fields_by_name['volatile_remote_data_cells'].message_type = _CELLCOORDSETARCHIVE
_VOLATILEDEPENDENCIESEXPANDEDARCHIVE.fields_by_name['volatile_geometry_cell_refs'].message_type = _INTERNALCELLREFSETARCHIVE
_RTREEINTERNALNODECONTENTSARCHIVE.fields_by_name['child'].message_type = _RTREENODEARCHIVE
_RTREELEAFNODECONTENTSARCHIVE.fields_by_name['cell_reference'].message_type = _CELLREFERENCEARCHIVE
_RTREENODEARCHIVE.fields_by_name['internal_node_contents'].message_type = _RTREEINTERNALNODECONTENTSARCHIVE
_RTREENODEARCHIVE.fields_by_name['leaf_node_contents'].message_type = _RTREELEAFNODECONTENTSARCHIVE
_RTREEARCHIVE.fields_by_name['root'].message_type = _RTREENODEARCHIVE
_RANGEBACKDEPENDENCYARCHIVE.fields_by_name['range_reference'].message_type = _RANGEREFERENCEARCHIVE
_RANGEBACKDEPENDENCYARCHIVE.fields_by_name['internal_range_reference'].message_type = _INTERNALRANGEREFERENCEARCHIVE
_RANGEDEPENDENCIESARCHIVE.fields_by_name['back_dependency'].message_type = _RANGEBACKDEPENDENCYARCHIVE
_RANGEPRECEDENTSTILEARCHIVE_FROMTORANGEARCHIVE.fields_by_name['from_coord'].message_type = _CELLCOORDINATEARCHIVE
_RANGEPRECEDENTSTILEARCHIVE_FROMTORANGEARCHIVE.fields_by_name['refers_to_rect'].message_type = _CELLRECTARCHIVE
_RANGEPRECEDENTSTILEARCHIVE_FROMTORANGEARCHIVE.containing_type = _RANGEPRECEDENTSTILEARCHIVE
_RANGEPRECEDENTSTILEARCHIVE.fields_by_name['from_to_range'].message_type = _RANGEPRECEDENTSTILEARCHIVE_FROMTORANGEARCHIVE
_RANGEDEPENDENCIESTILEDARCHIVE.fields_by_name['range_precedents_tile'].message_type = TSPMessages__pb2._REFERENCE
_SPANNINGDEPENDENCIESARCHIVE_REFERRINGCOLUMNTOLOCALCELLS.fields_by_name['range_context'].enum_type = _SPANNINGDEPENDENCIESARCHIVE_RANGECONTEXT
_SPANNINGDEPENDENCIESARCHIVE_REFERRINGCOLUMNTOLOCALCELLS.fields_by_name['cell_coordinate'].message_type = _CELLCOORDINATEARCHIVE
_SPANNINGDEPENDENCIESARCHIVE_REFERRINGCOLUMNTOLOCALCELLS.containing_type = _SPANNINGDEPENDENCIESARCHIVE
_SPANNINGDEPENDENCIESARCHIVE_REFERRINGCOLUMNTOREMOTECELLS.fields_by_name['range_context'].enum_type = _SPANNINGDEPENDENCIESARCHIVE_RANGECONTEXT
_SPANNINGDEPENDENCIESARCHIVE_REFERRINGCOLUMNTOREMOTECELLS.fields_by_name['internal_cell_reference'].message_type = _INTERNALCELLREFERENCEARCHIVE
_SPANNINGDEPENDENCIESARCHIVE_REFERRINGCOLUMNTOREMOTECELLS.containing_type = _SPANNINGDEPENDENCIESARCHIVE
_SPANNINGDEPENDENCIESARCHIVE.fields_by_name['range_context'].enum_type = _SPANNINGDEPENDENCIESARCHIVE_RANGECONTEXT
_SPANNINGDEPENDENCIESARCHIVE.fields_by_name['cell'].message_type = _CELLREFERENCEARCHIVE
_SPANNINGDEPENDENCIESARCHIVE.fields_by_name['total_range_for_deleted_table'].message_type = _RANGECOORDINATEARCHIVE
_SPANNINGDEPENDENCIESARCHIVE.fields_by_name['body_range_for_deleted_table'].message_type = _RANGECOORDINATEARCHIVE
_SPANNINGDEPENDENCIESARCHIVE.fields_by_name['referring_column_to_local_cells'].message_type = _SPANNINGDEPENDENCIESARCHIVE_REFERRINGCOLUMNTOLOCALCELLS
_SPANNINGDEPENDENCIESARCHIVE.fields_by_name['referring_column_to_remote_cells'].message_type = _SPANNINGDEPENDENCIESARCHIVE_REFERRINGCOLUMNTOREMOTECELLS
_SPANNINGDEPENDENCIESARCHIVE_RANGECONTEXT.containing_type = _SPANNINGDEPENDENCIESARCHIVE
_SPANNINGDEPENDENCIESEXPANDEDARCHIVE_EXTENTRANGE.containing_type = _SPANNINGDEPENDENCIESEXPANDEDARCHIVE
_SPANNINGDEPENDENCIESEXPANDEDARCHIVE_EXTENTRANGEWITHTABLEWITHCONTEXT.fields_by_name['range_context'].enum_type = _SPANNINGDEPENDENCIESEXPANDEDARCHIVE_RANGECONTEXT
_SPANNINGDEPENDENCIESEXPANDEDARCHIVE_EXTENTRANGEWITHTABLEWITHCONTEXT.fields_by_name['ranges'].message_type = _SPANNINGDEPENDENCIESEXPANDEDARCHIVE_EXTENTRANGE
_SPANNINGDEPENDENCIESEXPANDEDARCHIVE_EXTENTRANGEWITHTABLEWITHCONTEXT.containing_type = _SPANNINGDEPENDENCIESEXPANDEDARCHIVE
_SPANNINGDEPENDENCIESEXPANDEDARCHIVE_CELLCOORDREFERSTOEXTENTS.fields_by_name['coordinate'].message_type = _CELLCOORDINATEARCHIVE
_SPANNINGDEPENDENCIESEXPANDEDARCHIVE_CELLCOORDREFERSTOEXTENTS.fields_by_name['ranges_by_table_context'].message_type = _SPANNINGDEPENDENCIESEXPANDEDARCHIVE_EXTENTRANGEWITHTABLEWITHCONTEXT
_SPANNINGDEPENDENCIESEXPANDEDARCHIVE_CELLCOORDREFERSTOEXTENTS.containing_type = _SPANNINGDEPENDENCIESEXPANDEDARCHIVE
_SPANNINGDEPENDENCIESEXPANDEDARCHIVE.fields_by_name['coord_refers_to_spans'].message_type = _SPANNINGDEPENDENCIESEXPANDEDARCHIVE_CELLCOORDREFERSTOEXTENTS
_SPANNINGDEPENDENCIESEXPANDEDARCHIVE.fields_by_name['total_range_for_table'].message_type = _RANGECOORDINATEARCHIVE
_SPANNINGDEPENDENCIESEXPANDEDARCHIVE.fields_by_name['body_range_for_table'].message_type = _RANGECOORDINATEARCHIVE
_SPANNINGDEPENDENCIESEXPANDEDARCHIVE_RANGECONTEXT.containing_type = _SPANNINGDEPENDENCIESEXPANDEDARCHIVE
_WHOLEOWNERDEPENDENCIESARCHIVE.fields_by_name['dependent_cell'].message_type = _INTERNALCELLREFERENCEARCHIVE
_WHOLEOWNERDEPENDENCIESEXPANDEDARCHIVE.fields_by_name['dependent_cells'].message_type = _INTERNALCELLREFSETARCHIVE
_CELLERRORSARCHIVE_ERRORFORCELL.fields_by_name['coordinate'].message_type = _CELLCOORDINATEARCHIVE
_CELLERRORSARCHIVE_ERRORFORCELL.fields_by_name['error_flavor'].enum_type = _CELLERRORSARCHIVE_ERRORFLAVOR
_CELLERRORSARCHIVE_ERRORFORCELL.fields_by_name['err_due_to_cell'].message_type = _INTERNALCELLREFERENCEARCHIVE
_CELLERRORSARCHIVE_ERRORFORCELL.containing_type = _CELLERRORSARCHIVE
_CELLERRORSARCHIVE.fields_by_name['errors'].message_type = _CELLERRORSARCHIVE_ERRORFORCELL
_CELLERRORSARCHIVE_ERRORFLAVOR.containing_type = _CELLERRORSARCHIVE
_UUIDREFERENCESARCHIVE_TABLEREF.fields_by_name['owner_uuid'].message_type = TSPMessages__pb2._UUID
_UUIDREFERENCESARCHIVE_TABLEREF.fields_by_name['coord_set'].message_type = _CELLCOORDSETARCHIVE
_UUIDREFERENCESARCHIVE_TABLEREF.containing_type = _UUIDREFERENCESARCHIVE
_UUIDREFERENCESARCHIVE_UUIDREF.fields_by_name['uuid'].message_type = TSPMessages__pb2._UUID
_UUIDREFERENCESARCHIVE_UUIDREF.fields_by_name['coord_set'].message_type = _CELLCOORDSETARCHIVE
_UUIDREFERENCESARCHIVE_UUIDREF.containing_type = _UUIDREFERENCESARCHIVE
_UUIDREFERENCESARCHIVE_TABLEWITHUUIDREF.fields_by_name['owner_uuid'].message_type = TSPMessages__pb2._UUID
_UUIDREFERENCESARCHIVE_TABLEWITHUUIDREF.fields_by_name['uuid_refs'].message_type = _UUIDREFERENCESARCHIVE_UUIDREF
_UUIDREFERENCESARCHIVE_TABLEWITHUUIDREF.containing_type = _UUIDREFERENCESARCHIVE
_UUIDREFERENCESARCHIVE.fields_by_name['table_refs'].message_type = _UUIDREFERENCESARCHIVE_TABLEREF
_UUIDREFERENCESARCHIVE.fields_by_name['table_uuid_refs'].message_type = _UUIDREFERENCESARCHIVE_TABLEWITHUUIDREF
_FORMULAOWNERDEPENDENCIESARCHIVE.fields_by_name['formula_owner_uid'].message_type = TSPMessages__pb2._UUID
_FORMULAOWNERDEPENDENCIESARCHIVE.fields_by_name['cell_dependencies'].message_type = _CELLDEPENDENCIESEXPANDEDARCHIVE
_FORMULAOWNERDEPENDENCIESARCHIVE.fields_by_name['range_dependencies'].message_type = _RANGEDEPENDENCIESARCHIVE
_FORMULAOWNERDEPENDENCIESARCHIVE.fields_by_name['volatile_dependencies'].message_type = _VOLATILEDEPENDENCIESEXPANDEDARCHIVE
_FORMULAOWNERDEPENDENCIESARCHIVE.fields_by_name['spanning_column_dependencies'].message_type = _SPANNINGDEPENDENCIESEXPANDEDARCHIVE
_FORMULAOWNERDEPENDENCIESARCHIVE.fields_by_name['spanning_row_dependencies'].message_type = _SPANNINGDEPENDENCIESEXPANDEDARCHIVE
_FORMULAOWNERDEPENDENCIESARCHIVE.fields_by_name['whole_owner_dependencies'].message_type = _WHOLEOWNERDEPENDENCIESEXPANDEDARCHIVE
_FORMULAOWNERDEPENDENCIESARCHIVE.fields_by_name['cell_errors'].message_type = _CELLERRORSARCHIVE
_FORMULAOWNERDEPENDENCIESARCHIVE.fields_by_name['formula_owner'].message_type = TSPMessages__pb2._REFERENCE
_FORMULAOWNERDEPENDENCIESARCHIVE.fields_by_name['base_owner_uid'].message_type = TSPMessages__pb2._UUID
_FORMULAOWNERDEPENDENCIESARCHIVE.fields_by_name['tiled_cell_dependencies'].message_type = _CELLDEPENDENCIESTILEDARCHIVE
_FORMULAOWNERDEPENDENCIESARCHIVE.fields_by_name['uuid_references'].message_type = _UUIDREFERENCESARCHIVE
_FORMULAOWNERDEPENDENCIESARCHIVE.fields_by_name['tiled_range_dependencies'].message_type = _RANGEDEPENDENCIESTILEDARCHIVE
_FORMULAOWNERINFOARCHIVE.fields_by_name['formula_owner_id'].message_type = TSPMessages__pb2._CFUUIDARCHIVE
_FORMULAOWNERINFOARCHIVE.fields_by_name['cell_dependencies'].message_type = _CELLDEPENDENCIESARCHIVE
_FORMULAOWNERINFOARCHIVE.fields_by_name['range_dependencies'].message_type = _RANGEDEPENDENCIESARCHIVE
_FORMULAOWNERINFOARCHIVE.fields_by_name['volatile_dependencies'].message_type = _VOLATILEDEPENDENCIESARCHIVE
_FORMULAOWNERINFOARCHIVE.fields_by_name['spanning_column_dependencies'].message_type = _SPANNINGDEPENDENCIESARCHIVE
_FORMULAOWNERINFOARCHIVE.fields_by_name['spanning_row_dependencies'].message_type = _SPANNINGDEPENDENCIESARCHIVE
_FORMULAOWNERINFOARCHIVE.fields_by_name['whole_owner_dependencies'].message_type = _WHOLEOWNERDEPENDENCIESARCHIVE
_FORMULAOWNERINFOARCHIVE.fields_by_name['cell_errors'].message_type = _CELLERRORSARCHIVE
_FORMULAOWNERINFOARCHIVE.fields_by_name['formula_owner'].message_type = TSPMessages__pb2._REFERENCE
_SUBFORMULAOWNERIDARCHIVE.fields_by_name['base_owner_uid'].message_type = TSPMessages__pb2._UUID
_OWNERIDMAPARCHIVE_OWNERIDMAPARCHIVEENTRY.fields_by_name['owner_id'].message_type = TSPMessages__pb2._CFUUIDARCHIVE
_OWNERIDMAPARCHIVE_OWNERIDMAPARCHIVEENTRY.fields_by_name['sub_formula_owner_uid'].message_type = _SUBFORMULAOWNERIDARCHIVE
_OWNERIDMAPARCHIVE_OWNERIDMAPARCHIVEENTRY.containing_type = _OWNERIDMAPARCHIVE
_OWNERIDMAPARCHIVE.fields_by_name['map_entry'].message_type = _OWNERIDMAPARCHIVE_OWNERIDMAPARCHIVEENTRY
_UIDLOOKUPLISTARCHIVE.fields_by_name['uuids'].message_type = TSPMessages__pb2._UUID
_DEPENDENCYTRACKERARCHIVE.fields_by_name['formula_owner_info'].message_type = _FORMULAOWNERINFOARCHIVE
_DEPENDENCYTRACKERARCHIVE.fields_by_name['dirty_leaf'].message_type = _CELLREFERENCEARCHIVE
_DEPENDENCYTRACKERARCHIVE.fields_by_name['owner_id_map'].message_type = _OWNERIDMAPARCHIVE
_DEPENDENCYTRACKERARCHIVE.fields_by_name['internal_dirty_leaf'].message_type = _INTERNALCELLREFERENCEARCHIVE
_DEPENDENCYTRACKERARCHIVE.fields_by_name['formula_owner_dependencies'].message_type = TSPMessages__pb2._REFERENCE
_REMOTEDATAVALUEMAPARCHIVE_REMOTEDATAMAPENTRY.fields_by_name['specifier'].message_type = _REMOTEDATASPECIFIERARCHIVE
_REMOTEDATAVALUEMAPARCHIVE_REMOTEDATAMAPENTRY.fields_by_name['value'].message_type = _CELLVALUEARCHIVE
_REMOTEDATAVALUEMAPARCHIVE_REMOTEDATAMAPENTRY.containing_type = _REMOTEDATAVALUEMAPARCHIVE
_REMOTEDATAVALUEMAPARCHIVE.fields_by_name['entry'].message_type = _REMOTEDATAVALUEMAPARCHIVE_REMOTEDATAMAPENTRY
_STOCKARCHIVE_ATTRIBUTEENTRY.containing_type = _STOCKARCHIVE
_STOCKARCHIVE.fields_by_name['attribute'].message_type = _STOCKARCHIVE_ATTRIBUTEENTRY
_REMOTEDATASTOREARCHIVE.fields_by_name['value_map'].message_type = _REMOTEDATAVALUEMAPARCHIVE
_REMOTEDATASTOREARCHIVE.fields_by_name['stocks'].message_type = _STOCKARCHIVE
_NAMETRACKEDREFERENCEPAIR.fields_by_name['tracked_reference'].message_type = TSPMessages__pb2._REFERENCE
_NAMESBYTRACKEDREFERENCEARCHIVE.fields_by_name['table_id'].message_type = TSPMessages__pb2._CFUUIDARCHIVE
_NAMESBYTRACKEDREFERENCEARCHIVE.fields_by_name['name_tracked_reference_pair'].message_type = _NAMETRACKEDREFERENCEPAIR
_NAMEDREFERENCEMANAGERARCHIVE.fields_by_name['reference_tracker'].message_type = TSPMessages__pb2._REFERENCE
_NAMEDREFERENCEMANAGERARCHIVE.fields_by_name['names_by_tracked_reference_by_table'].message_type = _NAMESBYTRACKEDREFERENCEARCHIVE
_UUIDSETSTOREARCHIVE_UUIDSET.fields_by_name['uuid'].message_type = TSPMessages__pb2._UUID
_UUIDSETSTOREARCHIVE_UUIDSET.containing_type = _UUIDSETSTOREARCHIVE
_UUIDSETSTOREARCHIVE.fields_by_name['uuidSet'].message_type = _UUIDSETSTOREARCHIVE_UUIDSET
_UUIDREFERENCEMAPARCHIVE_CELLREFSFORUUID.fields_by_name['uuid'].message_type = TSPMessages__pb2._UUID
_UUIDREFERENCEMAPARCHIVE_CELLREFSFORUUID.fields_by_name['cell_ref'].message_type = _INTERNALCELLREFERENCEARCHIVE
_UUIDREFERENCEMAPARCHIVE_CELLREFSFORUUID.fields_by_name['cell_refs'].message_type = _INTERNALCELLREFSETARCHIVE
_UUIDREFERENCEMAPARCHIVE_CELLREFSFORUUID.containing_type = _UUIDREFERENCEMAPARCHIVE
_UUIDREFERENCEMAPARCHIVE.fields_by_name['cell_refs_for_uuid'].message_type = _UUIDREFERENCEMAPARCHIVE_CELLREFSFORUUID
_GROUPBYNODEMAPARCHIVE_CELLREFSFORGROUPNODE.fields_by_name['group_node_uid'].message_type = TSPMessages__pb2._UUID
_GROUPBYNODEMAPARCHIVE_CELLREFSFORGROUPNODE.fields_by_name['cell_refs'].message_type = _INTERNALCELLREFSETARCHIVE
_GROUPBYNODEMAPARCHIVE_CELLREFSFORGROUPNODE.containing_type = _GROUPBYNODEMAPARCHIVE
_GROUPBYNODEMAPARCHIVE_GROUPNODESFORGROUPBY.fields_by_name['group_by_uid'].message_type = TSPMessages__pb2._UUID
_GROUPBYNODEMAPARCHIVE_GROUPNODESFORGROUPBY.fields_by_name['refs_for_group_node'].message_type = _GROUPBYNODEMAPARCHIVE_CELLREFSFORGROUPNODE
_GROUPBYNODEMAPARCHIVE_GROUPNODESFORGROUPBY.containing_type = _GROUPBYNODEMAPARCHIVE
_GROUPBYNODEMAPARCHIVE.fields_by_name['refs_for_group_by'].message_type = _GROUPBYNODEMAPARCHIVE_GROUPNODESFORGROUPBY
_CALCULATIONENGINEARCHIVE.fields_by_name['dependency_tracker'].message_type = _DEPENDENCYTRACKERARCHIVE
_CALCULATIONENGINEARCHIVE.fields_by_name['named_reference_manager'].message_type = TSPMessages__pb2._REFERENCE
_CALCULATIONENGINEARCHIVE.fields_by_name['excel_import_date_mode'].enum_type = _CALCULATIONENGINEARCHIVE_EXCELIMPORTDATEMODE
_CALCULATIONENGINEARCHIVE.fields_by_name['uuid_reference_map'].message_type = _UUIDREFERENCEMAPARCHIVE
_CALCULATIONENGINEARCHIVE.fields_by_name['table_uid_history'].message_type = _REWRITETABLEUIDINFOARCHIVE
_CALCULATIONENGINEARCHIVE.fields_by_name['remote_data_store'].message_type = TSPMessages__pb2._REFERENCE
_CALCULATIONENGINEARCHIVE.fields_by_name['group_node_map'].message_type = _GROUPBYNODEMAPARCHIVE
_CALCULATIONENGINEARCHIVE.fields_by_name['header_name_manager'].message_type = TSPMessages__pb2._REFERENCE
_CALCULATIONENGINEARCHIVE.fields_by_name['refs_to_dirty'].message_type = TSPMessages__pb2._REFERENCE
_CALCULATIONENGINEARCHIVE.fields_by_name['begin_tracking_names_legacy_nrm'].message_type = TSPMessages__pb2._UUID
_CALCULATIONENGINEARCHIVE.fields_by_name['end_tracking_names_legacy_nrm'].message_type = TSPMessages__pb2._UUID
_CALCULATIONENGINEARCHIVE_EXCELIMPORTDATEMODE.containing_type = _CALCULATIONENGINEARCHIVE
_CATEGORYREFERENCEARCHIVE_CATREFUIDLIST.fields_by_name['uid'].message_type = TSPMessages__pb2._UUID
_CATEGORYREFERENCEARCHIVE_CATREFUIDLIST.containing_type = _CATEGORYREFERENCEARCHIVE
_CATEGORYREFERENCEARCHIVE.fields_by_name['group_by_uid'].message_type = TSPMessages__pb2._UUID
_CATEGORYREFERENCEARCHIVE.fields_by_name['column_uid'].message_type = TSPMessages__pb2._UUID
_CATEGORYREFERENCEARCHIVE.fields_by_name['aggregate_type'].enum_type = _CATEGORYAGGTYPE
_CATEGORYREFERENCEARCHIVE.fields_by_name['group_uids'].message_type = _CATEGORYREFERENCEARCHIVE_CATREFUIDLIST
_CATEGORYREFERENCEARCHIVE.fields_by_name['preserve_flags'].message_type = _PRESERVECOLUMNROWFLAGSARCHIVE
_CATEGORYREFERENCEARCHIVE.fields_by_name['relative_group_uid'].message_type = TSPMessages__pb2._UUID
_CATEGORYREFERENCEARCHIVE.fields_by_name['absolute_group_uid'].message_type = TSPMessages__pb2._UUID
_ASTNODEARRAYARCHIVE_ASTLOCALCELLREFERENCENODEARCHIVE.containing_type = _ASTNODEARRAYARCHIVE
_ASTNODEARRAYARCHIVE_ASTCROSSTABLECELLREFERENCENODEARCHIVE.fields_by_name['table_id'].message_type = TSPMessages__pb2._CFUUIDARCHIVE
_ASTNODEARRAYARCHIVE_ASTCROSSTABLECELLREFERENCENODEARCHIVE.containing_type = _ASTNODEARRAYARCHIVE
_ASTNODEARRAYARCHIVE_ASTCOLUMNCOORDINATEARCHIVE.containing_type = _ASTNODEARRAYARCHIVE
_ASTNODEARRAYARCHIVE_ASTROWCOORDINATEARCHIVE.containing_type = _ASTNODEARRAYARCHIVE
_ASTNODEARRAYARCHIVE_ASTUIDLIST.fields_by_name['uid'].message_type = TSPMessages__pb2._UUID
_ASTNODEARRAYARCHIVE_ASTUIDLIST.containing_type = _ASTNODEARRAYARCHIVE
_ASTNODEARRAYARCHIVE_ASTUIDTRACT.fields_by_name['columnUids'].message_type = _ASTNODEARRAYARCHIVE_ASTUIDLIST
_ASTNODEARRAYARCHIVE_ASTUIDTRACT.fields_by_name['rowUids'].message_type = _ASTNODEARRAYARCHIVE_ASTUIDLIST
_ASTNODEARRAYARCHIVE_ASTUIDTRACT.fields_by_name['purpose'].enum_type = _ASTNODEARRAYARCHIVE_ASTUIDTRACTPURPOSE
_ASTNODEARRAYARCHIVE_ASTUIDTRACT.containing_type = _ASTNODEARRAYARCHIVE
_ASTNODEARRAYARCHIVE_ASTSTICKYBITS.containing_type = _ASTNODEARRAYARCHIVE
_ASTNODEARRAYARCHIVE_ASTUIDTRACTLIST.fields_by_name['tract'].message_type = _ASTNODEARRAYARCHIVE_ASTUIDTRACT
_ASTNODEARRAYARCHIVE_ASTUIDTRACTLIST.fields_by_name['sticky_bits'].message_type = _ASTNODEARRAYARCHIVE_ASTSTICKYBITS
_ASTNODEARRAYARCHIVE_ASTUIDTRACTLIST.containing_type = _ASTNODEARRAYARCHIVE
_ASTNODEARRAYARCHIVE_ASTUIDCOORDINATEARCHIVE.fields_by_name['column_uid'].message_type = TSPMessages__pb2._UUID
_ASTNODEARRAYARCHIVE_ASTUIDCOORDINATEARCHIVE.fields_by_name['row_uid'].message_type = TSPMessages__pb2._UUID
_ASTNODEARRAYARCHIVE_ASTUIDCOORDINATEARCHIVE.containing_type = _ASTNODEARRAYARCHIVE
_ASTNODEARRAYARCHIVE_ASTCATEGORYREFERENCEARCHIVE.fields_by_name['category_ref'].message_type = _CATEGORYREFERENCEARCHIVE
_ASTNODEARRAYARCHIVE_ASTCATEGORYREFERENCEARCHIVE.containing_type = _ASTNODEARRAYARCHIVE
_ASTNODEARRAYARCHIVE_ASTCOLONTRACTARCHIVE_ASTCOLONTRACTRELATIVERANGEARCHIVE.containing_type = _ASTNODEARRAYARCHIVE_ASTCOLONTRACTARCHIVE
_ASTNODEARRAYARCHIVE_ASTCOLONTRACTARCHIVE_ASTCOLONTRACTABSOLUTERANGEARCHIVE.containing_type = _ASTNODEARRAYARCHIVE_ASTCOLONTRACTARCHIVE
_ASTNODEARRAYARCHIVE_ASTCOLONTRACTARCHIVE.fields_by_name['relative_column'].message_type = _ASTNODEARRAYARCHIVE_ASTCOLONTRACTARCHIVE_ASTCOLONTRACTRELATIVERANGEARCHIVE
_ASTNODEARRAYARCHIVE_ASTCOLONTRACTARCHIVE.fields_by_name['relative_row'].message_type = _ASTNODEARRAYARCHIVE_ASTCOLONTRACTARCHIVE_ASTCOLONTRACTRELATIVERANGEARCHIVE
_ASTNODEARRAYARCHIVE_ASTCOLONTRACTARCHIVE.fields_by_name['absolute_column'].message_type = _ASTNODEARRAYARCHIVE_ASTCOLONTRACTARCHIVE_ASTCOLONTRACTABSOLUTERANGEARCHIVE
_ASTNODEARRAYARCHIVE_ASTCOLONTRACTARCHIVE.fields_by_name['absolute_row'].message_type = _ASTNODEARRAYARCHIVE_ASTCOLONTRACTARCHIVE_ASTCOLONTRACTABSOLUTERANGEARCHIVE
_ASTNODEARRAYARCHIVE_ASTCOLONTRACTARCHIVE.containing_type = _ASTNODEARRAYARCHIVE
_ASTNODEARRAYARCHIVE_ASTCROSSTABLEREFERENCEEXTRAINFOARCHIVE.fields_by_name['table_id'].message_type = TSPMessages__pb2._CFUUIDARCHIVE
_ASTNODEARRAYARCHIVE_ASTCROSSTABLEREFERENCEEXTRAINFOARCHIVE.containing_type = _ASTNODEARRAYARCHIVE
_ASTNODEARRAYARCHIVE_ASTLETNODEWHITESPACE.containing_type = _ASTNODEARRAYARCHIVE
_ASTNODEARRAYARCHIVE_ASTNODEARCHIVE.fields_by_name['AST_node_type'].enum_type = _ASTNODEARRAYARCHIVE_ASTNODETYPE
_ASTNODEARRAYARCHIVE_ASTNODEARCHIVE.fields_by_name['AST_thunk_node_array'].message_type = _ASTNODEARRAYARCHIVE
_ASTNODEARRAYARCHIVE_ASTNODEARCHIVE.fields_by_name['AST_local_cell_reference_node_reference'].message_type = _ASTNODEARRAYARCHIVE_ASTLOCALCELLREFERENCENODEARCHIVE
_ASTNODEARRAYARCHIVE_ASTNODEARCHIVE.fields_by_name['AST_cross_table_cell_reference_node_reference'].message_type = _ASTNODEARRAYARCHIVE_ASTCROSSTABLECELLREFERENCENODEARCHIVE
_ASTNODEARRAYARCHIVE_ASTNODEARCHIVE.fields_by_name['AST_column'].message_type = _ASTNODEARRAYARCHIVE_ASTCOLUMNCOORDINATEARCHIVE
_ASTNODEARRAYARCHIVE_ASTNODEARCHIVE.fields_by_name['AST_row'].message_type = _ASTNODEARRAYARCHIVE_ASTROWCOORDINATEARCHIVE
_ASTNODEARRAYARCHIVE_ASTNODEARCHIVE.fields_by_name['AST_cross_table_reference_extra_info'].message_type = _ASTNODEARRAYARCHIVE_ASTCROSSTABLEREFERENCEEXTRAINFOARCHIVE
_ASTNODEARRAYARCHIVE_ASTNODEARCHIVE.fields_by_name['AST_uid_coordinate'].message_type = _ASTNODEARRAYARCHIVE_ASTUIDCOORDINATEARCHIVE
_ASTNODEARRAYARCHIVE_ASTNODEARCHIVE.fields_by_name['AST_sticky_bits'].message_type = _ASTNODEARRAYARCHIVE_ASTSTICKYBITS
_ASTNODEARRAYARCHIVE_ASTNODEARCHIVE.fields_by_name['AST_frozen_sticky_bits'].message_type = _ASTNODEARRAYARCHIVE_ASTSTICKYBITS
_ASTNODEARRAYARCHIVE_ASTNODEARCHIVE.fields_by_name['AST_let_e2'].message_type = _ASTNODEARRAYARCHIVE
_ASTNODEARRAYARCHIVE_ASTNODEARCHIVE.fields_by_name['AST_let_whitespace'].message_type = _ASTNODEARRAYARCHIVE_ASTLETNODEWHITESPACE
_ASTNODEARRAYARCHIVE_ASTNODEARCHIVE.fields_by_name['AST_tract_list'].message_type = _ASTNODEARRAYARCHIVE_ASTUIDTRACTLIST
_ASTNODEARRAYARCHIVE_ASTNODEARCHIVE.fields_by_name['AST_category_ref'].message_type = _ASTNODEARRAYARCHIVE_ASTCATEGORYREFERENCEARCHIVE
_ASTNODEARRAYARCHIVE_ASTNODEARCHIVE.fields_by_name['AST_colon_tract'].message_type = _ASTNODEARRAYARCHIVE_ASTCOLONTRACTARCHIVE
_ASTNODEARRAYARCHIVE_ASTNODEARCHIVE.containing_type = _ASTNODEARRAYARCHIVE
_ASTNODEARRAYARCHIVE.fields_by_name['AST_node'].message_type = _ASTNODEARRAYARCHIVE_ASTNODEARCHIVE
_ASTNODEARRAYARCHIVE_ASTNODETYPE.containing_type = _ASTNODEARRAYARCHIVE
_ASTNODEARRAYARCHIVE_ASTUIDTRACTPURPOSE.containing_type = _ASTNODEARRAYARCHIVE
_FORMULAARCHIVE.fields_by_name['AST_node_array'].message_type = _ASTNODEARRAYARCHIVE
_FORMULAARCHIVE.fields_by_name['translation_flags'].message_type = _FORMULATRANSLATIONFLAGSARCHIVE
_FORMULAARCHIVE.fields_by_name['host_table_uid'].message_type = TSPMessages__pb2._UUID
_FORMULAARCHIVE.fields_by_name['host_column_uid'].message_type = TSPMessages__pb2._UUID
_FORMULAARCHIVE.fields_by_name['host_row_uid'].message_type = TSPMessages__pb2._UUID
_FUNCTORARCHIVE.fields_by_name['formula'].message_type = _FORMULAARCHIVE
_TABLETRANSPOSEINFOARCHIVE.fields_by_name['body_range_for_transposed_table'].message_type = _RANGECOORDINATEARCHIVE
_OWNERUIDMAPPERARCHIVE.fields_by_name['table_uid'].message_type = TSPMessages__pb2._UUID
_OWNERUIDMAPPERARCHIVE.fields_by_name['next_table_uid'].message_type = TSPMessages__pb2._UUID
_OWNERUIDMAPPERARCHIVE.fields_by_name['hidden_state_for_rows_owner_uid'].message_type = TSPMessages__pb2._UUID
_OWNERUIDMAPPERARCHIVE.fields_by_name['next_hidden_state_for_rows_owner_uid'].message_type = TSPMessages__pb2._UUID
_OWNERUIDMAPPERARCHIVE.fields_by_name['hidden_state_for_columns_owner_uid'].message_type = TSPMessages__pb2._UUID
_OWNERUIDMAPPERARCHIVE.fields_by_name['next_hidden_state_for_columns_owner_uid'].message_type = TSPMessages__pb2._UUID
_OWNERUIDMAPPERARCHIVE.fields_by_name['conditional_style_owner_uid'].message_type = TSPMessages__pb2._UUID
_OWNERUIDMAPPERARCHIVE.fields_by_name['next_conditional_style_owner_uid'].message_type = TSPMessages__pb2._UUID
_OWNERUIDMAPPERARCHIVE.fields_by_name['sort_rule_reference_tracker_owner_uid'].message_type = TSPMessages__pb2._UUID
_OWNERUIDMAPPERARCHIVE.fields_by_name['next_sort_rule_reference_tracker_owner_uid'].message_type = TSPMessages__pb2._UUID
_OWNERUIDMAPPERARCHIVE.fields_by_name['merge_owner_uid'].message_type = TSPMessages__pb2._UUID
_OWNERUIDMAPPERARCHIVE.fields_by_name['next_merge_owner_uid'].message_type = TSPMessages__pb2._UUID
_OWNERUIDMAPPERARCHIVE.fields_by_name['category_owner_uid'].message_type = TSPMessages__pb2._UUID
_OWNERUIDMAPPERARCHIVE.fields_by_name['next_category_owner_uid'].message_type = TSPMessages__pb2._UUID
_OWNERUIDMAPPERARCHIVE.fields_by_name['category_aggregates_owner_uid'].message_type = TSPMessages__pb2._UUID
_OWNERUIDMAPPERARCHIVE.fields_by_name['next_category_aggregates_owner_uid'].message_type = TSPMessages__pb2._UUID
_OWNERUIDMAPPERARCHIVE.fields_by_name['group_by_uid'].message_type = TSPMessages__pb2._UUID
_OWNERUIDMAPPERARCHIVE.fields_by_name['next_group_by_uid'].message_type = TSPMessages__pb2._UUID
_OWNERUIDMAPPERARCHIVE.fields_by_name['pencil_annotation_owner_uid'].message_type = TSPMessages__pb2._UUID
_OWNERUIDMAPPERARCHIVE.fields_by_name['next_pencil_annotation_owner_uid'].message_type = TSPMessages__pb2._UUID
_REWRITETABLEUIDINFOARCHIVE_TABLEUIDMAPENTRYARCHIVE.fields_by_name['prev_table_uid'].message_type = TSPMessages__pb2._UUID
_REWRITETABLEUIDINFOARCHIVE_TABLEUIDMAPENTRYARCHIVE.fields_by_name['new_table_uid'].message_type = TSPMessages__pb2._UUID
_REWRITETABLEUIDINFOARCHIVE_TABLEUIDMAPENTRYARCHIVE.containing_type = _REWRITETABLEUIDINFOARCHIVE
_REWRITETABLEUIDINFOARCHIVE.fields_by_name['table_uid_map'].message_type = _REWRITETABLEUIDINFOARCHIVE_TABLEUIDMAPENTRYARCHIVE
_GROUPBYCHANGEARCHIVE_GROUPINGCOLUMNCHANGEARCHIVE.containing_type = _GROUPBYCHANGEARCHIVE
_GROUPBYCHANGEARCHIVE.fields_by_name['change_type'].enum_type = _GROUPBYCHANGEARCHIVE_CHANGETYPE
_GROUPBYCHANGEARCHIVE.fields_by_name['group_by_uid'].message_type = TSPMessages__pb2._UUID
_GROUPBYCHANGEARCHIVE.fields_by_name['previous_to_updated_map'].message_type = TSPMessages__pb2._UUIDMAPARCHIVE
_GROUPBYCHANGEARCHIVE.fields_by_name['updated_to_previous_map'].message_type = TSPMessages__pb2._UUIDMAPARCHIVE
_GROUPBYCHANGEARCHIVE.fields_by_name['removed_group_uids'].message_type = TSPMessages__pb2._UUID
_GROUPBYCHANGEARCHIVE.fields_by_name['grouping_column_changes'].message_type = _GROUPBYCHANGEARCHIVE_GROUPINGCOLUMNCHANGEARCHIVE
_GROUPBYCHANGEARCHIVE_CHANGETYPE.containing_type = _GROUPBYCHANGEARCHIVE
_REWRITEGROUPNODEUIDINFOARCHIVE.fields_by_name['group_by_uid'].message_type = TSPMessages__pb2._UUID
_REWRITEGROUPNODEUIDINFOARCHIVE.fields_by_name['group_node_uid_map'].message_type = TSPMessages__pb2._UUIDMAPARCHIVE
_INDEXEDUIDSARCHIVE_INDEXEDUID.fields_by_name['uid_for_index'].message_type = TSPMessages__pb2._UUID
_INDEXEDUIDSARCHIVE_INDEXEDUID.containing_type = _INDEXEDUIDSARCHIVE
_INDEXEDUIDSARCHIVE.fields_by_name['uids'].message_type = _INDEXEDUIDSARCHIVE_INDEXEDUID
_REWRITERANGEENTRYARCHIVE.fields_by_name['range_uids'].message_type = TSPMessages__pb2._UUID
_COLUMNORROWUUIDSINFOARCHIVE.fields_by_name['table_uid'].message_type = TSPMessages__pb2._UUID
_COLUMNORROWUUIDSINFOARCHIVE.fields_by_name['cond_style_owner_uid'].message_type = TSPMessages__pb2._UUID
_COLUMNORROWUUIDSINFOARCHIVE.fields_by_name['group_by_uid'].message_type = TSPMessages__pb2._UUID
_COLUMNORROWUUIDSINFOARCHIVE.fields_by_name['uids'].message_type = _INDEXEDUIDSARCHIVE
_COLUMNORROWUUIDSINFOARCHIVE.fields_by_name['range_entries'].message_type = _REWRITERANGEENTRYARCHIVE
_COLUMNORROWUUIDSINFOARCHIVE.fields_by_name['table_range'].message_type = _RANGECOORDINATEARCHIVE
_COLUMNORROWUUIDSINFOARCHIVE.fields_by_name['insert_at_uid'].message_type = TSPMessages__pb2._UUID
_COLUMNORROWUUIDSINFOARCHIVE.fields_by_name['insert_opposite_uid'].message_type = TSPMessages__pb2._UUID
_REGIONINFOARCHIVE.fields_by_name['table_uid'].message_type = TSPMessages__pb2._UUID
_REGIONINFOARCHIVE.fields_by_name['column_uids'].message_type = _INDEXEDUIDSARCHIVE
_REGIONINFOARCHIVE.fields_by_name['row_uids'].message_type = _INDEXEDUIDSARCHIVE
_REGIONMOVEDINFOARCHIVE.fields_by_name['src_region'].message_type = _REGIONINFOARCHIVE
_REGIONMOVEDINFOARCHIVE.fields_by_name['dst_region'].message_type = _REGIONINFOARCHIVE
_REGIONMOVEDINFOARCHIVE.fields_by_name['original_src_region'].message_type = _REGIONINFOARCHIVE
_REGIONMOVEDINFOARCHIVE.fields_by_name['final_dest_table_uid'].message_type = TSPMessages__pb2._UUID
_FORMULAREWRITESPECARCHIVE.fields_by_name['rewrite_type'].enum_type = _FORMULAREWRITESPECARCHIVE_REWRITETYPE
_FORMULAREWRITESPECARCHIVE.fields_by_name['table_uid'].message_type = TSPMessages__pb2._UUID
_FORMULAREWRITESPECARCHIVE.fields_by_name['cond_style_owner_uid'].message_type = TSPMessages__pb2._UUID
_FORMULAREWRITESPECARCHIVE.fields_by_name['group_by_uid'].message_type = TSPMessages__pb2._UUID
_FORMULAREWRITESPECARCHIVE.fields_by_name['column_or_row_uuids_info'].message_type = _COLUMNORROWUUIDSINFOARCHIVE
_FORMULAREWRITESPECARCHIVE.fields_by_name['aux_column_or_row_uuids_info'].message_type = _COLUMNORROWUUIDSINFOARCHIVE
_FORMULAREWRITESPECARCHIVE.fields_by_name['region_moved_info'].message_type = _REGIONMOVEDINFOARCHIVE
_FORMULAREWRITESPECARCHIVE.fields_by_name['region_info'].message_type = _REGIONINFOARCHIVE
_FORMULAREWRITESPECARCHIVE.fields_by_name['rewrite_table_id_info'].message_type = _REWRITETABLEUIDINFOARCHIVE
_FORMULAREWRITESPECARCHIVE.fields_by_name['transposed_table_info'].message_type = _TABLETRANSPOSEINFOARCHIVE
_FORMULAREWRITESPECARCHIVE.fields_by_name['merge_origin_moved_info'].message_type = _MERGEORIGINMOVEDARCHIVE
_FORMULAREWRITESPECARCHIVE.fields_by_name['merge_source'].message_type = _MERGESOURCEARCHIVE
_FORMULAREWRITESPECARCHIVE.fields_by_name['group_node_info'].message_type = _REWRITEGROUPNODEUIDINFOARCHIVE
_FORMULAREWRITESPECARCHIVE.fields_by_name['groupby_change'].message_type = _GROUPBYCHANGEARCHIVE
_FORMULAREWRITESPECARCHIVE_REWRITETYPE.containing_type = _FORMULAREWRITESPECARCHIVE
_HAUNTEDOWNERARCHIVE.fields_by_name['owner_uid'].message_type = TSPMessages__pb2._UUID
_CELLCOORDINATEVECTORARCHIVE.fields_by_name['cell_coord'].message_type = _CELLCOORDINATEARCHIVE
_EXPANDEDCELLREFOBJECTPAIRARCHIVE.fields_by_name['cell_ref'].message_type = _CELLREFERENCEARCHIVE
_EXPANDEDCELLREFOBJECTPAIRARCHIVE.fields_by_name['object'].message_type = TSPMessages__pb2._REFERENCE
_EXPANDEDCELLREFOBJECTMAPARCHIVE.fields_by_name['cell_ref_object_pair'].message_type = _EXPANDEDCELLREFOBJECTPAIRARCHIVE
_FORMULAATCOORDARCHIVE.fields_by_name['formula'].message_type = _FORMULAARCHIVE
_FORMULACOORDPAIRSBYOWNERARCHIVE.fields_by_name['owner_uid'].message_type = TSPMessages__pb2._UUID
_FORMULACOORDPAIRSBYOWNERARCHIVE.fields_by_name['formula_at_coords'].message_type = _FORMULAATCOORDARCHIVE
_FORMULASFORUNDOARCHIVE.fields_by_name['formulas_for_owner'].message_type = _FORMULACOORDPAIRSBYOWNERARCHIVE
_FORMULAREWRITECOMMANDARCHIVE.fields_by_name['table_rewrite_command'].message_type = TSPMessages__pb2._REFERENCE
_FORMULAREWRITECOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_EXTENDTABLEIDHISTORYCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_EXTENDTABLEIDHISTORYCOMMANDARCHIVE.fields_by_name['rewrite_spec'].message_type = _FORMULAREWRITESPECARCHIVE
_EXTENDTABLEIDHISTORYCOMMANDARCHIVE.fields_by_name['table_uid_history_rollback'].message_type = _REWRITETABLEUIDINFOARCHIVE
_NUMBERTRACKEDREFERENCEPAIRARCHIVE.fields_by_name['tracked_reference'].message_type = TSPMessages__pb2._REFERENCE
_NUMBERTOTRACKEDREFERENCEMAPARCHIVE.fields_by_name['number_tracked_reference_pair'].message_type = _NUMBERTRACKEDREFERENCEPAIRARCHIVE
_TRACKEDREFERENCESREWRITECOMMANDARCHIVE.fields_by_name['references_in_reference_tracker'].message_type = _NUMBERTOTRACKEDREFERENCEMAPARCHIVE
_TRACKEDREFERENCESREWRITECOMMANDARCHIVE.fields_by_name['original_tracked_reference_copies'].message_type = _NUMBERTOTRACKEDREFERENCEMAPARCHIVE
_TRACKEDREFERENCESREWRITECOMMANDARCHIVE.fields_by_name['rewrite_spec'].message_type = _FORMULAREWRITESPECARCHIVE
_TRACKEDREFERENCESREWRITECOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_TRACKEDREFERENCEARCHIVE.fields_by_name['ast'].message_type = _ASTNODEARRAYARCHIVE
_EXPANDEDTRACKEDREFERENCEARCHIVE.fields_by_name['ast'].message_type = _ASTNODEARRAYARCHIVE
_REFERENCETRACKERARCHIVE.fields_by_name['uuid'].message_type = TSPMessages__pb2._CFUUIDARCHIVE
_REFERENCETRACKERARCHIVE.fields_by_name['tracked_reference'].message_type = TSPMessages__pb2._REFERENCE
_REFERENCETRACKERARCHIVE.fields_by_name['contained_tracked_reference'].message_type = _TRACKEDREFERENCEARCHIVE
_REFERENCETRACKERARCHIVE.fields_by_name['contained_expanded_tracked_reference'].message_type = _EXPANDEDTRACKEDREFERENCEARCHIVE
_BOOLEANCELLVALUEARCHIVE.fields_by_name['format'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_DATECELLVALUEARCHIVE.fields_by_name['format'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_NUMBERCELLVALUEARCHIVE.fields_by_name['format'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_STRINGCELLVALUEARCHIVE.fields_by_name['format'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_ERRORCELLVALUEARCHIVE.fields_by_name['error_type'].enum_type = _ERRORCELLVALUEARCHIVE_ERRORTYPE
_ERRORCELLVALUEARCHIVE_ERRORTYPE.containing_type = _ERRORCELLVALUEARCHIVE
_CELLVALUEARCHIVE.fields_by_name['cell_value_type'].enum_type = _CELLVALUEARCHIVE_CELLVALUETYPE
_CELLVALUEARCHIVE.fields_by_name['boolean_value'].message_type = _BOOLEANCELLVALUEARCHIVE
_CELLVALUEARCHIVE.fields_by_name['date_value'].message_type = _DATECELLVALUEARCHIVE
_CELLVALUEARCHIVE.fields_by_name['number_value'].message_type = _NUMBERCELLVALUEARCHIVE
_CELLVALUEARCHIVE.fields_by_name['string_value'].message_type = _STRINGCELLVALUEARCHIVE
_CELLVALUEARCHIVE.fields_by_name['error_value'].message_type = _ERRORCELLVALUEARCHIVE
_CELLVALUEARCHIVE_CELLVALUETYPE.containing_type = _CELLVALUEARCHIVE
DESCRIPTOR.message_types_by_name['CellReferenceArchive'] = _CELLREFERENCEARCHIVE
DESCRIPTOR.message_types_by_name['InternalCellReferenceArchive'] = _INTERNALCELLREFERENCEARCHIVE
DESCRIPTOR.message_types_by_name['RangeReferenceArchive'] = _RANGEREFERENCEARCHIVE
DESCRIPTOR.message_types_by_name['InternalRangeReferenceArchive'] = _INTERNALRANGEREFERENCEARCHIVE
DESCRIPTOR.message_types_by_name['IndexSetArchive'] = _INDEXSETARCHIVE
DESCRIPTOR.message_types_by_name['CellCoordSetArchive'] = _CELLCOORDSETARCHIVE
DESCRIPTOR.message_types_by_name['InternalCellRefSetArchive'] = _INTERNALCELLREFSETARCHIVE
DESCRIPTOR.message_types_by_name['ColumnRowSize'] = _COLUMNROWSIZE
DESCRIPTOR.message_types_by_name['CellRectArchive'] = _CELLRECTARCHIVE
DESCRIPTOR.message_types_by_name['CellRefSetArchive'] = _CELLREFSETARCHIVE
DESCRIPTOR.message_types_by_name['UidCoordSetArchive'] = _UIDCOORDSETARCHIVE
DESCRIPTOR.message_types_by_name['UidCellRefSetArchive'] = _UIDCELLREFSETARCHIVE
DESCRIPTOR.message_types_by_name['ReferencesToDirtyArchive'] = _REFERENCESTODIRTYARCHIVE
DESCRIPTOR.message_types_by_name['CoordMapperArchive'] = _COORDMAPPERARCHIVE
DESCRIPTOR.message_types_by_name['ReferenceArchive'] = _REFERENCEARCHIVE
DESCRIPTOR.message_types_by_name['EdgeArchive'] = _EDGEARCHIVE
DESCRIPTOR.message_types_by_name['EdgesArchive'] = _EDGESARCHIVE
DESCRIPTOR.message_types_by_name['ExpandedEdgesArchive'] = _EXPANDEDEDGESARCHIVE
DESCRIPTOR.message_types_by_name['CellRecordArchive'] = _CELLRECORDARCHIVE
DESCRIPTOR.message_types_by_name['CellDependenciesArchive'] = _CELLDEPENDENCIESARCHIVE
DESCRIPTOR.message_types_by_name['CellRecordExpandedArchive'] = _CELLRECORDEXPANDEDARCHIVE
DESCRIPTOR.message_types_by_name['CellDependenciesExpandedArchive'] = _CELLDEPENDENCIESEXPANDEDARCHIVE
DESCRIPTOR.message_types_by_name['CellRecordTileArchive'] = _CELLRECORDTILEARCHIVE
DESCRIPTOR.message_types_by_name['CellDependenciesTiledArchive'] = _CELLDEPENDENCIESTILEDARCHIVE
DESCRIPTOR.message_types_by_name['VolatileDependenciesArchive'] = _VOLATILEDEPENDENCIESARCHIVE
DESCRIPTOR.message_types_by_name['VolatileDependenciesExpandedArchive'] = _VOLATILEDEPENDENCIESEXPANDEDARCHIVE
DESCRIPTOR.message_types_by_name['RTreeInternalNodeContentsArchive'] = _RTREEINTERNALNODECONTENTSARCHIVE
DESCRIPTOR.message_types_by_name['RTreeLeafNodeContentsArchive'] = _RTREELEAFNODECONTENTSARCHIVE
DESCRIPTOR.message_types_by_name['RTreeNodeArchive'] = _RTREENODEARCHIVE
DESCRIPTOR.message_types_by_name['RTreeArchive'] = _RTREEARCHIVE
DESCRIPTOR.message_types_by_name['RangeBackDependencyArchive'] = _RANGEBACKDEPENDENCYARCHIVE
DESCRIPTOR.message_types_by_name['RangeDependenciesArchive'] = _RANGEDEPENDENCIESARCHIVE
DESCRIPTOR.message_types_by_name['RangePrecedentsTileArchive'] = _RANGEPRECEDENTSTILEARCHIVE
DESCRIPTOR.message_types_by_name['RangeDependenciesTiledArchive'] = _RANGEDEPENDENCIESTILEDARCHIVE
DESCRIPTOR.message_types_by_name['SpanningDependenciesArchive'] = _SPANNINGDEPENDENCIESARCHIVE
DESCRIPTOR.message_types_by_name['SpanningDependenciesExpandedArchive'] = _SPANNINGDEPENDENCIESEXPANDEDARCHIVE
DESCRIPTOR.message_types_by_name['WholeOwnerDependenciesArchive'] = _WHOLEOWNERDEPENDENCIESARCHIVE
DESCRIPTOR.message_types_by_name['WholeOwnerDependenciesExpandedArchive'] = _WHOLEOWNERDEPENDENCIESEXPANDEDARCHIVE
DESCRIPTOR.message_types_by_name['CellErrorsArchive'] = _CELLERRORSARCHIVE
DESCRIPTOR.message_types_by_name['UuidReferencesArchive'] = _UUIDREFERENCESARCHIVE
DESCRIPTOR.message_types_by_name['FormulaOwnerDependenciesArchive'] = _FORMULAOWNERDEPENDENCIESARCHIVE
DESCRIPTOR.message_types_by_name['FormulaOwnerInfoArchive'] = _FORMULAOWNERINFOARCHIVE
DESCRIPTOR.message_types_by_name['SubFormulaOwnerIDArchive'] = _SUBFORMULAOWNERIDARCHIVE
DESCRIPTOR.message_types_by_name['OwnerIDMapArchive'] = _OWNERIDMAPARCHIVE
DESCRIPTOR.message_types_by_name['UidLookupListArchive'] = _UIDLOOKUPLISTARCHIVE
DESCRIPTOR.message_types_by_name['DependencyTrackerArchive'] = _DEPENDENCYTRACKERARCHIVE
DESCRIPTOR.message_types_by_name['RemoteDataSpecifierArchive'] = _REMOTEDATASPECIFIERARCHIVE
DESCRIPTOR.message_types_by_name['RemoteDataValueMapArchive'] = _REMOTEDATAVALUEMAPARCHIVE
DESCRIPTOR.message_types_by_name['StockArchive'] = _STOCKARCHIVE
DESCRIPTOR.message_types_by_name['RemoteDataStoreArchive'] = _REMOTEDATASTOREARCHIVE
DESCRIPTOR.message_types_by_name['NameTrackedReferencePair'] = _NAMETRACKEDREFERENCEPAIR
DESCRIPTOR.message_types_by_name['NamesByTrackedReferenceArchive'] = _NAMESBYTRACKEDREFERENCEARCHIVE
DESCRIPTOR.message_types_by_name['NamedReferenceManagerArchive'] = _NAMEDREFERENCEMANAGERARCHIVE
DESCRIPTOR.message_types_by_name['UuidSetStoreArchive'] = _UUIDSETSTOREARCHIVE
DESCRIPTOR.message_types_by_name['UuidReferenceMapArchive'] = _UUIDREFERENCEMAPARCHIVE
DESCRIPTOR.message_types_by_name['GroupByNodeMapArchive'] = _GROUPBYNODEMAPARCHIVE
DESCRIPTOR.message_types_by_name['CalculationEngineArchive'] = _CALCULATIONENGINEARCHIVE
DESCRIPTOR.message_types_by_name['PreserveColumnRowFlagsArchive'] = _PRESERVECOLUMNROWFLAGSARCHIVE
DESCRIPTOR.message_types_by_name['CategoryReferenceArchive'] = _CATEGORYREFERENCEARCHIVE
DESCRIPTOR.message_types_by_name['ASTNodeArrayArchive'] = _ASTNODEARRAYARCHIVE
DESCRIPTOR.message_types_by_name['FormulaTranslationFlagsArchive'] = _FORMULATRANSLATIONFLAGSARCHIVE
DESCRIPTOR.message_types_by_name['FormulaArchive'] = _FORMULAARCHIVE
DESCRIPTOR.message_types_by_name['FunctorArchive'] = _FUNCTORARCHIVE
DESCRIPTOR.message_types_by_name['FormatStructArchive'] = _FORMATSTRUCTARCHIVE
DESCRIPTOR.message_types_by_name['RangeCoordinateArchive'] = _RANGECOORDINATEARCHIVE
DESCRIPTOR.message_types_by_name['TableTransposeInfoArchive'] = _TABLETRANSPOSEINFOARCHIVE
DESCRIPTOR.message_types_by_name['MergeOriginMovedArchive'] = _MERGEORIGINMOVEDARCHIVE
DESCRIPTOR.message_types_by_name['OwnerUIDMapperArchive'] = _OWNERUIDMAPPERARCHIVE
DESCRIPTOR.message_types_by_name['RewriteTableUIDInfoArchive'] = _REWRITETABLEUIDINFOARCHIVE
DESCRIPTOR.message_types_by_name['GroupByChangeArchive'] = _GROUPBYCHANGEARCHIVE
DESCRIPTOR.message_types_by_name['RewriteGroupNodeUIDInfoArchive'] = _REWRITEGROUPNODEUIDINFOARCHIVE
DESCRIPTOR.message_types_by_name['IndexedUidsArchive'] = _INDEXEDUIDSARCHIVE
DESCRIPTOR.message_types_by_name['RewriteRangeEntryArchive'] = _REWRITERANGEENTRYARCHIVE
DESCRIPTOR.message_types_by_name['ColumnOrRowUuidsInfoArchive'] = _COLUMNORROWUUIDSINFOARCHIVE
DESCRIPTOR.message_types_by_name['RegionInfoArchive'] = _REGIONINFOARCHIVE
DESCRIPTOR.message_types_by_name['RegionMovedInfoArchive'] = _REGIONMOVEDINFOARCHIVE
DESCRIPTOR.message_types_by_name['MergeSourceArchive'] = _MERGESOURCEARCHIVE
DESCRIPTOR.message_types_by_name['FormulaRewriteSpecArchive'] = _FORMULAREWRITESPECARCHIVE
DESCRIPTOR.message_types_by_name['HauntedOwnerArchive'] = _HAUNTEDOWNERARCHIVE
DESCRIPTOR.message_types_by_name['CellCoordinateArchive'] = _CELLCOORDINATEARCHIVE
DESCRIPTOR.message_types_by_name['CellCoordinateVectorArchive'] = _CELLCOORDINATEVECTORARCHIVE
DESCRIPTOR.message_types_by_name['ExpandedCellRefObjectPairArchive'] = _EXPANDEDCELLREFOBJECTPAIRARCHIVE
DESCRIPTOR.message_types_by_name['ExpandedCellRefObjectMapArchive'] = _EXPANDEDCELLREFOBJECTMAPARCHIVE
DESCRIPTOR.message_types_by_name['FormulaAtCoordArchive'] = _FORMULAATCOORDARCHIVE
DESCRIPTOR.message_types_by_name['FormulaCoordPairsByOwnerArchive'] = _FORMULACOORDPAIRSBYOWNERARCHIVE
DESCRIPTOR.message_types_by_name['FormulasForUndoArchive'] = _FORMULASFORUNDOARCHIVE
DESCRIPTOR.message_types_by_name['FormulaRewriteCommandArchive'] = _FORMULAREWRITECOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['ExtendTableIDHistoryCommandArchive'] = _EXTENDTABLEIDHISTORYCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['NumberTrackedReferencePairArchive'] = _NUMBERTRACKEDREFERENCEPAIRARCHIVE
DESCRIPTOR.message_types_by_name['NumberToTrackedReferenceMapArchive'] = _NUMBERTOTRACKEDREFERENCEMAPARCHIVE
DESCRIPTOR.message_types_by_name['TrackedReferencesRewriteCommandArchive'] = _TRACKEDREFERENCESREWRITECOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['TrackedReferenceArchive'] = _TRACKEDREFERENCEARCHIVE
DESCRIPTOR.message_types_by_name['ExpandedTrackedReferenceArchive'] = _EXPANDEDTRACKEDREFERENCEARCHIVE
DESCRIPTOR.message_types_by_name['ReferenceTrackerArchive'] = _REFERENCETRACKERARCHIVE
DESCRIPTOR.message_types_by_name['BooleanCellValueArchive'] = _BOOLEANCELLVALUEARCHIVE
DESCRIPTOR.message_types_by_name['DateCellValueArchive'] = _DATECELLVALUEARCHIVE
DESCRIPTOR.message_types_by_name['NumberCellValueArchive'] = _NUMBERCELLVALUEARCHIVE
DESCRIPTOR.message_types_by_name['StringCellValueArchive'] = _STRINGCELLVALUEARCHIVE
DESCRIPTOR.message_types_by_name['ErrorCellValueArchive'] = _ERRORCELLVALUEARCHIVE
DESCRIPTOR.message_types_by_name['CellValueArchive'] = _CELLVALUEARCHIVE
DESCRIPTOR.enum_types_by_name['CategoryAggType'] = _CATEGORYAGGTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CellReferenceArchive = _reflection.GeneratedProtocolMessageType('CellReferenceArchive', (_message.Message,), dict(
  DESCRIPTOR = _CELLREFERENCEARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.CellReferenceArchive)
  ))
_sym_db.RegisterMessage(CellReferenceArchive)

InternalCellReferenceArchive = _reflection.GeneratedProtocolMessageType('InternalCellReferenceArchive', (_message.Message,), dict(
  DESCRIPTOR = _INTERNALCELLREFERENCEARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.InternalCellReferenceArchive)
  ))
_sym_db.RegisterMessage(InternalCellReferenceArchive)

RangeReferenceArchive = _reflection.GeneratedProtocolMessageType('RangeReferenceArchive', (_message.Message,), dict(
  DESCRIPTOR = _RANGEREFERENCEARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.RangeReferenceArchive)
  ))
_sym_db.RegisterMessage(RangeReferenceArchive)

InternalRangeReferenceArchive = _reflection.GeneratedProtocolMessageType('InternalRangeReferenceArchive', (_message.Message,), dict(
  DESCRIPTOR = _INTERNALRANGEREFERENCEARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.InternalRangeReferenceArchive)
  ))
_sym_db.RegisterMessage(InternalRangeReferenceArchive)

IndexSetArchive = _reflection.GeneratedProtocolMessageType('IndexSetArchive', (_message.Message,), dict(

  IndexSetEntry = _reflection.GeneratedProtocolMessageType('IndexSetEntry', (_message.Message,), dict(
    DESCRIPTOR = _INDEXSETARCHIVE_INDEXSETENTRY,
    __module__ = 'TSCEArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCE.IndexSetArchive.IndexSetEntry)
    ))
  ,
  DESCRIPTOR = _INDEXSETARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.IndexSetArchive)
  ))
_sym_db.RegisterMessage(IndexSetArchive)
_sym_db.RegisterMessage(IndexSetArchive.IndexSetEntry)

CellCoordSetArchive = _reflection.GeneratedProtocolMessageType('CellCoordSetArchive', (_message.Message,), dict(

  ColumnEntry = _reflection.GeneratedProtocolMessageType('ColumnEntry', (_message.Message,), dict(
    DESCRIPTOR = _CELLCOORDSETARCHIVE_COLUMNENTRY,
    __module__ = 'TSCEArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCE.CellCoordSetArchive.ColumnEntry)
    ))
  ,
  DESCRIPTOR = _CELLCOORDSETARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.CellCoordSetArchive)
  ))
_sym_db.RegisterMessage(CellCoordSetArchive)
_sym_db.RegisterMessage(CellCoordSetArchive.ColumnEntry)

InternalCellRefSetArchive = _reflection.GeneratedProtocolMessageType('InternalCellRefSetArchive', (_message.Message,), dict(

  OwnerEntry = _reflection.GeneratedProtocolMessageType('OwnerEntry', (_message.Message,), dict(
    DESCRIPTOR = _INTERNALCELLREFSETARCHIVE_OWNERENTRY,
    __module__ = 'TSCEArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCE.InternalCellRefSetArchive.OwnerEntry)
    ))
  ,
  DESCRIPTOR = _INTERNALCELLREFSETARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.InternalCellRefSetArchive)
  ))
_sym_db.RegisterMessage(InternalCellRefSetArchive)
_sym_db.RegisterMessage(InternalCellRefSetArchive.OwnerEntry)

ColumnRowSize = _reflection.GeneratedProtocolMessageType('ColumnRowSize', (_message.Message,), dict(
  DESCRIPTOR = _COLUMNROWSIZE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.ColumnRowSize)
  ))
_sym_db.RegisterMessage(ColumnRowSize)

CellRectArchive = _reflection.GeneratedProtocolMessageType('CellRectArchive', (_message.Message,), dict(
  DESCRIPTOR = _CELLRECTARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.CellRectArchive)
  ))
_sym_db.RegisterMessage(CellRectArchive)

CellRefSetArchive = _reflection.GeneratedProtocolMessageType('CellRefSetArchive', (_message.Message,), dict(

  OwnerEntry = _reflection.GeneratedProtocolMessageType('OwnerEntry', (_message.Message,), dict(
    DESCRIPTOR = _CELLREFSETARCHIVE_OWNERENTRY,
    __module__ = 'TSCEArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCE.CellRefSetArchive.OwnerEntry)
    ))
  ,
  DESCRIPTOR = _CELLREFSETARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.CellRefSetArchive)
  ))
_sym_db.RegisterMessage(CellRefSetArchive)
_sym_db.RegisterMessage(CellRefSetArchive.OwnerEntry)

UidCoordSetArchive = _reflection.GeneratedProtocolMessageType('UidCoordSetArchive', (_message.Message,), dict(

  ColumnEntry = _reflection.GeneratedProtocolMessageType('ColumnEntry', (_message.Message,), dict(
    DESCRIPTOR = _UIDCOORDSETARCHIVE_COLUMNENTRY,
    __module__ = 'TSCEArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCE.UidCoordSetArchive.ColumnEntry)
    ))
  ,
  DESCRIPTOR = _UIDCOORDSETARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.UidCoordSetArchive)
  ))
_sym_db.RegisterMessage(UidCoordSetArchive)
_sym_db.RegisterMessage(UidCoordSetArchive.ColumnEntry)

UidCellRefSetArchive = _reflection.GeneratedProtocolMessageType('UidCellRefSetArchive', (_message.Message,), dict(

  OwnerEntry = _reflection.GeneratedProtocolMessageType('OwnerEntry', (_message.Message,), dict(
    DESCRIPTOR = _UIDCELLREFSETARCHIVE_OWNERENTRY,
    __module__ = 'TSCEArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCE.UidCellRefSetArchive.OwnerEntry)
    ))
  ,
  DESCRIPTOR = _UIDCELLREFSETARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.UidCellRefSetArchive)
  ))
_sym_db.RegisterMessage(UidCellRefSetArchive)
_sym_db.RegisterMessage(UidCellRefSetArchive.OwnerEntry)

ReferencesToDirtyArchive = _reflection.GeneratedProtocolMessageType('ReferencesToDirtyArchive', (_message.Message,), dict(
  DESCRIPTOR = _REFERENCESTODIRTYARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.ReferencesToDirtyArchive)
  ))
_sym_db.RegisterMessage(ReferencesToDirtyArchive)

CoordMapperArchive = _reflection.GeneratedProtocolMessageType('CoordMapperArchive', (_message.Message,), dict(

  BaseToViewEntry = _reflection.GeneratedProtocolMessageType('BaseToViewEntry', (_message.Message,), dict(
    DESCRIPTOR = _COORDMAPPERARCHIVE_BASETOVIEWENTRY,
    __module__ = 'TSCEArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCE.CoordMapperArchive.BaseToViewEntry)
    ))
  ,
  DESCRIPTOR = _COORDMAPPERARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.CoordMapperArchive)
  ))
_sym_db.RegisterMessage(CoordMapperArchive)
_sym_db.RegisterMessage(CoordMapperArchive.BaseToViewEntry)

ReferenceArchive = _reflection.GeneratedProtocolMessageType('ReferenceArchive', (_message.Message,), dict(
  DESCRIPTOR = _REFERENCEARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.ReferenceArchive)
  ))
_sym_db.RegisterMessage(ReferenceArchive)

EdgeArchive = _reflection.GeneratedProtocolMessageType('EdgeArchive', (_message.Message,), dict(
  DESCRIPTOR = _EDGEARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.EdgeArchive)
  ))
_sym_db.RegisterMessage(EdgeArchive)

EdgesArchive = _reflection.GeneratedProtocolMessageType('EdgesArchive', (_message.Message,), dict(
  DESCRIPTOR = _EDGESARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.EdgesArchive)
  ))
_sym_db.RegisterMessage(EdgesArchive)

ExpandedEdgesArchive = _reflection.GeneratedProtocolMessageType('ExpandedEdgesArchive', (_message.Message,), dict(
  DESCRIPTOR = _EXPANDEDEDGESARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.ExpandedEdgesArchive)
  ))
_sym_db.RegisterMessage(ExpandedEdgesArchive)

CellRecordArchive = _reflection.GeneratedProtocolMessageType('CellRecordArchive', (_message.Message,), dict(
  DESCRIPTOR = _CELLRECORDARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.CellRecordArchive)
  ))
_sym_db.RegisterMessage(CellRecordArchive)

CellDependenciesArchive = _reflection.GeneratedProtocolMessageType('CellDependenciesArchive', (_message.Message,), dict(
  DESCRIPTOR = _CELLDEPENDENCIESARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.CellDependenciesArchive)
  ))
_sym_db.RegisterMessage(CellDependenciesArchive)

CellRecordExpandedArchive = _reflection.GeneratedProtocolMessageType('CellRecordExpandedArchive', (_message.Message,), dict(
  DESCRIPTOR = _CELLRECORDEXPANDEDARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.CellRecordExpandedArchive)
  ))
_sym_db.RegisterMessage(CellRecordExpandedArchive)

CellDependenciesExpandedArchive = _reflection.GeneratedProtocolMessageType('CellDependenciesExpandedArchive', (_message.Message,), dict(
  DESCRIPTOR = _CELLDEPENDENCIESEXPANDEDARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.CellDependenciesExpandedArchive)
  ))
_sym_db.RegisterMessage(CellDependenciesExpandedArchive)

CellRecordTileArchive = _reflection.GeneratedProtocolMessageType('CellRecordTileArchive', (_message.Message,), dict(
  DESCRIPTOR = _CELLRECORDTILEARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.CellRecordTileArchive)
  ))
_sym_db.RegisterMessage(CellRecordTileArchive)

CellDependenciesTiledArchive = _reflection.GeneratedProtocolMessageType('CellDependenciesTiledArchive', (_message.Message,), dict(
  DESCRIPTOR = _CELLDEPENDENCIESTILEDARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.CellDependenciesTiledArchive)
  ))
_sym_db.RegisterMessage(CellDependenciesTiledArchive)

VolatileDependenciesArchive = _reflection.GeneratedProtocolMessageType('VolatileDependenciesArchive', (_message.Message,), dict(
  DESCRIPTOR = _VOLATILEDEPENDENCIESARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.VolatileDependenciesArchive)
  ))
_sym_db.RegisterMessage(VolatileDependenciesArchive)

VolatileDependenciesExpandedArchive = _reflection.GeneratedProtocolMessageType('VolatileDependenciesExpandedArchive', (_message.Message,), dict(
  DESCRIPTOR = _VOLATILEDEPENDENCIESEXPANDEDARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.VolatileDependenciesExpandedArchive)
  ))
_sym_db.RegisterMessage(VolatileDependenciesExpandedArchive)

RTreeInternalNodeContentsArchive = _reflection.GeneratedProtocolMessageType('RTreeInternalNodeContentsArchive', (_message.Message,), dict(
  DESCRIPTOR = _RTREEINTERNALNODECONTENTSARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.RTreeInternalNodeContentsArchive)
  ))
_sym_db.RegisterMessage(RTreeInternalNodeContentsArchive)

RTreeLeafNodeContentsArchive = _reflection.GeneratedProtocolMessageType('RTreeLeafNodeContentsArchive', (_message.Message,), dict(
  DESCRIPTOR = _RTREELEAFNODECONTENTSARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.RTreeLeafNodeContentsArchive)
  ))
_sym_db.RegisterMessage(RTreeLeafNodeContentsArchive)

RTreeNodeArchive = _reflection.GeneratedProtocolMessageType('RTreeNodeArchive', (_message.Message,), dict(
  DESCRIPTOR = _RTREENODEARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.RTreeNodeArchive)
  ))
_sym_db.RegisterMessage(RTreeNodeArchive)

RTreeArchive = _reflection.GeneratedProtocolMessageType('RTreeArchive', (_message.Message,), dict(
  DESCRIPTOR = _RTREEARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.RTreeArchive)
  ))
_sym_db.RegisterMessage(RTreeArchive)

RangeBackDependencyArchive = _reflection.GeneratedProtocolMessageType('RangeBackDependencyArchive', (_message.Message,), dict(
  DESCRIPTOR = _RANGEBACKDEPENDENCYARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.RangeBackDependencyArchive)
  ))
_sym_db.RegisterMessage(RangeBackDependencyArchive)

RangeDependenciesArchive = _reflection.GeneratedProtocolMessageType('RangeDependenciesArchive', (_message.Message,), dict(
  DESCRIPTOR = _RANGEDEPENDENCIESARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.RangeDependenciesArchive)
  ))
_sym_db.RegisterMessage(RangeDependenciesArchive)

RangePrecedentsTileArchive = _reflection.GeneratedProtocolMessageType('RangePrecedentsTileArchive', (_message.Message,), dict(

  FromToRangeArchive = _reflection.GeneratedProtocolMessageType('FromToRangeArchive', (_message.Message,), dict(
    DESCRIPTOR = _RANGEPRECEDENTSTILEARCHIVE_FROMTORANGEARCHIVE,
    __module__ = 'TSCEArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCE.RangePrecedentsTileArchive.FromToRangeArchive)
    ))
  ,
  DESCRIPTOR = _RANGEPRECEDENTSTILEARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.RangePrecedentsTileArchive)
  ))
_sym_db.RegisterMessage(RangePrecedentsTileArchive)
_sym_db.RegisterMessage(RangePrecedentsTileArchive.FromToRangeArchive)

RangeDependenciesTiledArchive = _reflection.GeneratedProtocolMessageType('RangeDependenciesTiledArchive', (_message.Message,), dict(
  DESCRIPTOR = _RANGEDEPENDENCIESTILEDARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.RangeDependenciesTiledArchive)
  ))
_sym_db.RegisterMessage(RangeDependenciesTiledArchive)

SpanningDependenciesArchive = _reflection.GeneratedProtocolMessageType('SpanningDependenciesArchive', (_message.Message,), dict(

  ReferringColumnToLocalCells = _reflection.GeneratedProtocolMessageType('ReferringColumnToLocalCells', (_message.Message,), dict(
    DESCRIPTOR = _SPANNINGDEPENDENCIESARCHIVE_REFERRINGCOLUMNTOLOCALCELLS,
    __module__ = 'TSCEArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCE.SpanningDependenciesArchive.ReferringColumnToLocalCells)
    ))
  ,

  ReferringColumnToRemoteCells = _reflection.GeneratedProtocolMessageType('ReferringColumnToRemoteCells', (_message.Message,), dict(
    DESCRIPTOR = _SPANNINGDEPENDENCIESARCHIVE_REFERRINGCOLUMNTOREMOTECELLS,
    __module__ = 'TSCEArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCE.SpanningDependenciesArchive.ReferringColumnToRemoteCells)
    ))
  ,
  DESCRIPTOR = _SPANNINGDEPENDENCIESARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.SpanningDependenciesArchive)
  ))
_sym_db.RegisterMessage(SpanningDependenciesArchive)
_sym_db.RegisterMessage(SpanningDependenciesArchive.ReferringColumnToLocalCells)
_sym_db.RegisterMessage(SpanningDependenciesArchive.ReferringColumnToRemoteCells)

SpanningDependenciesExpandedArchive = _reflection.GeneratedProtocolMessageType('SpanningDependenciesExpandedArchive', (_message.Message,), dict(

  ExtentRange = _reflection.GeneratedProtocolMessageType('ExtentRange', (_message.Message,), dict(
    DESCRIPTOR = _SPANNINGDEPENDENCIESEXPANDEDARCHIVE_EXTENTRANGE,
    __module__ = 'TSCEArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCE.SpanningDependenciesExpandedArchive.ExtentRange)
    ))
  ,

  ExtentRangeWithTableWithContext = _reflection.GeneratedProtocolMessageType('ExtentRangeWithTableWithContext', (_message.Message,), dict(
    DESCRIPTOR = _SPANNINGDEPENDENCIESEXPANDEDARCHIVE_EXTENTRANGEWITHTABLEWITHCONTEXT,
    __module__ = 'TSCEArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCE.SpanningDependenciesExpandedArchive.ExtentRangeWithTableWithContext)
    ))
  ,

  CellCoordRefersToExtents = _reflection.GeneratedProtocolMessageType('CellCoordRefersToExtents', (_message.Message,), dict(
    DESCRIPTOR = _SPANNINGDEPENDENCIESEXPANDEDARCHIVE_CELLCOORDREFERSTOEXTENTS,
    __module__ = 'TSCEArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCE.SpanningDependenciesExpandedArchive.CellCoordRefersToExtents)
    ))
  ,
  DESCRIPTOR = _SPANNINGDEPENDENCIESEXPANDEDARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.SpanningDependenciesExpandedArchive)
  ))
_sym_db.RegisterMessage(SpanningDependenciesExpandedArchive)
_sym_db.RegisterMessage(SpanningDependenciesExpandedArchive.ExtentRange)
_sym_db.RegisterMessage(SpanningDependenciesExpandedArchive.ExtentRangeWithTableWithContext)
_sym_db.RegisterMessage(SpanningDependenciesExpandedArchive.CellCoordRefersToExtents)

WholeOwnerDependenciesArchive = _reflection.GeneratedProtocolMessageType('WholeOwnerDependenciesArchive', (_message.Message,), dict(
  DESCRIPTOR = _WHOLEOWNERDEPENDENCIESARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.WholeOwnerDependenciesArchive)
  ))
_sym_db.RegisterMessage(WholeOwnerDependenciesArchive)

WholeOwnerDependenciesExpandedArchive = _reflection.GeneratedProtocolMessageType('WholeOwnerDependenciesExpandedArchive', (_message.Message,), dict(
  DESCRIPTOR = _WHOLEOWNERDEPENDENCIESEXPANDEDARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.WholeOwnerDependenciesExpandedArchive)
  ))
_sym_db.RegisterMessage(WholeOwnerDependenciesExpandedArchive)

CellErrorsArchive = _reflection.GeneratedProtocolMessageType('CellErrorsArchive', (_message.Message,), dict(

  ErrorForCell = _reflection.GeneratedProtocolMessageType('ErrorForCell', (_message.Message,), dict(
    DESCRIPTOR = _CELLERRORSARCHIVE_ERRORFORCELL,
    __module__ = 'TSCEArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCE.CellErrorsArchive.ErrorForCell)
    ))
  ,
  DESCRIPTOR = _CELLERRORSARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.CellErrorsArchive)
  ))
_sym_db.RegisterMessage(CellErrorsArchive)
_sym_db.RegisterMessage(CellErrorsArchive.ErrorForCell)

UuidReferencesArchive = _reflection.GeneratedProtocolMessageType('UuidReferencesArchive', (_message.Message,), dict(

  TableRef = _reflection.GeneratedProtocolMessageType('TableRef', (_message.Message,), dict(
    DESCRIPTOR = _UUIDREFERENCESARCHIVE_TABLEREF,
    __module__ = 'TSCEArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCE.UuidReferencesArchive.TableRef)
    ))
  ,

  UuidRef = _reflection.GeneratedProtocolMessageType('UuidRef', (_message.Message,), dict(
    DESCRIPTOR = _UUIDREFERENCESARCHIVE_UUIDREF,
    __module__ = 'TSCEArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCE.UuidReferencesArchive.UuidRef)
    ))
  ,

  TableWithUuidRef = _reflection.GeneratedProtocolMessageType('TableWithUuidRef', (_message.Message,), dict(
    DESCRIPTOR = _UUIDREFERENCESARCHIVE_TABLEWITHUUIDREF,
    __module__ = 'TSCEArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCE.UuidReferencesArchive.TableWithUuidRef)
    ))
  ,
  DESCRIPTOR = _UUIDREFERENCESARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.UuidReferencesArchive)
  ))
_sym_db.RegisterMessage(UuidReferencesArchive)
_sym_db.RegisterMessage(UuidReferencesArchive.TableRef)
_sym_db.RegisterMessage(UuidReferencesArchive.UuidRef)
_sym_db.RegisterMessage(UuidReferencesArchive.TableWithUuidRef)

FormulaOwnerDependenciesArchive = _reflection.GeneratedProtocolMessageType('FormulaOwnerDependenciesArchive', (_message.Message,), dict(
  DESCRIPTOR = _FORMULAOWNERDEPENDENCIESARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.FormulaOwnerDependenciesArchive)
  ))
_sym_db.RegisterMessage(FormulaOwnerDependenciesArchive)

FormulaOwnerInfoArchive = _reflection.GeneratedProtocolMessageType('FormulaOwnerInfoArchive', (_message.Message,), dict(
  DESCRIPTOR = _FORMULAOWNERINFOARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.FormulaOwnerInfoArchive)
  ))
_sym_db.RegisterMessage(FormulaOwnerInfoArchive)

SubFormulaOwnerIDArchive = _reflection.GeneratedProtocolMessageType('SubFormulaOwnerIDArchive', (_message.Message,), dict(
  DESCRIPTOR = _SUBFORMULAOWNERIDARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.SubFormulaOwnerIDArchive)
  ))
_sym_db.RegisterMessage(SubFormulaOwnerIDArchive)

OwnerIDMapArchive = _reflection.GeneratedProtocolMessageType('OwnerIDMapArchive', (_message.Message,), dict(

  OwnerIDMapArchiveEntry = _reflection.GeneratedProtocolMessageType('OwnerIDMapArchiveEntry', (_message.Message,), dict(
    DESCRIPTOR = _OWNERIDMAPARCHIVE_OWNERIDMAPARCHIVEENTRY,
    __module__ = 'TSCEArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCE.OwnerIDMapArchive.OwnerIDMapArchiveEntry)
    ))
  ,
  DESCRIPTOR = _OWNERIDMAPARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.OwnerIDMapArchive)
  ))
_sym_db.RegisterMessage(OwnerIDMapArchive)
_sym_db.RegisterMessage(OwnerIDMapArchive.OwnerIDMapArchiveEntry)

UidLookupListArchive = _reflection.GeneratedProtocolMessageType('UidLookupListArchive', (_message.Message,), dict(
  DESCRIPTOR = _UIDLOOKUPLISTARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.UidLookupListArchive)
  ))
_sym_db.RegisterMessage(UidLookupListArchive)

DependencyTrackerArchive = _reflection.GeneratedProtocolMessageType('DependencyTrackerArchive', (_message.Message,), dict(
  DESCRIPTOR = _DEPENDENCYTRACKERARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.DependencyTrackerArchive)
  ))
_sym_db.RegisterMessage(DependencyTrackerArchive)

RemoteDataSpecifierArchive = _reflection.GeneratedProtocolMessageType('RemoteDataSpecifierArchive', (_message.Message,), dict(
  DESCRIPTOR = _REMOTEDATASPECIFIERARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.RemoteDataSpecifierArchive)
  ))
_sym_db.RegisterMessage(RemoteDataSpecifierArchive)

RemoteDataValueMapArchive = _reflection.GeneratedProtocolMessageType('RemoteDataValueMapArchive', (_message.Message,), dict(

  RemoteDataMapEntry = _reflection.GeneratedProtocolMessageType('RemoteDataMapEntry', (_message.Message,), dict(
    DESCRIPTOR = _REMOTEDATAVALUEMAPARCHIVE_REMOTEDATAMAPENTRY,
    __module__ = 'TSCEArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCE.RemoteDataValueMapArchive.RemoteDataMapEntry)
    ))
  ,
  DESCRIPTOR = _REMOTEDATAVALUEMAPARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.RemoteDataValueMapArchive)
  ))
_sym_db.RegisterMessage(RemoteDataValueMapArchive)
_sym_db.RegisterMessage(RemoteDataValueMapArchive.RemoteDataMapEntry)

StockArchive = _reflection.GeneratedProtocolMessageType('StockArchive', (_message.Message,), dict(

  AttributeEntry = _reflection.GeneratedProtocolMessageType('AttributeEntry', (_message.Message,), dict(
    DESCRIPTOR = _STOCKARCHIVE_ATTRIBUTEENTRY,
    __module__ = 'TSCEArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCE.StockArchive.AttributeEntry)
    ))
  ,
  DESCRIPTOR = _STOCKARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.StockArchive)
  ))
_sym_db.RegisterMessage(StockArchive)
_sym_db.RegisterMessage(StockArchive.AttributeEntry)

RemoteDataStoreArchive = _reflection.GeneratedProtocolMessageType('RemoteDataStoreArchive', (_message.Message,), dict(
  DESCRIPTOR = _REMOTEDATASTOREARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.RemoteDataStoreArchive)
  ))
_sym_db.RegisterMessage(RemoteDataStoreArchive)

NameTrackedReferencePair = _reflection.GeneratedProtocolMessageType('NameTrackedReferencePair', (_message.Message,), dict(
  DESCRIPTOR = _NAMETRACKEDREFERENCEPAIR,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.NameTrackedReferencePair)
  ))
_sym_db.RegisterMessage(NameTrackedReferencePair)

NamesByTrackedReferenceArchive = _reflection.GeneratedProtocolMessageType('NamesByTrackedReferenceArchive', (_message.Message,), dict(
  DESCRIPTOR = _NAMESBYTRACKEDREFERENCEARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.NamesByTrackedReferenceArchive)
  ))
_sym_db.RegisterMessage(NamesByTrackedReferenceArchive)

NamedReferenceManagerArchive = _reflection.GeneratedProtocolMessageType('NamedReferenceManagerArchive', (_message.Message,), dict(
  DESCRIPTOR = _NAMEDREFERENCEMANAGERARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.NamedReferenceManagerArchive)
  ))
_sym_db.RegisterMessage(NamedReferenceManagerArchive)

UuidSetStoreArchive = _reflection.GeneratedProtocolMessageType('UuidSetStoreArchive', (_message.Message,), dict(

  UuidSet = _reflection.GeneratedProtocolMessageType('UuidSet', (_message.Message,), dict(
    DESCRIPTOR = _UUIDSETSTOREARCHIVE_UUIDSET,
    __module__ = 'TSCEArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCE.UuidSetStoreArchive.UuidSet)
    ))
  ,
  DESCRIPTOR = _UUIDSETSTOREARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.UuidSetStoreArchive)
  ))
_sym_db.RegisterMessage(UuidSetStoreArchive)
_sym_db.RegisterMessage(UuidSetStoreArchive.UuidSet)

UuidReferenceMapArchive = _reflection.GeneratedProtocolMessageType('UuidReferenceMapArchive', (_message.Message,), dict(

  CellRefsForUuid = _reflection.GeneratedProtocolMessageType('CellRefsForUuid', (_message.Message,), dict(
    DESCRIPTOR = _UUIDREFERENCEMAPARCHIVE_CELLREFSFORUUID,
    __module__ = 'TSCEArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCE.UuidReferenceMapArchive.CellRefsForUuid)
    ))
  ,
  DESCRIPTOR = _UUIDREFERENCEMAPARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.UuidReferenceMapArchive)
  ))
_sym_db.RegisterMessage(UuidReferenceMapArchive)
_sym_db.RegisterMessage(UuidReferenceMapArchive.CellRefsForUuid)

GroupByNodeMapArchive = _reflection.GeneratedProtocolMessageType('GroupByNodeMapArchive', (_message.Message,), dict(

  CellRefsForGroupNode = _reflection.GeneratedProtocolMessageType('CellRefsForGroupNode', (_message.Message,), dict(
    DESCRIPTOR = _GROUPBYNODEMAPARCHIVE_CELLREFSFORGROUPNODE,
    __module__ = 'TSCEArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCE.GroupByNodeMapArchive.CellRefsForGroupNode)
    ))
  ,

  GroupNodesForGroupBy = _reflection.GeneratedProtocolMessageType('GroupNodesForGroupBy', (_message.Message,), dict(
    DESCRIPTOR = _GROUPBYNODEMAPARCHIVE_GROUPNODESFORGROUPBY,
    __module__ = 'TSCEArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCE.GroupByNodeMapArchive.GroupNodesForGroupBy)
    ))
  ,
  DESCRIPTOR = _GROUPBYNODEMAPARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.GroupByNodeMapArchive)
  ))
_sym_db.RegisterMessage(GroupByNodeMapArchive)
_sym_db.RegisterMessage(GroupByNodeMapArchive.CellRefsForGroupNode)
_sym_db.RegisterMessage(GroupByNodeMapArchive.GroupNodesForGroupBy)

CalculationEngineArchive = _reflection.GeneratedProtocolMessageType('CalculationEngineArchive', (_message.Message,), dict(
  DESCRIPTOR = _CALCULATIONENGINEARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.CalculationEngineArchive)
  ))
_sym_db.RegisterMessage(CalculationEngineArchive)

PreserveColumnRowFlagsArchive = _reflection.GeneratedProtocolMessageType('PreserveColumnRowFlagsArchive', (_message.Message,), dict(
  DESCRIPTOR = _PRESERVECOLUMNROWFLAGSARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.PreserveColumnRowFlagsArchive)
  ))
_sym_db.RegisterMessage(PreserveColumnRowFlagsArchive)

CategoryReferenceArchive = _reflection.GeneratedProtocolMessageType('CategoryReferenceArchive', (_message.Message,), dict(

  CatRefUidList = _reflection.GeneratedProtocolMessageType('CatRefUidList', (_message.Message,), dict(
    DESCRIPTOR = _CATEGORYREFERENCEARCHIVE_CATREFUIDLIST,
    __module__ = 'TSCEArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCE.CategoryReferenceArchive.CatRefUidList)
    ))
  ,
  DESCRIPTOR = _CATEGORYREFERENCEARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.CategoryReferenceArchive)
  ))
_sym_db.RegisterMessage(CategoryReferenceArchive)
_sym_db.RegisterMessage(CategoryReferenceArchive.CatRefUidList)

ASTNodeArrayArchive = _reflection.GeneratedProtocolMessageType('ASTNodeArrayArchive', (_message.Message,), dict(

  ASTLocalCellReferenceNodeArchive = _reflection.GeneratedProtocolMessageType('ASTLocalCellReferenceNodeArchive', (_message.Message,), dict(
    DESCRIPTOR = _ASTNODEARRAYARCHIVE_ASTLOCALCELLREFERENCENODEARCHIVE,
    __module__ = 'TSCEArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCE.ASTNodeArrayArchive.ASTLocalCellReferenceNodeArchive)
    ))
  ,

  ASTCrossTableCellReferenceNodeArchive = _reflection.GeneratedProtocolMessageType('ASTCrossTableCellReferenceNodeArchive', (_message.Message,), dict(
    DESCRIPTOR = _ASTNODEARRAYARCHIVE_ASTCROSSTABLECELLREFERENCENODEARCHIVE,
    __module__ = 'TSCEArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCE.ASTNodeArrayArchive.ASTCrossTableCellReferenceNodeArchive)
    ))
  ,

  ASTColumnCoordinateArchive = _reflection.GeneratedProtocolMessageType('ASTColumnCoordinateArchive', (_message.Message,), dict(
    DESCRIPTOR = _ASTNODEARRAYARCHIVE_ASTCOLUMNCOORDINATEARCHIVE,
    __module__ = 'TSCEArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCE.ASTNodeArrayArchive.ASTColumnCoordinateArchive)
    ))
  ,

  ASTRowCoordinateArchive = _reflection.GeneratedProtocolMessageType('ASTRowCoordinateArchive', (_message.Message,), dict(
    DESCRIPTOR = _ASTNODEARRAYARCHIVE_ASTROWCOORDINATEARCHIVE,
    __module__ = 'TSCEArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCE.ASTNodeArrayArchive.ASTRowCoordinateArchive)
    ))
  ,

  ASTUidList = _reflection.GeneratedProtocolMessageType('ASTUidList', (_message.Message,), dict(
    DESCRIPTOR = _ASTNODEARRAYARCHIVE_ASTUIDLIST,
    __module__ = 'TSCEArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCE.ASTNodeArrayArchive.ASTUidList)
    ))
  ,

  ASTUidTract = _reflection.GeneratedProtocolMessageType('ASTUidTract', (_message.Message,), dict(
    DESCRIPTOR = _ASTNODEARRAYARCHIVE_ASTUIDTRACT,
    __module__ = 'TSCEArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCE.ASTNodeArrayArchive.ASTUidTract)
    ))
  ,

  ASTStickyBits = _reflection.GeneratedProtocolMessageType('ASTStickyBits', (_message.Message,), dict(
    DESCRIPTOR = _ASTNODEARRAYARCHIVE_ASTSTICKYBITS,
    __module__ = 'TSCEArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCE.ASTNodeArrayArchive.ASTStickyBits)
    ))
  ,

  ASTUidTractList = _reflection.GeneratedProtocolMessageType('ASTUidTractList', (_message.Message,), dict(
    DESCRIPTOR = _ASTNODEARRAYARCHIVE_ASTUIDTRACTLIST,
    __module__ = 'TSCEArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCE.ASTNodeArrayArchive.ASTUidTractList)
    ))
  ,

  ASTUidCoordinateArchive = _reflection.GeneratedProtocolMessageType('ASTUidCoordinateArchive', (_message.Message,), dict(
    DESCRIPTOR = _ASTNODEARRAYARCHIVE_ASTUIDCOORDINATEARCHIVE,
    __module__ = 'TSCEArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCE.ASTNodeArrayArchive.ASTUidCoordinateArchive)
    ))
  ,

  ASTCategoryReferenceArchive = _reflection.GeneratedProtocolMessageType('ASTCategoryReferenceArchive', (_message.Message,), dict(
    DESCRIPTOR = _ASTNODEARRAYARCHIVE_ASTCATEGORYREFERENCEARCHIVE,
    __module__ = 'TSCEArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCE.ASTNodeArrayArchive.ASTCategoryReferenceArchive)
    ))
  ,

  ASTColonTractArchive = _reflection.GeneratedProtocolMessageType('ASTColonTractArchive', (_message.Message,), dict(

    ASTColonTractRelativeRangeArchive = _reflection.GeneratedProtocolMessageType('ASTColonTractRelativeRangeArchive', (_message.Message,), dict(
      DESCRIPTOR = _ASTNODEARRAYARCHIVE_ASTCOLONTRACTARCHIVE_ASTCOLONTRACTRELATIVERANGEARCHIVE,
      __module__ = 'TSCEArchives_pb2'
      # @@protoc_insertion_point(class_scope:TSCE.ASTNodeArrayArchive.ASTColonTractArchive.ASTColonTractRelativeRangeArchive)
      ))
    ,

    ASTColonTractAbsoluteRangeArchive = _reflection.GeneratedProtocolMessageType('ASTColonTractAbsoluteRangeArchive', (_message.Message,), dict(
      DESCRIPTOR = _ASTNODEARRAYARCHIVE_ASTCOLONTRACTARCHIVE_ASTCOLONTRACTABSOLUTERANGEARCHIVE,
      __module__ = 'TSCEArchives_pb2'
      # @@protoc_insertion_point(class_scope:TSCE.ASTNodeArrayArchive.ASTColonTractArchive.ASTColonTractAbsoluteRangeArchive)
      ))
    ,
    DESCRIPTOR = _ASTNODEARRAYARCHIVE_ASTCOLONTRACTARCHIVE,
    __module__ = 'TSCEArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCE.ASTNodeArrayArchive.ASTColonTractArchive)
    ))
  ,

  ASTCrossTableReferenceExtraInfoArchive = _reflection.GeneratedProtocolMessageType('ASTCrossTableReferenceExtraInfoArchive', (_message.Message,), dict(
    DESCRIPTOR = _ASTNODEARRAYARCHIVE_ASTCROSSTABLEREFERENCEEXTRAINFOARCHIVE,
    __module__ = 'TSCEArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCE.ASTNodeArrayArchive.ASTCrossTableReferenceExtraInfoArchive)
    ))
  ,

  ASTLetNodeWhitespace = _reflection.GeneratedProtocolMessageType('ASTLetNodeWhitespace', (_message.Message,), dict(
    DESCRIPTOR = _ASTNODEARRAYARCHIVE_ASTLETNODEWHITESPACE,
    __module__ = 'TSCEArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCE.ASTNodeArrayArchive.ASTLetNodeWhitespace)
    ))
  ,

  ASTNodeArchive = _reflection.GeneratedProtocolMessageType('ASTNodeArchive', (_message.Message,), dict(
    DESCRIPTOR = _ASTNODEARRAYARCHIVE_ASTNODEARCHIVE,
    __module__ = 'TSCEArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCE.ASTNodeArrayArchive.ASTNodeArchive)
    ))
  ,
  DESCRIPTOR = _ASTNODEARRAYARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.ASTNodeArrayArchive)
  ))
_sym_db.RegisterMessage(ASTNodeArrayArchive)
_sym_db.RegisterMessage(ASTNodeArrayArchive.ASTLocalCellReferenceNodeArchive)
_sym_db.RegisterMessage(ASTNodeArrayArchive.ASTCrossTableCellReferenceNodeArchive)
_sym_db.RegisterMessage(ASTNodeArrayArchive.ASTColumnCoordinateArchive)
_sym_db.RegisterMessage(ASTNodeArrayArchive.ASTRowCoordinateArchive)
_sym_db.RegisterMessage(ASTNodeArrayArchive.ASTUidList)
_sym_db.RegisterMessage(ASTNodeArrayArchive.ASTUidTract)
_sym_db.RegisterMessage(ASTNodeArrayArchive.ASTStickyBits)
_sym_db.RegisterMessage(ASTNodeArrayArchive.ASTUidTractList)
_sym_db.RegisterMessage(ASTNodeArrayArchive.ASTUidCoordinateArchive)
_sym_db.RegisterMessage(ASTNodeArrayArchive.ASTCategoryReferenceArchive)
_sym_db.RegisterMessage(ASTNodeArrayArchive.ASTColonTractArchive)
_sym_db.RegisterMessage(ASTNodeArrayArchive.ASTColonTractArchive.ASTColonTractRelativeRangeArchive)
_sym_db.RegisterMessage(ASTNodeArrayArchive.ASTColonTractArchive.ASTColonTractAbsoluteRangeArchive)
_sym_db.RegisterMessage(ASTNodeArrayArchive.ASTCrossTableReferenceExtraInfoArchive)
_sym_db.RegisterMessage(ASTNodeArrayArchive.ASTLetNodeWhitespace)
_sym_db.RegisterMessage(ASTNodeArrayArchive.ASTNodeArchive)

FormulaTranslationFlagsArchive = _reflection.GeneratedProtocolMessageType('FormulaTranslationFlagsArchive', (_message.Message,), dict(
  DESCRIPTOR = _FORMULATRANSLATIONFLAGSARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.FormulaTranslationFlagsArchive)
  ))
_sym_db.RegisterMessage(FormulaTranslationFlagsArchive)

FormulaArchive = _reflection.GeneratedProtocolMessageType('FormulaArchive', (_message.Message,), dict(
  DESCRIPTOR = _FORMULAARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.FormulaArchive)
  ))
_sym_db.RegisterMessage(FormulaArchive)

FunctorArchive = _reflection.GeneratedProtocolMessageType('FunctorArchive', (_message.Message,), dict(
  DESCRIPTOR = _FUNCTORARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.FunctorArchive)
  ))
_sym_db.RegisterMessage(FunctorArchive)

FormatStructArchive = _reflection.GeneratedProtocolMessageType('FormatStructArchive', (_message.Message,), dict(
  DESCRIPTOR = _FORMATSTRUCTARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.FormatStructArchive)
  ))
_sym_db.RegisterMessage(FormatStructArchive)

RangeCoordinateArchive = _reflection.GeneratedProtocolMessageType('RangeCoordinateArchive', (_message.Message,), dict(
  DESCRIPTOR = _RANGECOORDINATEARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.RangeCoordinateArchive)
  ))
_sym_db.RegisterMessage(RangeCoordinateArchive)

TableTransposeInfoArchive = _reflection.GeneratedProtocolMessageType('TableTransposeInfoArchive', (_message.Message,), dict(
  DESCRIPTOR = _TABLETRANSPOSEINFOARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.TableTransposeInfoArchive)
  ))
_sym_db.RegisterMessage(TableTransposeInfoArchive)

MergeOriginMovedArchive = _reflection.GeneratedProtocolMessageType('MergeOriginMovedArchive', (_message.Message,), dict(
  DESCRIPTOR = _MERGEORIGINMOVEDARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.MergeOriginMovedArchive)
  ))
_sym_db.RegisterMessage(MergeOriginMovedArchive)

OwnerUIDMapperArchive = _reflection.GeneratedProtocolMessageType('OwnerUIDMapperArchive', (_message.Message,), dict(
  DESCRIPTOR = _OWNERUIDMAPPERARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.OwnerUIDMapperArchive)
  ))
_sym_db.RegisterMessage(OwnerUIDMapperArchive)

RewriteTableUIDInfoArchive = _reflection.GeneratedProtocolMessageType('RewriteTableUIDInfoArchive', (_message.Message,), dict(

  TableUIDMapEntryArchive = _reflection.GeneratedProtocolMessageType('TableUIDMapEntryArchive', (_message.Message,), dict(
    DESCRIPTOR = _REWRITETABLEUIDINFOARCHIVE_TABLEUIDMAPENTRYARCHIVE,
    __module__ = 'TSCEArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCE.RewriteTableUIDInfoArchive.TableUIDMapEntryArchive)
    ))
  ,
  DESCRIPTOR = _REWRITETABLEUIDINFOARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.RewriteTableUIDInfoArchive)
  ))
_sym_db.RegisterMessage(RewriteTableUIDInfoArchive)
_sym_db.RegisterMessage(RewriteTableUIDInfoArchive.TableUIDMapEntryArchive)

GroupByChangeArchive = _reflection.GeneratedProtocolMessageType('GroupByChangeArchive', (_message.Message,), dict(

  GroupingColumnChangeArchive = _reflection.GeneratedProtocolMessageType('GroupingColumnChangeArchive', (_message.Message,), dict(
    DESCRIPTOR = _GROUPBYCHANGEARCHIVE_GROUPINGCOLUMNCHANGEARCHIVE,
    __module__ = 'TSCEArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCE.GroupByChangeArchive.GroupingColumnChangeArchive)
    ))
  ,
  DESCRIPTOR = _GROUPBYCHANGEARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.GroupByChangeArchive)
  ))
_sym_db.RegisterMessage(GroupByChangeArchive)
_sym_db.RegisterMessage(GroupByChangeArchive.GroupingColumnChangeArchive)

RewriteGroupNodeUIDInfoArchive = _reflection.GeneratedProtocolMessageType('RewriteGroupNodeUIDInfoArchive', (_message.Message,), dict(
  DESCRIPTOR = _REWRITEGROUPNODEUIDINFOARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.RewriteGroupNodeUIDInfoArchive)
  ))
_sym_db.RegisterMessage(RewriteGroupNodeUIDInfoArchive)

IndexedUidsArchive = _reflection.GeneratedProtocolMessageType('IndexedUidsArchive', (_message.Message,), dict(

  IndexedUid = _reflection.GeneratedProtocolMessageType('IndexedUid', (_message.Message,), dict(
    DESCRIPTOR = _INDEXEDUIDSARCHIVE_INDEXEDUID,
    __module__ = 'TSCEArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCE.IndexedUidsArchive.IndexedUid)
    ))
  ,
  DESCRIPTOR = _INDEXEDUIDSARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.IndexedUidsArchive)
  ))
_sym_db.RegisterMessage(IndexedUidsArchive)
_sym_db.RegisterMessage(IndexedUidsArchive.IndexedUid)

RewriteRangeEntryArchive = _reflection.GeneratedProtocolMessageType('RewriteRangeEntryArchive', (_message.Message,), dict(
  DESCRIPTOR = _REWRITERANGEENTRYARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.RewriteRangeEntryArchive)
  ))
_sym_db.RegisterMessage(RewriteRangeEntryArchive)

ColumnOrRowUuidsInfoArchive = _reflection.GeneratedProtocolMessageType('ColumnOrRowUuidsInfoArchive', (_message.Message,), dict(
  DESCRIPTOR = _COLUMNORROWUUIDSINFOARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.ColumnOrRowUuidsInfoArchive)
  ))
_sym_db.RegisterMessage(ColumnOrRowUuidsInfoArchive)

RegionInfoArchive = _reflection.GeneratedProtocolMessageType('RegionInfoArchive', (_message.Message,), dict(
  DESCRIPTOR = _REGIONINFOARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.RegionInfoArchive)
  ))
_sym_db.RegisterMessage(RegionInfoArchive)

RegionMovedInfoArchive = _reflection.GeneratedProtocolMessageType('RegionMovedInfoArchive', (_message.Message,), dict(
  DESCRIPTOR = _REGIONMOVEDINFOARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.RegionMovedInfoArchive)
  ))
_sym_db.RegisterMessage(RegionMovedInfoArchive)

MergeSourceArchive = _reflection.GeneratedProtocolMessageType('MergeSourceArchive', (_message.Message,), dict(
  DESCRIPTOR = _MERGESOURCEARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.MergeSourceArchive)
  ))
_sym_db.RegisterMessage(MergeSourceArchive)

FormulaRewriteSpecArchive = _reflection.GeneratedProtocolMessageType('FormulaRewriteSpecArchive', (_message.Message,), dict(
  DESCRIPTOR = _FORMULAREWRITESPECARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.FormulaRewriteSpecArchive)
  ))
_sym_db.RegisterMessage(FormulaRewriteSpecArchive)

HauntedOwnerArchive = _reflection.GeneratedProtocolMessageType('HauntedOwnerArchive', (_message.Message,), dict(
  DESCRIPTOR = _HAUNTEDOWNERARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.HauntedOwnerArchive)
  ))
_sym_db.RegisterMessage(HauntedOwnerArchive)

CellCoordinateArchive = _reflection.GeneratedProtocolMessageType('CellCoordinateArchive', (_message.Message,), dict(
  DESCRIPTOR = _CELLCOORDINATEARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.CellCoordinateArchive)
  ))
_sym_db.RegisterMessage(CellCoordinateArchive)

CellCoordinateVectorArchive = _reflection.GeneratedProtocolMessageType('CellCoordinateVectorArchive', (_message.Message,), dict(
  DESCRIPTOR = _CELLCOORDINATEVECTORARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.CellCoordinateVectorArchive)
  ))
_sym_db.RegisterMessage(CellCoordinateVectorArchive)

ExpandedCellRefObjectPairArchive = _reflection.GeneratedProtocolMessageType('ExpandedCellRefObjectPairArchive', (_message.Message,), dict(
  DESCRIPTOR = _EXPANDEDCELLREFOBJECTPAIRARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.ExpandedCellRefObjectPairArchive)
  ))
_sym_db.RegisterMessage(ExpandedCellRefObjectPairArchive)

ExpandedCellRefObjectMapArchive = _reflection.GeneratedProtocolMessageType('ExpandedCellRefObjectMapArchive', (_message.Message,), dict(
  DESCRIPTOR = _EXPANDEDCELLREFOBJECTMAPARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.ExpandedCellRefObjectMapArchive)
  ))
_sym_db.RegisterMessage(ExpandedCellRefObjectMapArchive)

FormulaAtCoordArchive = _reflection.GeneratedProtocolMessageType('FormulaAtCoordArchive', (_message.Message,), dict(
  DESCRIPTOR = _FORMULAATCOORDARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.FormulaAtCoordArchive)
  ))
_sym_db.RegisterMessage(FormulaAtCoordArchive)

FormulaCoordPairsByOwnerArchive = _reflection.GeneratedProtocolMessageType('FormulaCoordPairsByOwnerArchive', (_message.Message,), dict(
  DESCRIPTOR = _FORMULACOORDPAIRSBYOWNERARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.FormulaCoordPairsByOwnerArchive)
  ))
_sym_db.RegisterMessage(FormulaCoordPairsByOwnerArchive)

FormulasForUndoArchive = _reflection.GeneratedProtocolMessageType('FormulasForUndoArchive', (_message.Message,), dict(
  DESCRIPTOR = _FORMULASFORUNDOARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.FormulasForUndoArchive)
  ))
_sym_db.RegisterMessage(FormulasForUndoArchive)

FormulaRewriteCommandArchive = _reflection.GeneratedProtocolMessageType('FormulaRewriteCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _FORMULAREWRITECOMMANDARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.FormulaRewriteCommandArchive)
  ))
_sym_db.RegisterMessage(FormulaRewriteCommandArchive)

ExtendTableIDHistoryCommandArchive = _reflection.GeneratedProtocolMessageType('ExtendTableIDHistoryCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _EXTENDTABLEIDHISTORYCOMMANDARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.ExtendTableIDHistoryCommandArchive)
  ))
_sym_db.RegisterMessage(ExtendTableIDHistoryCommandArchive)

NumberTrackedReferencePairArchive = _reflection.GeneratedProtocolMessageType('NumberTrackedReferencePairArchive', (_message.Message,), dict(
  DESCRIPTOR = _NUMBERTRACKEDREFERENCEPAIRARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.NumberTrackedReferencePairArchive)
  ))
_sym_db.RegisterMessage(NumberTrackedReferencePairArchive)

NumberToTrackedReferenceMapArchive = _reflection.GeneratedProtocolMessageType('NumberToTrackedReferenceMapArchive', (_message.Message,), dict(
  DESCRIPTOR = _NUMBERTOTRACKEDREFERENCEMAPARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.NumberToTrackedReferenceMapArchive)
  ))
_sym_db.RegisterMessage(NumberToTrackedReferenceMapArchive)

TrackedReferencesRewriteCommandArchive = _reflection.GeneratedProtocolMessageType('TrackedReferencesRewriteCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _TRACKEDREFERENCESREWRITECOMMANDARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.TrackedReferencesRewriteCommandArchive)
  ))
_sym_db.RegisterMessage(TrackedReferencesRewriteCommandArchive)

TrackedReferenceArchive = _reflection.GeneratedProtocolMessageType('TrackedReferenceArchive', (_message.Message,), dict(
  DESCRIPTOR = _TRACKEDREFERENCEARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.TrackedReferenceArchive)
  ))
_sym_db.RegisterMessage(TrackedReferenceArchive)

ExpandedTrackedReferenceArchive = _reflection.GeneratedProtocolMessageType('ExpandedTrackedReferenceArchive', (_message.Message,), dict(
  DESCRIPTOR = _EXPANDEDTRACKEDREFERENCEARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.ExpandedTrackedReferenceArchive)
  ))
_sym_db.RegisterMessage(ExpandedTrackedReferenceArchive)

ReferenceTrackerArchive = _reflection.GeneratedProtocolMessageType('ReferenceTrackerArchive', (_message.Message,), dict(
  DESCRIPTOR = _REFERENCETRACKERARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.ReferenceTrackerArchive)
  ))
_sym_db.RegisterMessage(ReferenceTrackerArchive)

BooleanCellValueArchive = _reflection.GeneratedProtocolMessageType('BooleanCellValueArchive', (_message.Message,), dict(
  DESCRIPTOR = _BOOLEANCELLVALUEARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.BooleanCellValueArchive)
  ))
_sym_db.RegisterMessage(BooleanCellValueArchive)

DateCellValueArchive = _reflection.GeneratedProtocolMessageType('DateCellValueArchive', (_message.Message,), dict(
  DESCRIPTOR = _DATECELLVALUEARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.DateCellValueArchive)
  ))
_sym_db.RegisterMessage(DateCellValueArchive)

NumberCellValueArchive = _reflection.GeneratedProtocolMessageType('NumberCellValueArchive', (_message.Message,), dict(
  DESCRIPTOR = _NUMBERCELLVALUEARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.NumberCellValueArchive)
  ))
_sym_db.RegisterMessage(NumberCellValueArchive)

StringCellValueArchive = _reflection.GeneratedProtocolMessageType('StringCellValueArchive', (_message.Message,), dict(
  DESCRIPTOR = _STRINGCELLVALUEARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.StringCellValueArchive)
  ))
_sym_db.RegisterMessage(StringCellValueArchive)

ErrorCellValueArchive = _reflection.GeneratedProtocolMessageType('ErrorCellValueArchive', (_message.Message,), dict(
  DESCRIPTOR = _ERRORCELLVALUEARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.ErrorCellValueArchive)
  ))
_sym_db.RegisterMessage(ErrorCellValueArchive)

CellValueArchive = _reflection.GeneratedProtocolMessageType('CellValueArchive', (_message.Message,), dict(
  DESCRIPTOR = _CELLVALUEARCHIVE,
  __module__ = 'TSCEArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCE.CellValueArchive)
  ))
_sym_db.RegisterMessage(CellValueArchive)


_CELLRECORDARCHIVE.fields_by_name['edge']._options = None
_CELLRECORDARCHIVE.fields_by_name['calculate_precedents_on_next_recalc']._options = None
_DEPENDENCYTRACKERARCHIVE.fields_by_name['dirty_leaf']._options = None
_DEPENDENCYTRACKERARCHIVE.fields_by_name['internal_dirty_leaf']._options = None
_NAMEDREFERENCEMANAGERARCHIVE.fields_by_name['names_by_tracked_reference_by_table']._options = None
_TRACKEDREFERENCESREWRITECOMMANDARCHIVE.fields_by_name['references_in_reference_tracker']._options = None
_TRACKEDREFERENCESREWRITECOMMANDARCHIVE.fields_by_name['original_tracked_reference_copies']._options = None
_REFERENCETRACKERARCHIVE.fields_by_name['tracked_reference']._options = None
_DATECELLVALUEARCHIVE.fields_by_name['format_is_implicit']._options = None
_NUMBERCELLVALUEARCHIVE.fields_by_name['format_is_implicit']._options = None
_STRINGCELLVALUEARCHIVE.fields_by_name['format_is_implicit']._options = None
# @@protoc_insertion_point(module_scope)
