from __future__ import absolute_import
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: TSTArchives.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import TSPMessages_pb2 as TSPMessages__pb2
from . import TSDArchives_pb2 as TSDArchives__pb2
from . import TSKArchives_pb2 as TSKArchives__pb2
from . import TSSArchives_pb2 as TSSArchives__pb2
from . import TSCEArchives_pb2 as TSCEArchives__pb2
from . import TSWPArchives_pb2 as TSWPArchives__pb2
from . import TSTStylePropertyArchiving_pb2 as TSTStylePropertyArchiving__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='TSTArchives.proto',
  package='TST',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x11TSTArchives.proto\x12\x03TST\x1a\x11TSPMessages.proto\x1a\x11TSDArchives.proto\x1a\x11TSKArchives.proto\x1a\x11TSSArchives.proto\x1a\x12TSCEArchives.proto\x1a\x12TSWPArchives.proto\x1a\x1fTSTStylePropertyArchiving.proto\"Q\n\x06\x43\x65llID\x12\x12\n\npackedData\x18\x01 \x02(\x07\x12\x33\n\x0e\x65xpanded_coord\x18\x02 \x01(\x0b\x32\x1b.TSCE.CellCoordinateArchive\"\xa6\x01\n\x18\x43\x65llUIDLookupListArchive\x12/\n\x0b\x63olumn_uids\x18\x01 \x01(\x0b\x32\x1a.TSCE.UidLookupListArchive\x12,\n\x08row_uids\x18\x02 \x01(\x0b\x32\x1a.TSCE.UidLookupListArchive\x12\x16\n\x0e\x63olumn_indexes\x18\x03 \x03(\x05\x12\x13\n\x0brow_indexes\x18\x04 \x03(\x05\"\xd5\x01\n\x12\x43\x65llUIDListArchive\x12\x1b\n\x08row_uids\x18\x01 \x03(\x0b\x32\t.TSP.UUID\x12\x1e\n\x0b\x63olumn_uids\x18\x02 \x03(\x0b\x32\t.TSP.UUID\x12\x1e\n\x16\x63ompressed_row_indexes\x18\x03 \x03(\x05\x12!\n\x19\x63ompressed_column_indexes\x18\x04 \x03(\x05\x12?\n\x18uncompressed_lookup_list\x18\x05 \x01(\x0b\x32\x1d.TST.CellUIDLookupListArchive\"F\n\tTableSize\x12\x12\n\npackedData\x18\x01 \x02(\x07\x12\x13\n\x0bnum_columns\x18\x02 \x01(\r\x12\x10\n\x08num_rows\x18\x03 \x01(\r\":\n\x11\x45xpandedTableSize\x12\x13\n\x0bnum_columns\x18\x01 \x02(\r\x12\x10\n\x08num_rows\x18\x02 \x02(\r\"F\n\tCellRange\x12\x1b\n\x06origin\x18\x01 \x02(\x0b\x32\x0b.TST.CellID\x12\x1c\n\x04size\x18\x02 \x02(\x0b\x32\x0e.TST.TableSize\"f\n\x11\x45xpandedCellRange\x12+\n\x06origin\x18\x01 \x02(\x0b\x32\x1b.TSCE.CellCoordinateArchive\x12$\n\x04size\x18\x02 \x02(\x0b\x32\x16.TST.ExpandedTableSize\"\xb1\x01\n\x0eTableSelection\x12!\n\tcellRange\x18\x01 \x02(\x0b\x32\x0e.TST.CellRange\x12)\n\x11\x65xtendedCellRange\x18\x02 \x02(\x0b\x32\x0e.TST.CellRange\x12\x1e\n\x16\x65xtendedCellRangeValid\x18\x03 \x02(\x08\x12\x31\n\x0eselection_type\x18\x04 \x02(\x0e\x32\x19.TST.SelectionTypeArchive\"\xe2\x01\n\x0bTileRowInfo\x12\x16\n\x0etile_row_index\x18\x01 \x02(\r\x12\x12\n\ncell_count\x18\x02 \x02(\r\x12#\n\x1b\x63\x65ll_storage_buffer_pre_bnc\x18\x03 \x02(\x0c\x12\x1c\n\x14\x63\x65ll_offsets_pre_bnc\x18\x04 \x02(\x0c\x12\x17\n\x0fstorage_version\x18\x05 \x01(\r\x12\x1b\n\x13\x63\x65ll_storage_buffer\x18\x06 \x01(\x0c\x12\x14\n\x0c\x63\x65ll_offsets\x18\x07 \x01(\x0c\x12\x18\n\x10has_wide_offsets\x18\x08 \x01(\x08\"\xc2\x01\n\x04Tile\x12\x11\n\tmaxColumn\x18\x01 \x02(\r\x12\x0e\n\x06maxRow\x18\x02 \x02(\r\x12\x10\n\x08numCells\x18\x03 \x02(\r\x12\x0f\n\x07numrows\x18\x04 \x02(\r\x12\"\n\x08rowInfos\x18\x05 \x03(\x0b\x32\x10.TST.TileRowInfo\x12\x17\n\x0fstorage_version\x18\x06 \x01(\r\x12\x19\n\x11last_saved_in_BNC\x18\x07 \x01(\x08\x12\x1c\n\x14should_use_wide_rows\x18\x08 \x01(\x08\"\x9a\x01\n\x0bTileStorage\x12$\n\x05tiles\x18\x01 \x03(\x0b\x32\x15.TST.TileStorage.Tile\x12\x11\n\ttile_size\x18\x02 \x01(\r\x12\x1c\n\x14should_use_wide_rows\x18\x03 \x01(\x08\x1a\x34\n\x04Tile\x12\x0e\n\x06tileid\x18\x01 \x02(\r\x12\x1c\n\x04tile\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\"\xe6\x03\n\x0ePopUpMenuModel\x12/\n\x04item\x18\x01 \x03(\x0b\x32\x1d.TST.PopUpMenuModel.CellValueB\x02\x18\x01\x12)\n\ttsce_item\x18\x02 \x03(\x0b\x32\x16.TSCE.CellValueArchive\x1a\x95\x02\n\tCellValue\x12:\n\x0f\x63\x65ll_value_type\x18\x01 \x02(\x0e\x32!.TST.PopUpMenuModel.CellValueType\x12\x34\n\rboolean_value\x18\x02 \x01(\x0b\x32\x1d.TSCE.BooleanCellValueArchive\x12.\n\ndate_value\x18\x03 \x01(\x0b\x32\x1a.TSCE.DateCellValueArchive\x12\x32\n\x0cnumber_value\x18\x04 \x01(\x0b\x32\x1c.TSCE.NumberCellValueArchive\x12\x32\n\x0cstring_value\x18\x05 \x01(\x0b\x32\x1c.TSCE.StringCellValueArchive\"`\n\rCellValueType\x12\x0c\n\x08NIL_TYPE\x10\x01\x12\x10\n\x0c\x42OOLEAN_TYPE\x10\x02\x12\r\n\tDATE_TYPE\x10\x03\x12\x0f\n\x0bNUMBER_TYPE\x10\x04\x12\x0f\n\x0bSTRING_TYPE\x10\x05\"\xc9\n\n\x17ImportWarningSetArchive\x12Q\n\x16\x66ormula_import_warning\x18\x01 \x01(\x0b\x32\x31.TST.ImportWarningSetArchive.FormulaImportWarning\x12\'\n\x1f\x63ond_format_above_avg_equal_avg\x18\x02 \x01(\x08\x12%\n\x1d\x63ond_format_above_avg_std_dev\x18\x03 \x01(\x08\x12#\n\x1b\x63ond_format_complex_formula\x18\x04 \x01(\x08\x12#\n\x1b\x63ond_format_contains_errors\x18\x05 \x01(\x08\x12\x18\n\x10\x63ond_format_expr\x18\x06 \x01(\x08\x12\'\n\x1f\x63ond_format_not_contains_errors\x18\x07 \x01(\x08\x12\x30\n(cond_format_parameters_not_all_same_type\x18\x08 \x01(\x08\x12 \n\x18\x63ond_format_stop_if_true\x18\t \x01(\x08\x12(\n cond_format_unsupported_operator\x18\n \x01(\x08\x12\'\n\x1f\x63ond_format_unsupported_styling\x18\x0b \x01(\x08\x12+\n#cond_format_unsupported_time_period\x18\x0c \x01(\x08\x12\"\n\x1a\x65rror_cell_with_no_formula\x18\r \x01(\x08\x12\x1f\n\x17unsupported_cond_format\x18\x0e \x01(\x08\x12\x1c\n\x14original_data_format\x18\x0f \x01(\t\x12:\n2formula_warning_filtered_column_formula_not_copied\x18\x10 \x01(\x08\x12%\n\x1d\x64uration_format_range_changed\x18\x11 \x01(\x08\x1a\xbd\x01\n\x14\x46ormulaImportWarning\x12M\n\x14\x66ormula_warning_type\x18\x01 \x02(\x0e\x32/.TST.ImportWarningSetArchive.FormulaWarningType\x12\x18\n\x10original_formula\x18\x02 \x01(\t\x12\x1a\n\x12supplementary_text\x18\x03 \x01(\t\x12 \n\x18\x66ormula_warning_type_int\x18\x04 \x01(\x05\"\xa3\x03\n\x12\x46ormulaWarningType\x12\x15\n\x11THREE_D_REFERENCE\x10\x01\x12\x13\n\x0f\x41RRAYED_FORMULA\x10\x02\x12#\n\x1f\x44IFFERENT_BEHAVIOR_FOR_FUNCTION\x10\x03\x12\x0f\n\x0b\x45RROR_TOKEN\x10\x04\x12\x16\n\x12\x45XTERNAL_REFERENCE\x10\x05\x12\x1c\n\x18NATURAL_LANGUAGE_FORMULA\x10\x06\x12\x1b\n\x17REFERENCE_OUT_OF_BOUNDS\x10\x07\x12!\n\x1dSHARED_FORMULA_BASE_NOT_FOUND\x10\x08\x12\x10\n\x0cUNKNOWN_NAME\x10\t\x12\x17\n\x13UNSUPPORTED_FORMULA\x10\n\x12\x18\n\x14UNSUPPORTED_FUNCTION\x10\x0b\x12\x14\n\x10UNSUPPORTED_NAME\x10\x0c\x12\x18\n\x14TRANSPOSED_NO_ISSUES\x10\r\x12\x1a\n\x16TRANSPOSED_WITH_ISSUES\x10\x0e\x12$\n TRANSPOSED_WITH_ISSUES_UNCHANGED\x10\x0f\"\x85\x01\n\"CellRefImportWarningSetPairArchive\x12,\n\x08\x63\x65ll_ref\x18\x01 \x02(\x0b\x32\x1a.TSCE.CellReferenceArchive\x12\x31\n\x0bwarning_set\x18\x03 \x01(\x0b\x32\x1c.TST.ImportWarningSetArchive\"m\n ImportWarningSetByCellRefArchive\x12I\n\x18\x63\x65llref_warning_set_pair\x18\x01 \x03(\x0b\x32\'.TST.CellRefImportWarningSetPairArchive\"\xae\x06\n\rTableDataList\x12-\n\x08listType\x18\x01 \x02(\x0e\x32\x1b.TST.TableDataList.ListType\x12\x12\n\nnextListID\x18\x02 \x02(\r\x12-\n\x07\x65ntries\x18\x03 \x03(\x0b\x32\x1c.TST.TableDataList.ListEntry\x12 \n\x08segments\x18\x04 \x03(\x0b\x32\x0e.TSP.Reference\x1a\x96\x03\n\tListEntry\x12\x0b\n\x03key\x18\x01 \x02(\r\x12\x10\n\x08refcount\x18\x02 \x02(\r\x12\x0e\n\x06string\x18\x03 \x01(\t\x12!\n\treference\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\x12%\n\x07\x66ormula\x18\x05 \x01(\x0b\x32\x14.TSCE.FormulaArchive\x12(\n\x06\x66ormat\x18\x06 \x01(\x0b\x32\x18.TSK.FormatStructArchive\x12/\n\rcustom_format\x18\x08 \x01(\x0b\x32\x18.TSK.CustomFormatArchive\x12)\n\x11rich_text_payload\x18\t \x01(\x0b\x32\x0e.TSP.Reference\x12\'\n\x0f\x63omment_storage\x18\n \x01(\x0b\x32\x0e.TSP.Reference\x12\x38\n\x12import_warning_set\x18\x0b \x01(\x0b\x32\x1c.TST.ImportWarningSetArchive\x12\'\n\tcell_spec\x18\x0c \x01(\x0b\x32\x14.TST.CellSpecArchive\"\xef\x01\n\x08ListType\x12\n\n\x06STRING\x10\x01\x12\n\n\x06\x46ORMAT\x10\x02\x12\x0b\n\x07\x46ORMULA\x10\x03\x12\t\n\x05STYLE\x10\x04\x12\x11\n\rFORMULA_ERROR\x10\x05\x12\x11\n\rCUSTOM_FORMAT\x10\x06\x12\x1f\n\x1bMULTIPLE_CHOICE_LIST_FORMAT\x10\x07\x12\x15\n\x11RICH_TEXT_PAYLOAD\x10\x08\x12\x15\n\x11\x43ONDITIONAL_STYLE\x10\t\x12\x13\n\x0f\x43OMMENT_STORAGE\x10\n\x12\x12\n\x0eIMPORT_WARNING\x10\x0b\x12\x15\n\x11\x43ONTROL_CELL_SPEC\x10\x0c\"\x94\x01\n\x14TableDataListSegment\x12.\n\tlist_type\x18\x01 \x02(\x0e\x32\x1b.TST.TableDataList.ListType\x12\x1d\n\tkey_range\x18\x02 \x02(\x0b\x32\n.TSP.Range\x12-\n\x07\x65ntries\x18\x03 \x03(\x0b\x32\x1c.TST.TableDataList.ListEntry\"W\n\x0bTableRBTree\x12$\n\x05nodes\x18\x01 \x03(\x0b\x32\x15.TST.TableRBTree.Node\x1a\"\n\x04Node\x12\x0b\n\x03key\x18\x01 \x02(\r\x12\r\n\x05value\x18\x02 \x02(\r\"\xff\x01\n\x13HeaderStorageBucket\x12\x1a\n\x12\x62ucketHashFunction\x18\x01 \x02(\r\x12\x30\n\x07headers\x18\x02 \x03(\x0b\x32\x1f.TST.HeaderStorageBucket.Header\x1a\x99\x01\n\x06Header\x12\r\n\x05index\x18\x01 \x02(\r\x12\x0c\n\x04size\x18\x02 \x02(\x02\x12\x13\n\x0bhidingState\x18\x03 \x02(\r\x12\x15\n\rnumberOfCells\x18\x04 \x02(\r\x12\"\n\ncell_style\x18\x05 \x01(\x0b\x32\x0e.TSP.Reference\x12\"\n\ntext_style\x18\x06 \x01(\x0b\x32\x0e.TSP.Reference\"L\n\rHeaderStorage\x12\x1a\n\x12\x62ucketHashFunction\x18\x01 \x02(\r\x12\x1f\n\x07\x62uckets\x18\x02 \x03(\x0b\x32\x0e.TSP.Reference\"\x80\x07\n\tDataStore\x12&\n\nrowHeaders\x18\x01 \x02(\x0b\x32\x12.TST.HeaderStorage\x12%\n\rcolumnHeaders\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12\x1f\n\x05tiles\x18\x03 \x02(\x0b\x32\x10.TST.TileStorage\x12#\n\x0bstringTable\x18\x04 \x02(\x0b\x32\x0e.TSP.Reference\x12\"\n\nstyleTable\x18\x05 \x02(\x0b\x32\x0e.TSP.Reference\x12%\n\rformula_table\x18\x06 \x02(\x0b\x32\x0e.TSP.Reference\x12)\n\x11\x66ormulaErrorTable\x18\x0c \x01(\x0b\x32\x0e.TSP.Reference\x12,\n\x14\x66ormat_table_pre_bnc\x18\x0b \x02(\x0b\x32\x0e.TSP.Reference\x12\x35\n\x1dmultipleChoiceListFormatTable\x18\x10 \x01(\x0b\x32\x0e.TSP.Reference\x12(\n\x10merge_region_map\x18\r \x01(\x0b\x32\x0e.TSP.Reference\x12)\n\x11\x63ustomFormatTable\x18\x0f \x01(\x0b\x32\x0e.TSP.Reference\x12\x16\n\x0enextRowStripID\x18\x07 \x02(\r\x12\x19\n\x11nextColumnStripID\x18\x08 \x02(\r\x12%\n\x0browTileTree\x18\t \x02(\x0b\x32\x10.TST.TableRBTree\x12(\n\x0e\x63olumnTileTree\x18\n \x02(\x0b\x32\x10.TST.TableRBTree\x12\x1f\n\x17storage_version_pre_bnc\x18\x0e \x01(\r\x12\'\n\x0frich_text_table\x18\x11 \x01(\x0b\x32\x0e.TSP.Reference\x12-\n\x15\x63onditionalstyletable\x18\x12 \x01(\x0b\x32\x0e.TSP.Reference\x12+\n\x13\x63ommentStorageTable\x18\x13 \x01(\x0b\x32\x0e.TSP.Reference\x12-\n\x15importWarningSetTable\x18\x14 \x01(\x0b\x32\x0e.TSP.Reference\x12/\n\x17\x63ontrol_cell_spec_table\x18\x15 \x01(\x0b\x32\x0e.TSP.Reference\x12$\n\x0c\x66ormat_table\x18\x16 \x01(\x0b\x32\x0e.TSP.Reference\"\xff\x03\n\x10TableInfoArchive\x12#\n\x05super\x18\x01 \x02(\x0b\x32\x14.TSD.DrawableArchive\x12\"\n\ntableModel\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12)\n\rediting_state\x18\x03 \x01(\x0b\x32\x0e.TSP.ReferenceB\x02\x18\x01\x12%\n\rsummary_model\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\x12&\n\x0e\x63\x61tegory_order\x18\x05 \x01(\x0b\x32\x0e.TSP.Reference\x12,\n\x14view_column_row_uids\x18\x06 \x01(\x0b\x32\x0e.TSP.Reference\x12 \n\rgroup_by_uuid\x18\x07 \x01(\x0b\x32\t.TSP.UUID\x12%\n\x12hidden_states_uuid\x18\x08 \x01(\x0b\x32\t.TSP.UUID\x12(\n\x1c\x66ormula_coord_space_in_pre40\x18\t \x01(\rB\x02\x18\x01\x12\x1b\n\x13\x66ormula_coord_space\x18\n \x01(\r\x12\x39\n\x17pasteboard_coord_mapper\x18\r \x01(\x0b\x32\x18.TSCE.CoordMapperArchive\x12/\n\rmaster_layout\x18\x0e \x01(\x0b\x32\x18.TST.MasterLayoutArchive\"^\n\x13\x43\x61tegoryInfoArchive\x12#\n\x05super\x18\x01 \x02(\x0b\x32\x14.TSD.DrawableArchive\x12\"\n\ntableModel\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\"[\n\x12WPTableInfoArchive\x12$\n\x05super\x18\x01 \x02(\x0b\x32\x15.TST.TableInfoArchive\x12\x1f\n\x07storage\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\"\xe3\x0b\n\x18TableStyleNetworkArchive\x12#\n\x0btable_style\x18\t \x02(\x0b\x32\x0e.TSP.Reference\x12\'\n\x0f\x62ody_text_style\x18\x01 \x02(\x0b\x32\x0e.TSP.Reference\x12-\n\x15header_row_text_style\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12\x30\n\x18header_column_text_style\x18\x03 \x02(\x0b\x32\x0e.TSP.Reference\x12-\n\x15\x66ooter_row_text_style\x18\x04 \x02(\x0b\x32\x0e.TSP.Reference\x12\x33\n\x1b\x63\x61tegory_level_1_text_style\x18\r \x01(\x0b\x32\x0e.TSP.Reference\x12\x33\n\x1b\x63\x61tegory_level_2_text_style\x18\x0e \x01(\x0b\x32\x0e.TSP.Reference\x12\x33\n\x1b\x63\x61tegory_level_3_text_style\x18\x0f \x01(\x0b\x32\x0e.TSP.Reference\x12\x33\n\x1b\x63\x61tegory_level_4_text_style\x18\x10 \x01(\x0b\x32\x0e.TSP.Reference\x12\x33\n\x1b\x63\x61tegory_level_5_text_style\x18\x11 \x01(\x0b\x32\x0e.TSP.Reference\x12\x30\n\x18label_level_1_text_style\x18\x17 \x01(\x0b\x32\x0e.TSP.Reference\x12\x30\n\x18label_level_2_text_style\x18\x18 \x01(\x0b\x32\x0e.TSP.Reference\x12\x30\n\x18label_level_3_text_style\x18\x19 \x01(\x0b\x32\x0e.TSP.Reference\x12\x30\n\x18label_level_4_text_style\x18\x1a \x01(\x0b\x32\x0e.TSP.Reference\x12\x30\n\x18label_level_5_text_style\x18\x1b \x01(\x0b\x32\x0e.TSP.Reference\x12\'\n\x0f\x62ody_cell_style\x18\x05 \x02(\x0b\x32\x0e.TSP.Reference\x12(\n\x10header_row_style\x18\x06 \x02(\x0b\x32\x0e.TSP.Reference\x12+\n\x13header_column_style\x18\x07 \x02(\x0b\x32\x0e.TSP.Reference\x12(\n\x10\x66ooter_row_style\x18\x08 \x02(\x0b\x32\x0e.TSP.Reference\x12.\n\x16\x63\x61tegory_level_1_style\x18\x12 \x01(\x0b\x32\x0e.TSP.Reference\x12.\n\x16\x63\x61tegory_level_2_style\x18\x13 \x01(\x0b\x32\x0e.TSP.Reference\x12.\n\x16\x63\x61tegory_level_3_style\x18\x14 \x01(\x0b\x32\x0e.TSP.Reference\x12.\n\x16\x63\x61tegory_level_4_style\x18\x15 \x01(\x0b\x32\x0e.TSP.Reference\x12.\n\x16\x63\x61tegory_level_5_style\x18\x16 \x01(\x0b\x32\x0e.TSP.Reference\x12+\n\x13label_level_1_style\x18\x1c \x01(\x0b\x32\x0e.TSP.Reference\x12+\n\x13label_level_2_style\x18\x1d \x01(\x0b\x32\x0e.TSP.Reference\x12+\n\x13label_level_3_style\x18\x1e \x01(\x0b\x32\x0e.TSP.Reference\x12+\n\x13label_level_4_style\x18\x1f \x01(\x0b\x32\x0e.TSP.Reference\x12+\n\x13label_level_5_style\x18  \x01(\x0b\x32\x0e.TSP.Reference\x12(\n\x10table_name_style\x18\n \x01(\x0b\x32\x0e.TSP.Reference\x12.\n\x16table_name_shape_style\x18\x0b \x01(\x0b\x32\x0e.TSP.Reference\x12\x11\n\tpreset_id\x18\x0c \x01(\r\"\xcb\x02\n\x15TableSortOrderArchive\x12\x31\n\x04type\x18\x01 \x02(\x0e\x32#.TST.TableSortOrderArchive.SortType\x12\x39\n\x05rules\x18\x02 \x03(\x0b\x32*.TST.TableSortOrderArchive.SortRuleArchive\x1a\x96\x01\n\x0fSortRuleArchive\x12\x0e\n\x06\x63olumn\x18\x01 \x02(\r\x12G\n\tdirection\x18\x02 \x02(\x0e\x32\x34.TST.TableSortOrderArchive.SortRuleArchive.Direction\"*\n\tDirection\x12\r\n\tascending\x10\x00\x12\x0e\n\ndescending\x10\x01\"+\n\x08SortType\x12\x10\n\x0c\x65ntire_table\x10\x00\x12\r\n\trow_range\x10\x01\"\xe6\x02\n\x18TableSortOrderUIDArchive\x12\x34\n\x04type\x18\x01 \x02(\x0e\x32&.TST.TableSortOrderUIDArchive.SortType\x12<\n\x05rules\x18\x02 \x03(\x0b\x32-.TST.TableSortOrderUIDArchive.SortRuleArchive\x1a\xa8\x01\n\x0fSortRuleArchive\x12\x1d\n\ncolumn_uid\x18\x01 \x02(\x0b\x32\t.TSP.UUID\x12J\n\tdirection\x18\x02 \x02(\x0e\x32\x37.TST.TableSortOrderUIDArchive.SortRuleArchive.Direction\"*\n\tDirection\x12\r\n\tascending\x10\x00\x12\x0e\n\ndescending\x10\x01\"+\n\x08SortType\x12\x10\n\x0c\x65ntire_table\x10\x00\x12\r\n\trow_range\x10\x01\"L\n\x1fSortRuleReferenceTrackerArchive\x12)\n\x11reference_tracker\x18\x01 \x02(\x0b\x32\x0e.TSP.Reference\"1\n\nCellRegion\x12#\n\x0b\x63\x65ll_ranges\x18\x01 \x03(\x0b\x32\x0e.TST.CellRange\"E\n\x14\x43\x65llUIDRegionArchive\x12-\n\x0f\x63\x65ll_uid_ranges\x18\x01 \x03(\x0b\x32\x14.TSP.UUIDRectArchive\"\xa7\x02\n\x1aStructuredTextImportRecord\x12:\n\x0fimport_settings\x18\x01 \x02(\x0b\x32!.TSK.StructuredTextImportSettings\x12\x15\n\rimport_source\x18\x02 \x01(\t\x12\x13\n\x0bimport_date\x18\x03 \x01(\x01\x12\x13\n\x0bsource_data\x18\x04 \x01(\x0c\x12\x17\n\x0fsource_encoding\x18\x05 \x01(\x04\x12\x12\n\nconfidence\x18\x06 \x01(\x02\x12(\n\x0fimported_region\x18\x07 \x01(\x0b\x32\x0f.TST.CellRegion\x12\x18\n\x10source_row_count\x18\x08 \x01(\x04\x12\x1b\n\x13source_column_count\x18\t \x01(\x04\"\x8f\x19\n\x11TableModelArchive\x12\x10\n\x08table_id\x18\x01 \x02(\t\x12\x15\n\rfrom_table_id\x18+ \x01(\t\x12\x0f\n\x07was_cut\x18\x32 \x01(\x08\x12#\n\x0btable_style\x18\x03 \x02(\x0b\x32\x0e.TSP.Reference\x12\'\n\x0f\x62ody_text_style\x18\x18 \x02(\x0b\x32\x0e.TSP.Reference\x12-\n\x15header_row_text_style\x18\x19 \x02(\x0b\x32\x0e.TSP.Reference\x12\x30\n\x18header_column_text_style\x18\x1a \x02(\x0b\x32\x0e.TSP.Reference\x12-\n\x15\x66ooter_row_text_style\x18\x1b \x02(\x0b\x32\x0e.TSP.Reference\x12\'\n\x0f\x62ody_cell_style\x18\x12 \x02(\x0b\x32\x0e.TSP.Reference\x12(\n\x10header_row_style\x18\x13 \x02(\x0b\x32\x0e.TSP.Reference\x12+\n\x13header_column_style\x18\x14 \x02(\x0b\x32\x0e.TSP.Reference\x12(\n\x10\x66ooter_row_style\x18\x15 \x02(\x0b\x32\x0e.TSP.Reference\x12(\n\x10table_name_style\x18\x1e \x01(\x0b\x32\x0e.TSP.Reference\x12.\n\x16table_name_shape_style\x18$ \x01(\x0b\x32\x0e.TSP.Reference\x12*\n\x12table_style_preset\x18\x30 \x01(\x0b\x32\x0e.TSP.Reference\x12\x14\n\x0cpreset_index\x18\x1c \x01(\r\x12\'\n\x0f\x62\x61se_data_store\x18\x04 \x02(\x0b\x32\x0e.TST.DataStore\x12 \n\x08provider\x18\x05 \x01(\x0b\x32\x0e.TSP.Reference\x12\x16\n\x0enumber_of_rows\x18\x06 \x02(\r\x12\x19\n\x11number_of_columns\x18\x07 \x02(\r\x12\x12\n\ntable_name\x18\x08 \x02(\t\x12\x1a\n\x12table_name_enabled\x18\x16 \x01(\x08\x12\x19\n\x11table_name_height\x18! \x01(\x01\x12!\n\x19table_name_border_enabled\x18% \x01(\x08\x12\x1d\n\x15number_of_header_rows\x18\t \x01(\r\x12 \n\x18number_of_header_columns\x18\n \x01(\r\x12\x1d\n\x15number_of_footer_rows\x18\x0b \x01(\r\x12\x1a\n\x12header_rows_frozen\x18\x0c \x01(\x08\x12\x1d\n\x15header_columns_frozen\x18\r \x01(\x08\x12\x1d\n\x15number_of_hidden_rows\x18\x0e \x01(\r\x12 \n\x18number_of_hidden_columns\x18\x0f \x01(\r\x12\"\n\x1anumber_of_user_hidden_rows\x18) \x01(\r\x12%\n\x1dnumber_of_user_hidden_columns\x18* \x01(\r\x12\x1f\n\x17number_of_filtered_rows\x18( \x01(\r\x12\x1a\n\x12\x64\x65\x66\x61ult_row_height\x18\x10 \x02(\x01\x12\x1c\n\x14\x64\x65\x66\x61ult_column_width\x18\x11 \x02(\x01\x12&\n\rorigin_offset\x18\x17 \x01(\x0b\x32\x0b.TST.CellIDB\x02\x18\x01\x12%\n\x1drepeating_header_rows_enabled\x18\x1d \x01(\x08\x12(\n repeating_header_columns_enabled\x18  \x01(\x08\x12\x1e\n\x16style_apply_clears_all\x18\x1f \x01(\x08\x12>\n&hidden_state_formula_owner_for_columns\x18\" \x01(\x0b\x32\x0e.TSP.Reference\x12;\n#hidden_state_formula_owner_for_rows\x18# \x01(\x0b\x32\x0e.TSP.Reference\x12\"\n\nfilter_set\x18& \x01(\x0b\x32\x0e.TSP.Reference\x12>\n\"conditional_style_formula_owner_id\x18\' \x01(\x0b\x32\x12.TSP.CFUUIDArchive\x12.\n\nsort_order\x18, \x01(\x0b\x32\x1a.TST.TableSortOrderArchive\x12I\n\x1bsort_rule_reference_tracker\x18- \x01(\x0b\x32$.TST.SortRuleReferenceTrackerArchive\x12,\n\x14\x62\x61se_column_row_uids\x18. \x01(\x0b\x32\x0e.TSP.Reference\x12+\n\x0bmerge_owner\x18/ \x01(\x0b\x32\x16.TST.MergeOwnerArchive\x12&\n\x0estroke_sidecar\x18\x31 \x01(\x0b\x32\x0e.TSP.Reference\x12%\n\x1dpreset_needs_strong_ownership\x18\x33 \x01(\x08\x12;\n\x12text_import_record\x18\x34 \x01(\x0b\x32\x1f.TST.StructuredTextImportRecord\x12.\n\x16\x63\x61tegory_level_1_style\x18< \x01(\x0b\x32\x0e.TSP.Reference\x12.\n\x16\x63\x61tegory_level_2_style\x18= \x01(\x0b\x32\x0e.TSP.Reference\x12.\n\x16\x63\x61tegory_level_3_style\x18> \x01(\x0b\x32\x0e.TSP.Reference\x12.\n\x16\x63\x61tegory_level_4_style\x18? \x01(\x0b\x32\x0e.TSP.Reference\x12.\n\x16\x63\x61tegory_level_5_style\x18@ \x01(\x0b\x32\x0e.TSP.Reference\x12+\n\x13label_level_1_style\x18G \x01(\x0b\x32\x0e.TSP.Reference\x12+\n\x13label_level_2_style\x18H \x01(\x0b\x32\x0e.TSP.Reference\x12+\n\x13label_level_3_style\x18I \x01(\x0b\x32\x0e.TSP.Reference\x12+\n\x13label_level_4_style\x18J \x01(\x0b\x32\x0e.TSP.Reference\x12+\n\x13label_level_5_style\x18K \x01(\x0b\x32\x0e.TSP.Reference\x12\x33\n\x1b\x63\x61tegory_level_1_text_style\x18\x41 \x01(\x0b\x32\x0e.TSP.Reference\x12\x33\n\x1b\x63\x61tegory_level_2_text_style\x18\x42 \x01(\x0b\x32\x0e.TSP.Reference\x12\x33\n\x1b\x63\x61tegory_level_3_text_style\x18\x43 \x01(\x0b\x32\x0e.TSP.Reference\x12\x33\n\x1b\x63\x61tegory_level_4_text_style\x18\x44 \x01(\x0b\x32\x0e.TSP.Reference\x12\x33\n\x1b\x63\x61tegory_level_5_text_style\x18\x45 \x01(\x0b\x32\x0e.TSP.Reference\x12\x30\n\x18label_level_1_text_style\x18L \x01(\x0b\x32\x0e.TSP.Reference\x12\x30\n\x18label_level_2_text_style\x18M \x01(\x0b\x32\x0e.TSP.Reference\x12\x30\n\x18label_level_3_text_style\x18N \x01(\x0b\x32\x0e.TSP.Reference\x12\x30\n\x18label_level_4_text_style\x18O \x01(\x0b\x32\x0e.TSP.Reference\x12\x30\n\x18label_level_5_text_style\x18P \x01(\x0b\x32\x0e.TSP.Reference\x12:\n\x13hidden_states_owner\x18\x46 \x01(\x0b\x32\x1d.TST.HiddenStatesOwnerArchive\x12\x31\n\x0e\x63\x61tegory_owner\x18Q \x01(\x0b\x32\x19.TST.CategoryOwnerArchive\x12\x42\n\x17pencil_annotation_owner\x18R \x01(\x0b\x32!.TST.PencilAnnotationOwnerArchive\x12\x19\n\x11\x66rom_group_by_uid\x18S \x01(\t\x12\x30\n\rhaunted_owner\x18T \x01(\x0b\x32\x19.TSCE.HauntedOwnerArchive\"\xc8\x07\n\x13SummaryModelArchive\x12\"\n\ntable_info\x18\x01 \x02(\x0b\x32\x0e.TSP.Reference\x12\"\n\ndata_store\x18\x02 \x01(\x0b\x32\x0e.TST.DataStore\x12\'\n\x0f\x63olumn_row_uids\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12/\n\x1c\x61ggregate_formula_owner_uuid\x18\x04 \x01(\x0b\x32\t.TSP.UUID\x12+\n\x13summary_cell_vendor\x18\x05 \x01(\x0b\x32\x0e.TSP.Reference\x12\x1d\n\x15\x63\x61tegory_column_width\x18\n \x01(\x01\x12&\n\x1asummary_row_level_1_height\x18\x0b \x01(\x01\x42\x02\x18\x01\x12&\n\x1asummary_row_level_2_height\x18\x0c \x01(\x01\x42\x02\x18\x01\x12&\n\x1asummary_row_level_3_height\x18\r \x01(\x01\x42\x02\x18\x01\x12&\n\x1asummary_row_level_4_height\x18\x0e \x01(\x01\x42\x02\x18\x01\x12&\n\x1asummary_row_level_5_height\x18\x0f \x01(\x01\x42\x02\x18\x01\x12,\n summary_label_row_level_1_height\x18\x10 \x01(\x01\x42\x02\x18\x01\x12,\n summary_label_row_level_2_height\x18\x11 \x01(\x01\x42\x02\x18\x01\x12,\n summary_label_row_level_3_height\x18\x12 \x01(\x01\x42\x02\x18\x01\x12,\n summary_label_row_level_4_height\x18\x13 \x01(\x01\x42\x02\x18\x01\x12,\n summary_label_row_level_5_height\x18\x14 \x01(\x01\x42\x02\x18\x01\x12\"\n\x16label_row_visibility_1\x18\x15 \x01(\rB\x02\x18\x01\x12\"\n\x16label_row_visibility_2\x18\x16 \x01(\rB\x02\x18\x01\x12\"\n\x16label_row_visibility_3\x18\x17 \x01(\rB\x02\x18\x01\x12\"\n\x16label_row_visibility_4\x18\x18 \x01(\rB\x02\x18\x01\x12\"\n\x16label_row_visibility_5\x18\x19 \x01(\rB\x02\x18\x01\x12\x1f\n\x17summary_row_height_list\x18\x1a \x03(\x01\x12\x1d\n\x15label_row_height_list\x18\x1b \x03(\x01\x12!\n\x19label_row_visibility_list\x18\x1c \x03(\r\"\xac\x01\n%SummaryModelGroupByChangeStateArchive\x12 \n\x08\x63\x65ll_map\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\x12\x1f\n\x17summary_row_height_list\x18\x02 \x03(\x01\x12\x1d\n\x15label_row_height_list\x18\x03 \x03(\x01\x12!\n\x19label_row_visibility_list\x18\x04 \x03(\r\"\xd5\x01\n\x16\x43olumnRowUIDMapArchive\x12%\n\x12sorted_column_uids\x18\x01 \x03(\x0b\x32\t.TSP.UUID\x12\x1c\n\x14\x63olumn_index_for_uid\x18\x02 \x03(\r\x12\x1c\n\x14\x63olumn_uid_for_index\x18\x03 \x03(\r\x12\"\n\x0fsorted_row_uids\x18\x04 \x03(\x0b\x32\t.TSP.UUID\x12\x19\n\x11row_index_for_uid\x18\x05 \x03(\r\x12\x19\n\x11row_uid_for_index\x18\x06 \x03(\r\"\xd4\x01\n\x12StrokeLayerArchive\x12\x18\n\x10row_column_index\x18\x01 \x01(\r\x12=\n\x0bstroke_runs\x18\x02 \x03(\x0b\x32(.TST.StrokeLayerArchive.StrokeRunArchive\x1a\x65\n\x10StrokeRunArchive\x12\x0e\n\x06origin\x18\x01 \x01(\x05\x12\x0e\n\x06length\x18\x02 \x01(\r\x12\"\n\x06stroke\x18\x03 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\r\n\x05order\x18\x04 \x01(\r\"\x9a\x02\n\x14StrokeSidecarArchive\x12\x11\n\tmax_order\x18\x01 \x01(\r\x12\x14\n\x0c\x63olumn_count\x18\x02 \x01(\r\x12\x11\n\trow_count\x18\x03 \x01(\r\x12\x31\n\x19left_column_stroke_layers\x18\x04 \x03(\x0b\x32\x0e.TSP.Reference\x12\x32\n\x1aright_column_stroke_layers\x18\x05 \x03(\x0b\x32\x0e.TSP.Reference\x12-\n\x15top_row_stroke_layers\x18\x06 \x03(\x0b\x32\x0e.TSP.Reference\x12\x30\n\x18\x62ottom_row_stroke_layers\x18\x07 \x03(\x0b\x32\x0e.TSP.Reference\"\x18\n\x16\x44urationWrapperArchive\"\xe7\x08\n\x04\x43\x65ll\x12%\n\tvalueType\x18\x02 \x02(\x0e\x32\x12.TST.CellValueType\x12\"\n\ncell_style\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12\"\n\ntext_style\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\x12\x13\n\x0bnumberValue\x18\x05 \x01(\x01\x12\x13\n\x0bstringValue\x18\x06 \x01(\t\x12\x11\n\tboolValue\x18\x07 \x01(\x08\x12\x30\n\x0e\x63urrent_format\x18\t \x01(\x0b\x32\x18.TSK.FormatStructArchive\x12$\n\x0c\x66ormulaError\x18\n \x01(\x0b\x32\x0e.TSP.Reference\x12/\n\rnumber_format\x18\x0b \x01(\x0b\x32\x18.TSK.FormatStructArchive\x12\x31\n\x0f\x63urrency_format\x18\x0c \x01(\x0b\x32\x18.TSK.FormatStructArchive\x12\x31\n\x0f\x64uration_format\x18\r \x01(\x0b\x32\x18.TSK.FormatStructArchive\x12-\n\x0b\x64\x61te_format\x18\x0e \x01(\x0b\x32\x18.TSK.FormatStructArchive\x12/\n\rcustom_format\x18\x10 \x01(\x0b\x32\x18.TSK.FormatStructArchive\x12-\n\x0b\x62\x61se_format\x18\x11 \x01(\x0b\x32\x18.TSK.FormatStructArchive\x12\x1d\n\x15\x65xplicit_format_flags\x18\x13 \x01(\r\x12 \n\x08richText\x18\x14 \x01(\x0b\x32\x0e.TSP.Reference\x12)\n\x11\x63onditional_style\x18\x15 \x01(\x0b\x32\x0e.TSP.Reference\x12\'\n\x0f\x63omment_storage\x18\x17 \x01(\x0b\x32\x0e.TSP.Reference\x12&\n\x1e\x63onditional_style_applied_rule\x18\x18 \x01(\r\x12\x38\n\x12import_warning_set\x18\x19 \x01(\x0b\x32\x1c.TST.ImportWarningSetArchive\x12\x36\n\x14\x63ustom_format_object\x18\x1a \x01(\x0b\x32\x18.TSK.CustomFormatArchive\x12+\n\x0b\x63\x65ll_border\x18\x1b \x01(\x0b\x32\x16.TST.CellBorderArchive\x12\'\n\tcell_spec\x18\x1c \x01(\x0b\x32\x14.TST.CellSpecArchive\x12\x18\n\x10\x63\x65ll_format_kind\x18\x1d \x01(\r\x12-\n\x0btext_format\x18\x1e \x01(\x0b\x32\x18.TSK.FormatStructArchive\x12\x30\n\x0e\x62oolean_format\x18\x1f \x01(\x0b\x32\x18.TSK.FormatStructArchive\x12\x19\n\x11\x64\x65\x63imal_value_low\x18  \x01(\x04\x12\x1a\n\x12\x64\x65\x63imal_value_high\x18! \x01(\x04\";\n\x15MergeRegionMapArchive\x12\"\n\ncell_range\x18\x01 \x03(\x0b\x32\x0e.TST.CellRange\"\xa8\x03\n\x0e\x43\x65llMapArchive\x12\"\n\ncell_tiles\x18\x02 \x03(\x0b\x32\x0e.TSP.Reference\x12\x11\n\tuid_based\x18\x03 \x02(\x08\x12\x36\n\x11\x65xpanded_cell_ids\x18\x0e \x03(\x0b\x32\x1b.TSCE.CellCoordinateArchive\x12.\n\rcell_uid_list\x18\x05 \x01(\x0b\x32\x17.TST.CellUIDListArchive\x12.\n\x10merge_uid_ranges\x18\x07 \x03(\x0b\x32\x14.TSP.UUIDRectArchive\x12\x30\n\x12unmerge_uid_ranges\x18\t \x03(\x0b\x32\x14.TSP.UUIDRectArchive\x12\x31\n\rmerge_actions\x18\r \x03(\x0b\x32\x1a.TST.MergeOperationArchive\x12*\n\x1cmay_modify_formulas_in_cells\x18\n \x01(\x08:\x04true\x12\x36\n(may_modify_values_referenced_by_formulas\x18\x0b \x01(\x08:\x04true\"\x8f\x01\n\x0f\x43\x65llListArchive\x12\x30\n\x05\x63\x65lls\x18\x01 \x03(\x0b\x32!.TST.CellListArchive.OptionalCell\x12!\n\x19trailing_empty_cell_count\x18\x02 \x01(\r\x1a\'\n\x0cOptionalCell\x12\x17\n\x04\x63\x65ll\x18\x01 \x01(\x0b\x32\t.TST.Cell\"\xe8\x01\n\x18\x43oncurrentCellMapArchive\x12\"\n\ncell_lists\x18\x01 \x03(\x0b\x32\x0e.TSP.Reference\x12\x11\n\tuid_based\x18\x02 \x02(\x08\x12\x31\n\rmerge_actions\x18\x03 \x03(\x0b\x32\x1a.TST.MergeOperationArchive\x12*\n\x1cmay_modify_formulas_in_cells\x18\x04 \x01(\x08:\x04true\x12\x36\n(may_modify_values_referenced_by_formulas\x18\x05 \x01(\x08:\x04true\"\xd2\x01\n\x19\x43oncurrentCellListArchive\x12:\n\x05\x63\x65lls\x18\x01 \x03(\x0b\x32+.TST.ConcurrentCellListArchive.OptionalCell\x12,\n\x0e\x63\x65ll_uid_range\x18\x02 \x01(\x0b\x32\x14.TSP.UUIDRectArchive\x12\"\n\ncell_range\x18\x03 \x01(\x0b\x32\x0e.TST.CellRange\x1a\'\n\x0cOptionalCell\x12\x17\n\x04\x63\x65ll\x18\x01 \x01(\x0b\x32\t.TST.Cell\"\xd3\x05\n\x19\x43\x65llFormatAndValueArchive\x12%\n\tvalueType\x18\x01 \x02(\x0e\x32\x12.TST.CellValueType\x12\x13\n\x0bnumberValue\x18\x02 \x01(\x01\x12\x13\n\x0bstringValue\x18\x03 \x01(\t\x12\x11\n\tboolValue\x18\x04 \x01(\x08\x12\'\n\x0frichTextStorage\x18\x05 \x01(\x0b\x32\x0e.TSP.Reference\x12\x1d\n\x15use_all_spare_formats\x18\x06 \x02(\x08\x12\x16\n\x0e\x65xplicit_flags\x18\x07 \x02(\r\x12\x18\n\x10\x63\x65ll_format_kind\x18\x08 \x02(\r\x12/\n\rnumber_format\x18\n \x01(\x0b\x32\x18.TSK.FormatStructArchive\x12\x31\n\x0f\x63urrency_format\x18\x0b \x01(\x0b\x32\x18.TSK.FormatStructArchive\x12-\n\x0b\x64\x61te_format\x18\x0c \x01(\x0b\x32\x18.TSK.FormatStructArchive\x12\x31\n\x0f\x64uration_format\x18\r \x01(\x0b\x32\x18.TSK.FormatStructArchive\x12-\n\x0btext_format\x18\x0e \x01(\x0b\x32\x18.TSK.FormatStructArchive\x12\x30\n\x0e\x62oolean_format\x18\x0f \x01(\x0b\x32\x18.TSK.FormatStructArchive\x12\x17\n\x0f\x66ormatted_value\x18\x10 \x01(\t\x12\x31\n\x19\x66ormatted_rich_text_value\x18\x11 \x01(\x0b\x32\x0e.TSP.Reference\x12\x1f\n\x17\x61pply_spare_format_only\x18\x12 \x02(\x08\x12\x19\n\x11spare_format_type\x18\x13 \x02(\x08\x12\x13\n\x0b\x64\x65\x63imal_low\x18\x14 \x01(\x04\x12\x14\n\x0c\x64\x65\x63imal_high\x18\x15 \x01(\x04\"\xb2\x02\n\x0f\x43\x65llSpecArchive\x12\x18\n\x10interaction_type\x18\x01 \x02(\r\x12%\n\x07\x66ormula\x18\x02 \x01(\x0b\x32\x14.TSCE.FormulaArchive\x12\x19\n\x11range_control_min\x18\x03 \x01(\x01\x12\x19\n\x11range_control_max\x18\x04 \x01(\x01\x12\x19\n\x11range_control_inc\x18\x05 \x01(\x01\x12\x33\n\x1b\x63hooser_control_popup_model\x18\x06 \x01(\x0b\x32\x0e.TSP.Reference\x12%\n\x1d\x63hooser_control_start_w_first\x18\x07 \x01(\x08\x12\x31\n%category_summary_should_display_label\x18\x08 \x01(\x08\x42\x02\x18\x01\"G\n\x1c\x43ommentStorageWrapperArchive\x12\'\n\x0f\x63omment_storage\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\"\x8d\x01\n\x0f\x43\x65llDiffArchive\x12;\n\x13property_map_to_set\x18\x01 \x02(\x0b\x32\x1e.TSS.CommandPropertyMapArchive\x12=\n\x15property_map_to_reset\x18\x02 \x02(\x0b\x32\x1e.TSS.CommandPropertyMapArchive\"5\n\rCellDiffArray\x12$\n\x0blarge_array\x18\x01 \x01(\x0b\x32\x0f.TSP.LargeArray\"s\n\x14\x43\x65llDiffArraySegment\x12\x33\n\x13large_array_segment\x18\x01 \x01(\x0b\x32\x16.TSP.LargeArraySegment\x12&\n\x08\x65lements\x18\x02 \x03(\x0b\x32\x14.TST.CellDiffArchive\"\xb4\x01\n\x12\x43\x65llDiffMapArchive\x12\x11\n\tuid_based\x18\x01 \x02(\x08\x12\x36\n\x11\x65xpanded_cell_ids\x18\x02 \x03(\x0b\x32\x1b.TSCE.CellCoordinateArchive\x12*\n\tcell_uids\x18\x03 \x02(\x0b\x32\x17.TST.CellUIDListArchive\x12\'\n\x0f\x63\x65ll_diff_array\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\"\x8a\x02\n\x15\x44oubleStyleMapArchive\x12\x10\n\x08\x63\x61pacity\x18\x01 \x02(\r\x12\r\n\x05\x63ount\x18\x02 \x02(\r\x12M\n\x0e\x63\x65ll_map_entry\x18\x03 \x03(\x0b\x32\x35.TST.DoubleStyleMapArchive.DoubleStyleMapEntryArchive\x1a\x80\x01\n\x1a\x44oubleStyleMapEntryArchive\x12\x1c\n\x07\x63\x65ll_id\x18\x01 \x02(\x0b\x32\x0b.TST.CellID\x12!\n\told_style\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12!\n\tnew_style\x18\x03 \x02(\x0b\x32\x0e.TSP.Reference\"\xef\x01\n\x14StyleTableMapArchive\x12\x10\n\x08\x63\x61pacity\x18\x01 \x02(\r\x12\r\n\x05\x63ount\x18\x02 \x02(\r\x12\x46\n\tmap_entry\x18\x03 \x03(\x0b\x32\x33.TST.StyleTableMapArchive.StyleTableMapEntryArchive\x1an\n\x19StyleTableMapEntryArchive\x12\x0b\n\x03key\x18\x01 \x02(\r\x12!\n\told_style\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12!\n\tnew_style\x18\x03 \x02(\x0b\x32\x0e.TSP.Reference\"\xe7\x03\n\x10SelectionArchive\x12&\n\ntableModel\x18\x01 \x01(\x0b\x32\x0e.TSP.ReferenceB\x02\x18\x01\x12\x31\n\x0eselection_type\x18\x04 \x02(\x0e\x32\x19.TST.SelectionTypeArchive\x12 \n\x0b\x61nchor_cell\x18\x05 \x01(\x0b\x32\x0b.TST.CellID\x12#\n\x0b\x63\x65ll_ranges\x18\x06 \x03(\x0b\x32\x0e.TST.CellRange\x12#\n\x0b\x62\x61se_ranges\x18\x07 \x03(\x0b\x32\x0e.TST.CellRange\x12 \n\x0b\x63ursor_cell\x18\x08 \x01(\x0b\x32\x0b.TST.CellID\x12\"\n\ntable_info\x18\t \x01(\x0b\x32\x0e.TSP.Reference\x12\x32\n\x0f\x63\x65ll_uid_region\x18\n \x01(\x0b\x32\x19.TST.CellUIDRegionArchive\x12\x32\n\x0f\x62\x61se_uid_region\x18\x0b \x01(\x0b\x32\x19.TST.CellUIDRegionArchive\x12.\n\x0f\x61nchor_cell_uid\x18\x0c \x01(\x0b\x32\x15.TSP.UUIDCoordArchive\x12.\n\x0f\x63ursor_cell_uid\x18\r \x01(\x0b\x32\x15.TSP.UUIDCoordArchive\"\xca\x02\n)DeathhawkRdar39989167CellSelectionArchive\x12\"\n\ntable_info\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\x12\x31\n\x0eselection_type\x18\x02 \x01(\x0e\x32\x19.TST.SelectionTypeArchive\x12\x32\n\x0f\x63\x65ll_uid_region\x18\x03 \x01(\x0b\x32\x19.TST.CellUIDRegionArchive\x12\x32\n\x0f\x62\x61se_uid_region\x18\x04 \x01(\x0b\x32\x19.TST.CellUIDRegionArchive\x12.\n\x0f\x61nchor_cell_uid\x18\x05 \x01(\x0b\x32\x15.TSP.UUIDCoordArchive\x12.\n\x0f\x63ursor_cell_uid\x18\x06 \x01(\x0b\x32\x15.TSP.UUIDCoordArchive\"&\n\x16StrokeSelectionArchive\x12\x0c\n\x04mask\x18\x01 \x01(\x05\"\x1d\n\x1b\x43ontrolCellSelectionArchive\"\x1b\n\x19StockCellSelectionArchive\"\x1b\n\x19TableNameSelectionArchive\"p\n\x18\x41utofillSelectionArchive\x12)\n\x11source_cell_range\x18\x01 \x01(\x0b\x32\x0e.TST.CellRange\x12)\n\x11target_cell_range\x18\x02 \x01(\x0b\x32\x0e.TST.CellRange\"V\n\x11\x46ilterRuleArchive\x12/\n\tpredicate\x18\x01 \x02(\x0b\x32\x1c.TST.FormulaPredicateArchive\x12\x10\n\x08\x64isabled\x18\x02 \x01(\x08\"\x89\x01\n\x11TableStyleArchive\x12 \n\x05super\x18\x01 \x02(\x0b\x32\x11.TSS.StyleArchive\x12\x16\n\x0eoverride_count\x18\n \x01(\r\x12:\n\x10table_properties\x18\x0b \x01(\x0b\x32 .TST.TableStylePropertiesArchive\"\x86\x01\n\x10\x43\x65llStyleArchive\x12 \n\x05super\x18\x01 \x02(\x0b\x32\x11.TSS.StyleArchive\x12\x16\n\x0eoverride_count\x18\n \x01(\r\x12\x38\n\x0f\x63\x65ll_properties\x18\x0b \x01(\x0b\x32\x1f.TST.CellStylePropertiesArchive\"\xe2\x0b\n\x17\x46ormulaPredicateArchive\x12%\n\x07\x66ormula\x18\x01 \x02(\x0b\x32\x14.TSCE.FormulaArchive\x12I\n\x0epredicate_type\x18\x02 \x02(\x0e\x32\x31.TST.FormulaPredicateArchive.FormulaPredicateType\x12>\n\nqualifier1\x18\x03 \x02(\x0e\x32*.TST.FormulaPredicateArchive.QualifierType\x12>\n\nqualifier2\x18\x04 \x02(\x0e\x32*.TST.FormulaPredicateArchive.QualifierType\x12\x14\n\x0cparam_index1\x18\x05 \x02(\x05\x12\x14\n\x0cparam_index2\x18\x06 \x02(\x05\x12\x14\n\x0cparam_index0\x18\x07 \x02(\x05\"\x89\x08\n\x14\x46ormulaPredicateType\x12\x0c\n\x08PredNone\x10\x00\x12\x12\n\x0eTextStartsWith\x10\x01\x12\x10\n\x0cTextEndsWith\x10\x02\x12\x10\n\x0cTextContains\x10\x03\x12\x16\n\x12TextDoesNotContain\x10\x04\x12\x0e\n\nValueEqual\x10\x05\x12\x11\n\rValueNotEqual\x10\x06\x12\x14\n\x10ValueGreaterThan\x10\x07\x12\x1b\n\x17ValueGreaterThanOrEqual\x10\x08\x12\x11\n\rValueLessThan\x10\t\x12\x18\n\x14ValueLessThanOrEqual\x10\n\x12\x15\n\x11ValueAboveAverage\x10\x0b\x12\x15\n\x11ValueBelowAverage\x10\x0c\x12\x10\n\x0cValueBetween\x10\r\x12\x0b\n\x07\x46ormula\x10\x0e\x12\x0e\n\nDuplicates\x10\x0f\x12\x0b\n\x07Uniques\x10\x10\x12\x0f\n\x0b\x44\x61teIsToday\x10\x11\x12\x13\n\x0f\x44\x61teIsYesterday\x10\x12\x12\x12\n\x0e\x44\x61teIsTomorrow\x10\x13\x12\x11\n\rDateIsTheDate\x10\x14\x12\x15\n\x11\x44\x61teBeforeTheDate\x10\x15\x12\x14\n\x10\x44\x61teAfterTheDate\x10\x16\x12\x14\n\x10\x44\x61teIsInTheRange\x10\x17\x12\x11\n\rDateInTheNext\x10\x18\x12\x11\n\rDateInTheLast\x10\x19\x12\x11\n\rDateIsExactly\x10\x1a\x12\x16\n\x12\x44\x61teBeforeRelative\x10\x1b\x12\x15\n\x11\x44\x61teAfterRelative\x10\x1c\x12\x17\n\x13\x44\x61teBetweenRelative\x10\x1d\x12\x0c\n\x08ValueTop\x10\x1e\x12\x0f\n\x0bValueBottom\x10\x1f\x12\x13\n\x0fValueNotBetween\x10 \x12\x0e\n\nDateInThis\x10!\x12\x0b\n\x07IsBlank\x10\"\x12\x0e\n\nIsNotBlank\x10#\x12\n\n\x06TextIs\x10$\x12\r\n\tTextIsNot\x10%\x12\x11\n\rDurationEqual\x10&\x12\x14\n\x10\x44urationNotEqual\x10\'\x12\x17\n\x13\x44urationGreaterThan\x10(\x12\x1e\n\x1a\x44urationGreaterThanOrEqual\x10)\x12\x14\n\x10\x44urationLessThan\x10*\x12\x1b\n\x17\x44urationLessThanOrEqual\x10+\x12\x13\n\x0f\x44urationBetween\x10,\x12\x16\n\x12\x44urationNotBetween\x10-\x12\x18\n\x14\x44urationAboveAverage\x10.\x12\x18\n\x14\x44urationBelowAverage\x10/\x12\x0f\n\x0b\x44urationTop\x10\x30\x12\x12\n\x0e\x44urationBottom\x10\x31\"\x86\x01\n\rQualifierType\x12\x0c\n\x08QualNone\x10\x00\x12\x08\n\x04\x44\x61ys\x10\x02\x12\t\n\x05Weeks\x10\x03\x12\n\n\x06Months\x10\x04\x12\t\n\x05Years\x10\x05\x12\x07\n\x03\x41go\x10\x06\x12\x0b\n\x07\x46romNow\x10\x07\x12\x0c\n\x08Quarters\x10\x08\x12\x0b\n\x07Percent\x10\t\x12\n\n\x06Values\x10\n\"\x86\x02\n\x1a\x43onditionalStyleSetArchive\x12\x11\n\truleCount\x18\x01 \x02(\r\x12\x43\n\x05rules\x18\x02 \x03(\x0b\x32\x34.TST.ConditionalStyleSetArchive.ConditionalStyleRule\x1a\x8f\x01\n\x14\x43onditionalStyleRule\x12/\n\tpredicate\x18\x01 \x02(\x0b\x32\x1c.TST.FormulaPredicateArchive\x12\"\n\ncell_style\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12\"\n\ntext_style\x18\x03 \x02(\x0b\x32\x0e.TSP.Reference\"\xb2\x02\n\x10\x46ilterSetArchive\x12\x31\n\x04type\x18\x01 \x01(\x0e\x32#.TST.FilterSetArchive.FilterSetType\x12\x18\n\nis_enabled\x18\x02 \x01(\x08:\x04true\x12,\n\x0c\x66ilter_rules\x18\x03 \x03(\x0b\x32\x16.TST.FilterRuleArchive\x12(\n needs_formula_rewrite_for_import\x18\x04 \x01(\x08\x12\x16\n\x0e\x66ilter_offsets\x18\x05 \x03(\r\x12\x16\n\x0e\x66ilter_enabled\x18\x06 \x03(\x08\"I\n\rFilterSetType\x12\x1b\n\x17\x46ilterSetArchiveTypeAll\x10\x00\x12\x1b\n\x17\x46ilterSetArchiveTypeAny\x10\x01\"\x8b\x04\n\x18HiddenStateExtentArchive\x12*\n\x17hidden_state_extent_uid\x18\x01 \x02(\x0b\x32\t.TSP.UUID\x12\x45\n\rhidden_states\x18\x02 \x03(\x0b\x32..TST.HiddenStateExtentArchive.RowOrColumnState\x12S\n\x17row_or_column_direction\x18\x03 \x02(\x0e\x32\x32.TST.HiddenStateExtentArchive.RowOrColumnDirection\x12/\n\x0fthreshold_value\x18\x05 \x03(\x0b\x32\x16.TSCE.CellValueArchive\x12-\n%needs_to_update_filter_set_for_import\x18\x06 \x01(\x08\x12\'\n\x14\x63ollapsed_group_uids\x18\x07 \x03(\x0b\x32\t.TSP.UUID\x1a_\n\x10RowOrColumnState\x12$\n\x11row_or_column_uid\x18\x01 \x02(\x0b\x32\t.TSP.UUID\x12\x13\n\x0buser_hidden\x18\x02 \x01(\x08\x12\x10\n\x08\x66iltered\x18\x03 \x01(\x08\"=\n\x14RowOrColumnDirection\x12\x13\n\x0f\x43olumnDirection\x10\x00\x12\x10\n\x0cRowDirection\x10\x01\"\xbe\x01\n\x13HiddenStatesArchive\x12$\n\x11hidden_states_uid\x18\x01 \x02(\x0b\x32\t.TSP.UUID\x12\x41\n\x1a\x63olumn_hidden_state_extent\x18\x02 \x02(\x0b\x32\x1d.TST.HiddenStateExtentArchive\x12>\n\x17row_hidden_state_extent\x18\x03 \x02(\x0b\x32\x1d.TST.HiddenStateExtentArchive\"i\n\x18HiddenStatesOwnerArchive\x12\x1c\n\towner_uid\x18\x01 \x02(\x0b\x32\t.TSP.UUID\x12/\n\rhidden_states\x18\x02 \x03(\x0b\x32\x18.TST.HiddenStatesArchive\"a\n\x1a\x45xpandCollapseStateArchive\x12!\n\x0euids_collapsed\x18\x01 \x03(\x0b\x32\t.TSP.UUID\x12 \n\ruids_expanded\x18\x02 \x03(\x0b\x32\t.TSP.UUID\"l\n\x16TokenAttachmentArchive\x12*\n\x05super\x18\x01 \x02(\x0b\x32\x1b.TSWP.UIGraphicalAttachment\x12&\n\x0e\x65xpressionNode\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\"8\n\x0e\x46ormulaArchive\x12&\n\x0e\x65xpressionTree\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\"b\n\x15\x45xpressionNodeArchive\x12 \n\x08\x63hildren\x18\x01 \x03(\x0b\x32\x0e.TSP.Reference\x12\x13\n\x0b\x66irst_index\x18\x02 \x01(\x04\x12\x12\n\nlast_index\x18\x03 \x01(\x04\"N\n\x12\x42ooleanNodeArchive\x12)\n\x05super\x18\x01 \x02(\x0b\x32\x1a.TST.ExpressionNodeArchive\x12\r\n\x05value\x18\x02 \x02(\x08\"y\n\x11NumberNodeArchive\x12)\n\x05super\x18\x01 \x02(\x0b\x32\x1a.TST.ExpressionNodeArchive\x12\x0e\n\x06number\x18\x02 \x01(\x01\x12\x13\n\x0b\x64\x65\x63imal_low\x18\x03 \x01(\x04\x12\x14\n\x0c\x64\x65\x63imal_high\x18\x04 \x01(\x04\"M\n\x11StringNodeArchive\x12)\n\x05super\x18\x01 \x02(\x0b\x32\x1a.TST.ExpressionNodeArchive\x12\r\n\x05value\x18\x02 \x02(\t\"f\n\x15IdentifierNodeArchive\x12)\n\x05super\x18\x01 \x02(\x0b\x32\x1a.TST.ExpressionNodeArchive\x12\x12\n\nidentifier\x18\x02 \x01(\t\x12\x0e\n\x06symbol\x18\x03 \x01(\r\"\\\n\x10\x41rrayNodeArchive\x12)\n\x05super\x18\x01 \x02(\x0b\x32\x1a.TST.ExpressionNodeArchive\x12\x0f\n\x07\x63olumns\x18\x02 \x01(\r\x12\x0c\n\x04rows\x18\x03 \x01(\r\"<\n\x0fListNodeArchive\x12)\n\x05super\x18\x01 \x02(\x0b\x32\x1a.TST.ExpressionNodeArchive\"V\n\x13OperatorNodeArchive\x12)\n\x05super\x18\x01 \x02(\x0b\x32\x1a.TST.ExpressionNodeArchive\x12\x14\n\x0coperatorChar\x18\x02 \x02(\r\"E\n\x1aPostfixOperatorNodeArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.OperatorNodeArchive\"D\n\x19PrefixOperatorNodeArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.OperatorNodeArchive\"t\n\x13\x46unctionNodeArchive\x12)\n\x05super\x18\x01 \x02(\x0b\x32\x1a.TST.ExpressionNodeArchive\x12\x15\n\rfunctionIndex\x18\x02 \x02(\r\x12\x1b\n\x13invalidFunctionName\x18\x03 \x01(\t\"C\n\x16\x46unctionEndNodeArchive\x12)\n\x05super\x18\x01 \x02(\x0b\x32\x1a.TST.ExpressionNodeArchive\"[\n\x0f\x44\x61teNodeArchive\x12)\n\x05super\x18\x01 \x02(\x0b\x32\x1a.TST.ExpressionNodeArchive\x12\r\n\x05value\x18\x02 \x02(\t\x12\x0e\n\x06\x66ormat\x18\x03 \x01(\t\"\xba\x03\n\x14ReferenceNodeArchive\x12)\n\x05super\x18\x01 \x02(\x0b\x32\x1a.TST.ExpressionNodeArchive\x12\x33\n\x0erangeReference\x18\x02 \x01(\x0b\x32\x1b.TSCE.RangeReferenceArchive\x12\x16\n\x0epreserve_flags\x18\x03 \x02(\r\x12\x13\n\x0bhostTableID\x18\x04 \x01(\t\x12\x31\n\rhost_cell_ref\x18\n \x01(\x0b\x32\x1a.TSCE.CellReferenceArchive\x12\x1c\n\ttable_uid\x18\x05 \x01(\x0b\x32\t.TSP.UUID\x12-\n\x0erange_top_left\x18\x06 \x01(\x0b\x32\x15.TSP.UUIDCoordArchive\x12\x31\n\x12range_bottom_right\x18\x07 \x01(\x0b\x32\x15.TSP.UUIDCoordArchive\x12\x34\n\x0c\x63\x61tegory_ref\x18\x08 \x01(\x0b\x32\x1e.TSCE.CategoryReferenceArchive\x12,\n\x0euid_range_rect\x18\t \x01(\x0b\x32\x14.TSP.UUIDRectArchive\"\x88\x01\n\x13\x44urationNodeArchive\x12)\n\x05super\x18\x01 \x02(\x0b\x32\x1a.TST.ExpressionNodeArchive\x12\x14\n\x0ctimeinterval\x18\x02 \x02(\x01\x12\x10\n\x08smallest\x18\x03 \x02(\r\x12\x0f\n\x07largest\x18\x04 \x02(\r\x12\r\n\x05style\x18\x05 \x02(\r\"\x87\x01\n\x1e\x41rgumentPlaceholderNodeArchive\x12)\n\x05super\x18\x01 \x02(\x0b\x32\x1a.TST.ExpressionNodeArchive\x12\x15\n\rfunctionIndex\x18\x02 \x01(\r\x12\x15\n\rargumentIndex\x18\x03 \x01(\r\x12\x0c\n\x04mode\x18\x04 \x01(\r\"G\n\x1a\x45mptyExpressionNodeArchive\x12)\n\x05super\x18\x01 \x02(\x0b\x32\x1a.TST.ExpressionNodeArchive\"\xc3\x01\n\x0eLetNodeArchive\x12)\n\x05super\x18\x01 \x02(\x0b\x32\x1a.TST.ExpressionNodeArchive\x12\x1c\n\x14whitespace_after_let\x18\x02 \x01(\t\x12#\n\x1bwhitespace_after_identifier\x18\x03 \x01(\t\x12\x1f\n\x17whitespace_after_equals\x18\x04 \x01(\t\x12\"\n\x1awhitespace_after_delimiter\x18\x05 \x01(\t\":\n\rInNodeArchive\x12)\n\x05super\x18\x01 \x02(\x0b\x32\x1a.TST.ExpressionNodeArchive\"d\n\x13VariableNodeArchive\x12)\n\x05super\x18\x01 \x02(\x0b\x32\x1a.TST.ExpressionNodeArchive\x12\x12\n\nidentifier\x18\x02 \x02(\t\x12\x0e\n\x06symbol\x18\x03 \x02(\r\"\xef\x01\n\x11LayoutHintArchive\x12\x0f\n\x07isValid\x18\x01 \x02(\x08\x12!\n\tcellRange\x18\x02 \x01(\x0b\x32\x0e.TST.CellRange\x12\x1b\n\x06hintID\x18\x03 \x01(\x0b\x32\x0b.TST.CellID\x12\x1e\n\x0bmaximumSize\x18\x04 \x02(\x0b\x32\t.TSP.Size\x12\x19\n\x11partitionPosition\x18\x05 \x02(\r\x12\x12\n\nhorizontal\x18\x06 \x02(\x08\x12 \n\reffectiveSize\x18\x07 \x01(\x0b\x32\t.TSP.Size\x12\x18\n\x10partitioningPass\x18\x08 \x01(\r\"\x92\x01\n CompletionTokenAttachmentArchive\x12*\n\x05super\x18\x01 \x02(\x0b\x32\x1b.TST.TokenAttachmentArchive\x12\x16\n\x0e\x63ompletionText\x18\x02 \x01(\t\x12\x15\n\rcaretPosition\x18\x03 \x01(\r\x12\x13\n\x0bprefixStart\x18\x04 \x01(\r\"\xa6\x01\n\x1eHiddenStateFormulaOwnerArchive\x12$\n\x08owner_id\x18\x01 \x01(\x0b\x32\x12.TSP.CFUUIDArchive\x12/\n\x0fthreshold_value\x18\x02 \x03(\x0b\x32\x16.TSCE.CellValueArchive\x12-\n%needs_to_update_filter_set_for_import\x18\x03 \x01(\x08\"\xc0\x01\n\x13\x46ormulaStoreArchive\x12\x1a\n\x12next_formula_index\x18\x02 \x02(\r\x12;\n\x08\x66ormulas\x18\x03 \x03(\x0b\x32).TST.FormulaStoreArchive.FormulaStorePair\x1aP\n\x10\x46ormulaStorePair\x12\x15\n\rformula_index\x18\x01 \x02(\r\x12%\n\x07\x66ormula\x18\x02 \x02(\x0b\x32\x14.TSCE.FormulaArchive\"\xbd\x01\n\x15MergeOperationArchive\x12+\n\nmerge_type\x18\x01 \x02(\x0e\x32\x17.TST.MergeActionArchive\x12*\n\x0cmerge_ranges\x18\x02 \x03(\x0b\x32\x14.TSP.UUIDRectArchive\x12,\n\x0emerge_formulas\x18\x03 \x03(\x0b\x32\x14.TSCE.FormulaArchive\x12\x1d\n\x15merge_formula_indexes\x18\x04 \x03(\r\"j\n\x11MergeOwnerArchive\x12$\n\x08owner_id\x18\x01 \x02(\x0b\x32\x12.TSP.CFUUIDArchive\x12/\n\rformula_store\x18\x02 \x01(\x0b\x32\x18.TST.FormulaStoreArchive\"p\n\x17PencilAnnotationArchive\x12\"\n\ntable_info\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\x12\x31\n\x19pencil_annotation_storage\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\"\x9a\x01\n\x1cPencilAnnotationOwnerArchive\x12$\n\x08owner_id\x18\x01 \x02(\x0b\x32\x12.TSP.CFUUIDArchive\x12/\n\rformula_store\x18\x02 \x01(\x0b\x32\x18.TST.FormulaStoreArchive\x12#\n\x0b\x61nnotations\x18\x03 \x03(\x0b\x32\x0e.TSP.Reference\"\xba\x03\n\x12\x41\x63\x63umulatorArchive\x12\x12\n\nbool_count\x18\x01 \x01(\r\x12\x17\n\x0f\x62ool_true_count\x18\x0c \x01(\r\x12\x14\n\x0cnumber_count\x18\x02 \x01(\r\x12\x12\n\ndate_count\x18\x03 \x01(\r\x12\x16\n\x0e\x64uration_count\x18\x04 \x01(\r\x12\x14\n\x0cstring_count\x18\x05 \x01(\r\x12\x13\n\x0b\x65rror_count\x18\r \x01(\r\x12\x17\n\x0fis_circular_ref\x18\x0e \x01(\x08\x12)\n\tmin_value\x18\x06 \x02(\x0b\x32\x16.TSCE.CellValueArchive\x12)\n\tmax_value\x18\x07 \x02(\x0b\x32\x16.TSCE.CellValueArchive\x12\x32\n\x12number_total_value\x18\x08 \x02(\x0b\x32\x16.TSCE.CellValueArchive\x12/\n\x0f\x66irst_date_seen\x18\t \x01(\x0b\x32\x16.TSCE.CellValueArchive\x12!\n\x19total_secs_since_ref_date\x18\n \x01(\x01\x12\x13\n\x0bsecs_to_add\x18\x0b \x01(\x01\"\xb5\x01\n\x12GroupColumnArchive\x12\x1d\n\ncolumn_uid\x18\x01 \x02(\x0b\x32\t.TSP.UUID\x12(\n\rgrouping_type\x18\x02 \x02(\x0e\x32\x11.TST.GroupingType\x12.\n\x10grouping_functor\x18\x03 \x01(\x0b\x32\x14.TSCE.FunctorArchive\x12&\n\x13grouping_column_uid\x18\x04 \x01(\x0b\x32\t.TSP.UUID\"G\n\x16GroupColumnListArchive\x12-\n\x0cgroup_column\x18\x01 \x03(\x0b\x32\x17.TST.GroupColumnArchive\"l\n\x16\x43olumnAggregateArchive\x12\x1d\n\ncolumn_uid\x18\x01 \x02(\x0b\x32\t.TSP.UUID\x12\r\n\x05level\x18\x02 \x02(\r\x12$\n\x08\x61gg_type\x18\x03 \x02(\x0e\x32\x12.TST.AggregateType\"M\n\x1a\x43olumnAggregateListArchive\x12/\n\naggregates\x18\x01 \x03(\x0b\x32\x1b.TST.ColumnAggregateArchive\"\xff\x0f\n\x14\x43\x61tegoryOwnerArchive\x12\x1c\n\towner_uid\x18\x01 \x02(\x0b\x32\t.TSP.UUID\x12:\n\x08group_by\x18\x02 \x03(\x0b\x32(.TST.CategoryOwnerArchive.GroupByArchive\x1a\x8c\x0f\n\x0eGroupByArchive\x12\x1f\n\x0cgroup_by_uid\x18\x01 \x02(\x0b\x32\t.TSP.UUID\x12-\n\x0cgroup_column\x18\x02 \x03(\x0b\x32\x17.TST.GroupColumnArchive\x12R\n\x0fgroup_node_root\x18\x03 \x02(\x0b\x32\x39.TST.CategoryOwnerArchive.GroupByArchive.GroupNodeArchive\x12N\n\naggregator\x18\x04 \x03(\x0b\x32:.TST.CategoryOwnerArchive.GroupByArchive.AggregatorArchive\x12\x34\n\x0f\x63olumn_agg_type\x18\x05 \x03(\x0b\x32\x1b.TST.ColumnAggregateArchive\x12\x12\n\nis_enabled\x18\x06 \x02(\x08\x12\x45\n indirect_agg_type_change_formula\x18\x07 \x01(\x0b\x32\x1b.TSCE.CellCoordinateArchive\x12=\n\x18grouping_columns_formula\x18\x08 \x01(\x0b\x32\x1b.TSCE.CellCoordinateArchive\x12\x44\n\x1fgrouping_column_headers_formula\x18\n \x01(\x0b\x32\x1b.TSCE.CellCoordinateArchive\x12?\n\x1a\x61ggs_in_group_root_formula\x18\t \x01(\x0b\x32\x1b.TSCE.CellCoordinateArchive\x12\x41\n\x1c\x63olumn_order_changed_formula\x18\x0b \x01(\x0b\x32\x1b.TSCE.CellCoordinateArchive\x12>\n\x19row_order_changed_formula\x18\x0c \x01(\x0b\x32\x1b.TSCE.CellCoordinateArchive\x12N\n)row_order_changed_ignoring_recalc_formula\x18\r \x01(\x0b\x32\x1b.TSCE.CellCoordinateArchive\x1a\xb4\x01\n\x0e\x41ggNodeArchive\x12\x32\n\rformula_coord\x18\x01 \x02(\x0b\x32\x1b.TSCE.CellCoordinateArchive\x12&\n\x05\x61\x63\x63um\x18\x02 \x01(\x0b\x32\x17.TST.AccumulatorArchive\x12\x46\n\x05\x63hild\x18\x03 \x03(\x0b\x32\x37.TST.CategoryOwnerArchive.GroupByArchive.AggNodeArchive\x1a\xa5\x06\n\x10GroupNodeArchive\x12\x1c\n\tgroup_uid\x18\x01 \x02(\x0b\x32\t.TSP.UUID\x12k\n\x11group_value_tuple\x18\x02 \x01(\x0b\x32P.TST.CategoryOwnerArchive.GroupByArchive.GroupNodeArchive.GroupValueTupleArchive\x12\x30\n\x10group_cell_value\x18\x07 \x01(\x0b\x32\x16.TSCE.CellValueArchive\x12H\n\x05\x63hild\x18\x03 \x03(\x0b\x32\x39.TST.CategoryOwnerArchive.GroupByArchive.GroupNodeArchive\x12\x1a\n\x07row_uid\x18\x04 \x03(\x0b\x32\t.TSP.UUID\x12\x37\n\x12\x61gg_formula_coords\x18\x05 \x03(\x0b\x32\x1b.TSCE.CellCoordinateArchive\x12\x66\n\x0e\x66ormat_manager\x18\x06 \x01(\x0b\x32N.TST.CategoryOwnerArchive.GroupByArchive.GroupNodeArchive.FormatManagerArchive\x1a?\n\x16GroupValueTupleArchive\x12%\n\x05value\x18\x01 \x03(\x0b\x32\x16.TSCE.CellValueArchive\x1a\x8b\x02\n\x14\x46ormatManagerArchive\x12*\n\ncell_value\x18\x01 \x01(\x0b\x32\x16.TSCE.CellValueArchive\x12)\n\x07\x66ormats\x18\x02 \x03(\x0b\x32\x18.TSK.FormatStructArchive\x12n\n\x08row_sets\x18\x03 \x03(\x0b\x32\\.TST.CategoryOwnerArchive.GroupByArchive.GroupNodeArchive.FormatManagerArchive.RowSetArchive\x1a,\n\rRowSetArchive\x12\x1b\n\x08row_uids\x18\x01 \x03(\x0b\x32\t.TSP.UUID\x1a}\n\x11\x41ggregatorArchive\x12\x1d\n\ncolumn_uid\x18\x01 \x02(\x0b\x32\t.TSP.UUID\x12I\n\x08\x61gg_node\x18\x02 \x01(\x0b\x32\x37.TST.CategoryOwnerArchive.GroupByArchive.AggNodeArchive\"q\n\x16RichTextPayloadArchive\x12\x1f\n\x07storage\x18\x01 \x02(\x0b\x32\x0e.TSP.Reference\x12\x19\n\x05range\x18\x02 \x01(\x0b\x32\n.TSP.Range\x12\x1b\n\x06\x63\x65llid\x18\x03 \x02(\x0b\x32\x0b.TST.CellID\"Q\n#FormulaEqualsTokenAttachmentArchive\x12*\n\x05super\x18\x01 \x02(\x0b\x32\x1b.TSWP.UIGraphicalAttachment\"\x9d\x05\n\x0f\x43\x65llFillStandIn\x12\x1e\n\x04\x66ill\x18\x01 \x02(\x0b\x32\x10.TSD.FillArchive\x12\x15\n\rtype_is_mixed\x18\x02 \x01(\x08\x12\x1f\n\x17\x63olor_has_been_modified\x18\x03 \x01(\x08\x12\x16\n\x0e\x63olor_is_mixed\x18\x04 \x01(\x08\x12%\n\x1d\x66irst_color_has_been_modified\x18\x05 \x01(\x08\x12\x1c\n\x14\x66irst_color_is_mixed\x18\x06 \x01(\x08\x12$\n\x1clast_color_has_been_modified\x18\x07 \x01(\x08\x12\x1b\n\x13last_color_is_mixed\x18\x08 \x01(\x08\x12\'\n\x1fgradient_type_has_been_modified\x18\t \x01(\x08\x12\x1e\n\x16gradient_type_is_mixed\x18\n \x01(\x08\x12(\n gradient_angle_has_been_modified\x18\x0b \x01(\x08\x12\x1f\n\x17gradient_angle_is_mixed\x18\x0c \x01(\x08\x12$\n\x1cimage_data_has_been_modified\x18\r \x01(\x08\x12\x1b\n\x13image_data_is_mixed\x18\x0e \x01(\x08\x12$\n\x1ctint_color_has_been_modified\x18\x0f \x01(\x08\x12\x1b\n\x13tint_color_is_mixed\x18\x10 \x01(\x08\x12\x1f\n\x17scale_has_been_modified\x18\x11 \x01(\x08\x12\x16\n\x0escale_is_mixed\x18\x12 \x01(\x08\x12#\n\x1btechnique_has_been_modified\x18\x13 \x01(\x08\x12\x1a\n\x12technique_is_mixed\x18\x14 \x01(\x08\"^\n\x17\x46ormulaSelectionArchive\x12%\n\x05super\x18\x01 \x02(\x0b\x32\x16.TSWP.SelectionArchive\x12\x1c\n\x14\x61\x63tiveTokenCharIndex\x18\x02 \x01(\r\"\xa7\x02\n\x11\x43\x65llBorderArchive\x12&\n\ntop_stroke\x18\x01 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x18\n\x10top_stroke_order\x18\x02 \x01(\x05\x12(\n\x0cright_stroke\x18\x03 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x1a\n\x12right_stroke_order\x18\x04 \x01(\x05\x12)\n\rbottom_stroke\x18\x05 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x1b\n\x13\x62ottom_stroke_order\x18\x06 \x01(\x05\x12\'\n\x0bleft_stroke\x18\x07 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x19\n\x11left_stroke_order\x18\x08 \x01(\x05\"\xbf\x01\n!DefaultCellStylesContainerArchive\x12+\n\x13table_style_network\x18\x01 \x02(\x0b\x32\x0e.TSP.Reference\x12\"\n\x0fheader_row_uids\x18\x02 \x03(\x0b\x32\t.TSP.UUID\x12\"\n\x0f\x66ooter_row_uids\x18\x03 \x03(\x0b\x32\t.TSP.UUID\x12%\n\x12header_column_uids\x18\x04 \x03(\x0b\x32\t.TSP.UUID\"\x95\x03\n\x19MultiTableRemapperArchive\x12?\n\x0fmapping_purpose\x18\x01 \x02(\x0e\x32&.TST.MultiTableRemapperArchive.Purpose\x12\x1f\n\x17should_steal_references\x18\x02 \x02(\x08\x12\x1d\n\x15\x63\x61n_reuse_table_names\x18\x03 \x02(\x08\x12\x35\n\x10owner_uid_mapper\x18\x04 \x03(\x0b\x32\x1b.TSCE.OwnerUIDMapperArchive\x12\x36\n\x19\x62\x61\x63king_tables_for_charts\x18\x05 \x02(\x0b\x32\x13.TSP.UUIDMapArchive\x12\x1c\n\x14\x63ross_document_paste\x18\x06 \x02(\x08\x12\x1b\n\x13nested_inner_mapper\x18\x07 \x02(\x08\"M\n\x07Purpose\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x0c\n\x08GROUPING\x10\x01\x12\'\n#PAGES_SECTION_DUPLICATION_NONCOLLAB\x10\x02\"\xfc\x04\n\x1b\x43hangePropagationMapWrapper\x12\x1c\n\x14replacement_behavior\x18\x01 \x02(\x05\x12\x30\n\x18style_replace_prototypes\x18\x02 \x03(\x0b\x32\x0e.TSP.Reference\x12\x32\n\x1astyle_replace_replacements\x18\x03 \x03(\x0b\x32\x0e.TSP.Reference\x12+\n\x13style_modify_styles\x18\x04 \x03(\x0b\x32\x0e.TSP.Reference\x12\x32\n\x1astyle_modify_old_prop_maps\x18\x05 \x03(\x0b\x32\x0e.TSP.Reference\x12\x32\n\x1astyle_modify_new_prop_maps\x18\x06 \x03(\x0b\x32\x0e.TSP.Reference\x12/\n\x17style_delete_prototypes\x18\x07 \x03(\x0b\x32\x0e.TSP.Reference\x12\x31\n\x19style_delete_replacements\x18\x08 \x03(\x0b\x32\x0e.TSP.Reference\x12\x36\n\x1etable_preset_replace_prototype\x18\t \x01(\x0b\x32\x0e.TSP.Reference\x12\x38\n table_preset_replace_replacement\x18\n \x01(\x0b\x32\x0e.TSP.Reference\x12\x35\n\x1dtable_preset_delete_prototype\x18\x0b \x01(\x0b\x32\x0e.TSP.Reference\x12\x37\n\x1ftable_preset_delete_replacement\x18\x0c \x01(\x0b\x32\x0e.TSP.Reference\"\xea\x01\n\x18SummaryCellVendorArchive\x12\"\n\ntable_info\x18\x01 \x02(\x0b\x32\x0e.TSP.Reference\x12?\n\x07\x65ntries\x18\x02 \x03(\x0b\x32..TST.SummaryCellVendorArchive.SummaryCellEntry\x1ai\n\x10SummaryCellEntry\x12\x1e\n\x0bwildcardUID\x18\x01 \x02(\x0b\x32\t.TSP.UUID\x12\x1c\n\tcolumnUID\x18\x02 \x02(\x0b\x32\t.TSP.UUID\x12\x17\n\x04\x63\x65ll\x18\x03 \x02(\x0b\x32\t.TST.Cell\"[\n\x14\x43\x61tegoryOrderArchive\x12\"\n\ntable_info\x18\x01 \x02(\x0b\x32\x0e.TSP.Reference\x12\x1f\n\x07uid_map\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\"\xb6\x02\n\x18HeaderNameMgrTileArchive\x12\x16\n\x0e\x66irst_fragment\x18\x01 \x02(\t\x12\x15\n\rlast_fragment\x18\x02 \x02(\t\x12L\n\x11name_frag_entries\x18\x03 \x03(\x0b\x32\x31.TST.HeaderNameMgrTileArchive.NameFragmentArchive\x1a\x9c\x01\n\x13NameFragmentArchive\x12\x15\n\rname_fragment\x18\x01 \x02(\t\x12\x33\n\x0ename_precedent\x18\x02 \x02(\x0b\x32\x1b.TSCE.CellCoordinateArchive\x12\x39\n\x15uses_of_name_fragment\x18\x03 \x01(\x0b\x32\x1a.TSCE.UidCellRefSetArchive\"\xe2\x03\n\x14HeaderNameMgrArchive\x12\x1c\n\towner_uid\x18\x01 \x02(\x0b\x32\t.TSP.UUID\x12 \n\rnrm_owner_uid\x18\x02 \x01(\x0b\x32\t.TSP.UUID\x12=\n\nper_tables\x18\x03 \x03(\x0b\x32).TST.HeaderNameMgrArchive.PerTableArchive\x12\'\n\x0fname_frag_tiles\x18\x04 \x03(\x0b\x32\x0e.TSP.Reference\x1a\xa1\x02\n\x0fPerTableArchive\x12\x1c\n\ttable_uid\x18\x01 \x02(\x0b\x32\t.TSP.UUID\x12\x38\n\x13per_table_precedent\x18\x02 \x02(\x0b\x32\x1b.TSCE.CellCoordinateArchive\x12\x12\n\nis_deleted\x18\x03 \x01(\x08\x12\"\n\x0fheader_row_uids\x18\x05 \x03(\x0b\x32\t.TSP.UUID\x12%\n\x12header_column_uids\x18\x06 \x03(\x0b\x32\t.TSP.UUID\x12)\n\x16update_header_row_uids\x18\x07 \x03(\x0b\x32\t.TSP.UUID\x12,\n\x19update_header_column_uids\x18\x08 \x03(\x0b\x32\t.TSP.UUID\"K\n\x1cWidthHeightCacheFittingEntry\x12\x15\n\rfitting_index\x18\x01 \x01(\r\x12\x14\n\x0c\x66itting_size\x18\x02 \x01(\x02\"j\n\x10WidthHeightCache\x12?\n\x14rows_fitting_entries\x18\x01 \x03(\x0b\x32!.TST.WidthHeightCacheFittingEntry\x12\x15\n\rcolumns_count\x18\x03 \x01(\r\"H\n\x13MasterLayoutArchive\x12\x31\n\x12width_height_cache\x18\x01 \x01(\x0b\x32\x15.TST.WidthHeightCache*\xd7\x01\n\x08\x43\x65llType\x12\x13\n\x0fgenericCellType\x10\x00\x12\x10\n\x0cspanCellType\x10\x01\x12\x12\n\x0enumberCellType\x10\x02\x12\x10\n\x0ctextCellType\x10\x03\x12\x13\n\x0f\x66ormulaCellType\x10\x04\x12\x10\n\x0c\x64\x61teCellType\x10\x05\x12\x10\n\x0c\x62oolCellType\x10\x06\x12\x14\n\x10\x64urationCellType\x10\x07\x12\x18\n\x14\x66ormulaErrorCellType\x10\x08\x12\x15\n\x11\x61utomaticCellType\x10\t*\x86\x02\n\rCellValueType\x12\x16\n\x12\x65mptyCellValueType\x10\x00\x12\x17\n\x13numberCellValueType\x10\x01\x12\x17\n\x13stringCellValueType\x10\x02\x12\x19\n\x15providedCellValueType\x10\x03\x12\x15\n\x11\x64\x61teCellValueType\x10\x04\x12\x15\n\x11\x62oolCellValueType\x10\x05\x12\x19\n\x15\x64urationCellValueType\x10\x06\x12\x16\n\x12\x65rrorCellValueType\x10\x07\x12\x14\n\x10richTextCellType\x10\x08\x12\x19\n\x15\x63urrencyCellValueType\x10\t*>\n\x15TableDimensionArchive\x12\x10\n\x0c\x64imensionRow\x10\x00\x12\x13\n\x0f\x64imensionColumn\x10\x01*\x84\x02\n\x14SelectionTypeArchive\x12\x1f\n\x1b\x64\x65precatedCellSelectionType\x10\x00\x12\x14\n\x10rowSelectionType\x10\x01\x12\x17\n\x13\x63olumnSelectionType\x10\x02\x12&\n\"deprecatedCellEditingSelectionType\x10\x03\x12$\n deprecatedTableNameSelectionType\x10\x04\x12 \n\x1c\x64\x65precatedTableSelectionType\x10\x05\x12\x17\n\x13regionSelectionType\x10\x06\x12\x13\n\x0fnoSelectionType\x10\x07*y\n\x14\x46illDirectionArchive\x12\x17\n\x13kTSTFillDownArchive\x10\x01\x12\x15\n\x11kTSTFillUpArchive\x10\x02\x12\x18\n\x14kTSTFillRightArchive\x10\x03\x12\x17\n\x13kTSTFillLeftArchive\x10\x04*n\n\x12MergeActionArchive\x12\x15\n\x11mergeActionInsert\x10\x01\x12\x15\n\x11mergeActionRemove\x10\x02\x12\x15\n\x11mergeActionShrink\x10\x03\x12\x13\n\x0fmergeActionGrow\x10\x04*G\n\x15HideShowActionArchive\x12\x16\n\x12hideShowActionHide\x10\x00\x12\x16\n\x12hideShowActionShow\x10\x01*s\n\x0cGroupingType\x12\n\n\x06UNIQUE\x10\x00\x12\x08\n\x04YEAR\x10\x01\x12\t\n\x05MONTH\x10\x02\x12\r\n\tDAYOFWEEK\x10\x03\x12\x07\n\x03\x44\x41Y\x10\x04\x12\x0c\n\x08YEARWEEK\x10\x05\x12\x0f\n\x0bYEARQUARTER\x10\x06\x12\x0b\n\x07ROUND_0\x10\n*z\n\rAggregateType\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05\x43OUNT\x10\x01\x12\t\n\x05TOTAL\x10\x02\x12\x0b\n\x07\x41VERAGE\x10\x03\x12\x07\n\x03MIN\x10\x04\x12\x07\n\x03MAX\x10\x05\x12\x0e\n\nGROUPVALUE\x10\t\x12\x0c\n\x08\x42ODYROWS\x10\n\x12\x0c\n\x08INDIRECT\x10\x0b:[\n\x12import_warning_set\x12 .TSS.CommandPropertyEntryArchive\x18\xf4\x03 \x01(\x0b\x32\x1c.TST.ImportWarningSetArchive:[\n\x10\x66ormat_and_value\x12 .TSS.CommandPropertyEntryArchive\x18\xf5\x03 \x01(\x0b\x32\x1e.TST.CellFormatAndValueArchive:N\n\x0b\x63\x65ll_border\x12 .TSS.CommandPropertyEntryArchive\x18\xf7\x03 \x01(\x0b\x32\x16.TST.CellBorderArchive:]\n\x0f\x63omment_storage\x12 .TSS.CommandPropertyEntryArchive\x18\xf8\x03 \x01(\x0b\x32!.TST.CommentStorageWrapperArchive:J\n\tcell_spec\x12 .TSS.CommandPropertyEntryArchive\x18\xf9\x03 \x01(\x0b\x32\x14.TST.CellSpecArchive')
  ,
  dependencies=[TSPMessages__pb2.DESCRIPTOR,TSDArchives__pb2.DESCRIPTOR,TSKArchives__pb2.DESCRIPTOR,TSSArchives__pb2.DESCRIPTOR,TSCEArchives__pb2.DESCRIPTOR,TSWPArchives__pb2.DESCRIPTOR,TSTStylePropertyArchiving__pb2.DESCRIPTOR,])

_CELLTYPE = _descriptor.EnumDescriptor(
  name='CellType',
  full_name='TST.CellType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='genericCellType', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='spanCellType', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='numberCellType', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='textCellType', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='formulaCellType', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='dateCellType', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='boolCellType', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='durationCellType', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='formulaErrorCellType', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='automaticCellType', index=9, number=9,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=34013,
  serialized_end=34228,
)
_sym_db.RegisterEnumDescriptor(_CELLTYPE)

CellType = enum_type_wrapper.EnumTypeWrapper(_CELLTYPE)
_CELLVALUETYPE = _descriptor.EnumDescriptor(
  name='CellValueType',
  full_name='TST.CellValueType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='emptyCellValueType', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='numberCellValueType', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='stringCellValueType', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='providedCellValueType', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='dateCellValueType', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='boolCellValueType', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='durationCellValueType', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='errorCellValueType', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='richTextCellType', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='currencyCellValueType', index=9, number=9,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=34231,
  serialized_end=34493,
)
_sym_db.RegisterEnumDescriptor(_CELLVALUETYPE)

CellValueType = enum_type_wrapper.EnumTypeWrapper(_CELLVALUETYPE)
_TABLEDIMENSIONARCHIVE = _descriptor.EnumDescriptor(
  name='TableDimensionArchive',
  full_name='TST.TableDimensionArchive',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='dimensionRow', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='dimensionColumn', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=34495,
  serialized_end=34557,
)
_sym_db.RegisterEnumDescriptor(_TABLEDIMENSIONARCHIVE)

TableDimensionArchive = enum_type_wrapper.EnumTypeWrapper(_TABLEDIMENSIONARCHIVE)
_SELECTIONTYPEARCHIVE = _descriptor.EnumDescriptor(
  name='SelectionTypeArchive',
  full_name='TST.SelectionTypeArchive',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='deprecatedCellSelectionType', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='rowSelectionType', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='columnSelectionType', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='deprecatedCellEditingSelectionType', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='deprecatedTableNameSelectionType', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='deprecatedTableSelectionType', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='regionSelectionType', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='noSelectionType', index=7, number=7,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=34560,
  serialized_end=34820,
)
_sym_db.RegisterEnumDescriptor(_SELECTIONTYPEARCHIVE)

SelectionTypeArchive = enum_type_wrapper.EnumTypeWrapper(_SELECTIONTYPEARCHIVE)
_FILLDIRECTIONARCHIVE = _descriptor.EnumDescriptor(
  name='FillDirectionArchive',
  full_name='TST.FillDirectionArchive',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='kTSTFillDownArchive', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kTSTFillUpArchive', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kTSTFillRightArchive', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kTSTFillLeftArchive', index=3, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=34822,
  serialized_end=34943,
)
_sym_db.RegisterEnumDescriptor(_FILLDIRECTIONARCHIVE)

FillDirectionArchive = enum_type_wrapper.EnumTypeWrapper(_FILLDIRECTIONARCHIVE)
_MERGEACTIONARCHIVE = _descriptor.EnumDescriptor(
  name='MergeActionArchive',
  full_name='TST.MergeActionArchive',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='mergeActionInsert', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='mergeActionRemove', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='mergeActionShrink', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='mergeActionGrow', index=3, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=34945,
  serialized_end=35055,
)
_sym_db.RegisterEnumDescriptor(_MERGEACTIONARCHIVE)

MergeActionArchive = enum_type_wrapper.EnumTypeWrapper(_MERGEACTIONARCHIVE)
_HIDESHOWACTIONARCHIVE = _descriptor.EnumDescriptor(
  name='HideShowActionArchive',
  full_name='TST.HideShowActionArchive',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='hideShowActionHide', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='hideShowActionShow', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=35057,
  serialized_end=35128,
)
_sym_db.RegisterEnumDescriptor(_HIDESHOWACTIONARCHIVE)

HideShowActionArchive = enum_type_wrapper.EnumTypeWrapper(_HIDESHOWACTIONARCHIVE)
_GROUPINGTYPE = _descriptor.EnumDescriptor(
  name='GroupingType',
  full_name='TST.GroupingType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNIQUE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='YEAR', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MONTH', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DAYOFWEEK', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DAY', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='YEARWEEK', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='YEARQUARTER', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ROUND_0', index=7, number=10,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=35130,
  serialized_end=35245,
)
_sym_db.RegisterEnumDescriptor(_GROUPINGTYPE)

GroupingType = enum_type_wrapper.EnumTypeWrapper(_GROUPINGTYPE)
_AGGREGATETYPE = _descriptor.EnumDescriptor(
  name='AggregateType',
  full_name='TST.AggregateType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COUNT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOTAL', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AVERAGE', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MIN', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MAX', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GROUPVALUE', index=6, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BODYROWS', index=7, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INDIRECT', index=8, number=11,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=35247,
  serialized_end=35369,
)
_sym_db.RegisterEnumDescriptor(_AGGREGATETYPE)

AggregateType = enum_type_wrapper.EnumTypeWrapper(_AGGREGATETYPE)
genericCellType = 0
spanCellType = 1
numberCellType = 2
textCellType = 3
formulaCellType = 4
dateCellType = 5
boolCellType = 6
durationCellType = 7
formulaErrorCellType = 8
automaticCellType = 9
emptyCellValueType = 0
numberCellValueType = 1
stringCellValueType = 2
providedCellValueType = 3
dateCellValueType = 4
boolCellValueType = 5
durationCellValueType = 6
errorCellValueType = 7
richTextCellType = 8
currencyCellValueType = 9
dimensionRow = 0
dimensionColumn = 1
deprecatedCellSelectionType = 0
rowSelectionType = 1
columnSelectionType = 2
deprecatedCellEditingSelectionType = 3
deprecatedTableNameSelectionType = 4
deprecatedTableSelectionType = 5
regionSelectionType = 6
noSelectionType = 7
kTSTFillDownArchive = 1
kTSTFillUpArchive = 2
kTSTFillRightArchive = 3
kTSTFillLeftArchive = 4
mergeActionInsert = 1
mergeActionRemove = 2
mergeActionShrink = 3
mergeActionGrow = 4
hideShowActionHide = 0
hideShowActionShow = 1
UNIQUE = 0
YEAR = 1
MONTH = 2
DAYOFWEEK = 3
DAY = 4
YEARWEEK = 5
YEARQUARTER = 6
ROUND_0 = 10
NONE = 0
COUNT = 1
TOTAL = 2
AVERAGE = 3
MIN = 4
MAX = 5
GROUPVALUE = 9
BODYROWS = 10
INDIRECT = 11

IMPORT_WARNING_SET_FIELD_NUMBER = 500
import_warning_set = _descriptor.FieldDescriptor(
  name='import_warning_set', full_name='TST.import_warning_set', index=0,
  number=500, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR)
FORMAT_AND_VALUE_FIELD_NUMBER = 501
format_and_value = _descriptor.FieldDescriptor(
  name='format_and_value', full_name='TST.format_and_value', index=1,
  number=501, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR)
CELL_BORDER_FIELD_NUMBER = 503
cell_border = _descriptor.FieldDescriptor(
  name='cell_border', full_name='TST.cell_border', index=2,
  number=503, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR)
COMMENT_STORAGE_FIELD_NUMBER = 504
comment_storage = _descriptor.FieldDescriptor(
  name='comment_storage', full_name='TST.comment_storage', index=3,
  number=504, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR)
CELL_SPEC_FIELD_NUMBER = 505
cell_spec = _descriptor.FieldDescriptor(
  name='cell_spec', full_name='TST.cell_spec', index=4,
  number=505, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR)

_POPUPMENUMODEL_CELLVALUETYPE = _descriptor.EnumDescriptor(
  name='CellValueType',
  full_name='TST.PopUpMenuModel.CellValueType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NIL_TYPE', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BOOLEAN_TYPE', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DATE_TYPE', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NUMBER_TYPE', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STRING_TYPE', index=4, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2105,
  serialized_end=2201,
)
_sym_db.RegisterEnumDescriptor(_POPUPMENUMODEL_CELLVALUETYPE)

_IMPORTWARNINGSETARCHIVE_FORMULAWARNINGTYPE = _descriptor.EnumDescriptor(
  name='FormulaWarningType',
  full_name='TST.ImportWarningSetArchive.FormulaWarningType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='THREE_D_REFERENCE', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ARRAYED_FORMULA', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DIFFERENT_BEHAVIOR_FOR_FUNCTION', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_TOKEN', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXTERNAL_REFERENCE', index=4, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NATURAL_LANGUAGE_FORMULA', index=5, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REFERENCE_OUT_OF_BOUNDS', index=6, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHARED_FORMULA_BASE_NOT_FOUND', index=7, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_NAME', index=8, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNSUPPORTED_FORMULA', index=9, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNSUPPORTED_FUNCTION', index=10, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNSUPPORTED_NAME', index=11, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRANSPOSED_NO_ISSUES', index=12, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRANSPOSED_WITH_ISSUES', index=13, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRANSPOSED_WITH_ISSUES_UNCHANGED', index=14, number=15,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3138,
  serialized_end=3557,
)
_sym_db.RegisterEnumDescriptor(_IMPORTWARNINGSETARCHIVE_FORMULAWARNINGTYPE)

_TABLEDATALIST_LISTTYPE = _descriptor.EnumDescriptor(
  name='ListType',
  full_name='TST.TableDataList.ListType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STRING', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FORMAT', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FORMULA', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STYLE', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FORMULA_ERROR', index=4, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CUSTOM_FORMAT', index=5, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MULTIPLE_CHOICE_LIST_FORMAT', index=6, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RICH_TEXT_PAYLOAD', index=7, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONDITIONAL_STYLE', index=8, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMMENT_STORAGE', index=9, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IMPORT_WARNING', index=10, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONTROL_CELL_SPEC', index=11, number=12,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4382,
  serialized_end=4621,
)
_sym_db.RegisterEnumDescriptor(_TABLEDATALIST_LISTTYPE)

_TABLESORTORDERARCHIVE_SORTRULEARCHIVE_DIRECTION = _descriptor.EnumDescriptor(
  name='Direction',
  full_name='TST.TableSortOrderArchive.SortRuleArchive.Direction',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ascending', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='descending', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8556,
  serialized_end=8598,
)
_sym_db.RegisterEnumDescriptor(_TABLESORTORDERARCHIVE_SORTRULEARCHIVE_DIRECTION)

_TABLESORTORDERARCHIVE_SORTTYPE = _descriptor.EnumDescriptor(
  name='SortType',
  full_name='TST.TableSortOrderArchive.SortType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='entire_table', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='row_range', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8600,
  serialized_end=8643,
)
_sym_db.RegisterEnumDescriptor(_TABLESORTORDERARCHIVE_SORTTYPE)

_TABLESORTORDERUIDARCHIVE_SORTRULEARCHIVE_DIRECTION = _descriptor.EnumDescriptor(
  name='Direction',
  full_name='TST.TableSortOrderUIDArchive.SortRuleArchive.Direction',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ascending', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='descending', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8556,
  serialized_end=8598,
)
_sym_db.RegisterEnumDescriptor(_TABLESORTORDERUIDARCHIVE_SORTRULEARCHIVE_DIRECTION)

_TABLESORTORDERUIDARCHIVE_SORTTYPE = _descriptor.EnumDescriptor(
  name='SortType',
  full_name='TST.TableSortOrderUIDArchive.SortType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='entire_table', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='row_range', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8600,
  serialized_end=8643,
)
_sym_db.RegisterEnumDescriptor(_TABLESORTORDERUIDARCHIVE_SORTTYPE)

_FORMULAPREDICATEARCHIVE_FORMULAPREDICATETYPE = _descriptor.EnumDescriptor(
  name='FormulaPredicateType',
  full_name='TST.FormulaPredicateArchive.FormulaPredicateType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PredNone', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TextStartsWith', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TextEndsWith', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TextContains', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TextDoesNotContain', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ValueEqual', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ValueNotEqual', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ValueGreaterThan', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ValueGreaterThanOrEqual', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ValueLessThan', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ValueLessThanOrEqual', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ValueAboveAverage', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ValueBelowAverage', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ValueBetween', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Formula', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Duplicates', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Uniques', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DateIsToday', index=17, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DateIsYesterday', index=18, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DateIsTomorrow', index=19, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DateIsTheDate', index=20, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DateBeforeTheDate', index=21, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DateAfterTheDate', index=22, number=22,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DateIsInTheRange', index=23, number=23,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DateInTheNext', index=24, number=24,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DateInTheLast', index=25, number=25,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DateIsExactly', index=26, number=26,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DateBeforeRelative', index=27, number=27,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DateAfterRelative', index=28, number=28,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DateBetweenRelative', index=29, number=29,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ValueTop', index=30, number=30,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ValueBottom', index=31, number=31,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ValueNotBetween', index=32, number=32,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DateInThis', index=33, number=33,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IsBlank', index=34, number=34,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IsNotBlank', index=35, number=35,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TextIs', index=36, number=36,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TextIsNot', index=37, number=37,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DurationEqual', index=38, number=38,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DurationNotEqual', index=39, number=39,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DurationGreaterThan', index=40, number=40,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DurationGreaterThanOrEqual', index=41, number=41,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DurationLessThan', index=42, number=42,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DurationLessThanOrEqual', index=43, number=43,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DurationBetween', index=44, number=44,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DurationNotBetween', index=45, number=45,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DurationAboveAverage', index=46, number=46,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DurationBelowAverage', index=47, number=47,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DurationTop', index=48, number=48,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DurationBottom', index=49, number=49,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=20708,
  serialized_end=21741,
)
_sym_db.RegisterEnumDescriptor(_FORMULAPREDICATEARCHIVE_FORMULAPREDICATETYPE)

_FORMULAPREDICATEARCHIVE_QUALIFIERTYPE = _descriptor.EnumDescriptor(
  name='QualifierType',
  full_name='TST.FormulaPredicateArchive.QualifierType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='QualNone', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Days', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Weeks', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Months', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Years', index=4, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Ago', index=5, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FromNow', index=6, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Quarters', index=7, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Percent', index=8, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Values', index=9, number=10,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=21744,
  serialized_end=21878,
)
_sym_db.RegisterEnumDescriptor(_FORMULAPREDICATEARCHIVE_QUALIFIERTYPE)

_FILTERSETARCHIVE_FILTERSETTYPE = _descriptor.EnumDescriptor(
  name='FilterSetType',
  full_name='TST.FilterSetArchive.FilterSetType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FilterSetArchiveTypeAll', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FilterSetArchiveTypeAny', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=22379,
  serialized_end=22452,
)
_sym_db.RegisterEnumDescriptor(_FILTERSETARCHIVE_FILTERSETTYPE)

_HIDDENSTATEEXTENTARCHIVE_ROWORCOLUMNDIRECTION = _descriptor.EnumDescriptor(
  name='RowOrColumnDirection',
  full_name='TST.HiddenStateExtentArchive.RowOrColumnDirection',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ColumnDirection', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RowDirection', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=22917,
  serialized_end=22978,
)
_sym_db.RegisterEnumDescriptor(_HIDDENSTATEEXTENTARCHIVE_ROWORCOLUMNDIRECTION)

_MULTITABLEREMAPPERARCHIVE_PURPOSE = _descriptor.EnumDescriptor(
  name='Purpose',
  full_name='TST.MultiTableRemapperArchive.Purpose',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DEFAULT', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GROUPING', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PAGES_SECTION_DUPLICATION_NONCOLLAB', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=31907,
  serialized_end=31984,
)
_sym_db.RegisterEnumDescriptor(_MULTITABLEREMAPPERARCHIVE_PURPOSE)


_CELLID = _descriptor.Descriptor(
  name='CellID',
  full_name='TST.CellID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='packedData', full_name='TST.CellID.packedData', index=0,
      number=1, type=7, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expanded_coord', full_name='TST.CellID.expanded_coord', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=175,
  serialized_end=256,
)


_CELLUIDLOOKUPLISTARCHIVE = _descriptor.Descriptor(
  name='CellUIDLookupListArchive',
  full_name='TST.CellUIDLookupListArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='column_uids', full_name='TST.CellUIDLookupListArchive.column_uids', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row_uids', full_name='TST.CellUIDLookupListArchive.row_uids', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column_indexes', full_name='TST.CellUIDLookupListArchive.column_indexes', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row_indexes', full_name='TST.CellUIDLookupListArchive.row_indexes', index=3,
      number=4, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=259,
  serialized_end=425,
)


_CELLUIDLISTARCHIVE = _descriptor.Descriptor(
  name='CellUIDListArchive',
  full_name='TST.CellUIDListArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='row_uids', full_name='TST.CellUIDListArchive.row_uids', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column_uids', full_name='TST.CellUIDListArchive.column_uids', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='compressed_row_indexes', full_name='TST.CellUIDListArchive.compressed_row_indexes', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='compressed_column_indexes', full_name='TST.CellUIDListArchive.compressed_column_indexes', index=3,
      number=4, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uncompressed_lookup_list', full_name='TST.CellUIDListArchive.uncompressed_lookup_list', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=428,
  serialized_end=641,
)


_TABLESIZE = _descriptor.Descriptor(
  name='TableSize',
  full_name='TST.TableSize',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='packedData', full_name='TST.TableSize.packedData', index=0,
      number=1, type=7, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_columns', full_name='TST.TableSize.num_columns', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_rows', full_name='TST.TableSize.num_rows', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=643,
  serialized_end=713,
)


_EXPANDEDTABLESIZE = _descriptor.Descriptor(
  name='ExpandedTableSize',
  full_name='TST.ExpandedTableSize',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='num_columns', full_name='TST.ExpandedTableSize.num_columns', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_rows', full_name='TST.ExpandedTableSize.num_rows', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=715,
  serialized_end=773,
)


_CELLRANGE = _descriptor.Descriptor(
  name='CellRange',
  full_name='TST.CellRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='origin', full_name='TST.CellRange.origin', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='TST.CellRange.size', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=775,
  serialized_end=845,
)


_EXPANDEDCELLRANGE = _descriptor.Descriptor(
  name='ExpandedCellRange',
  full_name='TST.ExpandedCellRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='origin', full_name='TST.ExpandedCellRange.origin', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='TST.ExpandedCellRange.size', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=847,
  serialized_end=949,
)


_TABLESELECTION = _descriptor.Descriptor(
  name='TableSelection',
  full_name='TST.TableSelection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cellRange', full_name='TST.TableSelection.cellRange', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extendedCellRange', full_name='TST.TableSelection.extendedCellRange', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extendedCellRangeValid', full_name='TST.TableSelection.extendedCellRangeValid', index=2,
      number=3, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='selection_type', full_name='TST.TableSelection.selection_type', index=3,
      number=4, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=952,
  serialized_end=1129,
)


_TILEROWINFO = _descriptor.Descriptor(
  name='TileRowInfo',
  full_name='TST.TileRowInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tile_row_index', full_name='TST.TileRowInfo.tile_row_index', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_count', full_name='TST.TileRowInfo.cell_count', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_storage_buffer_pre_bnc', full_name='TST.TileRowInfo.cell_storage_buffer_pre_bnc', index=2,
      number=3, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_offsets_pre_bnc', full_name='TST.TileRowInfo.cell_offsets_pre_bnc', index=3,
      number=4, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='storage_version', full_name='TST.TileRowInfo.storage_version', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_storage_buffer', full_name='TST.TileRowInfo.cell_storage_buffer', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_offsets', full_name='TST.TileRowInfo.cell_offsets', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='has_wide_offsets', full_name='TST.TileRowInfo.has_wide_offsets', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1132,
  serialized_end=1358,
)


_TILE = _descriptor.Descriptor(
  name='Tile',
  full_name='TST.Tile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='maxColumn', full_name='TST.Tile.maxColumn', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maxRow', full_name='TST.Tile.maxRow', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numCells', full_name='TST.Tile.numCells', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numrows', full_name='TST.Tile.numrows', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rowInfos', full_name='TST.Tile.rowInfos', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='storage_version', full_name='TST.Tile.storage_version', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_saved_in_BNC', full_name='TST.Tile.last_saved_in_BNC', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='should_use_wide_rows', full_name='TST.Tile.should_use_wide_rows', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1361,
  serialized_end=1555,
)


_TILESTORAGE_TILE = _descriptor.Descriptor(
  name='Tile',
  full_name='TST.TileStorage.Tile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tileid', full_name='TST.TileStorage.Tile.tileid', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tile', full_name='TST.TileStorage.Tile.tile', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1660,
  serialized_end=1712,
)

_TILESTORAGE = _descriptor.Descriptor(
  name='TileStorage',
  full_name='TST.TileStorage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tiles', full_name='TST.TileStorage.tiles', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tile_size', full_name='TST.TileStorage.tile_size', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='should_use_wide_rows', full_name='TST.TileStorage.should_use_wide_rows', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_TILESTORAGE_TILE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1558,
  serialized_end=1712,
)


_POPUPMENUMODEL_CELLVALUE = _descriptor.Descriptor(
  name='CellValue',
  full_name='TST.PopUpMenuModel.CellValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cell_value_type', full_name='TST.PopUpMenuModel.CellValue.cell_value_type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='boolean_value', full_name='TST.PopUpMenuModel.CellValue.boolean_value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date_value', full_name='TST.PopUpMenuModel.CellValue.date_value', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='number_value', full_name='TST.PopUpMenuModel.CellValue.number_value', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='string_value', full_name='TST.PopUpMenuModel.CellValue.string_value', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1826,
  serialized_end=2103,
)

_POPUPMENUMODEL = _descriptor.Descriptor(
  name='PopUpMenuModel',
  full_name='TST.PopUpMenuModel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='TST.PopUpMenuModel.item', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tsce_item', full_name='TST.PopUpMenuModel.tsce_item', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_POPUPMENUMODEL_CELLVALUE, ],
  enum_types=[
    _POPUPMENUMODEL_CELLVALUETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1715,
  serialized_end=2201,
)


_IMPORTWARNINGSETARCHIVE_FORMULAIMPORTWARNING = _descriptor.Descriptor(
  name='FormulaImportWarning',
  full_name='TST.ImportWarningSetArchive.FormulaImportWarning',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='formula_warning_type', full_name='TST.ImportWarningSetArchive.FormulaImportWarning.formula_warning_type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='original_formula', full_name='TST.ImportWarningSetArchive.FormulaImportWarning.original_formula', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='supplementary_text', full_name='TST.ImportWarningSetArchive.FormulaImportWarning.supplementary_text', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formula_warning_type_int', full_name='TST.ImportWarningSetArchive.FormulaImportWarning.formula_warning_type_int', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2946,
  serialized_end=3135,
)

_IMPORTWARNINGSETARCHIVE = _descriptor.Descriptor(
  name='ImportWarningSetArchive',
  full_name='TST.ImportWarningSetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='formula_import_warning', full_name='TST.ImportWarningSetArchive.formula_import_warning', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cond_format_above_avg_equal_avg', full_name='TST.ImportWarningSetArchive.cond_format_above_avg_equal_avg', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cond_format_above_avg_std_dev', full_name='TST.ImportWarningSetArchive.cond_format_above_avg_std_dev', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cond_format_complex_formula', full_name='TST.ImportWarningSetArchive.cond_format_complex_formula', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cond_format_contains_errors', full_name='TST.ImportWarningSetArchive.cond_format_contains_errors', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cond_format_expr', full_name='TST.ImportWarningSetArchive.cond_format_expr', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cond_format_not_contains_errors', full_name='TST.ImportWarningSetArchive.cond_format_not_contains_errors', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cond_format_parameters_not_all_same_type', full_name='TST.ImportWarningSetArchive.cond_format_parameters_not_all_same_type', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cond_format_stop_if_true', full_name='TST.ImportWarningSetArchive.cond_format_stop_if_true', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cond_format_unsupported_operator', full_name='TST.ImportWarningSetArchive.cond_format_unsupported_operator', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cond_format_unsupported_styling', full_name='TST.ImportWarningSetArchive.cond_format_unsupported_styling', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cond_format_unsupported_time_period', full_name='TST.ImportWarningSetArchive.cond_format_unsupported_time_period', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error_cell_with_no_formula', full_name='TST.ImportWarningSetArchive.error_cell_with_no_formula', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unsupported_cond_format', full_name='TST.ImportWarningSetArchive.unsupported_cond_format', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='original_data_format', full_name='TST.ImportWarningSetArchive.original_data_format', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formula_warning_filtered_column_formula_not_copied', full_name='TST.ImportWarningSetArchive.formula_warning_filtered_column_formula_not_copied', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration_format_range_changed', full_name='TST.ImportWarningSetArchive.duration_format_range_changed', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_IMPORTWARNINGSETARCHIVE_FORMULAIMPORTWARNING, ],
  enum_types=[
    _IMPORTWARNINGSETARCHIVE_FORMULAWARNINGTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2204,
  serialized_end=3557,
)


_CELLREFIMPORTWARNINGSETPAIRARCHIVE = _descriptor.Descriptor(
  name='CellRefImportWarningSetPairArchive',
  full_name='TST.CellRefImportWarningSetPairArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cell_ref', full_name='TST.CellRefImportWarningSetPairArchive.cell_ref', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='warning_set', full_name='TST.CellRefImportWarningSetPairArchive.warning_set', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3560,
  serialized_end=3693,
)


_IMPORTWARNINGSETBYCELLREFARCHIVE = _descriptor.Descriptor(
  name='ImportWarningSetByCellRefArchive',
  full_name='TST.ImportWarningSetByCellRefArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cellref_warning_set_pair', full_name='TST.ImportWarningSetByCellRefArchive.cellref_warning_set_pair', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3695,
  serialized_end=3804,
)


_TABLEDATALIST_LISTENTRY = _descriptor.Descriptor(
  name='ListEntry',
  full_name='TST.TableDataList.ListEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='TST.TableDataList.ListEntry.key', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='refcount', full_name='TST.TableDataList.ListEntry.refcount', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='string', full_name='TST.TableDataList.ListEntry.string', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reference', full_name='TST.TableDataList.ListEntry.reference', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formula', full_name='TST.TableDataList.ListEntry.formula', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='format', full_name='TST.TableDataList.ListEntry.format', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_format', full_name='TST.TableDataList.ListEntry.custom_format', index=6,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rich_text_payload', full_name='TST.TableDataList.ListEntry.rich_text_payload', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='comment_storage', full_name='TST.TableDataList.ListEntry.comment_storage', index=8,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='import_warning_set', full_name='TST.TableDataList.ListEntry.import_warning_set', index=9,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_spec', full_name='TST.TableDataList.ListEntry.cell_spec', index=10,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3973,
  serialized_end=4379,
)

_TABLEDATALIST = _descriptor.Descriptor(
  name='TableDataList',
  full_name='TST.TableDataList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='listType', full_name='TST.TableDataList.listType', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nextListID', full_name='TST.TableDataList.nextListID', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entries', full_name='TST.TableDataList.entries', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='segments', full_name='TST.TableDataList.segments', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_TABLEDATALIST_LISTENTRY, ],
  enum_types=[
    _TABLEDATALIST_LISTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3807,
  serialized_end=4621,
)


_TABLEDATALISTSEGMENT = _descriptor.Descriptor(
  name='TableDataListSegment',
  full_name='TST.TableDataListSegment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='list_type', full_name='TST.TableDataListSegment.list_type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='key_range', full_name='TST.TableDataListSegment.key_range', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entries', full_name='TST.TableDataListSegment.entries', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4624,
  serialized_end=4772,
)


_TABLERBTREE_NODE = _descriptor.Descriptor(
  name='Node',
  full_name='TST.TableRBTree.Node',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='TST.TableRBTree.Node.key', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='TST.TableRBTree.Node.value', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4827,
  serialized_end=4861,
)

_TABLERBTREE = _descriptor.Descriptor(
  name='TableRBTree',
  full_name='TST.TableRBTree',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nodes', full_name='TST.TableRBTree.nodes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_TABLERBTREE_NODE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4774,
  serialized_end=4861,
)


_HEADERSTORAGEBUCKET_HEADER = _descriptor.Descriptor(
  name='Header',
  full_name='TST.HeaderStorageBucket.Header',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='TST.HeaderStorageBucket.Header.index', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='TST.HeaderStorageBucket.Header.size', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hidingState', full_name='TST.HeaderStorageBucket.Header.hidingState', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numberOfCells', full_name='TST.HeaderStorageBucket.Header.numberOfCells', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_style', full_name='TST.HeaderStorageBucket.Header.cell_style', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text_style', full_name='TST.HeaderStorageBucket.Header.text_style', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4966,
  serialized_end=5119,
)

_HEADERSTORAGEBUCKET = _descriptor.Descriptor(
  name='HeaderStorageBucket',
  full_name='TST.HeaderStorageBucket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='bucketHashFunction', full_name='TST.HeaderStorageBucket.bucketHashFunction', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='headers', full_name='TST.HeaderStorageBucket.headers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_HEADERSTORAGEBUCKET_HEADER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4864,
  serialized_end=5119,
)


_HEADERSTORAGE = _descriptor.Descriptor(
  name='HeaderStorage',
  full_name='TST.HeaderStorage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='bucketHashFunction', full_name='TST.HeaderStorage.bucketHashFunction', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='buckets', full_name='TST.HeaderStorage.buckets', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5121,
  serialized_end=5197,
)


_DATASTORE = _descriptor.Descriptor(
  name='DataStore',
  full_name='TST.DataStore',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rowHeaders', full_name='TST.DataStore.rowHeaders', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='columnHeaders', full_name='TST.DataStore.columnHeaders', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tiles', full_name='TST.DataStore.tiles', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stringTable', full_name='TST.DataStore.stringTable', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='styleTable', full_name='TST.DataStore.styleTable', index=4,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formula_table', full_name='TST.DataStore.formula_table', index=5,
      number=6, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formulaErrorTable', full_name='TST.DataStore.formulaErrorTable', index=6,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='format_table_pre_bnc', full_name='TST.DataStore.format_table_pre_bnc', index=7,
      number=11, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='multipleChoiceListFormatTable', full_name='TST.DataStore.multipleChoiceListFormatTable', index=8,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='merge_region_map', full_name='TST.DataStore.merge_region_map', index=9,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='customFormatTable', full_name='TST.DataStore.customFormatTable', index=10,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nextRowStripID', full_name='TST.DataStore.nextRowStripID', index=11,
      number=7, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nextColumnStripID', full_name='TST.DataStore.nextColumnStripID', index=12,
      number=8, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rowTileTree', full_name='TST.DataStore.rowTileTree', index=13,
      number=9, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='columnTileTree', full_name='TST.DataStore.columnTileTree', index=14,
      number=10, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='storage_version_pre_bnc', full_name='TST.DataStore.storage_version_pre_bnc', index=15,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rich_text_table', full_name='TST.DataStore.rich_text_table', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conditionalstyletable', full_name='TST.DataStore.conditionalstyletable', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commentStorageTable', full_name='TST.DataStore.commentStorageTable', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='importWarningSetTable', full_name='TST.DataStore.importWarningSetTable', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='control_cell_spec_table', full_name='TST.DataStore.control_cell_spec_table', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='format_table', full_name='TST.DataStore.format_table', index=21,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5200,
  serialized_end=6096,
)


_TABLEINFOARCHIVE = _descriptor.Descriptor(
  name='TableInfoArchive',
  full_name='TST.TableInfoArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.TableInfoArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tableModel', full_name='TST.TableInfoArchive.tableModel', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='editing_state', full_name='TST.TableInfoArchive.editing_state', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='summary_model', full_name='TST.TableInfoArchive.summary_model', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_order', full_name='TST.TableInfoArchive.category_order', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='view_column_row_uids', full_name='TST.TableInfoArchive.view_column_row_uids', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group_by_uuid', full_name='TST.TableInfoArchive.group_by_uuid', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hidden_states_uuid', full_name='TST.TableInfoArchive.hidden_states_uuid', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formula_coord_space_in_pre40', full_name='TST.TableInfoArchive.formula_coord_space_in_pre40', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formula_coord_space', full_name='TST.TableInfoArchive.formula_coord_space', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pasteboard_coord_mapper', full_name='TST.TableInfoArchive.pasteboard_coord_mapper', index=10,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='master_layout', full_name='TST.TableInfoArchive.master_layout', index=11,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6099,
  serialized_end=6610,
)


_CATEGORYINFOARCHIVE = _descriptor.Descriptor(
  name='CategoryInfoArchive',
  full_name='TST.CategoryInfoArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CategoryInfoArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tableModel', full_name='TST.CategoryInfoArchive.tableModel', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6612,
  serialized_end=6706,
)


_WPTABLEINFOARCHIVE = _descriptor.Descriptor(
  name='WPTableInfoArchive',
  full_name='TST.WPTableInfoArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.WPTableInfoArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='storage', full_name='TST.WPTableInfoArchive.storage', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6708,
  serialized_end=6799,
)


_TABLESTYLENETWORKARCHIVE = _descriptor.Descriptor(
  name='TableStyleNetworkArchive',
  full_name='TST.TableStyleNetworkArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='table_style', full_name='TST.TableStyleNetworkArchive.table_style', index=0,
      number=9, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='body_text_style', full_name='TST.TableStyleNetworkArchive.body_text_style', index=1,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_row_text_style', full_name='TST.TableStyleNetworkArchive.header_row_text_style', index=2,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_column_text_style', full_name='TST.TableStyleNetworkArchive.header_column_text_style', index=3,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='footer_row_text_style', full_name='TST.TableStyleNetworkArchive.footer_row_text_style', index=4,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level_1_text_style', full_name='TST.TableStyleNetworkArchive.category_level_1_text_style', index=5,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level_2_text_style', full_name='TST.TableStyleNetworkArchive.category_level_2_text_style', index=6,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level_3_text_style', full_name='TST.TableStyleNetworkArchive.category_level_3_text_style', index=7,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level_4_text_style', full_name='TST.TableStyleNetworkArchive.category_level_4_text_style', index=8,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level_5_text_style', full_name='TST.TableStyleNetworkArchive.category_level_5_text_style', index=9,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_level_1_text_style', full_name='TST.TableStyleNetworkArchive.label_level_1_text_style', index=10,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_level_2_text_style', full_name='TST.TableStyleNetworkArchive.label_level_2_text_style', index=11,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_level_3_text_style', full_name='TST.TableStyleNetworkArchive.label_level_3_text_style', index=12,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_level_4_text_style', full_name='TST.TableStyleNetworkArchive.label_level_4_text_style', index=13,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_level_5_text_style', full_name='TST.TableStyleNetworkArchive.label_level_5_text_style', index=14,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='body_cell_style', full_name='TST.TableStyleNetworkArchive.body_cell_style', index=15,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_row_style', full_name='TST.TableStyleNetworkArchive.header_row_style', index=16,
      number=6, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_column_style', full_name='TST.TableStyleNetworkArchive.header_column_style', index=17,
      number=7, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='footer_row_style', full_name='TST.TableStyleNetworkArchive.footer_row_style', index=18,
      number=8, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level_1_style', full_name='TST.TableStyleNetworkArchive.category_level_1_style', index=19,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level_2_style', full_name='TST.TableStyleNetworkArchive.category_level_2_style', index=20,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level_3_style', full_name='TST.TableStyleNetworkArchive.category_level_3_style', index=21,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level_4_style', full_name='TST.TableStyleNetworkArchive.category_level_4_style', index=22,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level_5_style', full_name='TST.TableStyleNetworkArchive.category_level_5_style', index=23,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_level_1_style', full_name='TST.TableStyleNetworkArchive.label_level_1_style', index=24,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_level_2_style', full_name='TST.TableStyleNetworkArchive.label_level_2_style', index=25,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_level_3_style', full_name='TST.TableStyleNetworkArchive.label_level_3_style', index=26,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_level_4_style', full_name='TST.TableStyleNetworkArchive.label_level_4_style', index=27,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_level_5_style', full_name='TST.TableStyleNetworkArchive.label_level_5_style', index=28,
      number=32, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_name_style', full_name='TST.TableStyleNetworkArchive.table_name_style', index=29,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_name_shape_style', full_name='TST.TableStyleNetworkArchive.table_name_shape_style', index=30,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preset_id', full_name='TST.TableStyleNetworkArchive.preset_id', index=31,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6802,
  serialized_end=8309,
)


_TABLESORTORDERARCHIVE_SORTRULEARCHIVE = _descriptor.Descriptor(
  name='SortRuleArchive',
  full_name='TST.TableSortOrderArchive.SortRuleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='column', full_name='TST.TableSortOrderArchive.SortRuleArchive.column', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='direction', full_name='TST.TableSortOrderArchive.SortRuleArchive.direction', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TABLESORTORDERARCHIVE_SORTRULEARCHIVE_DIRECTION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8448,
  serialized_end=8598,
)

_TABLESORTORDERARCHIVE = _descriptor.Descriptor(
  name='TableSortOrderArchive',
  full_name='TST.TableSortOrderArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='TST.TableSortOrderArchive.type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rules', full_name='TST.TableSortOrderArchive.rules', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_TABLESORTORDERARCHIVE_SORTRULEARCHIVE, ],
  enum_types=[
    _TABLESORTORDERARCHIVE_SORTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8312,
  serialized_end=8643,
)


_TABLESORTORDERUIDARCHIVE_SORTRULEARCHIVE = _descriptor.Descriptor(
  name='SortRuleArchive',
  full_name='TST.TableSortOrderUIDArchive.SortRuleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='column_uid', full_name='TST.TableSortOrderUIDArchive.SortRuleArchive.column_uid', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='direction', full_name='TST.TableSortOrderUIDArchive.SortRuleArchive.direction', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TABLESORTORDERUIDARCHIVE_SORTRULEARCHIVE_DIRECTION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8791,
  serialized_end=8959,
)

_TABLESORTORDERUIDARCHIVE = _descriptor.Descriptor(
  name='TableSortOrderUIDArchive',
  full_name='TST.TableSortOrderUIDArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='TST.TableSortOrderUIDArchive.type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rules', full_name='TST.TableSortOrderUIDArchive.rules', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_TABLESORTORDERUIDARCHIVE_SORTRULEARCHIVE, ],
  enum_types=[
    _TABLESORTORDERUIDARCHIVE_SORTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8646,
  serialized_end=9004,
)


_SORTRULEREFERENCETRACKERARCHIVE = _descriptor.Descriptor(
  name='SortRuleReferenceTrackerArchive',
  full_name='TST.SortRuleReferenceTrackerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='reference_tracker', full_name='TST.SortRuleReferenceTrackerArchive.reference_tracker', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9006,
  serialized_end=9082,
)


_CELLREGION = _descriptor.Descriptor(
  name='CellRegion',
  full_name='TST.CellRegion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cell_ranges', full_name='TST.CellRegion.cell_ranges', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9084,
  serialized_end=9133,
)


_CELLUIDREGIONARCHIVE = _descriptor.Descriptor(
  name='CellUIDRegionArchive',
  full_name='TST.CellUIDRegionArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cell_uid_ranges', full_name='TST.CellUIDRegionArchive.cell_uid_ranges', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9135,
  serialized_end=9204,
)


_STRUCTUREDTEXTIMPORTRECORD = _descriptor.Descriptor(
  name='StructuredTextImportRecord',
  full_name='TST.StructuredTextImportRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='import_settings', full_name='TST.StructuredTextImportRecord.import_settings', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='import_source', full_name='TST.StructuredTextImportRecord.import_source', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='import_date', full_name='TST.StructuredTextImportRecord.import_date', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source_data', full_name='TST.StructuredTextImportRecord.source_data', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source_encoding', full_name='TST.StructuredTextImportRecord.source_encoding', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='confidence', full_name='TST.StructuredTextImportRecord.confidence', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='imported_region', full_name='TST.StructuredTextImportRecord.imported_region', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source_row_count', full_name='TST.StructuredTextImportRecord.source_row_count', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source_column_count', full_name='TST.StructuredTextImportRecord.source_column_count', index=8,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9207,
  serialized_end=9502,
)


_TABLEMODELARCHIVE = _descriptor.Descriptor(
  name='TableModelArchive',
  full_name='TST.TableModelArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='table_id', full_name='TST.TableModelArchive.table_id', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='from_table_id', full_name='TST.TableModelArchive.from_table_id', index=1,
      number=43, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='was_cut', full_name='TST.TableModelArchive.was_cut', index=2,
      number=50, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_style', full_name='TST.TableModelArchive.table_style', index=3,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='body_text_style', full_name='TST.TableModelArchive.body_text_style', index=4,
      number=24, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_row_text_style', full_name='TST.TableModelArchive.header_row_text_style', index=5,
      number=25, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_column_text_style', full_name='TST.TableModelArchive.header_column_text_style', index=6,
      number=26, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='footer_row_text_style', full_name='TST.TableModelArchive.footer_row_text_style', index=7,
      number=27, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='body_cell_style', full_name='TST.TableModelArchive.body_cell_style', index=8,
      number=18, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_row_style', full_name='TST.TableModelArchive.header_row_style', index=9,
      number=19, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_column_style', full_name='TST.TableModelArchive.header_column_style', index=10,
      number=20, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='footer_row_style', full_name='TST.TableModelArchive.footer_row_style', index=11,
      number=21, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_name_style', full_name='TST.TableModelArchive.table_name_style', index=12,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_name_shape_style', full_name='TST.TableModelArchive.table_name_shape_style', index=13,
      number=36, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_style_preset', full_name='TST.TableModelArchive.table_style_preset', index=14,
      number=48, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preset_index', full_name='TST.TableModelArchive.preset_index', index=15,
      number=28, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='base_data_store', full_name='TST.TableModelArchive.base_data_store', index=16,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='provider', full_name='TST.TableModelArchive.provider', index=17,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='number_of_rows', full_name='TST.TableModelArchive.number_of_rows', index=18,
      number=6, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='number_of_columns', full_name='TST.TableModelArchive.number_of_columns', index=19,
      number=7, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_name', full_name='TST.TableModelArchive.table_name', index=20,
      number=8, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_name_enabled', full_name='TST.TableModelArchive.table_name_enabled', index=21,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_name_height', full_name='TST.TableModelArchive.table_name_height', index=22,
      number=33, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_name_border_enabled', full_name='TST.TableModelArchive.table_name_border_enabled', index=23,
      number=37, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='number_of_header_rows', full_name='TST.TableModelArchive.number_of_header_rows', index=24,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='number_of_header_columns', full_name='TST.TableModelArchive.number_of_header_columns', index=25,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='number_of_footer_rows', full_name='TST.TableModelArchive.number_of_footer_rows', index=26,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_rows_frozen', full_name='TST.TableModelArchive.header_rows_frozen', index=27,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_columns_frozen', full_name='TST.TableModelArchive.header_columns_frozen', index=28,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='number_of_hidden_rows', full_name='TST.TableModelArchive.number_of_hidden_rows', index=29,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='number_of_hidden_columns', full_name='TST.TableModelArchive.number_of_hidden_columns', index=30,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='number_of_user_hidden_rows', full_name='TST.TableModelArchive.number_of_user_hidden_rows', index=31,
      number=41, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='number_of_user_hidden_columns', full_name='TST.TableModelArchive.number_of_user_hidden_columns', index=32,
      number=42, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='number_of_filtered_rows', full_name='TST.TableModelArchive.number_of_filtered_rows', index=33,
      number=40, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_row_height', full_name='TST.TableModelArchive.default_row_height', index=34,
      number=16, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_column_width', full_name='TST.TableModelArchive.default_column_width', index=35,
      number=17, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='origin_offset', full_name='TST.TableModelArchive.origin_offset', index=36,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repeating_header_rows_enabled', full_name='TST.TableModelArchive.repeating_header_rows_enabled', index=37,
      number=29, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repeating_header_columns_enabled', full_name='TST.TableModelArchive.repeating_header_columns_enabled', index=38,
      number=32, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='style_apply_clears_all', full_name='TST.TableModelArchive.style_apply_clears_all', index=39,
      number=31, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hidden_state_formula_owner_for_columns', full_name='TST.TableModelArchive.hidden_state_formula_owner_for_columns', index=40,
      number=34, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hidden_state_formula_owner_for_rows', full_name='TST.TableModelArchive.hidden_state_formula_owner_for_rows', index=41,
      number=35, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filter_set', full_name='TST.TableModelArchive.filter_set', index=42,
      number=38, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conditional_style_formula_owner_id', full_name='TST.TableModelArchive.conditional_style_formula_owner_id', index=43,
      number=39, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sort_order', full_name='TST.TableModelArchive.sort_order', index=44,
      number=44, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sort_rule_reference_tracker', full_name='TST.TableModelArchive.sort_rule_reference_tracker', index=45,
      number=45, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='base_column_row_uids', full_name='TST.TableModelArchive.base_column_row_uids', index=46,
      number=46, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='merge_owner', full_name='TST.TableModelArchive.merge_owner', index=47,
      number=47, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stroke_sidecar', full_name='TST.TableModelArchive.stroke_sidecar', index=48,
      number=49, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preset_needs_strong_ownership', full_name='TST.TableModelArchive.preset_needs_strong_ownership', index=49,
      number=51, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text_import_record', full_name='TST.TableModelArchive.text_import_record', index=50,
      number=52, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level_1_style', full_name='TST.TableModelArchive.category_level_1_style', index=51,
      number=60, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level_2_style', full_name='TST.TableModelArchive.category_level_2_style', index=52,
      number=61, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level_3_style', full_name='TST.TableModelArchive.category_level_3_style', index=53,
      number=62, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level_4_style', full_name='TST.TableModelArchive.category_level_4_style', index=54,
      number=63, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level_5_style', full_name='TST.TableModelArchive.category_level_5_style', index=55,
      number=64, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_level_1_style', full_name='TST.TableModelArchive.label_level_1_style', index=56,
      number=71, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_level_2_style', full_name='TST.TableModelArchive.label_level_2_style', index=57,
      number=72, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_level_3_style', full_name='TST.TableModelArchive.label_level_3_style', index=58,
      number=73, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_level_4_style', full_name='TST.TableModelArchive.label_level_4_style', index=59,
      number=74, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_level_5_style', full_name='TST.TableModelArchive.label_level_5_style', index=60,
      number=75, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level_1_text_style', full_name='TST.TableModelArchive.category_level_1_text_style', index=61,
      number=65, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level_2_text_style', full_name='TST.TableModelArchive.category_level_2_text_style', index=62,
      number=66, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level_3_text_style', full_name='TST.TableModelArchive.category_level_3_text_style', index=63,
      number=67, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level_4_text_style', full_name='TST.TableModelArchive.category_level_4_text_style', index=64,
      number=68, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level_5_text_style', full_name='TST.TableModelArchive.category_level_5_text_style', index=65,
      number=69, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_level_1_text_style', full_name='TST.TableModelArchive.label_level_1_text_style', index=66,
      number=76, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_level_2_text_style', full_name='TST.TableModelArchive.label_level_2_text_style', index=67,
      number=77, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_level_3_text_style', full_name='TST.TableModelArchive.label_level_3_text_style', index=68,
      number=78, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_level_4_text_style', full_name='TST.TableModelArchive.label_level_4_text_style', index=69,
      number=79, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_level_5_text_style', full_name='TST.TableModelArchive.label_level_5_text_style', index=70,
      number=80, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hidden_states_owner', full_name='TST.TableModelArchive.hidden_states_owner', index=71,
      number=70, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_owner', full_name='TST.TableModelArchive.category_owner', index=72,
      number=81, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pencil_annotation_owner', full_name='TST.TableModelArchive.pencil_annotation_owner', index=73,
      number=82, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='from_group_by_uid', full_name='TST.TableModelArchive.from_group_by_uid', index=74,
      number=83, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='haunted_owner', full_name='TST.TableModelArchive.haunted_owner', index=75,
      number=84, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9505,
  serialized_end=12720,
)


_SUMMARYMODELARCHIVE = _descriptor.Descriptor(
  name='SummaryModelArchive',
  full_name='TST.SummaryModelArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='table_info', full_name='TST.SummaryModelArchive.table_info', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_store', full_name='TST.SummaryModelArchive.data_store', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column_row_uids', full_name='TST.SummaryModelArchive.column_row_uids', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aggregate_formula_owner_uuid', full_name='TST.SummaryModelArchive.aggregate_formula_owner_uuid', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='summary_cell_vendor', full_name='TST.SummaryModelArchive.summary_cell_vendor', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_column_width', full_name='TST.SummaryModelArchive.category_column_width', index=5,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='summary_row_level_1_height', full_name='TST.SummaryModelArchive.summary_row_level_1_height', index=6,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='summary_row_level_2_height', full_name='TST.SummaryModelArchive.summary_row_level_2_height', index=7,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='summary_row_level_3_height', full_name='TST.SummaryModelArchive.summary_row_level_3_height', index=8,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='summary_row_level_4_height', full_name='TST.SummaryModelArchive.summary_row_level_4_height', index=9,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='summary_row_level_5_height', full_name='TST.SummaryModelArchive.summary_row_level_5_height', index=10,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='summary_label_row_level_1_height', full_name='TST.SummaryModelArchive.summary_label_row_level_1_height', index=11,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='summary_label_row_level_2_height', full_name='TST.SummaryModelArchive.summary_label_row_level_2_height', index=12,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='summary_label_row_level_3_height', full_name='TST.SummaryModelArchive.summary_label_row_level_3_height', index=13,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='summary_label_row_level_4_height', full_name='TST.SummaryModelArchive.summary_label_row_level_4_height', index=14,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='summary_label_row_level_5_height', full_name='TST.SummaryModelArchive.summary_label_row_level_5_height', index=15,
      number=20, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_row_visibility_1', full_name='TST.SummaryModelArchive.label_row_visibility_1', index=16,
      number=21, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_row_visibility_2', full_name='TST.SummaryModelArchive.label_row_visibility_2', index=17,
      number=22, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_row_visibility_3', full_name='TST.SummaryModelArchive.label_row_visibility_3', index=18,
      number=23, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_row_visibility_4', full_name='TST.SummaryModelArchive.label_row_visibility_4', index=19,
      number=24, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_row_visibility_5', full_name='TST.SummaryModelArchive.label_row_visibility_5', index=20,
      number=25, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='summary_row_height_list', full_name='TST.SummaryModelArchive.summary_row_height_list', index=21,
      number=26, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_row_height_list', full_name='TST.SummaryModelArchive.label_row_height_list', index=22,
      number=27, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_row_visibility_list', full_name='TST.SummaryModelArchive.label_row_visibility_list', index=23,
      number=28, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12723,
  serialized_end=13691,
)


_SUMMARYMODELGROUPBYCHANGESTATEARCHIVE = _descriptor.Descriptor(
  name='SummaryModelGroupByChangeStateArchive',
  full_name='TST.SummaryModelGroupByChangeStateArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cell_map', full_name='TST.SummaryModelGroupByChangeStateArchive.cell_map', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='summary_row_height_list', full_name='TST.SummaryModelGroupByChangeStateArchive.summary_row_height_list', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_row_height_list', full_name='TST.SummaryModelGroupByChangeStateArchive.label_row_height_list', index=2,
      number=3, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_row_visibility_list', full_name='TST.SummaryModelGroupByChangeStateArchive.label_row_visibility_list', index=3,
      number=4, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13694,
  serialized_end=13866,
)


_COLUMNROWUIDMAPARCHIVE = _descriptor.Descriptor(
  name='ColumnRowUIDMapArchive',
  full_name='TST.ColumnRowUIDMapArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sorted_column_uids', full_name='TST.ColumnRowUIDMapArchive.sorted_column_uids', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column_index_for_uid', full_name='TST.ColumnRowUIDMapArchive.column_index_for_uid', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column_uid_for_index', full_name='TST.ColumnRowUIDMapArchive.column_uid_for_index', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sorted_row_uids', full_name='TST.ColumnRowUIDMapArchive.sorted_row_uids', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row_index_for_uid', full_name='TST.ColumnRowUIDMapArchive.row_index_for_uid', index=4,
      number=5, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row_uid_for_index', full_name='TST.ColumnRowUIDMapArchive.row_uid_for_index', index=5,
      number=6, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13869,
  serialized_end=14082,
)


_STROKELAYERARCHIVE_STROKERUNARCHIVE = _descriptor.Descriptor(
  name='StrokeRunArchive',
  full_name='TST.StrokeLayerArchive.StrokeRunArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='origin', full_name='TST.StrokeLayerArchive.StrokeRunArchive.origin', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='length', full_name='TST.StrokeLayerArchive.StrokeRunArchive.length', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stroke', full_name='TST.StrokeLayerArchive.StrokeRunArchive.stroke', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order', full_name='TST.StrokeLayerArchive.StrokeRunArchive.order', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14196,
  serialized_end=14297,
)

_STROKELAYERARCHIVE = _descriptor.Descriptor(
  name='StrokeLayerArchive',
  full_name='TST.StrokeLayerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='row_column_index', full_name='TST.StrokeLayerArchive.row_column_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stroke_runs', full_name='TST.StrokeLayerArchive.stroke_runs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_STROKELAYERARCHIVE_STROKERUNARCHIVE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14085,
  serialized_end=14297,
)


_STROKESIDECARARCHIVE = _descriptor.Descriptor(
  name='StrokeSidecarArchive',
  full_name='TST.StrokeSidecarArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_order', full_name='TST.StrokeSidecarArchive.max_order', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column_count', full_name='TST.StrokeSidecarArchive.column_count', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row_count', full_name='TST.StrokeSidecarArchive.row_count', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='left_column_stroke_layers', full_name='TST.StrokeSidecarArchive.left_column_stroke_layers', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='right_column_stroke_layers', full_name='TST.StrokeSidecarArchive.right_column_stroke_layers', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='top_row_stroke_layers', full_name='TST.StrokeSidecarArchive.top_row_stroke_layers', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bottom_row_stroke_layers', full_name='TST.StrokeSidecarArchive.bottom_row_stroke_layers', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14300,
  serialized_end=14582,
)


_DURATIONWRAPPERARCHIVE = _descriptor.Descriptor(
  name='DurationWrapperArchive',
  full_name='TST.DurationWrapperArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14584,
  serialized_end=14608,
)


_CELL = _descriptor.Descriptor(
  name='Cell',
  full_name='TST.Cell',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='valueType', full_name='TST.Cell.valueType', index=0,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_style', full_name='TST.Cell.cell_style', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text_style', full_name='TST.Cell.text_style', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numberValue', full_name='TST.Cell.numberValue', index=3,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stringValue', full_name='TST.Cell.stringValue', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='boolValue', full_name='TST.Cell.boolValue', index=5,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='current_format', full_name='TST.Cell.current_format', index=6,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formulaError', full_name='TST.Cell.formulaError', index=7,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='number_format', full_name='TST.Cell.number_format', index=8,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency_format', full_name='TST.Cell.currency_format', index=9,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration_format', full_name='TST.Cell.duration_format', index=10,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date_format', full_name='TST.Cell.date_format', index=11,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_format', full_name='TST.Cell.custom_format', index=12,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='base_format', full_name='TST.Cell.base_format', index=13,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='explicit_format_flags', full_name='TST.Cell.explicit_format_flags', index=14,
      number=19, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='richText', full_name='TST.Cell.richText', index=15,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conditional_style', full_name='TST.Cell.conditional_style', index=16,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='comment_storage', full_name='TST.Cell.comment_storage', index=17,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conditional_style_applied_rule', full_name='TST.Cell.conditional_style_applied_rule', index=18,
      number=24, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='import_warning_set', full_name='TST.Cell.import_warning_set', index=19,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_format_object', full_name='TST.Cell.custom_format_object', index=20,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_border', full_name='TST.Cell.cell_border', index=21,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_spec', full_name='TST.Cell.cell_spec', index=22,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_format_kind', full_name='TST.Cell.cell_format_kind', index=23,
      number=29, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text_format', full_name='TST.Cell.text_format', index=24,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='boolean_format', full_name='TST.Cell.boolean_format', index=25,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='decimal_value_low', full_name='TST.Cell.decimal_value_low', index=26,
      number=32, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='decimal_value_high', full_name='TST.Cell.decimal_value_high', index=27,
      number=33, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14611,
  serialized_end=15738,
)


_MERGEREGIONMAPARCHIVE = _descriptor.Descriptor(
  name='MergeRegionMapArchive',
  full_name='TST.MergeRegionMapArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cell_range', full_name='TST.MergeRegionMapArchive.cell_range', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15740,
  serialized_end=15799,
)


_CELLMAPARCHIVE = _descriptor.Descriptor(
  name='CellMapArchive',
  full_name='TST.CellMapArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cell_tiles', full_name='TST.CellMapArchive.cell_tiles', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uid_based', full_name='TST.CellMapArchive.uid_based', index=1,
      number=3, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expanded_cell_ids', full_name='TST.CellMapArchive.expanded_cell_ids', index=2,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_uid_list', full_name='TST.CellMapArchive.cell_uid_list', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='merge_uid_ranges', full_name='TST.CellMapArchive.merge_uid_ranges', index=4,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unmerge_uid_ranges', full_name='TST.CellMapArchive.unmerge_uid_ranges', index=5,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='merge_actions', full_name='TST.CellMapArchive.merge_actions', index=6,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='may_modify_formulas_in_cells', full_name='TST.CellMapArchive.may_modify_formulas_in_cells', index=7,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='may_modify_values_referenced_by_formulas', full_name='TST.CellMapArchive.may_modify_values_referenced_by_formulas', index=8,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15802,
  serialized_end=16226,
)


_CELLLISTARCHIVE_OPTIONALCELL = _descriptor.Descriptor(
  name='OptionalCell',
  full_name='TST.CellListArchive.OptionalCell',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cell', full_name='TST.CellListArchive.OptionalCell.cell', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16333,
  serialized_end=16372,
)

_CELLLISTARCHIVE = _descriptor.Descriptor(
  name='CellListArchive',
  full_name='TST.CellListArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cells', full_name='TST.CellListArchive.cells', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trailing_empty_cell_count', full_name='TST.CellListArchive.trailing_empty_cell_count', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CELLLISTARCHIVE_OPTIONALCELL, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16229,
  serialized_end=16372,
)


_CONCURRENTCELLMAPARCHIVE = _descriptor.Descriptor(
  name='ConcurrentCellMapArchive',
  full_name='TST.ConcurrentCellMapArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cell_lists', full_name='TST.ConcurrentCellMapArchive.cell_lists', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uid_based', full_name='TST.ConcurrentCellMapArchive.uid_based', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='merge_actions', full_name='TST.ConcurrentCellMapArchive.merge_actions', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='may_modify_formulas_in_cells', full_name='TST.ConcurrentCellMapArchive.may_modify_formulas_in_cells', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='may_modify_values_referenced_by_formulas', full_name='TST.ConcurrentCellMapArchive.may_modify_values_referenced_by_formulas', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16375,
  serialized_end=16607,
)


_CONCURRENTCELLLISTARCHIVE_OPTIONALCELL = _descriptor.Descriptor(
  name='OptionalCell',
  full_name='TST.ConcurrentCellListArchive.OptionalCell',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cell', full_name='TST.ConcurrentCellListArchive.OptionalCell.cell', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16333,
  serialized_end=16372,
)

_CONCURRENTCELLLISTARCHIVE = _descriptor.Descriptor(
  name='ConcurrentCellListArchive',
  full_name='TST.ConcurrentCellListArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cells', full_name='TST.ConcurrentCellListArchive.cells', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_uid_range', full_name='TST.ConcurrentCellListArchive.cell_uid_range', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_range', full_name='TST.ConcurrentCellListArchive.cell_range', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CONCURRENTCELLLISTARCHIVE_OPTIONALCELL, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16610,
  serialized_end=16820,
)


_CELLFORMATANDVALUEARCHIVE = _descriptor.Descriptor(
  name='CellFormatAndValueArchive',
  full_name='TST.CellFormatAndValueArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='valueType', full_name='TST.CellFormatAndValueArchive.valueType', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numberValue', full_name='TST.CellFormatAndValueArchive.numberValue', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stringValue', full_name='TST.CellFormatAndValueArchive.stringValue', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='boolValue', full_name='TST.CellFormatAndValueArchive.boolValue', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='richTextStorage', full_name='TST.CellFormatAndValueArchive.richTextStorage', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_all_spare_formats', full_name='TST.CellFormatAndValueArchive.use_all_spare_formats', index=5,
      number=6, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='explicit_flags', full_name='TST.CellFormatAndValueArchive.explicit_flags', index=6,
      number=7, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_format_kind', full_name='TST.CellFormatAndValueArchive.cell_format_kind', index=7,
      number=8, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='number_format', full_name='TST.CellFormatAndValueArchive.number_format', index=8,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency_format', full_name='TST.CellFormatAndValueArchive.currency_format', index=9,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date_format', full_name='TST.CellFormatAndValueArchive.date_format', index=10,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration_format', full_name='TST.CellFormatAndValueArchive.duration_format', index=11,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text_format', full_name='TST.CellFormatAndValueArchive.text_format', index=12,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='boolean_format', full_name='TST.CellFormatAndValueArchive.boolean_format', index=13,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formatted_value', full_name='TST.CellFormatAndValueArchive.formatted_value', index=14,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formatted_rich_text_value', full_name='TST.CellFormatAndValueArchive.formatted_rich_text_value', index=15,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='apply_spare_format_only', full_name='TST.CellFormatAndValueArchive.apply_spare_format_only', index=16,
      number=18, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spare_format_type', full_name='TST.CellFormatAndValueArchive.spare_format_type', index=17,
      number=19, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='decimal_low', full_name='TST.CellFormatAndValueArchive.decimal_low', index=18,
      number=20, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='decimal_high', full_name='TST.CellFormatAndValueArchive.decimal_high', index=19,
      number=21, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16823,
  serialized_end=17546,
)


_CELLSPECARCHIVE = _descriptor.Descriptor(
  name='CellSpecArchive',
  full_name='TST.CellSpecArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='interaction_type', full_name='TST.CellSpecArchive.interaction_type', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formula', full_name='TST.CellSpecArchive.formula', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range_control_min', full_name='TST.CellSpecArchive.range_control_min', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range_control_max', full_name='TST.CellSpecArchive.range_control_max', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range_control_inc', full_name='TST.CellSpecArchive.range_control_inc', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chooser_control_popup_model', full_name='TST.CellSpecArchive.chooser_control_popup_model', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chooser_control_start_w_first', full_name='TST.CellSpecArchive.chooser_control_start_w_first', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_summary_should_display_label', full_name='TST.CellSpecArchive.category_summary_should_display_label', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17549,
  serialized_end=17855,
)


_COMMENTSTORAGEWRAPPERARCHIVE = _descriptor.Descriptor(
  name='CommentStorageWrapperArchive',
  full_name='TST.CommentStorageWrapperArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='comment_storage', full_name='TST.CommentStorageWrapperArchive.comment_storage', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17857,
  serialized_end=17928,
)


_CELLDIFFARCHIVE = _descriptor.Descriptor(
  name='CellDiffArchive',
  full_name='TST.CellDiffArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='property_map_to_set', full_name='TST.CellDiffArchive.property_map_to_set', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='property_map_to_reset', full_name='TST.CellDiffArchive.property_map_to_reset', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17931,
  serialized_end=18072,
)


_CELLDIFFARRAY = _descriptor.Descriptor(
  name='CellDiffArray',
  full_name='TST.CellDiffArray',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='large_array', full_name='TST.CellDiffArray.large_array', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18074,
  serialized_end=18127,
)


_CELLDIFFARRAYSEGMENT = _descriptor.Descriptor(
  name='CellDiffArraySegment',
  full_name='TST.CellDiffArraySegment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='large_array_segment', full_name='TST.CellDiffArraySegment.large_array_segment', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='elements', full_name='TST.CellDiffArraySegment.elements', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18129,
  serialized_end=18244,
)


_CELLDIFFMAPARCHIVE = _descriptor.Descriptor(
  name='CellDiffMapArchive',
  full_name='TST.CellDiffMapArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid_based', full_name='TST.CellDiffMapArchive.uid_based', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expanded_cell_ids', full_name='TST.CellDiffMapArchive.expanded_cell_ids', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_uids', full_name='TST.CellDiffMapArchive.cell_uids', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_diff_array', full_name='TST.CellDiffMapArchive.cell_diff_array', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18247,
  serialized_end=18427,
)


_DOUBLESTYLEMAPARCHIVE_DOUBLESTYLEMAPENTRYARCHIVE = _descriptor.Descriptor(
  name='DoubleStyleMapEntryArchive',
  full_name='TST.DoubleStyleMapArchive.DoubleStyleMapEntryArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cell_id', full_name='TST.DoubleStyleMapArchive.DoubleStyleMapEntryArchive.cell_id', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_style', full_name='TST.DoubleStyleMapArchive.DoubleStyleMapEntryArchive.old_style', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_style', full_name='TST.DoubleStyleMapArchive.DoubleStyleMapEntryArchive.new_style', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18568,
  serialized_end=18696,
)

_DOUBLESTYLEMAPARCHIVE = _descriptor.Descriptor(
  name='DoubleStyleMapArchive',
  full_name='TST.DoubleStyleMapArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='capacity', full_name='TST.DoubleStyleMapArchive.capacity', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='count', full_name='TST.DoubleStyleMapArchive.count', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_map_entry', full_name='TST.DoubleStyleMapArchive.cell_map_entry', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_DOUBLESTYLEMAPARCHIVE_DOUBLESTYLEMAPENTRYARCHIVE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18430,
  serialized_end=18696,
)


_STYLETABLEMAPARCHIVE_STYLETABLEMAPENTRYARCHIVE = _descriptor.Descriptor(
  name='StyleTableMapEntryArchive',
  full_name='TST.StyleTableMapArchive.StyleTableMapEntryArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='TST.StyleTableMapArchive.StyleTableMapEntryArchive.key', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_style', full_name='TST.StyleTableMapArchive.StyleTableMapEntryArchive.old_style', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_style', full_name='TST.StyleTableMapArchive.StyleTableMapEntryArchive.new_style', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18828,
  serialized_end=18938,
)

_STYLETABLEMAPARCHIVE = _descriptor.Descriptor(
  name='StyleTableMapArchive',
  full_name='TST.StyleTableMapArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='capacity', full_name='TST.StyleTableMapArchive.capacity', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='count', full_name='TST.StyleTableMapArchive.count', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='map_entry', full_name='TST.StyleTableMapArchive.map_entry', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_STYLETABLEMAPARCHIVE_STYLETABLEMAPENTRYARCHIVE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18699,
  serialized_end=18938,
)


_SELECTIONARCHIVE = _descriptor.Descriptor(
  name='SelectionArchive',
  full_name='TST.SelectionArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tableModel', full_name='TST.SelectionArchive.tableModel', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='selection_type', full_name='TST.SelectionArchive.selection_type', index=1,
      number=4, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='anchor_cell', full_name='TST.SelectionArchive.anchor_cell', index=2,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_ranges', full_name='TST.SelectionArchive.cell_ranges', index=3,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='base_ranges', full_name='TST.SelectionArchive.base_ranges', index=4,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cursor_cell', full_name='TST.SelectionArchive.cursor_cell', index=5,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_info', full_name='TST.SelectionArchive.table_info', index=6,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_uid_region', full_name='TST.SelectionArchive.cell_uid_region', index=7,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='base_uid_region', full_name='TST.SelectionArchive.base_uid_region', index=8,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='anchor_cell_uid', full_name='TST.SelectionArchive.anchor_cell_uid', index=9,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cursor_cell_uid', full_name='TST.SelectionArchive.cursor_cell_uid', index=10,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18941,
  serialized_end=19428,
)


_DEATHHAWKRDAR39989167CELLSELECTIONARCHIVE = _descriptor.Descriptor(
  name='DeathhawkRdar39989167CellSelectionArchive',
  full_name='TST.DeathhawkRdar39989167CellSelectionArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='table_info', full_name='TST.DeathhawkRdar39989167CellSelectionArchive.table_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='selection_type', full_name='TST.DeathhawkRdar39989167CellSelectionArchive.selection_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_uid_region', full_name='TST.DeathhawkRdar39989167CellSelectionArchive.cell_uid_region', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='base_uid_region', full_name='TST.DeathhawkRdar39989167CellSelectionArchive.base_uid_region', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='anchor_cell_uid', full_name='TST.DeathhawkRdar39989167CellSelectionArchive.anchor_cell_uid', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cursor_cell_uid', full_name='TST.DeathhawkRdar39989167CellSelectionArchive.cursor_cell_uid', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19431,
  serialized_end=19761,
)


_STROKESELECTIONARCHIVE = _descriptor.Descriptor(
  name='StrokeSelectionArchive',
  full_name='TST.StrokeSelectionArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mask', full_name='TST.StrokeSelectionArchive.mask', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19763,
  serialized_end=19801,
)


_CONTROLCELLSELECTIONARCHIVE = _descriptor.Descriptor(
  name='ControlCellSelectionArchive',
  full_name='TST.ControlCellSelectionArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19803,
  serialized_end=19832,
)


_STOCKCELLSELECTIONARCHIVE = _descriptor.Descriptor(
  name='StockCellSelectionArchive',
  full_name='TST.StockCellSelectionArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19834,
  serialized_end=19861,
)


_TABLENAMESELECTIONARCHIVE = _descriptor.Descriptor(
  name='TableNameSelectionArchive',
  full_name='TST.TableNameSelectionArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19863,
  serialized_end=19890,
)


_AUTOFILLSELECTIONARCHIVE = _descriptor.Descriptor(
  name='AutofillSelectionArchive',
  full_name='TST.AutofillSelectionArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='source_cell_range', full_name='TST.AutofillSelectionArchive.source_cell_range', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target_cell_range', full_name='TST.AutofillSelectionArchive.target_cell_range', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19892,
  serialized_end=20004,
)


_FILTERRULEARCHIVE = _descriptor.Descriptor(
  name='FilterRuleArchive',
  full_name='TST.FilterRuleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='predicate', full_name='TST.FilterRuleArchive.predicate', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='disabled', full_name='TST.FilterRuleArchive.disabled', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20006,
  serialized_end=20092,
)


_TABLESTYLEARCHIVE = _descriptor.Descriptor(
  name='TableStyleArchive',
  full_name='TST.TableStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.TableStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='override_count', full_name='TST.TableStyleArchive.override_count', index=1,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_properties', full_name='TST.TableStyleArchive.table_properties', index=2,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20095,
  serialized_end=20232,
)


_CELLSTYLEARCHIVE = _descriptor.Descriptor(
  name='CellStyleArchive',
  full_name='TST.CellStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CellStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='override_count', full_name='TST.CellStyleArchive.override_count', index=1,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_properties', full_name='TST.CellStyleArchive.cell_properties', index=2,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20235,
  serialized_end=20369,
)


_FORMULAPREDICATEARCHIVE = _descriptor.Descriptor(
  name='FormulaPredicateArchive',
  full_name='TST.FormulaPredicateArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='formula', full_name='TST.FormulaPredicateArchive.formula', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='predicate_type', full_name='TST.FormulaPredicateArchive.predicate_type', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='qualifier1', full_name='TST.FormulaPredicateArchive.qualifier1', index=2,
      number=3, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='qualifier2', full_name='TST.FormulaPredicateArchive.qualifier2', index=3,
      number=4, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='param_index1', full_name='TST.FormulaPredicateArchive.param_index1', index=4,
      number=5, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='param_index2', full_name='TST.FormulaPredicateArchive.param_index2', index=5,
      number=6, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='param_index0', full_name='TST.FormulaPredicateArchive.param_index0', index=6,
      number=7, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FORMULAPREDICATEARCHIVE_FORMULAPREDICATETYPE,
    _FORMULAPREDICATEARCHIVE_QUALIFIERTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20372,
  serialized_end=21878,
)


_CONDITIONALSTYLESETARCHIVE_CONDITIONALSTYLERULE = _descriptor.Descriptor(
  name='ConditionalStyleRule',
  full_name='TST.ConditionalStyleSetArchive.ConditionalStyleRule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='predicate', full_name='TST.ConditionalStyleSetArchive.ConditionalStyleRule.predicate', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_style', full_name='TST.ConditionalStyleSetArchive.ConditionalStyleRule.cell_style', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text_style', full_name='TST.ConditionalStyleSetArchive.ConditionalStyleRule.text_style', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22000,
  serialized_end=22143,
)

_CONDITIONALSTYLESETARCHIVE = _descriptor.Descriptor(
  name='ConditionalStyleSetArchive',
  full_name='TST.ConditionalStyleSetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ruleCount', full_name='TST.ConditionalStyleSetArchive.ruleCount', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rules', full_name='TST.ConditionalStyleSetArchive.rules', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CONDITIONALSTYLESETARCHIVE_CONDITIONALSTYLERULE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21881,
  serialized_end=22143,
)


_FILTERSETARCHIVE = _descriptor.Descriptor(
  name='FilterSetArchive',
  full_name='TST.FilterSetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='TST.FilterSetArchive.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_enabled', full_name='TST.FilterSetArchive.is_enabled', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filter_rules', full_name='TST.FilterSetArchive.filter_rules', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='needs_formula_rewrite_for_import', full_name='TST.FilterSetArchive.needs_formula_rewrite_for_import', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filter_offsets', full_name='TST.FilterSetArchive.filter_offsets', index=4,
      number=5, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filter_enabled', full_name='TST.FilterSetArchive.filter_enabled', index=5,
      number=6, type=8, cpp_type=7, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FILTERSETARCHIVE_FILTERSETTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22146,
  serialized_end=22452,
)


_HIDDENSTATEEXTENTARCHIVE_ROWORCOLUMNSTATE = _descriptor.Descriptor(
  name='RowOrColumnState',
  full_name='TST.HiddenStateExtentArchive.RowOrColumnState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='row_or_column_uid', full_name='TST.HiddenStateExtentArchive.RowOrColumnState.row_or_column_uid', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_hidden', full_name='TST.HiddenStateExtentArchive.RowOrColumnState.user_hidden', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filtered', full_name='TST.HiddenStateExtentArchive.RowOrColumnState.filtered', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22820,
  serialized_end=22915,
)

_HIDDENSTATEEXTENTARCHIVE = _descriptor.Descriptor(
  name='HiddenStateExtentArchive',
  full_name='TST.HiddenStateExtentArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hidden_state_extent_uid', full_name='TST.HiddenStateExtentArchive.hidden_state_extent_uid', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hidden_states', full_name='TST.HiddenStateExtentArchive.hidden_states', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row_or_column_direction', full_name='TST.HiddenStateExtentArchive.row_or_column_direction', index=2,
      number=3, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='threshold_value', full_name='TST.HiddenStateExtentArchive.threshold_value', index=3,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='needs_to_update_filter_set_for_import', full_name='TST.HiddenStateExtentArchive.needs_to_update_filter_set_for_import', index=4,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collapsed_group_uids', full_name='TST.HiddenStateExtentArchive.collapsed_group_uids', index=5,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_HIDDENSTATEEXTENTARCHIVE_ROWORCOLUMNSTATE, ],
  enum_types=[
    _HIDDENSTATEEXTENTARCHIVE_ROWORCOLUMNDIRECTION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22455,
  serialized_end=22978,
)


_HIDDENSTATESARCHIVE = _descriptor.Descriptor(
  name='HiddenStatesArchive',
  full_name='TST.HiddenStatesArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hidden_states_uid', full_name='TST.HiddenStatesArchive.hidden_states_uid', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column_hidden_state_extent', full_name='TST.HiddenStatesArchive.column_hidden_state_extent', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row_hidden_state_extent', full_name='TST.HiddenStatesArchive.row_hidden_state_extent', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22981,
  serialized_end=23171,
)


_HIDDENSTATESOWNERARCHIVE = _descriptor.Descriptor(
  name='HiddenStatesOwnerArchive',
  full_name='TST.HiddenStatesOwnerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner_uid', full_name='TST.HiddenStatesOwnerArchive.owner_uid', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hidden_states', full_name='TST.HiddenStatesOwnerArchive.hidden_states', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23173,
  serialized_end=23278,
)


_EXPANDCOLLAPSESTATEARCHIVE = _descriptor.Descriptor(
  name='ExpandCollapseStateArchive',
  full_name='TST.ExpandCollapseStateArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uids_collapsed', full_name='TST.ExpandCollapseStateArchive.uids_collapsed', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uids_expanded', full_name='TST.ExpandCollapseStateArchive.uids_expanded', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23280,
  serialized_end=23377,
)


_TOKENATTACHMENTARCHIVE = _descriptor.Descriptor(
  name='TokenAttachmentArchive',
  full_name='TST.TokenAttachmentArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.TokenAttachmentArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expressionNode', full_name='TST.TokenAttachmentArchive.expressionNode', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23379,
  serialized_end=23487,
)


_FORMULAARCHIVE = _descriptor.Descriptor(
  name='FormulaArchive',
  full_name='TST.FormulaArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expressionTree', full_name='TST.FormulaArchive.expressionTree', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23489,
  serialized_end=23545,
)


_EXPRESSIONNODEARCHIVE = _descriptor.Descriptor(
  name='ExpressionNodeArchive',
  full_name='TST.ExpressionNodeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='children', full_name='TST.ExpressionNodeArchive.children', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='first_index', full_name='TST.ExpressionNodeArchive.first_index', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_index', full_name='TST.ExpressionNodeArchive.last_index', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23547,
  serialized_end=23645,
)


_BOOLEANNODEARCHIVE = _descriptor.Descriptor(
  name='BooleanNodeArchive',
  full_name='TST.BooleanNodeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.BooleanNodeArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='TST.BooleanNodeArchive.value', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23647,
  serialized_end=23725,
)


_NUMBERNODEARCHIVE = _descriptor.Descriptor(
  name='NumberNodeArchive',
  full_name='TST.NumberNodeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.NumberNodeArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='number', full_name='TST.NumberNodeArchive.number', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='decimal_low', full_name='TST.NumberNodeArchive.decimal_low', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='decimal_high', full_name='TST.NumberNodeArchive.decimal_high', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23727,
  serialized_end=23848,
)


_STRINGNODEARCHIVE = _descriptor.Descriptor(
  name='StringNodeArchive',
  full_name='TST.StringNodeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.StringNodeArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='TST.StringNodeArchive.value', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23850,
  serialized_end=23927,
)


_IDENTIFIERNODEARCHIVE = _descriptor.Descriptor(
  name='IdentifierNodeArchive',
  full_name='TST.IdentifierNodeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.IdentifierNodeArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='identifier', full_name='TST.IdentifierNodeArchive.identifier', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='TST.IdentifierNodeArchive.symbol', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23929,
  serialized_end=24031,
)


_ARRAYNODEARCHIVE = _descriptor.Descriptor(
  name='ArrayNodeArchive',
  full_name='TST.ArrayNodeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.ArrayNodeArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='columns', full_name='TST.ArrayNodeArchive.columns', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rows', full_name='TST.ArrayNodeArchive.rows', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24033,
  serialized_end=24125,
)


_LISTNODEARCHIVE = _descriptor.Descriptor(
  name='ListNodeArchive',
  full_name='TST.ListNodeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.ListNodeArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24127,
  serialized_end=24187,
)


_OPERATORNODEARCHIVE = _descriptor.Descriptor(
  name='OperatorNodeArchive',
  full_name='TST.OperatorNodeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.OperatorNodeArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operatorChar', full_name='TST.OperatorNodeArchive.operatorChar', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24189,
  serialized_end=24275,
)


_POSTFIXOPERATORNODEARCHIVE = _descriptor.Descriptor(
  name='PostfixOperatorNodeArchive',
  full_name='TST.PostfixOperatorNodeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.PostfixOperatorNodeArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24277,
  serialized_end=24346,
)


_PREFIXOPERATORNODEARCHIVE = _descriptor.Descriptor(
  name='PrefixOperatorNodeArchive',
  full_name='TST.PrefixOperatorNodeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.PrefixOperatorNodeArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24348,
  serialized_end=24416,
)


_FUNCTIONNODEARCHIVE = _descriptor.Descriptor(
  name='FunctionNodeArchive',
  full_name='TST.FunctionNodeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.FunctionNodeArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='functionIndex', full_name='TST.FunctionNodeArchive.functionIndex', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='invalidFunctionName', full_name='TST.FunctionNodeArchive.invalidFunctionName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24418,
  serialized_end=24534,
)


_FUNCTIONENDNODEARCHIVE = _descriptor.Descriptor(
  name='FunctionEndNodeArchive',
  full_name='TST.FunctionEndNodeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.FunctionEndNodeArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24536,
  serialized_end=24603,
)


_DATENODEARCHIVE = _descriptor.Descriptor(
  name='DateNodeArchive',
  full_name='TST.DateNodeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.DateNodeArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='TST.DateNodeArchive.value', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='format', full_name='TST.DateNodeArchive.format', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24605,
  serialized_end=24696,
)


_REFERENCENODEARCHIVE = _descriptor.Descriptor(
  name='ReferenceNodeArchive',
  full_name='TST.ReferenceNodeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.ReferenceNodeArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rangeReference', full_name='TST.ReferenceNodeArchive.rangeReference', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preserve_flags', full_name='TST.ReferenceNodeArchive.preserve_flags', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hostTableID', full_name='TST.ReferenceNodeArchive.hostTableID', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='host_cell_ref', full_name='TST.ReferenceNodeArchive.host_cell_ref', index=4,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_uid', full_name='TST.ReferenceNodeArchive.table_uid', index=5,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range_top_left', full_name='TST.ReferenceNodeArchive.range_top_left', index=6,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range_bottom_right', full_name='TST.ReferenceNodeArchive.range_bottom_right', index=7,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_ref', full_name='TST.ReferenceNodeArchive.category_ref', index=8,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uid_range_rect', full_name='TST.ReferenceNodeArchive.uid_range_rect', index=9,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24699,
  serialized_end=25141,
)


_DURATIONNODEARCHIVE = _descriptor.Descriptor(
  name='DurationNodeArchive',
  full_name='TST.DurationNodeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.DurationNodeArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeinterval', full_name='TST.DurationNodeArchive.timeinterval', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='smallest', full_name='TST.DurationNodeArchive.smallest', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='largest', full_name='TST.DurationNodeArchive.largest', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='style', full_name='TST.DurationNodeArchive.style', index=4,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25144,
  serialized_end=25280,
)


_ARGUMENTPLACEHOLDERNODEARCHIVE = _descriptor.Descriptor(
  name='ArgumentPlaceholderNodeArchive',
  full_name='TST.ArgumentPlaceholderNodeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.ArgumentPlaceholderNodeArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='functionIndex', full_name='TST.ArgumentPlaceholderNodeArchive.functionIndex', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='argumentIndex', full_name='TST.ArgumentPlaceholderNodeArchive.argumentIndex', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mode', full_name='TST.ArgumentPlaceholderNodeArchive.mode', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25283,
  serialized_end=25418,
)


_EMPTYEXPRESSIONNODEARCHIVE = _descriptor.Descriptor(
  name='EmptyExpressionNodeArchive',
  full_name='TST.EmptyExpressionNodeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.EmptyExpressionNodeArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25420,
  serialized_end=25491,
)


_LETNODEARCHIVE = _descriptor.Descriptor(
  name='LetNodeArchive',
  full_name='TST.LetNodeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.LetNodeArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='whitespace_after_let', full_name='TST.LetNodeArchive.whitespace_after_let', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='whitespace_after_identifier', full_name='TST.LetNodeArchive.whitespace_after_identifier', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='whitespace_after_equals', full_name='TST.LetNodeArchive.whitespace_after_equals', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='whitespace_after_delimiter', full_name='TST.LetNodeArchive.whitespace_after_delimiter', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25494,
  serialized_end=25689,
)


_INNODEARCHIVE = _descriptor.Descriptor(
  name='InNodeArchive',
  full_name='TST.InNodeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.InNodeArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25691,
  serialized_end=25749,
)


_VARIABLENODEARCHIVE = _descriptor.Descriptor(
  name='VariableNodeArchive',
  full_name='TST.VariableNodeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.VariableNodeArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='identifier', full_name='TST.VariableNodeArchive.identifier', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='TST.VariableNodeArchive.symbol', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25751,
  serialized_end=25851,
)


_LAYOUTHINTARCHIVE = _descriptor.Descriptor(
  name='LayoutHintArchive',
  full_name='TST.LayoutHintArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='isValid', full_name='TST.LayoutHintArchive.isValid', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cellRange', full_name='TST.LayoutHintArchive.cellRange', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hintID', full_name='TST.LayoutHintArchive.hintID', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maximumSize', full_name='TST.LayoutHintArchive.maximumSize', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partitionPosition', full_name='TST.LayoutHintArchive.partitionPosition', index=4,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='horizontal', full_name='TST.LayoutHintArchive.horizontal', index=5,
      number=6, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='effectiveSize', full_name='TST.LayoutHintArchive.effectiveSize', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partitioningPass', full_name='TST.LayoutHintArchive.partitioningPass', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25854,
  serialized_end=26093,
)


_COMPLETIONTOKENATTACHMENTARCHIVE = _descriptor.Descriptor(
  name='CompletionTokenAttachmentArchive',
  full_name='TST.CompletionTokenAttachmentArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CompletionTokenAttachmentArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='completionText', full_name='TST.CompletionTokenAttachmentArchive.completionText', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='caretPosition', full_name='TST.CompletionTokenAttachmentArchive.caretPosition', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prefixStart', full_name='TST.CompletionTokenAttachmentArchive.prefixStart', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26096,
  serialized_end=26242,
)


_HIDDENSTATEFORMULAOWNERARCHIVE = _descriptor.Descriptor(
  name='HiddenStateFormulaOwnerArchive',
  full_name='TST.HiddenStateFormulaOwnerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner_id', full_name='TST.HiddenStateFormulaOwnerArchive.owner_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='threshold_value', full_name='TST.HiddenStateFormulaOwnerArchive.threshold_value', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='needs_to_update_filter_set_for_import', full_name='TST.HiddenStateFormulaOwnerArchive.needs_to_update_filter_set_for_import', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26245,
  serialized_end=26411,
)


_FORMULASTOREARCHIVE_FORMULASTOREPAIR = _descriptor.Descriptor(
  name='FormulaStorePair',
  full_name='TST.FormulaStoreArchive.FormulaStorePair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='formula_index', full_name='TST.FormulaStoreArchive.FormulaStorePair.formula_index', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formula', full_name='TST.FormulaStoreArchive.FormulaStorePair.formula', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26526,
  serialized_end=26606,
)

_FORMULASTOREARCHIVE = _descriptor.Descriptor(
  name='FormulaStoreArchive',
  full_name='TST.FormulaStoreArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='next_formula_index', full_name='TST.FormulaStoreArchive.next_formula_index', index=0,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formulas', full_name='TST.FormulaStoreArchive.formulas', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_FORMULASTOREARCHIVE_FORMULASTOREPAIR, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26414,
  serialized_end=26606,
)


_MERGEOPERATIONARCHIVE = _descriptor.Descriptor(
  name='MergeOperationArchive',
  full_name='TST.MergeOperationArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='merge_type', full_name='TST.MergeOperationArchive.merge_type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='merge_ranges', full_name='TST.MergeOperationArchive.merge_ranges', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='merge_formulas', full_name='TST.MergeOperationArchive.merge_formulas', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='merge_formula_indexes', full_name='TST.MergeOperationArchive.merge_formula_indexes', index=3,
      number=4, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26609,
  serialized_end=26798,
)


_MERGEOWNERARCHIVE = _descriptor.Descriptor(
  name='MergeOwnerArchive',
  full_name='TST.MergeOwnerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner_id', full_name='TST.MergeOwnerArchive.owner_id', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formula_store', full_name='TST.MergeOwnerArchive.formula_store', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26800,
  serialized_end=26906,
)


_PENCILANNOTATIONARCHIVE = _descriptor.Descriptor(
  name='PencilAnnotationArchive',
  full_name='TST.PencilAnnotationArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='table_info', full_name='TST.PencilAnnotationArchive.table_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pencil_annotation_storage', full_name='TST.PencilAnnotationArchive.pencil_annotation_storage', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26908,
  serialized_end=27020,
)


_PENCILANNOTATIONOWNERARCHIVE = _descriptor.Descriptor(
  name='PencilAnnotationOwnerArchive',
  full_name='TST.PencilAnnotationOwnerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner_id', full_name='TST.PencilAnnotationOwnerArchive.owner_id', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formula_store', full_name='TST.PencilAnnotationOwnerArchive.formula_store', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='annotations', full_name='TST.PencilAnnotationOwnerArchive.annotations', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27023,
  serialized_end=27177,
)


_ACCUMULATORARCHIVE = _descriptor.Descriptor(
  name='AccumulatorArchive',
  full_name='TST.AccumulatorArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='bool_count', full_name='TST.AccumulatorArchive.bool_count', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bool_true_count', full_name='TST.AccumulatorArchive.bool_true_count', index=1,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='number_count', full_name='TST.AccumulatorArchive.number_count', index=2,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date_count', full_name='TST.AccumulatorArchive.date_count', index=3,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration_count', full_name='TST.AccumulatorArchive.duration_count', index=4,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='string_count', full_name='TST.AccumulatorArchive.string_count', index=5,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error_count', full_name='TST.AccumulatorArchive.error_count', index=6,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_circular_ref', full_name='TST.AccumulatorArchive.is_circular_ref', index=7,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='min_value', full_name='TST.AccumulatorArchive.min_value', index=8,
      number=6, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_value', full_name='TST.AccumulatorArchive.max_value', index=9,
      number=7, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='number_total_value', full_name='TST.AccumulatorArchive.number_total_value', index=10,
      number=8, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='first_date_seen', full_name='TST.AccumulatorArchive.first_date_seen', index=11,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_secs_since_ref_date', full_name='TST.AccumulatorArchive.total_secs_since_ref_date', index=12,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='secs_to_add', full_name='TST.AccumulatorArchive.secs_to_add', index=13,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27180,
  serialized_end=27622,
)


_GROUPCOLUMNARCHIVE = _descriptor.Descriptor(
  name='GroupColumnArchive',
  full_name='TST.GroupColumnArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='column_uid', full_name='TST.GroupColumnArchive.column_uid', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='grouping_type', full_name='TST.GroupColumnArchive.grouping_type', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='grouping_functor', full_name='TST.GroupColumnArchive.grouping_functor', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='grouping_column_uid', full_name='TST.GroupColumnArchive.grouping_column_uid', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27625,
  serialized_end=27806,
)


_GROUPCOLUMNLISTARCHIVE = _descriptor.Descriptor(
  name='GroupColumnListArchive',
  full_name='TST.GroupColumnListArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_column', full_name='TST.GroupColumnListArchive.group_column', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27808,
  serialized_end=27879,
)


_COLUMNAGGREGATEARCHIVE = _descriptor.Descriptor(
  name='ColumnAggregateArchive',
  full_name='TST.ColumnAggregateArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='column_uid', full_name='TST.ColumnAggregateArchive.column_uid', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='level', full_name='TST.ColumnAggregateArchive.level', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='agg_type', full_name='TST.ColumnAggregateArchive.agg_type', index=2,
      number=3, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27881,
  serialized_end=27989,
)


_COLUMNAGGREGATELISTARCHIVE = _descriptor.Descriptor(
  name='ColumnAggregateListArchive',
  full_name='TST.ColumnAggregateListArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='aggregates', full_name='TST.ColumnAggregateListArchive.aggregates', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27991,
  serialized_end=28068,
)


_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_AGGNODEARCHIVE = _descriptor.Descriptor(
  name='AggNodeArchive',
  full_name='TST.CategoryOwnerArchive.GroupByArchive.AggNodeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='formula_coord', full_name='TST.CategoryOwnerArchive.GroupByArchive.AggNodeArchive.formula_coord', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='accum', full_name='TST.CategoryOwnerArchive.GroupByArchive.AggNodeArchive.accum', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='child', full_name='TST.CategoryOwnerArchive.GroupByArchive.AggNodeArchive.child', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29003,
  serialized_end=29183,
)

_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_GROUPNODEARCHIVE_GROUPVALUETUPLEARCHIVE = _descriptor.Descriptor(
  name='GroupValueTupleArchive',
  full_name='TST.CategoryOwnerArchive.GroupByArchive.GroupNodeArchive.GroupValueTupleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='TST.CategoryOwnerArchive.GroupByArchive.GroupNodeArchive.GroupValueTupleArchive.value', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29658,
  serialized_end=29721,
)

_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_GROUPNODEARCHIVE_FORMATMANAGERARCHIVE_ROWSETARCHIVE = _descriptor.Descriptor(
  name='RowSetArchive',
  full_name='TST.CategoryOwnerArchive.GroupByArchive.GroupNodeArchive.FormatManagerArchive.RowSetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='row_uids', full_name='TST.CategoryOwnerArchive.GroupByArchive.GroupNodeArchive.FormatManagerArchive.RowSetArchive.row_uids', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29947,
  serialized_end=29991,
)

_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_GROUPNODEARCHIVE_FORMATMANAGERARCHIVE = _descriptor.Descriptor(
  name='FormatManagerArchive',
  full_name='TST.CategoryOwnerArchive.GroupByArchive.GroupNodeArchive.FormatManagerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cell_value', full_name='TST.CategoryOwnerArchive.GroupByArchive.GroupNodeArchive.FormatManagerArchive.cell_value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formats', full_name='TST.CategoryOwnerArchive.GroupByArchive.GroupNodeArchive.FormatManagerArchive.formats', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row_sets', full_name='TST.CategoryOwnerArchive.GroupByArchive.GroupNodeArchive.FormatManagerArchive.row_sets', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_GROUPNODEARCHIVE_FORMATMANAGERARCHIVE_ROWSETARCHIVE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29724,
  serialized_end=29991,
)

_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_GROUPNODEARCHIVE = _descriptor.Descriptor(
  name='GroupNodeArchive',
  full_name='TST.CategoryOwnerArchive.GroupByArchive.GroupNodeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_uid', full_name='TST.CategoryOwnerArchive.GroupByArchive.GroupNodeArchive.group_uid', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group_value_tuple', full_name='TST.CategoryOwnerArchive.GroupByArchive.GroupNodeArchive.group_value_tuple', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group_cell_value', full_name='TST.CategoryOwnerArchive.GroupByArchive.GroupNodeArchive.group_cell_value', index=2,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='child', full_name='TST.CategoryOwnerArchive.GroupByArchive.GroupNodeArchive.child', index=3,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row_uid', full_name='TST.CategoryOwnerArchive.GroupByArchive.GroupNodeArchive.row_uid', index=4,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='agg_formula_coords', full_name='TST.CategoryOwnerArchive.GroupByArchive.GroupNodeArchive.agg_formula_coords', index=5,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='format_manager', full_name='TST.CategoryOwnerArchive.GroupByArchive.GroupNodeArchive.format_manager', index=6,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_GROUPNODEARCHIVE_GROUPVALUETUPLEARCHIVE, _CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_GROUPNODEARCHIVE_FORMATMANAGERARCHIVE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29186,
  serialized_end=29991,
)

_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_AGGREGATORARCHIVE = _descriptor.Descriptor(
  name='AggregatorArchive',
  full_name='TST.CategoryOwnerArchive.GroupByArchive.AggregatorArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='column_uid', full_name='TST.CategoryOwnerArchive.GroupByArchive.AggregatorArchive.column_uid', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='agg_node', full_name='TST.CategoryOwnerArchive.GroupByArchive.AggregatorArchive.agg_node', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29993,
  serialized_end=30118,
)

_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE = _descriptor.Descriptor(
  name='GroupByArchive',
  full_name='TST.CategoryOwnerArchive.GroupByArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_by_uid', full_name='TST.CategoryOwnerArchive.GroupByArchive.group_by_uid', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group_column', full_name='TST.CategoryOwnerArchive.GroupByArchive.group_column', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group_node_root', full_name='TST.CategoryOwnerArchive.GroupByArchive.group_node_root', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aggregator', full_name='TST.CategoryOwnerArchive.GroupByArchive.aggregator', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column_agg_type', full_name='TST.CategoryOwnerArchive.GroupByArchive.column_agg_type', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_enabled', full_name='TST.CategoryOwnerArchive.GroupByArchive.is_enabled', index=5,
      number=6, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='indirect_agg_type_change_formula', full_name='TST.CategoryOwnerArchive.GroupByArchive.indirect_agg_type_change_formula', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='grouping_columns_formula', full_name='TST.CategoryOwnerArchive.GroupByArchive.grouping_columns_formula', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='grouping_column_headers_formula', full_name='TST.CategoryOwnerArchive.GroupByArchive.grouping_column_headers_formula', index=8,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aggs_in_group_root_formula', full_name='TST.CategoryOwnerArchive.GroupByArchive.aggs_in_group_root_formula', index=9,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column_order_changed_formula', full_name='TST.CategoryOwnerArchive.GroupByArchive.column_order_changed_formula', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row_order_changed_formula', full_name='TST.CategoryOwnerArchive.GroupByArchive.row_order_changed_formula', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row_order_changed_ignoring_recalc_formula', full_name='TST.CategoryOwnerArchive.GroupByArchive.row_order_changed_ignoring_recalc_formula', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_AGGNODEARCHIVE, _CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_GROUPNODEARCHIVE, _CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_AGGREGATORARCHIVE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28186,
  serialized_end=30118,
)

_CATEGORYOWNERARCHIVE = _descriptor.Descriptor(
  name='CategoryOwnerArchive',
  full_name='TST.CategoryOwnerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner_uid', full_name='TST.CategoryOwnerArchive.owner_uid', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group_by', full_name='TST.CategoryOwnerArchive.group_by', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28071,
  serialized_end=30118,
)


_RICHTEXTPAYLOADARCHIVE = _descriptor.Descriptor(
  name='RichTextPayloadArchive',
  full_name='TST.RichTextPayloadArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='storage', full_name='TST.RichTextPayloadArchive.storage', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range', full_name='TST.RichTextPayloadArchive.range', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cellid', full_name='TST.RichTextPayloadArchive.cellid', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=30120,
  serialized_end=30233,
)


_FORMULAEQUALSTOKENATTACHMENTARCHIVE = _descriptor.Descriptor(
  name='FormulaEqualsTokenAttachmentArchive',
  full_name='TST.FormulaEqualsTokenAttachmentArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.FormulaEqualsTokenAttachmentArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=30235,
  serialized_end=30316,
)


_CELLFILLSTANDIN = _descriptor.Descriptor(
  name='CellFillStandIn',
  full_name='TST.CellFillStandIn',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fill', full_name='TST.CellFillStandIn.fill', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type_is_mixed', full_name='TST.CellFillStandIn.type_is_mixed', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='color_has_been_modified', full_name='TST.CellFillStandIn.color_has_been_modified', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='color_is_mixed', full_name='TST.CellFillStandIn.color_is_mixed', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='first_color_has_been_modified', full_name='TST.CellFillStandIn.first_color_has_been_modified', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='first_color_is_mixed', full_name='TST.CellFillStandIn.first_color_is_mixed', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_color_has_been_modified', full_name='TST.CellFillStandIn.last_color_has_been_modified', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_color_is_mixed', full_name='TST.CellFillStandIn.last_color_is_mixed', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gradient_type_has_been_modified', full_name='TST.CellFillStandIn.gradient_type_has_been_modified', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gradient_type_is_mixed', full_name='TST.CellFillStandIn.gradient_type_is_mixed', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gradient_angle_has_been_modified', full_name='TST.CellFillStandIn.gradient_angle_has_been_modified', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gradient_angle_is_mixed', full_name='TST.CellFillStandIn.gradient_angle_is_mixed', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image_data_has_been_modified', full_name='TST.CellFillStandIn.image_data_has_been_modified', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image_data_is_mixed', full_name='TST.CellFillStandIn.image_data_is_mixed', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tint_color_has_been_modified', full_name='TST.CellFillStandIn.tint_color_has_been_modified', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tint_color_is_mixed', full_name='TST.CellFillStandIn.tint_color_is_mixed', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scale_has_been_modified', full_name='TST.CellFillStandIn.scale_has_been_modified', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scale_is_mixed', full_name='TST.CellFillStandIn.scale_is_mixed', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='technique_has_been_modified', full_name='TST.CellFillStandIn.technique_has_been_modified', index=18,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='technique_is_mixed', full_name='TST.CellFillStandIn.technique_is_mixed', index=19,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=30319,
  serialized_end=30988,
)


_FORMULASELECTIONARCHIVE = _descriptor.Descriptor(
  name='FormulaSelectionArchive',
  full_name='TST.FormulaSelectionArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.FormulaSelectionArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='activeTokenCharIndex', full_name='TST.FormulaSelectionArchive.activeTokenCharIndex', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=30990,
  serialized_end=31084,
)


_CELLBORDERARCHIVE = _descriptor.Descriptor(
  name='CellBorderArchive',
  full_name='TST.CellBorderArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='top_stroke', full_name='TST.CellBorderArchive.top_stroke', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='top_stroke_order', full_name='TST.CellBorderArchive.top_stroke_order', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='right_stroke', full_name='TST.CellBorderArchive.right_stroke', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='right_stroke_order', full_name='TST.CellBorderArchive.right_stroke_order', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bottom_stroke', full_name='TST.CellBorderArchive.bottom_stroke', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bottom_stroke_order', full_name='TST.CellBorderArchive.bottom_stroke_order', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='left_stroke', full_name='TST.CellBorderArchive.left_stroke', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='left_stroke_order', full_name='TST.CellBorderArchive.left_stroke_order', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31087,
  serialized_end=31382,
)


_DEFAULTCELLSTYLESCONTAINERARCHIVE = _descriptor.Descriptor(
  name='DefaultCellStylesContainerArchive',
  full_name='TST.DefaultCellStylesContainerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='table_style_network', full_name='TST.DefaultCellStylesContainerArchive.table_style_network', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_row_uids', full_name='TST.DefaultCellStylesContainerArchive.header_row_uids', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='footer_row_uids', full_name='TST.DefaultCellStylesContainerArchive.footer_row_uids', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_column_uids', full_name='TST.DefaultCellStylesContainerArchive.header_column_uids', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31385,
  serialized_end=31576,
)


_MULTITABLEREMAPPERARCHIVE = _descriptor.Descriptor(
  name='MultiTableRemapperArchive',
  full_name='TST.MultiTableRemapperArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mapping_purpose', full_name='TST.MultiTableRemapperArchive.mapping_purpose', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='should_steal_references', full_name='TST.MultiTableRemapperArchive.should_steal_references', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='can_reuse_table_names', full_name='TST.MultiTableRemapperArchive.can_reuse_table_names', index=2,
      number=3, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner_uid_mapper', full_name='TST.MultiTableRemapperArchive.owner_uid_mapper', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='backing_tables_for_charts', full_name='TST.MultiTableRemapperArchive.backing_tables_for_charts', index=4,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cross_document_paste', full_name='TST.MultiTableRemapperArchive.cross_document_paste', index=5,
      number=6, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nested_inner_mapper', full_name='TST.MultiTableRemapperArchive.nested_inner_mapper', index=6,
      number=7, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MULTITABLEREMAPPERARCHIVE_PURPOSE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31579,
  serialized_end=31984,
)


_CHANGEPROPAGATIONMAPWRAPPER = _descriptor.Descriptor(
  name='ChangePropagationMapWrapper',
  full_name='TST.ChangePropagationMapWrapper',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='replacement_behavior', full_name='TST.ChangePropagationMapWrapper.replacement_behavior', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='style_replace_prototypes', full_name='TST.ChangePropagationMapWrapper.style_replace_prototypes', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='style_replace_replacements', full_name='TST.ChangePropagationMapWrapper.style_replace_replacements', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='style_modify_styles', full_name='TST.ChangePropagationMapWrapper.style_modify_styles', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='style_modify_old_prop_maps', full_name='TST.ChangePropagationMapWrapper.style_modify_old_prop_maps', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='style_modify_new_prop_maps', full_name='TST.ChangePropagationMapWrapper.style_modify_new_prop_maps', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='style_delete_prototypes', full_name='TST.ChangePropagationMapWrapper.style_delete_prototypes', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='style_delete_replacements', full_name='TST.ChangePropagationMapWrapper.style_delete_replacements', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_preset_replace_prototype', full_name='TST.ChangePropagationMapWrapper.table_preset_replace_prototype', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_preset_replace_replacement', full_name='TST.ChangePropagationMapWrapper.table_preset_replace_replacement', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_preset_delete_prototype', full_name='TST.ChangePropagationMapWrapper.table_preset_delete_prototype', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_preset_delete_replacement', full_name='TST.ChangePropagationMapWrapper.table_preset_delete_replacement', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31987,
  serialized_end=32623,
)


_SUMMARYCELLVENDORARCHIVE_SUMMARYCELLENTRY = _descriptor.Descriptor(
  name='SummaryCellEntry',
  full_name='TST.SummaryCellVendorArchive.SummaryCellEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='wildcardUID', full_name='TST.SummaryCellVendorArchive.SummaryCellEntry.wildcardUID', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='columnUID', full_name='TST.SummaryCellVendorArchive.SummaryCellEntry.columnUID', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell', full_name='TST.SummaryCellVendorArchive.SummaryCellEntry.cell', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32755,
  serialized_end=32860,
)

_SUMMARYCELLVENDORARCHIVE = _descriptor.Descriptor(
  name='SummaryCellVendorArchive',
  full_name='TST.SummaryCellVendorArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='table_info', full_name='TST.SummaryCellVendorArchive.table_info', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entries', full_name='TST.SummaryCellVendorArchive.entries', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SUMMARYCELLVENDORARCHIVE_SUMMARYCELLENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32626,
  serialized_end=32860,
)


_CATEGORYORDERARCHIVE = _descriptor.Descriptor(
  name='CategoryOrderArchive',
  full_name='TST.CategoryOrderArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='table_info', full_name='TST.CategoryOrderArchive.table_info', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uid_map', full_name='TST.CategoryOrderArchive.uid_map', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32862,
  serialized_end=32953,
)


_HEADERNAMEMGRTILEARCHIVE_NAMEFRAGMENTARCHIVE = _descriptor.Descriptor(
  name='NameFragmentArchive',
  full_name='TST.HeaderNameMgrTileArchive.NameFragmentArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name_fragment', full_name='TST.HeaderNameMgrTileArchive.NameFragmentArchive.name_fragment', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name_precedent', full_name='TST.HeaderNameMgrTileArchive.NameFragmentArchive.name_precedent', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uses_of_name_fragment', full_name='TST.HeaderNameMgrTileArchive.NameFragmentArchive.uses_of_name_fragment', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33110,
  serialized_end=33266,
)

_HEADERNAMEMGRTILEARCHIVE = _descriptor.Descriptor(
  name='HeaderNameMgrTileArchive',
  full_name='TST.HeaderNameMgrTileArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='first_fragment', full_name='TST.HeaderNameMgrTileArchive.first_fragment', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_fragment', full_name='TST.HeaderNameMgrTileArchive.last_fragment', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name_frag_entries', full_name='TST.HeaderNameMgrTileArchive.name_frag_entries', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_HEADERNAMEMGRTILEARCHIVE_NAMEFRAGMENTARCHIVE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32956,
  serialized_end=33266,
)


_HEADERNAMEMGRARCHIVE_PERTABLEARCHIVE = _descriptor.Descriptor(
  name='PerTableArchive',
  full_name='TST.HeaderNameMgrArchive.PerTableArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='table_uid', full_name='TST.HeaderNameMgrArchive.PerTableArchive.table_uid', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='per_table_precedent', full_name='TST.HeaderNameMgrArchive.PerTableArchive.per_table_precedent', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_deleted', full_name='TST.HeaderNameMgrArchive.PerTableArchive.is_deleted', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_row_uids', full_name='TST.HeaderNameMgrArchive.PerTableArchive.header_row_uids', index=3,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_column_uids', full_name='TST.HeaderNameMgrArchive.PerTableArchive.header_column_uids', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update_header_row_uids', full_name='TST.HeaderNameMgrArchive.PerTableArchive.update_header_row_uids', index=5,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update_header_column_uids', full_name='TST.HeaderNameMgrArchive.PerTableArchive.update_header_column_uids', index=6,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33462,
  serialized_end=33751,
)

_HEADERNAMEMGRARCHIVE = _descriptor.Descriptor(
  name='HeaderNameMgrArchive',
  full_name='TST.HeaderNameMgrArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner_uid', full_name='TST.HeaderNameMgrArchive.owner_uid', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nrm_owner_uid', full_name='TST.HeaderNameMgrArchive.nrm_owner_uid', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='per_tables', full_name='TST.HeaderNameMgrArchive.per_tables', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name_frag_tiles', full_name='TST.HeaderNameMgrArchive.name_frag_tiles', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_HEADERNAMEMGRARCHIVE_PERTABLEARCHIVE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33269,
  serialized_end=33751,
)


_WIDTHHEIGHTCACHEFITTINGENTRY = _descriptor.Descriptor(
  name='WidthHeightCacheFittingEntry',
  full_name='TST.WidthHeightCacheFittingEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fitting_index', full_name='TST.WidthHeightCacheFittingEntry.fitting_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fitting_size', full_name='TST.WidthHeightCacheFittingEntry.fitting_size', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33753,
  serialized_end=33828,
)


_WIDTHHEIGHTCACHE = _descriptor.Descriptor(
  name='WidthHeightCache',
  full_name='TST.WidthHeightCache',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rows_fitting_entries', full_name='TST.WidthHeightCache.rows_fitting_entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='columns_count', full_name='TST.WidthHeightCache.columns_count', index=1,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33830,
  serialized_end=33936,
)


_MASTERLAYOUTARCHIVE = _descriptor.Descriptor(
  name='MasterLayoutArchive',
  full_name='TST.MasterLayoutArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='width_height_cache', full_name='TST.MasterLayoutArchive.width_height_cache', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33938,
  serialized_end=34010,
)

_CELLID.fields_by_name['expanded_coord'].message_type = TSCEArchives__pb2._CELLCOORDINATEARCHIVE
_CELLUIDLOOKUPLISTARCHIVE.fields_by_name['column_uids'].message_type = TSCEArchives__pb2._UIDLOOKUPLISTARCHIVE
_CELLUIDLOOKUPLISTARCHIVE.fields_by_name['row_uids'].message_type = TSCEArchives__pb2._UIDLOOKUPLISTARCHIVE
_CELLUIDLISTARCHIVE.fields_by_name['row_uids'].message_type = TSPMessages__pb2._UUID
_CELLUIDLISTARCHIVE.fields_by_name['column_uids'].message_type = TSPMessages__pb2._UUID
_CELLUIDLISTARCHIVE.fields_by_name['uncompressed_lookup_list'].message_type = _CELLUIDLOOKUPLISTARCHIVE
_CELLRANGE.fields_by_name['origin'].message_type = _CELLID
_CELLRANGE.fields_by_name['size'].message_type = _TABLESIZE
_EXPANDEDCELLRANGE.fields_by_name['origin'].message_type = TSCEArchives__pb2._CELLCOORDINATEARCHIVE
_EXPANDEDCELLRANGE.fields_by_name['size'].message_type = _EXPANDEDTABLESIZE
_TABLESELECTION.fields_by_name['cellRange'].message_type = _CELLRANGE
_TABLESELECTION.fields_by_name['extendedCellRange'].message_type = _CELLRANGE
_TABLESELECTION.fields_by_name['selection_type'].enum_type = _SELECTIONTYPEARCHIVE
_TILE.fields_by_name['rowInfos'].message_type = _TILEROWINFO
_TILESTORAGE_TILE.fields_by_name['tile'].message_type = TSPMessages__pb2._REFERENCE
_TILESTORAGE_TILE.containing_type = _TILESTORAGE
_TILESTORAGE.fields_by_name['tiles'].message_type = _TILESTORAGE_TILE
_POPUPMENUMODEL_CELLVALUE.fields_by_name['cell_value_type'].enum_type = _POPUPMENUMODEL_CELLVALUETYPE
_POPUPMENUMODEL_CELLVALUE.fields_by_name['boolean_value'].message_type = TSCEArchives__pb2._BOOLEANCELLVALUEARCHIVE
_POPUPMENUMODEL_CELLVALUE.fields_by_name['date_value'].message_type = TSCEArchives__pb2._DATECELLVALUEARCHIVE
_POPUPMENUMODEL_CELLVALUE.fields_by_name['number_value'].message_type = TSCEArchives__pb2._NUMBERCELLVALUEARCHIVE
_POPUPMENUMODEL_CELLVALUE.fields_by_name['string_value'].message_type = TSCEArchives__pb2._STRINGCELLVALUEARCHIVE
_POPUPMENUMODEL_CELLVALUE.containing_type = _POPUPMENUMODEL
_POPUPMENUMODEL.fields_by_name['item'].message_type = _POPUPMENUMODEL_CELLVALUE
_POPUPMENUMODEL.fields_by_name['tsce_item'].message_type = TSCEArchives__pb2._CELLVALUEARCHIVE
_POPUPMENUMODEL_CELLVALUETYPE.containing_type = _POPUPMENUMODEL
_IMPORTWARNINGSETARCHIVE_FORMULAIMPORTWARNING.fields_by_name['formula_warning_type'].enum_type = _IMPORTWARNINGSETARCHIVE_FORMULAWARNINGTYPE
_IMPORTWARNINGSETARCHIVE_FORMULAIMPORTWARNING.containing_type = _IMPORTWARNINGSETARCHIVE
_IMPORTWARNINGSETARCHIVE.fields_by_name['formula_import_warning'].message_type = _IMPORTWARNINGSETARCHIVE_FORMULAIMPORTWARNING
_IMPORTWARNINGSETARCHIVE_FORMULAWARNINGTYPE.containing_type = _IMPORTWARNINGSETARCHIVE
_CELLREFIMPORTWARNINGSETPAIRARCHIVE.fields_by_name['cell_ref'].message_type = TSCEArchives__pb2._CELLREFERENCEARCHIVE
_CELLREFIMPORTWARNINGSETPAIRARCHIVE.fields_by_name['warning_set'].message_type = _IMPORTWARNINGSETARCHIVE
_IMPORTWARNINGSETBYCELLREFARCHIVE.fields_by_name['cellref_warning_set_pair'].message_type = _CELLREFIMPORTWARNINGSETPAIRARCHIVE
_TABLEDATALIST_LISTENTRY.fields_by_name['reference'].message_type = TSPMessages__pb2._REFERENCE
_TABLEDATALIST_LISTENTRY.fields_by_name['formula'].message_type = TSCEArchives__pb2._FORMULAARCHIVE
_TABLEDATALIST_LISTENTRY.fields_by_name['format'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_TABLEDATALIST_LISTENTRY.fields_by_name['custom_format'].message_type = TSKArchives__pb2._CUSTOMFORMATARCHIVE
_TABLEDATALIST_LISTENTRY.fields_by_name['rich_text_payload'].message_type = TSPMessages__pb2._REFERENCE
_TABLEDATALIST_LISTENTRY.fields_by_name['comment_storage'].message_type = TSPMessages__pb2._REFERENCE
_TABLEDATALIST_LISTENTRY.fields_by_name['import_warning_set'].message_type = _IMPORTWARNINGSETARCHIVE
_TABLEDATALIST_LISTENTRY.fields_by_name['cell_spec'].message_type = _CELLSPECARCHIVE
_TABLEDATALIST_LISTENTRY.containing_type = _TABLEDATALIST
_TABLEDATALIST.fields_by_name['listType'].enum_type = _TABLEDATALIST_LISTTYPE
_TABLEDATALIST.fields_by_name['entries'].message_type = _TABLEDATALIST_LISTENTRY
_TABLEDATALIST.fields_by_name['segments'].message_type = TSPMessages__pb2._REFERENCE
_TABLEDATALIST_LISTTYPE.containing_type = _TABLEDATALIST
_TABLEDATALISTSEGMENT.fields_by_name['list_type'].enum_type = _TABLEDATALIST_LISTTYPE
_TABLEDATALISTSEGMENT.fields_by_name['key_range'].message_type = TSPMessages__pb2._RANGE
_TABLEDATALISTSEGMENT.fields_by_name['entries'].message_type = _TABLEDATALIST_LISTENTRY
_TABLERBTREE_NODE.containing_type = _TABLERBTREE
_TABLERBTREE.fields_by_name['nodes'].message_type = _TABLERBTREE_NODE
_HEADERSTORAGEBUCKET_HEADER.fields_by_name['cell_style'].message_type = TSPMessages__pb2._REFERENCE
_HEADERSTORAGEBUCKET_HEADER.fields_by_name['text_style'].message_type = TSPMessages__pb2._REFERENCE
_HEADERSTORAGEBUCKET_HEADER.containing_type = _HEADERSTORAGEBUCKET
_HEADERSTORAGEBUCKET.fields_by_name['headers'].message_type = _HEADERSTORAGEBUCKET_HEADER
_HEADERSTORAGE.fields_by_name['buckets'].message_type = TSPMessages__pb2._REFERENCE
_DATASTORE.fields_by_name['rowHeaders'].message_type = _HEADERSTORAGE
_DATASTORE.fields_by_name['columnHeaders'].message_type = TSPMessages__pb2._REFERENCE
_DATASTORE.fields_by_name['tiles'].message_type = _TILESTORAGE
_DATASTORE.fields_by_name['stringTable'].message_type = TSPMessages__pb2._REFERENCE
_DATASTORE.fields_by_name['styleTable'].message_type = TSPMessages__pb2._REFERENCE
_DATASTORE.fields_by_name['formula_table'].message_type = TSPMessages__pb2._REFERENCE
_DATASTORE.fields_by_name['formulaErrorTable'].message_type = TSPMessages__pb2._REFERENCE
_DATASTORE.fields_by_name['format_table_pre_bnc'].message_type = TSPMessages__pb2._REFERENCE
_DATASTORE.fields_by_name['multipleChoiceListFormatTable'].message_type = TSPMessages__pb2._REFERENCE
_DATASTORE.fields_by_name['merge_region_map'].message_type = TSPMessages__pb2._REFERENCE
_DATASTORE.fields_by_name['customFormatTable'].message_type = TSPMessages__pb2._REFERENCE
_DATASTORE.fields_by_name['rowTileTree'].message_type = _TABLERBTREE
_DATASTORE.fields_by_name['columnTileTree'].message_type = _TABLERBTREE
_DATASTORE.fields_by_name['rich_text_table'].message_type = TSPMessages__pb2._REFERENCE
_DATASTORE.fields_by_name['conditionalstyletable'].message_type = TSPMessages__pb2._REFERENCE
_DATASTORE.fields_by_name['commentStorageTable'].message_type = TSPMessages__pb2._REFERENCE
_DATASTORE.fields_by_name['importWarningSetTable'].message_type = TSPMessages__pb2._REFERENCE
_DATASTORE.fields_by_name['control_cell_spec_table'].message_type = TSPMessages__pb2._REFERENCE
_DATASTORE.fields_by_name['format_table'].message_type = TSPMessages__pb2._REFERENCE
_TABLEINFOARCHIVE.fields_by_name['super'].message_type = TSDArchives__pb2._DRAWABLEARCHIVE
_TABLEINFOARCHIVE.fields_by_name['tableModel'].message_type = TSPMessages__pb2._REFERENCE
_TABLEINFOARCHIVE.fields_by_name['editing_state'].message_type = TSPMessages__pb2._REFERENCE
_TABLEINFOARCHIVE.fields_by_name['summary_model'].message_type = TSPMessages__pb2._REFERENCE
_TABLEINFOARCHIVE.fields_by_name['category_order'].message_type = TSPMessages__pb2._REFERENCE
_TABLEINFOARCHIVE.fields_by_name['view_column_row_uids'].message_type = TSPMessages__pb2._REFERENCE
_TABLEINFOARCHIVE.fields_by_name['group_by_uuid'].message_type = TSPMessages__pb2._UUID
_TABLEINFOARCHIVE.fields_by_name['hidden_states_uuid'].message_type = TSPMessages__pb2._UUID
_TABLEINFOARCHIVE.fields_by_name['pasteboard_coord_mapper'].message_type = TSCEArchives__pb2._COORDMAPPERARCHIVE
_TABLEINFOARCHIVE.fields_by_name['master_layout'].message_type = _MASTERLAYOUTARCHIVE
_CATEGORYINFOARCHIVE.fields_by_name['super'].message_type = TSDArchives__pb2._DRAWABLEARCHIVE
_CATEGORYINFOARCHIVE.fields_by_name['tableModel'].message_type = TSPMessages__pb2._REFERENCE
_WPTABLEINFOARCHIVE.fields_by_name['super'].message_type = _TABLEINFOARCHIVE
_WPTABLEINFOARCHIVE.fields_by_name['storage'].message_type = TSPMessages__pb2._REFERENCE
_TABLESTYLENETWORKARCHIVE.fields_by_name['table_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLESTYLENETWORKARCHIVE.fields_by_name['body_text_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLESTYLENETWORKARCHIVE.fields_by_name['header_row_text_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLESTYLENETWORKARCHIVE.fields_by_name['header_column_text_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLESTYLENETWORKARCHIVE.fields_by_name['footer_row_text_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLESTYLENETWORKARCHIVE.fields_by_name['category_level_1_text_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLESTYLENETWORKARCHIVE.fields_by_name['category_level_2_text_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLESTYLENETWORKARCHIVE.fields_by_name['category_level_3_text_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLESTYLENETWORKARCHIVE.fields_by_name['category_level_4_text_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLESTYLENETWORKARCHIVE.fields_by_name['category_level_5_text_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLESTYLENETWORKARCHIVE.fields_by_name['label_level_1_text_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLESTYLENETWORKARCHIVE.fields_by_name['label_level_2_text_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLESTYLENETWORKARCHIVE.fields_by_name['label_level_3_text_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLESTYLENETWORKARCHIVE.fields_by_name['label_level_4_text_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLESTYLENETWORKARCHIVE.fields_by_name['label_level_5_text_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLESTYLENETWORKARCHIVE.fields_by_name['body_cell_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLESTYLENETWORKARCHIVE.fields_by_name['header_row_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLESTYLENETWORKARCHIVE.fields_by_name['header_column_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLESTYLENETWORKARCHIVE.fields_by_name['footer_row_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLESTYLENETWORKARCHIVE.fields_by_name['category_level_1_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLESTYLENETWORKARCHIVE.fields_by_name['category_level_2_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLESTYLENETWORKARCHIVE.fields_by_name['category_level_3_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLESTYLENETWORKARCHIVE.fields_by_name['category_level_4_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLESTYLENETWORKARCHIVE.fields_by_name['category_level_5_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLESTYLENETWORKARCHIVE.fields_by_name['label_level_1_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLESTYLENETWORKARCHIVE.fields_by_name['label_level_2_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLESTYLENETWORKARCHIVE.fields_by_name['label_level_3_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLESTYLENETWORKARCHIVE.fields_by_name['label_level_4_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLESTYLENETWORKARCHIVE.fields_by_name['label_level_5_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLESTYLENETWORKARCHIVE.fields_by_name['table_name_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLESTYLENETWORKARCHIVE.fields_by_name['table_name_shape_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLESORTORDERARCHIVE_SORTRULEARCHIVE.fields_by_name['direction'].enum_type = _TABLESORTORDERARCHIVE_SORTRULEARCHIVE_DIRECTION
_TABLESORTORDERARCHIVE_SORTRULEARCHIVE.containing_type = _TABLESORTORDERARCHIVE
_TABLESORTORDERARCHIVE_SORTRULEARCHIVE_DIRECTION.containing_type = _TABLESORTORDERARCHIVE_SORTRULEARCHIVE
_TABLESORTORDERARCHIVE.fields_by_name['type'].enum_type = _TABLESORTORDERARCHIVE_SORTTYPE
_TABLESORTORDERARCHIVE.fields_by_name['rules'].message_type = _TABLESORTORDERARCHIVE_SORTRULEARCHIVE
_TABLESORTORDERARCHIVE_SORTTYPE.containing_type = _TABLESORTORDERARCHIVE
_TABLESORTORDERUIDARCHIVE_SORTRULEARCHIVE.fields_by_name['column_uid'].message_type = TSPMessages__pb2._UUID
_TABLESORTORDERUIDARCHIVE_SORTRULEARCHIVE.fields_by_name['direction'].enum_type = _TABLESORTORDERUIDARCHIVE_SORTRULEARCHIVE_DIRECTION
_TABLESORTORDERUIDARCHIVE_SORTRULEARCHIVE.containing_type = _TABLESORTORDERUIDARCHIVE
_TABLESORTORDERUIDARCHIVE_SORTRULEARCHIVE_DIRECTION.containing_type = _TABLESORTORDERUIDARCHIVE_SORTRULEARCHIVE
_TABLESORTORDERUIDARCHIVE.fields_by_name['type'].enum_type = _TABLESORTORDERUIDARCHIVE_SORTTYPE
_TABLESORTORDERUIDARCHIVE.fields_by_name['rules'].message_type = _TABLESORTORDERUIDARCHIVE_SORTRULEARCHIVE
_TABLESORTORDERUIDARCHIVE_SORTTYPE.containing_type = _TABLESORTORDERUIDARCHIVE
_SORTRULEREFERENCETRACKERARCHIVE.fields_by_name['reference_tracker'].message_type = TSPMessages__pb2._REFERENCE
_CELLREGION.fields_by_name['cell_ranges'].message_type = _CELLRANGE
_CELLUIDREGIONARCHIVE.fields_by_name['cell_uid_ranges'].message_type = TSPMessages__pb2._UUIDRECTARCHIVE
_STRUCTUREDTEXTIMPORTRECORD.fields_by_name['import_settings'].message_type = TSKArchives__pb2._STRUCTUREDTEXTIMPORTSETTINGS
_STRUCTUREDTEXTIMPORTRECORD.fields_by_name['imported_region'].message_type = _CELLREGION
_TABLEMODELARCHIVE.fields_by_name['table_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLEMODELARCHIVE.fields_by_name['body_text_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLEMODELARCHIVE.fields_by_name['header_row_text_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLEMODELARCHIVE.fields_by_name['header_column_text_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLEMODELARCHIVE.fields_by_name['footer_row_text_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLEMODELARCHIVE.fields_by_name['body_cell_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLEMODELARCHIVE.fields_by_name['header_row_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLEMODELARCHIVE.fields_by_name['header_column_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLEMODELARCHIVE.fields_by_name['footer_row_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLEMODELARCHIVE.fields_by_name['table_name_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLEMODELARCHIVE.fields_by_name['table_name_shape_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLEMODELARCHIVE.fields_by_name['table_style_preset'].message_type = TSPMessages__pb2._REFERENCE
_TABLEMODELARCHIVE.fields_by_name['base_data_store'].message_type = _DATASTORE
_TABLEMODELARCHIVE.fields_by_name['provider'].message_type = TSPMessages__pb2._REFERENCE
_TABLEMODELARCHIVE.fields_by_name['origin_offset'].message_type = _CELLID
_TABLEMODELARCHIVE.fields_by_name['hidden_state_formula_owner_for_columns'].message_type = TSPMessages__pb2._REFERENCE
_TABLEMODELARCHIVE.fields_by_name['hidden_state_formula_owner_for_rows'].message_type = TSPMessages__pb2._REFERENCE
_TABLEMODELARCHIVE.fields_by_name['filter_set'].message_type = TSPMessages__pb2._REFERENCE
_TABLEMODELARCHIVE.fields_by_name['conditional_style_formula_owner_id'].message_type = TSPMessages__pb2._CFUUIDARCHIVE
_TABLEMODELARCHIVE.fields_by_name['sort_order'].message_type = _TABLESORTORDERARCHIVE
_TABLEMODELARCHIVE.fields_by_name['sort_rule_reference_tracker'].message_type = _SORTRULEREFERENCETRACKERARCHIVE
_TABLEMODELARCHIVE.fields_by_name['base_column_row_uids'].message_type = TSPMessages__pb2._REFERENCE
_TABLEMODELARCHIVE.fields_by_name['merge_owner'].message_type = _MERGEOWNERARCHIVE
_TABLEMODELARCHIVE.fields_by_name['stroke_sidecar'].message_type = TSPMessages__pb2._REFERENCE
_TABLEMODELARCHIVE.fields_by_name['text_import_record'].message_type = _STRUCTUREDTEXTIMPORTRECORD
_TABLEMODELARCHIVE.fields_by_name['category_level_1_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLEMODELARCHIVE.fields_by_name['category_level_2_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLEMODELARCHIVE.fields_by_name['category_level_3_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLEMODELARCHIVE.fields_by_name['category_level_4_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLEMODELARCHIVE.fields_by_name['category_level_5_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLEMODELARCHIVE.fields_by_name['label_level_1_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLEMODELARCHIVE.fields_by_name['label_level_2_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLEMODELARCHIVE.fields_by_name['label_level_3_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLEMODELARCHIVE.fields_by_name['label_level_4_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLEMODELARCHIVE.fields_by_name['label_level_5_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLEMODELARCHIVE.fields_by_name['category_level_1_text_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLEMODELARCHIVE.fields_by_name['category_level_2_text_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLEMODELARCHIVE.fields_by_name['category_level_3_text_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLEMODELARCHIVE.fields_by_name['category_level_4_text_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLEMODELARCHIVE.fields_by_name['category_level_5_text_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLEMODELARCHIVE.fields_by_name['label_level_1_text_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLEMODELARCHIVE.fields_by_name['label_level_2_text_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLEMODELARCHIVE.fields_by_name['label_level_3_text_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLEMODELARCHIVE.fields_by_name['label_level_4_text_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLEMODELARCHIVE.fields_by_name['label_level_5_text_style'].message_type = TSPMessages__pb2._REFERENCE
_TABLEMODELARCHIVE.fields_by_name['hidden_states_owner'].message_type = _HIDDENSTATESOWNERARCHIVE
_TABLEMODELARCHIVE.fields_by_name['category_owner'].message_type = _CATEGORYOWNERARCHIVE
_TABLEMODELARCHIVE.fields_by_name['pencil_annotation_owner'].message_type = _PENCILANNOTATIONOWNERARCHIVE
_TABLEMODELARCHIVE.fields_by_name['haunted_owner'].message_type = TSCEArchives__pb2._HAUNTEDOWNERARCHIVE
_SUMMARYMODELARCHIVE.fields_by_name['table_info'].message_type = TSPMessages__pb2._REFERENCE
_SUMMARYMODELARCHIVE.fields_by_name['data_store'].message_type = _DATASTORE
_SUMMARYMODELARCHIVE.fields_by_name['column_row_uids'].message_type = TSPMessages__pb2._REFERENCE
_SUMMARYMODELARCHIVE.fields_by_name['aggregate_formula_owner_uuid'].message_type = TSPMessages__pb2._UUID
_SUMMARYMODELARCHIVE.fields_by_name['summary_cell_vendor'].message_type = TSPMessages__pb2._REFERENCE
_SUMMARYMODELGROUPBYCHANGESTATEARCHIVE.fields_by_name['cell_map'].message_type = TSPMessages__pb2._REFERENCE
_COLUMNROWUIDMAPARCHIVE.fields_by_name['sorted_column_uids'].message_type = TSPMessages__pb2._UUID
_COLUMNROWUIDMAPARCHIVE.fields_by_name['sorted_row_uids'].message_type = TSPMessages__pb2._UUID
_STROKELAYERARCHIVE_STROKERUNARCHIVE.fields_by_name['stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_STROKELAYERARCHIVE_STROKERUNARCHIVE.containing_type = _STROKELAYERARCHIVE
_STROKELAYERARCHIVE.fields_by_name['stroke_runs'].message_type = _STROKELAYERARCHIVE_STROKERUNARCHIVE
_STROKESIDECARARCHIVE.fields_by_name['left_column_stroke_layers'].message_type = TSPMessages__pb2._REFERENCE
_STROKESIDECARARCHIVE.fields_by_name['right_column_stroke_layers'].message_type = TSPMessages__pb2._REFERENCE
_STROKESIDECARARCHIVE.fields_by_name['top_row_stroke_layers'].message_type = TSPMessages__pb2._REFERENCE
_STROKESIDECARARCHIVE.fields_by_name['bottom_row_stroke_layers'].message_type = TSPMessages__pb2._REFERENCE
_CELL.fields_by_name['valueType'].enum_type = _CELLVALUETYPE
_CELL.fields_by_name['cell_style'].message_type = TSPMessages__pb2._REFERENCE
_CELL.fields_by_name['text_style'].message_type = TSPMessages__pb2._REFERENCE
_CELL.fields_by_name['current_format'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_CELL.fields_by_name['formulaError'].message_type = TSPMessages__pb2._REFERENCE
_CELL.fields_by_name['number_format'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_CELL.fields_by_name['currency_format'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_CELL.fields_by_name['duration_format'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_CELL.fields_by_name['date_format'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_CELL.fields_by_name['custom_format'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_CELL.fields_by_name['base_format'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_CELL.fields_by_name['richText'].message_type = TSPMessages__pb2._REFERENCE
_CELL.fields_by_name['conditional_style'].message_type = TSPMessages__pb2._REFERENCE
_CELL.fields_by_name['comment_storage'].message_type = TSPMessages__pb2._REFERENCE
_CELL.fields_by_name['import_warning_set'].message_type = _IMPORTWARNINGSETARCHIVE
_CELL.fields_by_name['custom_format_object'].message_type = TSKArchives__pb2._CUSTOMFORMATARCHIVE
_CELL.fields_by_name['cell_border'].message_type = _CELLBORDERARCHIVE
_CELL.fields_by_name['cell_spec'].message_type = _CELLSPECARCHIVE
_CELL.fields_by_name['text_format'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_CELL.fields_by_name['boolean_format'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_MERGEREGIONMAPARCHIVE.fields_by_name['cell_range'].message_type = _CELLRANGE
_CELLMAPARCHIVE.fields_by_name['cell_tiles'].message_type = TSPMessages__pb2._REFERENCE
_CELLMAPARCHIVE.fields_by_name['expanded_cell_ids'].message_type = TSCEArchives__pb2._CELLCOORDINATEARCHIVE
_CELLMAPARCHIVE.fields_by_name['cell_uid_list'].message_type = _CELLUIDLISTARCHIVE
_CELLMAPARCHIVE.fields_by_name['merge_uid_ranges'].message_type = TSPMessages__pb2._UUIDRECTARCHIVE
_CELLMAPARCHIVE.fields_by_name['unmerge_uid_ranges'].message_type = TSPMessages__pb2._UUIDRECTARCHIVE
_CELLMAPARCHIVE.fields_by_name['merge_actions'].message_type = _MERGEOPERATIONARCHIVE
_CELLLISTARCHIVE_OPTIONALCELL.fields_by_name['cell'].message_type = _CELL
_CELLLISTARCHIVE_OPTIONALCELL.containing_type = _CELLLISTARCHIVE
_CELLLISTARCHIVE.fields_by_name['cells'].message_type = _CELLLISTARCHIVE_OPTIONALCELL
_CONCURRENTCELLMAPARCHIVE.fields_by_name['cell_lists'].message_type = TSPMessages__pb2._REFERENCE
_CONCURRENTCELLMAPARCHIVE.fields_by_name['merge_actions'].message_type = _MERGEOPERATIONARCHIVE
_CONCURRENTCELLLISTARCHIVE_OPTIONALCELL.fields_by_name['cell'].message_type = _CELL
_CONCURRENTCELLLISTARCHIVE_OPTIONALCELL.containing_type = _CONCURRENTCELLLISTARCHIVE
_CONCURRENTCELLLISTARCHIVE.fields_by_name['cells'].message_type = _CONCURRENTCELLLISTARCHIVE_OPTIONALCELL
_CONCURRENTCELLLISTARCHIVE.fields_by_name['cell_uid_range'].message_type = TSPMessages__pb2._UUIDRECTARCHIVE
_CONCURRENTCELLLISTARCHIVE.fields_by_name['cell_range'].message_type = _CELLRANGE
_CELLFORMATANDVALUEARCHIVE.fields_by_name['valueType'].enum_type = _CELLVALUETYPE
_CELLFORMATANDVALUEARCHIVE.fields_by_name['richTextStorage'].message_type = TSPMessages__pb2._REFERENCE
_CELLFORMATANDVALUEARCHIVE.fields_by_name['number_format'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_CELLFORMATANDVALUEARCHIVE.fields_by_name['currency_format'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_CELLFORMATANDVALUEARCHIVE.fields_by_name['date_format'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_CELLFORMATANDVALUEARCHIVE.fields_by_name['duration_format'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_CELLFORMATANDVALUEARCHIVE.fields_by_name['text_format'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_CELLFORMATANDVALUEARCHIVE.fields_by_name['boolean_format'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_CELLFORMATANDVALUEARCHIVE.fields_by_name['formatted_rich_text_value'].message_type = TSPMessages__pb2._REFERENCE
_CELLSPECARCHIVE.fields_by_name['formula'].message_type = TSCEArchives__pb2._FORMULAARCHIVE
_CELLSPECARCHIVE.fields_by_name['chooser_control_popup_model'].message_type = TSPMessages__pb2._REFERENCE
_COMMENTSTORAGEWRAPPERARCHIVE.fields_by_name['comment_storage'].message_type = TSPMessages__pb2._REFERENCE
_CELLDIFFARCHIVE.fields_by_name['property_map_to_set'].message_type = TSSArchives__pb2._COMMANDPROPERTYMAPARCHIVE
_CELLDIFFARCHIVE.fields_by_name['property_map_to_reset'].message_type = TSSArchives__pb2._COMMANDPROPERTYMAPARCHIVE
_CELLDIFFARRAY.fields_by_name['large_array'].message_type = TSPMessages__pb2._LARGEARRAY
_CELLDIFFARRAYSEGMENT.fields_by_name['large_array_segment'].message_type = TSPMessages__pb2._LARGEARRAYSEGMENT
_CELLDIFFARRAYSEGMENT.fields_by_name['elements'].message_type = _CELLDIFFARCHIVE
_CELLDIFFMAPARCHIVE.fields_by_name['expanded_cell_ids'].message_type = TSCEArchives__pb2._CELLCOORDINATEARCHIVE
_CELLDIFFMAPARCHIVE.fields_by_name['cell_uids'].message_type = _CELLUIDLISTARCHIVE
_CELLDIFFMAPARCHIVE.fields_by_name['cell_diff_array'].message_type = TSPMessages__pb2._REFERENCE
_DOUBLESTYLEMAPARCHIVE_DOUBLESTYLEMAPENTRYARCHIVE.fields_by_name['cell_id'].message_type = _CELLID
_DOUBLESTYLEMAPARCHIVE_DOUBLESTYLEMAPENTRYARCHIVE.fields_by_name['old_style'].message_type = TSPMessages__pb2._REFERENCE
_DOUBLESTYLEMAPARCHIVE_DOUBLESTYLEMAPENTRYARCHIVE.fields_by_name['new_style'].message_type = TSPMessages__pb2._REFERENCE
_DOUBLESTYLEMAPARCHIVE_DOUBLESTYLEMAPENTRYARCHIVE.containing_type = _DOUBLESTYLEMAPARCHIVE
_DOUBLESTYLEMAPARCHIVE.fields_by_name['cell_map_entry'].message_type = _DOUBLESTYLEMAPARCHIVE_DOUBLESTYLEMAPENTRYARCHIVE
_STYLETABLEMAPARCHIVE_STYLETABLEMAPENTRYARCHIVE.fields_by_name['old_style'].message_type = TSPMessages__pb2._REFERENCE
_STYLETABLEMAPARCHIVE_STYLETABLEMAPENTRYARCHIVE.fields_by_name['new_style'].message_type = TSPMessages__pb2._REFERENCE
_STYLETABLEMAPARCHIVE_STYLETABLEMAPENTRYARCHIVE.containing_type = _STYLETABLEMAPARCHIVE
_STYLETABLEMAPARCHIVE.fields_by_name['map_entry'].message_type = _STYLETABLEMAPARCHIVE_STYLETABLEMAPENTRYARCHIVE
_SELECTIONARCHIVE.fields_by_name['tableModel'].message_type = TSPMessages__pb2._REFERENCE
_SELECTIONARCHIVE.fields_by_name['selection_type'].enum_type = _SELECTIONTYPEARCHIVE
_SELECTIONARCHIVE.fields_by_name['anchor_cell'].message_type = _CELLID
_SELECTIONARCHIVE.fields_by_name['cell_ranges'].message_type = _CELLRANGE
_SELECTIONARCHIVE.fields_by_name['base_ranges'].message_type = _CELLRANGE
_SELECTIONARCHIVE.fields_by_name['cursor_cell'].message_type = _CELLID
_SELECTIONARCHIVE.fields_by_name['table_info'].message_type = TSPMessages__pb2._REFERENCE
_SELECTIONARCHIVE.fields_by_name['cell_uid_region'].message_type = _CELLUIDREGIONARCHIVE
_SELECTIONARCHIVE.fields_by_name['base_uid_region'].message_type = _CELLUIDREGIONARCHIVE
_SELECTIONARCHIVE.fields_by_name['anchor_cell_uid'].message_type = TSPMessages__pb2._UUIDCOORDARCHIVE
_SELECTIONARCHIVE.fields_by_name['cursor_cell_uid'].message_type = TSPMessages__pb2._UUIDCOORDARCHIVE
_DEATHHAWKRDAR39989167CELLSELECTIONARCHIVE.fields_by_name['table_info'].message_type = TSPMessages__pb2._REFERENCE
_DEATHHAWKRDAR39989167CELLSELECTIONARCHIVE.fields_by_name['selection_type'].enum_type = _SELECTIONTYPEARCHIVE
_DEATHHAWKRDAR39989167CELLSELECTIONARCHIVE.fields_by_name['cell_uid_region'].message_type = _CELLUIDREGIONARCHIVE
_DEATHHAWKRDAR39989167CELLSELECTIONARCHIVE.fields_by_name['base_uid_region'].message_type = _CELLUIDREGIONARCHIVE
_DEATHHAWKRDAR39989167CELLSELECTIONARCHIVE.fields_by_name['anchor_cell_uid'].message_type = TSPMessages__pb2._UUIDCOORDARCHIVE
_DEATHHAWKRDAR39989167CELLSELECTIONARCHIVE.fields_by_name['cursor_cell_uid'].message_type = TSPMessages__pb2._UUIDCOORDARCHIVE
_AUTOFILLSELECTIONARCHIVE.fields_by_name['source_cell_range'].message_type = _CELLRANGE
_AUTOFILLSELECTIONARCHIVE.fields_by_name['target_cell_range'].message_type = _CELLRANGE
_FILTERRULEARCHIVE.fields_by_name['predicate'].message_type = _FORMULAPREDICATEARCHIVE
_TABLESTYLEARCHIVE.fields_by_name['super'].message_type = TSSArchives__pb2._STYLEARCHIVE
_TABLESTYLEARCHIVE.fields_by_name['table_properties'].message_type = TSTStylePropertyArchiving__pb2._TABLESTYLEPROPERTIESARCHIVE
_CELLSTYLEARCHIVE.fields_by_name['super'].message_type = TSSArchives__pb2._STYLEARCHIVE
_CELLSTYLEARCHIVE.fields_by_name['cell_properties'].message_type = TSTStylePropertyArchiving__pb2._CELLSTYLEPROPERTIESARCHIVE
_FORMULAPREDICATEARCHIVE.fields_by_name['formula'].message_type = TSCEArchives__pb2._FORMULAARCHIVE
_FORMULAPREDICATEARCHIVE.fields_by_name['predicate_type'].enum_type = _FORMULAPREDICATEARCHIVE_FORMULAPREDICATETYPE
_FORMULAPREDICATEARCHIVE.fields_by_name['qualifier1'].enum_type = _FORMULAPREDICATEARCHIVE_QUALIFIERTYPE
_FORMULAPREDICATEARCHIVE.fields_by_name['qualifier2'].enum_type = _FORMULAPREDICATEARCHIVE_QUALIFIERTYPE
_FORMULAPREDICATEARCHIVE_FORMULAPREDICATETYPE.containing_type = _FORMULAPREDICATEARCHIVE
_FORMULAPREDICATEARCHIVE_QUALIFIERTYPE.containing_type = _FORMULAPREDICATEARCHIVE
_CONDITIONALSTYLESETARCHIVE_CONDITIONALSTYLERULE.fields_by_name['predicate'].message_type = _FORMULAPREDICATEARCHIVE
_CONDITIONALSTYLESETARCHIVE_CONDITIONALSTYLERULE.fields_by_name['cell_style'].message_type = TSPMessages__pb2._REFERENCE
_CONDITIONALSTYLESETARCHIVE_CONDITIONALSTYLERULE.fields_by_name['text_style'].message_type = TSPMessages__pb2._REFERENCE
_CONDITIONALSTYLESETARCHIVE_CONDITIONALSTYLERULE.containing_type = _CONDITIONALSTYLESETARCHIVE
_CONDITIONALSTYLESETARCHIVE.fields_by_name['rules'].message_type = _CONDITIONALSTYLESETARCHIVE_CONDITIONALSTYLERULE
_FILTERSETARCHIVE.fields_by_name['type'].enum_type = _FILTERSETARCHIVE_FILTERSETTYPE
_FILTERSETARCHIVE.fields_by_name['filter_rules'].message_type = _FILTERRULEARCHIVE
_FILTERSETARCHIVE_FILTERSETTYPE.containing_type = _FILTERSETARCHIVE
_HIDDENSTATEEXTENTARCHIVE_ROWORCOLUMNSTATE.fields_by_name['row_or_column_uid'].message_type = TSPMessages__pb2._UUID
_HIDDENSTATEEXTENTARCHIVE_ROWORCOLUMNSTATE.containing_type = _HIDDENSTATEEXTENTARCHIVE
_HIDDENSTATEEXTENTARCHIVE.fields_by_name['hidden_state_extent_uid'].message_type = TSPMessages__pb2._UUID
_HIDDENSTATEEXTENTARCHIVE.fields_by_name['hidden_states'].message_type = _HIDDENSTATEEXTENTARCHIVE_ROWORCOLUMNSTATE
_HIDDENSTATEEXTENTARCHIVE.fields_by_name['row_or_column_direction'].enum_type = _HIDDENSTATEEXTENTARCHIVE_ROWORCOLUMNDIRECTION
_HIDDENSTATEEXTENTARCHIVE.fields_by_name['threshold_value'].message_type = TSCEArchives__pb2._CELLVALUEARCHIVE
_HIDDENSTATEEXTENTARCHIVE.fields_by_name['collapsed_group_uids'].message_type = TSPMessages__pb2._UUID
_HIDDENSTATEEXTENTARCHIVE_ROWORCOLUMNDIRECTION.containing_type = _HIDDENSTATEEXTENTARCHIVE
_HIDDENSTATESARCHIVE.fields_by_name['hidden_states_uid'].message_type = TSPMessages__pb2._UUID
_HIDDENSTATESARCHIVE.fields_by_name['column_hidden_state_extent'].message_type = _HIDDENSTATEEXTENTARCHIVE
_HIDDENSTATESARCHIVE.fields_by_name['row_hidden_state_extent'].message_type = _HIDDENSTATEEXTENTARCHIVE
_HIDDENSTATESOWNERARCHIVE.fields_by_name['owner_uid'].message_type = TSPMessages__pb2._UUID
_HIDDENSTATESOWNERARCHIVE.fields_by_name['hidden_states'].message_type = _HIDDENSTATESARCHIVE
_EXPANDCOLLAPSESTATEARCHIVE.fields_by_name['uids_collapsed'].message_type = TSPMessages__pb2._UUID
_EXPANDCOLLAPSESTATEARCHIVE.fields_by_name['uids_expanded'].message_type = TSPMessages__pb2._UUID
_TOKENATTACHMENTARCHIVE.fields_by_name['super'].message_type = TSWPArchives__pb2._UIGRAPHICALATTACHMENT
_TOKENATTACHMENTARCHIVE.fields_by_name['expressionNode'].message_type = TSPMessages__pb2._REFERENCE
_FORMULAARCHIVE.fields_by_name['expressionTree'].message_type = TSPMessages__pb2._REFERENCE
_EXPRESSIONNODEARCHIVE.fields_by_name['children'].message_type = TSPMessages__pb2._REFERENCE
_BOOLEANNODEARCHIVE.fields_by_name['super'].message_type = _EXPRESSIONNODEARCHIVE
_NUMBERNODEARCHIVE.fields_by_name['super'].message_type = _EXPRESSIONNODEARCHIVE
_STRINGNODEARCHIVE.fields_by_name['super'].message_type = _EXPRESSIONNODEARCHIVE
_IDENTIFIERNODEARCHIVE.fields_by_name['super'].message_type = _EXPRESSIONNODEARCHIVE
_ARRAYNODEARCHIVE.fields_by_name['super'].message_type = _EXPRESSIONNODEARCHIVE
_LISTNODEARCHIVE.fields_by_name['super'].message_type = _EXPRESSIONNODEARCHIVE
_OPERATORNODEARCHIVE.fields_by_name['super'].message_type = _EXPRESSIONNODEARCHIVE
_POSTFIXOPERATORNODEARCHIVE.fields_by_name['super'].message_type = _OPERATORNODEARCHIVE
_PREFIXOPERATORNODEARCHIVE.fields_by_name['super'].message_type = _OPERATORNODEARCHIVE
_FUNCTIONNODEARCHIVE.fields_by_name['super'].message_type = _EXPRESSIONNODEARCHIVE
_FUNCTIONENDNODEARCHIVE.fields_by_name['super'].message_type = _EXPRESSIONNODEARCHIVE
_DATENODEARCHIVE.fields_by_name['super'].message_type = _EXPRESSIONNODEARCHIVE
_REFERENCENODEARCHIVE.fields_by_name['super'].message_type = _EXPRESSIONNODEARCHIVE
_REFERENCENODEARCHIVE.fields_by_name['rangeReference'].message_type = TSCEArchives__pb2._RANGEREFERENCEARCHIVE
_REFERENCENODEARCHIVE.fields_by_name['host_cell_ref'].message_type = TSCEArchives__pb2._CELLREFERENCEARCHIVE
_REFERENCENODEARCHIVE.fields_by_name['table_uid'].message_type = TSPMessages__pb2._UUID
_REFERENCENODEARCHIVE.fields_by_name['range_top_left'].message_type = TSPMessages__pb2._UUIDCOORDARCHIVE
_REFERENCENODEARCHIVE.fields_by_name['range_bottom_right'].message_type = TSPMessages__pb2._UUIDCOORDARCHIVE
_REFERENCENODEARCHIVE.fields_by_name['category_ref'].message_type = TSCEArchives__pb2._CATEGORYREFERENCEARCHIVE
_REFERENCENODEARCHIVE.fields_by_name['uid_range_rect'].message_type = TSPMessages__pb2._UUIDRECTARCHIVE
_DURATIONNODEARCHIVE.fields_by_name['super'].message_type = _EXPRESSIONNODEARCHIVE
_ARGUMENTPLACEHOLDERNODEARCHIVE.fields_by_name['super'].message_type = _EXPRESSIONNODEARCHIVE
_EMPTYEXPRESSIONNODEARCHIVE.fields_by_name['super'].message_type = _EXPRESSIONNODEARCHIVE
_LETNODEARCHIVE.fields_by_name['super'].message_type = _EXPRESSIONNODEARCHIVE
_INNODEARCHIVE.fields_by_name['super'].message_type = _EXPRESSIONNODEARCHIVE
_VARIABLENODEARCHIVE.fields_by_name['super'].message_type = _EXPRESSIONNODEARCHIVE
_LAYOUTHINTARCHIVE.fields_by_name['cellRange'].message_type = _CELLRANGE
_LAYOUTHINTARCHIVE.fields_by_name['hintID'].message_type = _CELLID
_LAYOUTHINTARCHIVE.fields_by_name['maximumSize'].message_type = TSPMessages__pb2._SIZE
_LAYOUTHINTARCHIVE.fields_by_name['effectiveSize'].message_type = TSPMessages__pb2._SIZE
_COMPLETIONTOKENATTACHMENTARCHIVE.fields_by_name['super'].message_type = _TOKENATTACHMENTARCHIVE
_HIDDENSTATEFORMULAOWNERARCHIVE.fields_by_name['owner_id'].message_type = TSPMessages__pb2._CFUUIDARCHIVE
_HIDDENSTATEFORMULAOWNERARCHIVE.fields_by_name['threshold_value'].message_type = TSCEArchives__pb2._CELLVALUEARCHIVE
_FORMULASTOREARCHIVE_FORMULASTOREPAIR.fields_by_name['formula'].message_type = TSCEArchives__pb2._FORMULAARCHIVE
_FORMULASTOREARCHIVE_FORMULASTOREPAIR.containing_type = _FORMULASTOREARCHIVE
_FORMULASTOREARCHIVE.fields_by_name['formulas'].message_type = _FORMULASTOREARCHIVE_FORMULASTOREPAIR
_MERGEOPERATIONARCHIVE.fields_by_name['merge_type'].enum_type = _MERGEACTIONARCHIVE
_MERGEOPERATIONARCHIVE.fields_by_name['merge_ranges'].message_type = TSPMessages__pb2._UUIDRECTARCHIVE
_MERGEOPERATIONARCHIVE.fields_by_name['merge_formulas'].message_type = TSCEArchives__pb2._FORMULAARCHIVE
_MERGEOWNERARCHIVE.fields_by_name['owner_id'].message_type = TSPMessages__pb2._CFUUIDARCHIVE
_MERGEOWNERARCHIVE.fields_by_name['formula_store'].message_type = _FORMULASTOREARCHIVE
_PENCILANNOTATIONARCHIVE.fields_by_name['table_info'].message_type = TSPMessages__pb2._REFERENCE
_PENCILANNOTATIONARCHIVE.fields_by_name['pencil_annotation_storage'].message_type = TSPMessages__pb2._REFERENCE
_PENCILANNOTATIONOWNERARCHIVE.fields_by_name['owner_id'].message_type = TSPMessages__pb2._CFUUIDARCHIVE
_PENCILANNOTATIONOWNERARCHIVE.fields_by_name['formula_store'].message_type = _FORMULASTOREARCHIVE
_PENCILANNOTATIONOWNERARCHIVE.fields_by_name['annotations'].message_type = TSPMessages__pb2._REFERENCE
_ACCUMULATORARCHIVE.fields_by_name['min_value'].message_type = TSCEArchives__pb2._CELLVALUEARCHIVE
_ACCUMULATORARCHIVE.fields_by_name['max_value'].message_type = TSCEArchives__pb2._CELLVALUEARCHIVE
_ACCUMULATORARCHIVE.fields_by_name['number_total_value'].message_type = TSCEArchives__pb2._CELLVALUEARCHIVE
_ACCUMULATORARCHIVE.fields_by_name['first_date_seen'].message_type = TSCEArchives__pb2._CELLVALUEARCHIVE
_GROUPCOLUMNARCHIVE.fields_by_name['column_uid'].message_type = TSPMessages__pb2._UUID
_GROUPCOLUMNARCHIVE.fields_by_name['grouping_type'].enum_type = _GROUPINGTYPE
_GROUPCOLUMNARCHIVE.fields_by_name['grouping_functor'].message_type = TSCEArchives__pb2._FUNCTORARCHIVE
_GROUPCOLUMNARCHIVE.fields_by_name['grouping_column_uid'].message_type = TSPMessages__pb2._UUID
_GROUPCOLUMNLISTARCHIVE.fields_by_name['group_column'].message_type = _GROUPCOLUMNARCHIVE
_COLUMNAGGREGATEARCHIVE.fields_by_name['column_uid'].message_type = TSPMessages__pb2._UUID
_COLUMNAGGREGATEARCHIVE.fields_by_name['agg_type'].enum_type = _AGGREGATETYPE
_COLUMNAGGREGATELISTARCHIVE.fields_by_name['aggregates'].message_type = _COLUMNAGGREGATEARCHIVE
_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_AGGNODEARCHIVE.fields_by_name['formula_coord'].message_type = TSCEArchives__pb2._CELLCOORDINATEARCHIVE
_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_AGGNODEARCHIVE.fields_by_name['accum'].message_type = _ACCUMULATORARCHIVE
_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_AGGNODEARCHIVE.fields_by_name['child'].message_type = _CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_AGGNODEARCHIVE
_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_AGGNODEARCHIVE.containing_type = _CATEGORYOWNERARCHIVE_GROUPBYARCHIVE
_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_GROUPNODEARCHIVE_GROUPVALUETUPLEARCHIVE.fields_by_name['value'].message_type = TSCEArchives__pb2._CELLVALUEARCHIVE
_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_GROUPNODEARCHIVE_GROUPVALUETUPLEARCHIVE.containing_type = _CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_GROUPNODEARCHIVE
_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_GROUPNODEARCHIVE_FORMATMANAGERARCHIVE_ROWSETARCHIVE.fields_by_name['row_uids'].message_type = TSPMessages__pb2._UUID
_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_GROUPNODEARCHIVE_FORMATMANAGERARCHIVE_ROWSETARCHIVE.containing_type = _CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_GROUPNODEARCHIVE_FORMATMANAGERARCHIVE
_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_GROUPNODEARCHIVE_FORMATMANAGERARCHIVE.fields_by_name['cell_value'].message_type = TSCEArchives__pb2._CELLVALUEARCHIVE
_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_GROUPNODEARCHIVE_FORMATMANAGERARCHIVE.fields_by_name['formats'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_GROUPNODEARCHIVE_FORMATMANAGERARCHIVE.fields_by_name['row_sets'].message_type = _CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_GROUPNODEARCHIVE_FORMATMANAGERARCHIVE_ROWSETARCHIVE
_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_GROUPNODEARCHIVE_FORMATMANAGERARCHIVE.containing_type = _CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_GROUPNODEARCHIVE
_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_GROUPNODEARCHIVE.fields_by_name['group_uid'].message_type = TSPMessages__pb2._UUID
_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_GROUPNODEARCHIVE.fields_by_name['group_value_tuple'].message_type = _CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_GROUPNODEARCHIVE_GROUPVALUETUPLEARCHIVE
_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_GROUPNODEARCHIVE.fields_by_name['group_cell_value'].message_type = TSCEArchives__pb2._CELLVALUEARCHIVE
_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_GROUPNODEARCHIVE.fields_by_name['child'].message_type = _CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_GROUPNODEARCHIVE
_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_GROUPNODEARCHIVE.fields_by_name['row_uid'].message_type = TSPMessages__pb2._UUID
_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_GROUPNODEARCHIVE.fields_by_name['agg_formula_coords'].message_type = TSCEArchives__pb2._CELLCOORDINATEARCHIVE
_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_GROUPNODEARCHIVE.fields_by_name['format_manager'].message_type = _CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_GROUPNODEARCHIVE_FORMATMANAGERARCHIVE
_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_GROUPNODEARCHIVE.containing_type = _CATEGORYOWNERARCHIVE_GROUPBYARCHIVE
_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_AGGREGATORARCHIVE.fields_by_name['column_uid'].message_type = TSPMessages__pb2._UUID
_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_AGGREGATORARCHIVE.fields_by_name['agg_node'].message_type = _CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_AGGNODEARCHIVE
_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_AGGREGATORARCHIVE.containing_type = _CATEGORYOWNERARCHIVE_GROUPBYARCHIVE
_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE.fields_by_name['group_by_uid'].message_type = TSPMessages__pb2._UUID
_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE.fields_by_name['group_column'].message_type = _GROUPCOLUMNARCHIVE
_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE.fields_by_name['group_node_root'].message_type = _CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_GROUPNODEARCHIVE
_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE.fields_by_name['aggregator'].message_type = _CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_AGGREGATORARCHIVE
_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE.fields_by_name['column_agg_type'].message_type = _COLUMNAGGREGATEARCHIVE
_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE.fields_by_name['indirect_agg_type_change_formula'].message_type = TSCEArchives__pb2._CELLCOORDINATEARCHIVE
_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE.fields_by_name['grouping_columns_formula'].message_type = TSCEArchives__pb2._CELLCOORDINATEARCHIVE
_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE.fields_by_name['grouping_column_headers_formula'].message_type = TSCEArchives__pb2._CELLCOORDINATEARCHIVE
_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE.fields_by_name['aggs_in_group_root_formula'].message_type = TSCEArchives__pb2._CELLCOORDINATEARCHIVE
_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE.fields_by_name['column_order_changed_formula'].message_type = TSCEArchives__pb2._CELLCOORDINATEARCHIVE
_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE.fields_by_name['row_order_changed_formula'].message_type = TSCEArchives__pb2._CELLCOORDINATEARCHIVE
_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE.fields_by_name['row_order_changed_ignoring_recalc_formula'].message_type = TSCEArchives__pb2._CELLCOORDINATEARCHIVE
_CATEGORYOWNERARCHIVE_GROUPBYARCHIVE.containing_type = _CATEGORYOWNERARCHIVE
_CATEGORYOWNERARCHIVE.fields_by_name['owner_uid'].message_type = TSPMessages__pb2._UUID
_CATEGORYOWNERARCHIVE.fields_by_name['group_by'].message_type = _CATEGORYOWNERARCHIVE_GROUPBYARCHIVE
_RICHTEXTPAYLOADARCHIVE.fields_by_name['storage'].message_type = TSPMessages__pb2._REFERENCE
_RICHTEXTPAYLOADARCHIVE.fields_by_name['range'].message_type = TSPMessages__pb2._RANGE
_RICHTEXTPAYLOADARCHIVE.fields_by_name['cellid'].message_type = _CELLID
_FORMULAEQUALSTOKENATTACHMENTARCHIVE.fields_by_name['super'].message_type = TSWPArchives__pb2._UIGRAPHICALATTACHMENT
_CELLFILLSTANDIN.fields_by_name['fill'].message_type = TSDArchives__pb2._FILLARCHIVE
_FORMULASELECTIONARCHIVE.fields_by_name['super'].message_type = TSWPArchives__pb2._SELECTIONARCHIVE
_CELLBORDERARCHIVE.fields_by_name['top_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CELLBORDERARCHIVE.fields_by_name['right_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CELLBORDERARCHIVE.fields_by_name['bottom_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CELLBORDERARCHIVE.fields_by_name['left_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_DEFAULTCELLSTYLESCONTAINERARCHIVE.fields_by_name['table_style_network'].message_type = TSPMessages__pb2._REFERENCE
_DEFAULTCELLSTYLESCONTAINERARCHIVE.fields_by_name['header_row_uids'].message_type = TSPMessages__pb2._UUID
_DEFAULTCELLSTYLESCONTAINERARCHIVE.fields_by_name['footer_row_uids'].message_type = TSPMessages__pb2._UUID
_DEFAULTCELLSTYLESCONTAINERARCHIVE.fields_by_name['header_column_uids'].message_type = TSPMessages__pb2._UUID
_MULTITABLEREMAPPERARCHIVE.fields_by_name['mapping_purpose'].enum_type = _MULTITABLEREMAPPERARCHIVE_PURPOSE
_MULTITABLEREMAPPERARCHIVE.fields_by_name['owner_uid_mapper'].message_type = TSCEArchives__pb2._OWNERUIDMAPPERARCHIVE
_MULTITABLEREMAPPERARCHIVE.fields_by_name['backing_tables_for_charts'].message_type = TSPMessages__pb2._UUIDMAPARCHIVE
_MULTITABLEREMAPPERARCHIVE_PURPOSE.containing_type = _MULTITABLEREMAPPERARCHIVE
_CHANGEPROPAGATIONMAPWRAPPER.fields_by_name['style_replace_prototypes'].message_type = TSPMessages__pb2._REFERENCE
_CHANGEPROPAGATIONMAPWRAPPER.fields_by_name['style_replace_replacements'].message_type = TSPMessages__pb2._REFERENCE
_CHANGEPROPAGATIONMAPWRAPPER.fields_by_name['style_modify_styles'].message_type = TSPMessages__pb2._REFERENCE
_CHANGEPROPAGATIONMAPWRAPPER.fields_by_name['style_modify_old_prop_maps'].message_type = TSPMessages__pb2._REFERENCE
_CHANGEPROPAGATIONMAPWRAPPER.fields_by_name['style_modify_new_prop_maps'].message_type = TSPMessages__pb2._REFERENCE
_CHANGEPROPAGATIONMAPWRAPPER.fields_by_name['style_delete_prototypes'].message_type = TSPMessages__pb2._REFERENCE
_CHANGEPROPAGATIONMAPWRAPPER.fields_by_name['style_delete_replacements'].message_type = TSPMessages__pb2._REFERENCE
_CHANGEPROPAGATIONMAPWRAPPER.fields_by_name['table_preset_replace_prototype'].message_type = TSPMessages__pb2._REFERENCE
_CHANGEPROPAGATIONMAPWRAPPER.fields_by_name['table_preset_replace_replacement'].message_type = TSPMessages__pb2._REFERENCE
_CHANGEPROPAGATIONMAPWRAPPER.fields_by_name['table_preset_delete_prototype'].message_type = TSPMessages__pb2._REFERENCE
_CHANGEPROPAGATIONMAPWRAPPER.fields_by_name['table_preset_delete_replacement'].message_type = TSPMessages__pb2._REFERENCE
_SUMMARYCELLVENDORARCHIVE_SUMMARYCELLENTRY.fields_by_name['wildcardUID'].message_type = TSPMessages__pb2._UUID
_SUMMARYCELLVENDORARCHIVE_SUMMARYCELLENTRY.fields_by_name['columnUID'].message_type = TSPMessages__pb2._UUID
_SUMMARYCELLVENDORARCHIVE_SUMMARYCELLENTRY.fields_by_name['cell'].message_type = _CELL
_SUMMARYCELLVENDORARCHIVE_SUMMARYCELLENTRY.containing_type = _SUMMARYCELLVENDORARCHIVE
_SUMMARYCELLVENDORARCHIVE.fields_by_name['table_info'].message_type = TSPMessages__pb2._REFERENCE
_SUMMARYCELLVENDORARCHIVE.fields_by_name['entries'].message_type = _SUMMARYCELLVENDORARCHIVE_SUMMARYCELLENTRY
_CATEGORYORDERARCHIVE.fields_by_name['table_info'].message_type = TSPMessages__pb2._REFERENCE
_CATEGORYORDERARCHIVE.fields_by_name['uid_map'].message_type = TSPMessages__pb2._REFERENCE
_HEADERNAMEMGRTILEARCHIVE_NAMEFRAGMENTARCHIVE.fields_by_name['name_precedent'].message_type = TSCEArchives__pb2._CELLCOORDINATEARCHIVE
_HEADERNAMEMGRTILEARCHIVE_NAMEFRAGMENTARCHIVE.fields_by_name['uses_of_name_fragment'].message_type = TSCEArchives__pb2._UIDCELLREFSETARCHIVE
_HEADERNAMEMGRTILEARCHIVE_NAMEFRAGMENTARCHIVE.containing_type = _HEADERNAMEMGRTILEARCHIVE
_HEADERNAMEMGRTILEARCHIVE.fields_by_name['name_frag_entries'].message_type = _HEADERNAMEMGRTILEARCHIVE_NAMEFRAGMENTARCHIVE
_HEADERNAMEMGRARCHIVE_PERTABLEARCHIVE.fields_by_name['table_uid'].message_type = TSPMessages__pb2._UUID
_HEADERNAMEMGRARCHIVE_PERTABLEARCHIVE.fields_by_name['per_table_precedent'].message_type = TSCEArchives__pb2._CELLCOORDINATEARCHIVE
_HEADERNAMEMGRARCHIVE_PERTABLEARCHIVE.fields_by_name['header_row_uids'].message_type = TSPMessages__pb2._UUID
_HEADERNAMEMGRARCHIVE_PERTABLEARCHIVE.fields_by_name['header_column_uids'].message_type = TSPMessages__pb2._UUID
_HEADERNAMEMGRARCHIVE_PERTABLEARCHIVE.fields_by_name['update_header_row_uids'].message_type = TSPMessages__pb2._UUID
_HEADERNAMEMGRARCHIVE_PERTABLEARCHIVE.fields_by_name['update_header_column_uids'].message_type = TSPMessages__pb2._UUID
_HEADERNAMEMGRARCHIVE_PERTABLEARCHIVE.containing_type = _HEADERNAMEMGRARCHIVE
_HEADERNAMEMGRARCHIVE.fields_by_name['owner_uid'].message_type = TSPMessages__pb2._UUID
_HEADERNAMEMGRARCHIVE.fields_by_name['nrm_owner_uid'].message_type = TSPMessages__pb2._UUID
_HEADERNAMEMGRARCHIVE.fields_by_name['per_tables'].message_type = _HEADERNAMEMGRARCHIVE_PERTABLEARCHIVE
_HEADERNAMEMGRARCHIVE.fields_by_name['name_frag_tiles'].message_type = TSPMessages__pb2._REFERENCE
_WIDTHHEIGHTCACHE.fields_by_name['rows_fitting_entries'].message_type = _WIDTHHEIGHTCACHEFITTINGENTRY
_MASTERLAYOUTARCHIVE.fields_by_name['width_height_cache'].message_type = _WIDTHHEIGHTCACHE
DESCRIPTOR.message_types_by_name['CellID'] = _CELLID
DESCRIPTOR.message_types_by_name['CellUIDLookupListArchive'] = _CELLUIDLOOKUPLISTARCHIVE
DESCRIPTOR.message_types_by_name['CellUIDListArchive'] = _CELLUIDLISTARCHIVE
DESCRIPTOR.message_types_by_name['TableSize'] = _TABLESIZE
DESCRIPTOR.message_types_by_name['ExpandedTableSize'] = _EXPANDEDTABLESIZE
DESCRIPTOR.message_types_by_name['CellRange'] = _CELLRANGE
DESCRIPTOR.message_types_by_name['ExpandedCellRange'] = _EXPANDEDCELLRANGE
DESCRIPTOR.message_types_by_name['TableSelection'] = _TABLESELECTION
DESCRIPTOR.message_types_by_name['TileRowInfo'] = _TILEROWINFO
DESCRIPTOR.message_types_by_name['Tile'] = _TILE
DESCRIPTOR.message_types_by_name['TileStorage'] = _TILESTORAGE
DESCRIPTOR.message_types_by_name['PopUpMenuModel'] = _POPUPMENUMODEL
DESCRIPTOR.message_types_by_name['ImportWarningSetArchive'] = _IMPORTWARNINGSETARCHIVE
DESCRIPTOR.message_types_by_name['CellRefImportWarningSetPairArchive'] = _CELLREFIMPORTWARNINGSETPAIRARCHIVE
DESCRIPTOR.message_types_by_name['ImportWarningSetByCellRefArchive'] = _IMPORTWARNINGSETBYCELLREFARCHIVE
DESCRIPTOR.message_types_by_name['TableDataList'] = _TABLEDATALIST
DESCRIPTOR.message_types_by_name['TableDataListSegment'] = _TABLEDATALISTSEGMENT
DESCRIPTOR.message_types_by_name['TableRBTree'] = _TABLERBTREE
DESCRIPTOR.message_types_by_name['HeaderStorageBucket'] = _HEADERSTORAGEBUCKET
DESCRIPTOR.message_types_by_name['HeaderStorage'] = _HEADERSTORAGE
DESCRIPTOR.message_types_by_name['DataStore'] = _DATASTORE
DESCRIPTOR.message_types_by_name['TableInfoArchive'] = _TABLEINFOARCHIVE
DESCRIPTOR.message_types_by_name['CategoryInfoArchive'] = _CATEGORYINFOARCHIVE
DESCRIPTOR.message_types_by_name['WPTableInfoArchive'] = _WPTABLEINFOARCHIVE
DESCRIPTOR.message_types_by_name['TableStyleNetworkArchive'] = _TABLESTYLENETWORKARCHIVE
DESCRIPTOR.message_types_by_name['TableSortOrderArchive'] = _TABLESORTORDERARCHIVE
DESCRIPTOR.message_types_by_name['TableSortOrderUIDArchive'] = _TABLESORTORDERUIDARCHIVE
DESCRIPTOR.message_types_by_name['SortRuleReferenceTrackerArchive'] = _SORTRULEREFERENCETRACKERARCHIVE
DESCRIPTOR.message_types_by_name['CellRegion'] = _CELLREGION
DESCRIPTOR.message_types_by_name['CellUIDRegionArchive'] = _CELLUIDREGIONARCHIVE
DESCRIPTOR.message_types_by_name['StructuredTextImportRecord'] = _STRUCTUREDTEXTIMPORTRECORD
DESCRIPTOR.message_types_by_name['TableModelArchive'] = _TABLEMODELARCHIVE
DESCRIPTOR.message_types_by_name['SummaryModelArchive'] = _SUMMARYMODELARCHIVE
DESCRIPTOR.message_types_by_name['SummaryModelGroupByChangeStateArchive'] = _SUMMARYMODELGROUPBYCHANGESTATEARCHIVE
DESCRIPTOR.message_types_by_name['ColumnRowUIDMapArchive'] = _COLUMNROWUIDMAPARCHIVE
DESCRIPTOR.message_types_by_name['StrokeLayerArchive'] = _STROKELAYERARCHIVE
DESCRIPTOR.message_types_by_name['StrokeSidecarArchive'] = _STROKESIDECARARCHIVE
DESCRIPTOR.message_types_by_name['DurationWrapperArchive'] = _DURATIONWRAPPERARCHIVE
DESCRIPTOR.message_types_by_name['Cell'] = _CELL
DESCRIPTOR.message_types_by_name['MergeRegionMapArchive'] = _MERGEREGIONMAPARCHIVE
DESCRIPTOR.message_types_by_name['CellMapArchive'] = _CELLMAPARCHIVE
DESCRIPTOR.message_types_by_name['CellListArchive'] = _CELLLISTARCHIVE
DESCRIPTOR.message_types_by_name['ConcurrentCellMapArchive'] = _CONCURRENTCELLMAPARCHIVE
DESCRIPTOR.message_types_by_name['ConcurrentCellListArchive'] = _CONCURRENTCELLLISTARCHIVE
DESCRIPTOR.message_types_by_name['CellFormatAndValueArchive'] = _CELLFORMATANDVALUEARCHIVE
DESCRIPTOR.message_types_by_name['CellSpecArchive'] = _CELLSPECARCHIVE
DESCRIPTOR.message_types_by_name['CommentStorageWrapperArchive'] = _COMMENTSTORAGEWRAPPERARCHIVE
DESCRIPTOR.message_types_by_name['CellDiffArchive'] = _CELLDIFFARCHIVE
DESCRIPTOR.message_types_by_name['CellDiffArray'] = _CELLDIFFARRAY
DESCRIPTOR.message_types_by_name['CellDiffArraySegment'] = _CELLDIFFARRAYSEGMENT
DESCRIPTOR.message_types_by_name['CellDiffMapArchive'] = _CELLDIFFMAPARCHIVE
DESCRIPTOR.message_types_by_name['DoubleStyleMapArchive'] = _DOUBLESTYLEMAPARCHIVE
DESCRIPTOR.message_types_by_name['StyleTableMapArchive'] = _STYLETABLEMAPARCHIVE
DESCRIPTOR.message_types_by_name['SelectionArchive'] = _SELECTIONARCHIVE
DESCRIPTOR.message_types_by_name['DeathhawkRdar39989167CellSelectionArchive'] = _DEATHHAWKRDAR39989167CELLSELECTIONARCHIVE
DESCRIPTOR.message_types_by_name['StrokeSelectionArchive'] = _STROKESELECTIONARCHIVE
DESCRIPTOR.message_types_by_name['ControlCellSelectionArchive'] = _CONTROLCELLSELECTIONARCHIVE
DESCRIPTOR.message_types_by_name['StockCellSelectionArchive'] = _STOCKCELLSELECTIONARCHIVE
DESCRIPTOR.message_types_by_name['TableNameSelectionArchive'] = _TABLENAMESELECTIONARCHIVE
DESCRIPTOR.message_types_by_name['AutofillSelectionArchive'] = _AUTOFILLSELECTIONARCHIVE
DESCRIPTOR.message_types_by_name['FilterRuleArchive'] = _FILTERRULEARCHIVE
DESCRIPTOR.message_types_by_name['TableStyleArchive'] = _TABLESTYLEARCHIVE
DESCRIPTOR.message_types_by_name['CellStyleArchive'] = _CELLSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['FormulaPredicateArchive'] = _FORMULAPREDICATEARCHIVE
DESCRIPTOR.message_types_by_name['ConditionalStyleSetArchive'] = _CONDITIONALSTYLESETARCHIVE
DESCRIPTOR.message_types_by_name['FilterSetArchive'] = _FILTERSETARCHIVE
DESCRIPTOR.message_types_by_name['HiddenStateExtentArchive'] = _HIDDENSTATEEXTENTARCHIVE
DESCRIPTOR.message_types_by_name['HiddenStatesArchive'] = _HIDDENSTATESARCHIVE
DESCRIPTOR.message_types_by_name['HiddenStatesOwnerArchive'] = _HIDDENSTATESOWNERARCHIVE
DESCRIPTOR.message_types_by_name['ExpandCollapseStateArchive'] = _EXPANDCOLLAPSESTATEARCHIVE
DESCRIPTOR.message_types_by_name['TokenAttachmentArchive'] = _TOKENATTACHMENTARCHIVE
DESCRIPTOR.message_types_by_name['FormulaArchive'] = _FORMULAARCHIVE
DESCRIPTOR.message_types_by_name['ExpressionNodeArchive'] = _EXPRESSIONNODEARCHIVE
DESCRIPTOR.message_types_by_name['BooleanNodeArchive'] = _BOOLEANNODEARCHIVE
DESCRIPTOR.message_types_by_name['NumberNodeArchive'] = _NUMBERNODEARCHIVE
DESCRIPTOR.message_types_by_name['StringNodeArchive'] = _STRINGNODEARCHIVE
DESCRIPTOR.message_types_by_name['IdentifierNodeArchive'] = _IDENTIFIERNODEARCHIVE
DESCRIPTOR.message_types_by_name['ArrayNodeArchive'] = _ARRAYNODEARCHIVE
DESCRIPTOR.message_types_by_name['ListNodeArchive'] = _LISTNODEARCHIVE
DESCRIPTOR.message_types_by_name['OperatorNodeArchive'] = _OPERATORNODEARCHIVE
DESCRIPTOR.message_types_by_name['PostfixOperatorNodeArchive'] = _POSTFIXOPERATORNODEARCHIVE
DESCRIPTOR.message_types_by_name['PrefixOperatorNodeArchive'] = _PREFIXOPERATORNODEARCHIVE
DESCRIPTOR.message_types_by_name['FunctionNodeArchive'] = _FUNCTIONNODEARCHIVE
DESCRIPTOR.message_types_by_name['FunctionEndNodeArchive'] = _FUNCTIONENDNODEARCHIVE
DESCRIPTOR.message_types_by_name['DateNodeArchive'] = _DATENODEARCHIVE
DESCRIPTOR.message_types_by_name['ReferenceNodeArchive'] = _REFERENCENODEARCHIVE
DESCRIPTOR.message_types_by_name['DurationNodeArchive'] = _DURATIONNODEARCHIVE
DESCRIPTOR.message_types_by_name['ArgumentPlaceholderNodeArchive'] = _ARGUMENTPLACEHOLDERNODEARCHIVE
DESCRIPTOR.message_types_by_name['EmptyExpressionNodeArchive'] = _EMPTYEXPRESSIONNODEARCHIVE
DESCRIPTOR.message_types_by_name['LetNodeArchive'] = _LETNODEARCHIVE
DESCRIPTOR.message_types_by_name['InNodeArchive'] = _INNODEARCHIVE
DESCRIPTOR.message_types_by_name['VariableNodeArchive'] = _VARIABLENODEARCHIVE
DESCRIPTOR.message_types_by_name['LayoutHintArchive'] = _LAYOUTHINTARCHIVE
DESCRIPTOR.message_types_by_name['CompletionTokenAttachmentArchive'] = _COMPLETIONTOKENATTACHMENTARCHIVE
DESCRIPTOR.message_types_by_name['HiddenStateFormulaOwnerArchive'] = _HIDDENSTATEFORMULAOWNERARCHIVE
DESCRIPTOR.message_types_by_name['FormulaStoreArchive'] = _FORMULASTOREARCHIVE
DESCRIPTOR.message_types_by_name['MergeOperationArchive'] = _MERGEOPERATIONARCHIVE
DESCRIPTOR.message_types_by_name['MergeOwnerArchive'] = _MERGEOWNERARCHIVE
DESCRIPTOR.message_types_by_name['PencilAnnotationArchive'] = _PENCILANNOTATIONARCHIVE
DESCRIPTOR.message_types_by_name['PencilAnnotationOwnerArchive'] = _PENCILANNOTATIONOWNERARCHIVE
DESCRIPTOR.message_types_by_name['AccumulatorArchive'] = _ACCUMULATORARCHIVE
DESCRIPTOR.message_types_by_name['GroupColumnArchive'] = _GROUPCOLUMNARCHIVE
DESCRIPTOR.message_types_by_name['GroupColumnListArchive'] = _GROUPCOLUMNLISTARCHIVE
DESCRIPTOR.message_types_by_name['ColumnAggregateArchive'] = _COLUMNAGGREGATEARCHIVE
DESCRIPTOR.message_types_by_name['ColumnAggregateListArchive'] = _COLUMNAGGREGATELISTARCHIVE
DESCRIPTOR.message_types_by_name['CategoryOwnerArchive'] = _CATEGORYOWNERARCHIVE
DESCRIPTOR.message_types_by_name['RichTextPayloadArchive'] = _RICHTEXTPAYLOADARCHIVE
DESCRIPTOR.message_types_by_name['FormulaEqualsTokenAttachmentArchive'] = _FORMULAEQUALSTOKENATTACHMENTARCHIVE
DESCRIPTOR.message_types_by_name['CellFillStandIn'] = _CELLFILLSTANDIN
DESCRIPTOR.message_types_by_name['FormulaSelectionArchive'] = _FORMULASELECTIONARCHIVE
DESCRIPTOR.message_types_by_name['CellBorderArchive'] = _CELLBORDERARCHIVE
DESCRIPTOR.message_types_by_name['DefaultCellStylesContainerArchive'] = _DEFAULTCELLSTYLESCONTAINERARCHIVE
DESCRIPTOR.message_types_by_name['MultiTableRemapperArchive'] = _MULTITABLEREMAPPERARCHIVE
DESCRIPTOR.message_types_by_name['ChangePropagationMapWrapper'] = _CHANGEPROPAGATIONMAPWRAPPER
DESCRIPTOR.message_types_by_name['SummaryCellVendorArchive'] = _SUMMARYCELLVENDORARCHIVE
DESCRIPTOR.message_types_by_name['CategoryOrderArchive'] = _CATEGORYORDERARCHIVE
DESCRIPTOR.message_types_by_name['HeaderNameMgrTileArchive'] = _HEADERNAMEMGRTILEARCHIVE
DESCRIPTOR.message_types_by_name['HeaderNameMgrArchive'] = _HEADERNAMEMGRARCHIVE
DESCRIPTOR.message_types_by_name['WidthHeightCacheFittingEntry'] = _WIDTHHEIGHTCACHEFITTINGENTRY
DESCRIPTOR.message_types_by_name['WidthHeightCache'] = _WIDTHHEIGHTCACHE
DESCRIPTOR.message_types_by_name['MasterLayoutArchive'] = _MASTERLAYOUTARCHIVE
DESCRIPTOR.enum_types_by_name['CellType'] = _CELLTYPE
DESCRIPTOR.enum_types_by_name['CellValueType'] = _CELLVALUETYPE
DESCRIPTOR.enum_types_by_name['TableDimensionArchive'] = _TABLEDIMENSIONARCHIVE
DESCRIPTOR.enum_types_by_name['SelectionTypeArchive'] = _SELECTIONTYPEARCHIVE
DESCRIPTOR.enum_types_by_name['FillDirectionArchive'] = _FILLDIRECTIONARCHIVE
DESCRIPTOR.enum_types_by_name['MergeActionArchive'] = _MERGEACTIONARCHIVE
DESCRIPTOR.enum_types_by_name['HideShowActionArchive'] = _HIDESHOWACTIONARCHIVE
DESCRIPTOR.enum_types_by_name['GroupingType'] = _GROUPINGTYPE
DESCRIPTOR.enum_types_by_name['AggregateType'] = _AGGREGATETYPE
DESCRIPTOR.extensions_by_name['import_warning_set'] = import_warning_set
DESCRIPTOR.extensions_by_name['format_and_value'] = format_and_value
DESCRIPTOR.extensions_by_name['cell_border'] = cell_border
DESCRIPTOR.extensions_by_name['comment_storage'] = comment_storage
DESCRIPTOR.extensions_by_name['cell_spec'] = cell_spec
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CellID = _reflection.GeneratedProtocolMessageType('CellID', (_message.Message,), dict(
  DESCRIPTOR = _CELLID,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CellID)
  ))
_sym_db.RegisterMessage(CellID)

CellUIDLookupListArchive = _reflection.GeneratedProtocolMessageType('CellUIDLookupListArchive', (_message.Message,), dict(
  DESCRIPTOR = _CELLUIDLOOKUPLISTARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CellUIDLookupListArchive)
  ))
_sym_db.RegisterMessage(CellUIDLookupListArchive)

CellUIDListArchive = _reflection.GeneratedProtocolMessageType('CellUIDListArchive', (_message.Message,), dict(
  DESCRIPTOR = _CELLUIDLISTARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CellUIDListArchive)
  ))
_sym_db.RegisterMessage(CellUIDListArchive)

TableSize = _reflection.GeneratedProtocolMessageType('TableSize', (_message.Message,), dict(
  DESCRIPTOR = _TABLESIZE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.TableSize)
  ))
_sym_db.RegisterMessage(TableSize)

ExpandedTableSize = _reflection.GeneratedProtocolMessageType('ExpandedTableSize', (_message.Message,), dict(
  DESCRIPTOR = _EXPANDEDTABLESIZE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.ExpandedTableSize)
  ))
_sym_db.RegisterMessage(ExpandedTableSize)

CellRange = _reflection.GeneratedProtocolMessageType('CellRange', (_message.Message,), dict(
  DESCRIPTOR = _CELLRANGE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CellRange)
  ))
_sym_db.RegisterMessage(CellRange)

ExpandedCellRange = _reflection.GeneratedProtocolMessageType('ExpandedCellRange', (_message.Message,), dict(
  DESCRIPTOR = _EXPANDEDCELLRANGE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.ExpandedCellRange)
  ))
_sym_db.RegisterMessage(ExpandedCellRange)

TableSelection = _reflection.GeneratedProtocolMessageType('TableSelection', (_message.Message,), dict(
  DESCRIPTOR = _TABLESELECTION,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.TableSelection)
  ))
_sym_db.RegisterMessage(TableSelection)

TileRowInfo = _reflection.GeneratedProtocolMessageType('TileRowInfo', (_message.Message,), dict(
  DESCRIPTOR = _TILEROWINFO,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.TileRowInfo)
  ))
_sym_db.RegisterMessage(TileRowInfo)

Tile = _reflection.GeneratedProtocolMessageType('Tile', (_message.Message,), dict(
  DESCRIPTOR = _TILE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.Tile)
  ))
_sym_db.RegisterMessage(Tile)

TileStorage = _reflection.GeneratedProtocolMessageType('TileStorage', (_message.Message,), dict(

  Tile = _reflection.GeneratedProtocolMessageType('Tile', (_message.Message,), dict(
    DESCRIPTOR = _TILESTORAGE_TILE,
    __module__ = 'TSTArchives_pb2'
    # @@protoc_insertion_point(class_scope:TST.TileStorage.Tile)
    ))
  ,
  DESCRIPTOR = _TILESTORAGE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.TileStorage)
  ))
_sym_db.RegisterMessage(TileStorage)
_sym_db.RegisterMessage(TileStorage.Tile)

PopUpMenuModel = _reflection.GeneratedProtocolMessageType('PopUpMenuModel', (_message.Message,), dict(

  CellValue = _reflection.GeneratedProtocolMessageType('CellValue', (_message.Message,), dict(
    DESCRIPTOR = _POPUPMENUMODEL_CELLVALUE,
    __module__ = 'TSTArchives_pb2'
    # @@protoc_insertion_point(class_scope:TST.PopUpMenuModel.CellValue)
    ))
  ,
  DESCRIPTOR = _POPUPMENUMODEL,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.PopUpMenuModel)
  ))
_sym_db.RegisterMessage(PopUpMenuModel)
_sym_db.RegisterMessage(PopUpMenuModel.CellValue)

ImportWarningSetArchive = _reflection.GeneratedProtocolMessageType('ImportWarningSetArchive', (_message.Message,), dict(

  FormulaImportWarning = _reflection.GeneratedProtocolMessageType('FormulaImportWarning', (_message.Message,), dict(
    DESCRIPTOR = _IMPORTWARNINGSETARCHIVE_FORMULAIMPORTWARNING,
    __module__ = 'TSTArchives_pb2'
    # @@protoc_insertion_point(class_scope:TST.ImportWarningSetArchive.FormulaImportWarning)
    ))
  ,
  DESCRIPTOR = _IMPORTWARNINGSETARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.ImportWarningSetArchive)
  ))
_sym_db.RegisterMessage(ImportWarningSetArchive)
_sym_db.RegisterMessage(ImportWarningSetArchive.FormulaImportWarning)

CellRefImportWarningSetPairArchive = _reflection.GeneratedProtocolMessageType('CellRefImportWarningSetPairArchive', (_message.Message,), dict(
  DESCRIPTOR = _CELLREFIMPORTWARNINGSETPAIRARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CellRefImportWarningSetPairArchive)
  ))
_sym_db.RegisterMessage(CellRefImportWarningSetPairArchive)

ImportWarningSetByCellRefArchive = _reflection.GeneratedProtocolMessageType('ImportWarningSetByCellRefArchive', (_message.Message,), dict(
  DESCRIPTOR = _IMPORTWARNINGSETBYCELLREFARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.ImportWarningSetByCellRefArchive)
  ))
_sym_db.RegisterMessage(ImportWarningSetByCellRefArchive)

TableDataList = _reflection.GeneratedProtocolMessageType('TableDataList', (_message.Message,), dict(

  ListEntry = _reflection.GeneratedProtocolMessageType('ListEntry', (_message.Message,), dict(
    DESCRIPTOR = _TABLEDATALIST_LISTENTRY,
    __module__ = 'TSTArchives_pb2'
    # @@protoc_insertion_point(class_scope:TST.TableDataList.ListEntry)
    ))
  ,
  DESCRIPTOR = _TABLEDATALIST,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.TableDataList)
  ))
_sym_db.RegisterMessage(TableDataList)
_sym_db.RegisterMessage(TableDataList.ListEntry)

TableDataListSegment = _reflection.GeneratedProtocolMessageType('TableDataListSegment', (_message.Message,), dict(
  DESCRIPTOR = _TABLEDATALISTSEGMENT,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.TableDataListSegment)
  ))
_sym_db.RegisterMessage(TableDataListSegment)

TableRBTree = _reflection.GeneratedProtocolMessageType('TableRBTree', (_message.Message,), dict(

  Node = _reflection.GeneratedProtocolMessageType('Node', (_message.Message,), dict(
    DESCRIPTOR = _TABLERBTREE_NODE,
    __module__ = 'TSTArchives_pb2'
    # @@protoc_insertion_point(class_scope:TST.TableRBTree.Node)
    ))
  ,
  DESCRIPTOR = _TABLERBTREE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.TableRBTree)
  ))
_sym_db.RegisterMessage(TableRBTree)
_sym_db.RegisterMessage(TableRBTree.Node)

HeaderStorageBucket = _reflection.GeneratedProtocolMessageType('HeaderStorageBucket', (_message.Message,), dict(

  Header = _reflection.GeneratedProtocolMessageType('Header', (_message.Message,), dict(
    DESCRIPTOR = _HEADERSTORAGEBUCKET_HEADER,
    __module__ = 'TSTArchives_pb2'
    # @@protoc_insertion_point(class_scope:TST.HeaderStorageBucket.Header)
    ))
  ,
  DESCRIPTOR = _HEADERSTORAGEBUCKET,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.HeaderStorageBucket)
  ))
_sym_db.RegisterMessage(HeaderStorageBucket)
_sym_db.RegisterMessage(HeaderStorageBucket.Header)

HeaderStorage = _reflection.GeneratedProtocolMessageType('HeaderStorage', (_message.Message,), dict(
  DESCRIPTOR = _HEADERSTORAGE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.HeaderStorage)
  ))
_sym_db.RegisterMessage(HeaderStorage)

DataStore = _reflection.GeneratedProtocolMessageType('DataStore', (_message.Message,), dict(
  DESCRIPTOR = _DATASTORE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.DataStore)
  ))
_sym_db.RegisterMessage(DataStore)

TableInfoArchive = _reflection.GeneratedProtocolMessageType('TableInfoArchive', (_message.Message,), dict(
  DESCRIPTOR = _TABLEINFOARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.TableInfoArchive)
  ))
_sym_db.RegisterMessage(TableInfoArchive)

CategoryInfoArchive = _reflection.GeneratedProtocolMessageType('CategoryInfoArchive', (_message.Message,), dict(
  DESCRIPTOR = _CATEGORYINFOARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CategoryInfoArchive)
  ))
_sym_db.RegisterMessage(CategoryInfoArchive)

WPTableInfoArchive = _reflection.GeneratedProtocolMessageType('WPTableInfoArchive', (_message.Message,), dict(
  DESCRIPTOR = _WPTABLEINFOARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.WPTableInfoArchive)
  ))
_sym_db.RegisterMessage(WPTableInfoArchive)

TableStyleNetworkArchive = _reflection.GeneratedProtocolMessageType('TableStyleNetworkArchive', (_message.Message,), dict(
  DESCRIPTOR = _TABLESTYLENETWORKARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.TableStyleNetworkArchive)
  ))
_sym_db.RegisterMessage(TableStyleNetworkArchive)

TableSortOrderArchive = _reflection.GeneratedProtocolMessageType('TableSortOrderArchive', (_message.Message,), dict(

  SortRuleArchive = _reflection.GeneratedProtocolMessageType('SortRuleArchive', (_message.Message,), dict(
    DESCRIPTOR = _TABLESORTORDERARCHIVE_SORTRULEARCHIVE,
    __module__ = 'TSTArchives_pb2'
    # @@protoc_insertion_point(class_scope:TST.TableSortOrderArchive.SortRuleArchive)
    ))
  ,
  DESCRIPTOR = _TABLESORTORDERARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.TableSortOrderArchive)
  ))
_sym_db.RegisterMessage(TableSortOrderArchive)
_sym_db.RegisterMessage(TableSortOrderArchive.SortRuleArchive)

TableSortOrderUIDArchive = _reflection.GeneratedProtocolMessageType('TableSortOrderUIDArchive', (_message.Message,), dict(

  SortRuleArchive = _reflection.GeneratedProtocolMessageType('SortRuleArchive', (_message.Message,), dict(
    DESCRIPTOR = _TABLESORTORDERUIDARCHIVE_SORTRULEARCHIVE,
    __module__ = 'TSTArchives_pb2'
    # @@protoc_insertion_point(class_scope:TST.TableSortOrderUIDArchive.SortRuleArchive)
    ))
  ,
  DESCRIPTOR = _TABLESORTORDERUIDARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.TableSortOrderUIDArchive)
  ))
_sym_db.RegisterMessage(TableSortOrderUIDArchive)
_sym_db.RegisterMessage(TableSortOrderUIDArchive.SortRuleArchive)

SortRuleReferenceTrackerArchive = _reflection.GeneratedProtocolMessageType('SortRuleReferenceTrackerArchive', (_message.Message,), dict(
  DESCRIPTOR = _SORTRULEREFERENCETRACKERARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.SortRuleReferenceTrackerArchive)
  ))
_sym_db.RegisterMessage(SortRuleReferenceTrackerArchive)

CellRegion = _reflection.GeneratedProtocolMessageType('CellRegion', (_message.Message,), dict(
  DESCRIPTOR = _CELLREGION,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CellRegion)
  ))
_sym_db.RegisterMessage(CellRegion)

CellUIDRegionArchive = _reflection.GeneratedProtocolMessageType('CellUIDRegionArchive', (_message.Message,), dict(
  DESCRIPTOR = _CELLUIDREGIONARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CellUIDRegionArchive)
  ))
_sym_db.RegisterMessage(CellUIDRegionArchive)

StructuredTextImportRecord = _reflection.GeneratedProtocolMessageType('StructuredTextImportRecord', (_message.Message,), dict(
  DESCRIPTOR = _STRUCTUREDTEXTIMPORTRECORD,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.StructuredTextImportRecord)
  ))
_sym_db.RegisterMessage(StructuredTextImportRecord)

TableModelArchive = _reflection.GeneratedProtocolMessageType('TableModelArchive', (_message.Message,), dict(
  DESCRIPTOR = _TABLEMODELARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.TableModelArchive)
  ))
_sym_db.RegisterMessage(TableModelArchive)

SummaryModelArchive = _reflection.GeneratedProtocolMessageType('SummaryModelArchive', (_message.Message,), dict(
  DESCRIPTOR = _SUMMARYMODELARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.SummaryModelArchive)
  ))
_sym_db.RegisterMessage(SummaryModelArchive)

SummaryModelGroupByChangeStateArchive = _reflection.GeneratedProtocolMessageType('SummaryModelGroupByChangeStateArchive', (_message.Message,), dict(
  DESCRIPTOR = _SUMMARYMODELGROUPBYCHANGESTATEARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.SummaryModelGroupByChangeStateArchive)
  ))
_sym_db.RegisterMessage(SummaryModelGroupByChangeStateArchive)

ColumnRowUIDMapArchive = _reflection.GeneratedProtocolMessageType('ColumnRowUIDMapArchive', (_message.Message,), dict(
  DESCRIPTOR = _COLUMNROWUIDMAPARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.ColumnRowUIDMapArchive)
  ))
_sym_db.RegisterMessage(ColumnRowUIDMapArchive)

StrokeLayerArchive = _reflection.GeneratedProtocolMessageType('StrokeLayerArchive', (_message.Message,), dict(

  StrokeRunArchive = _reflection.GeneratedProtocolMessageType('StrokeRunArchive', (_message.Message,), dict(
    DESCRIPTOR = _STROKELAYERARCHIVE_STROKERUNARCHIVE,
    __module__ = 'TSTArchives_pb2'
    # @@protoc_insertion_point(class_scope:TST.StrokeLayerArchive.StrokeRunArchive)
    ))
  ,
  DESCRIPTOR = _STROKELAYERARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.StrokeLayerArchive)
  ))
_sym_db.RegisterMessage(StrokeLayerArchive)
_sym_db.RegisterMessage(StrokeLayerArchive.StrokeRunArchive)

StrokeSidecarArchive = _reflection.GeneratedProtocolMessageType('StrokeSidecarArchive', (_message.Message,), dict(
  DESCRIPTOR = _STROKESIDECARARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.StrokeSidecarArchive)
  ))
_sym_db.RegisterMessage(StrokeSidecarArchive)

DurationWrapperArchive = _reflection.GeneratedProtocolMessageType('DurationWrapperArchive', (_message.Message,), dict(
  DESCRIPTOR = _DURATIONWRAPPERARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.DurationWrapperArchive)
  ))
_sym_db.RegisterMessage(DurationWrapperArchive)

Cell = _reflection.GeneratedProtocolMessageType('Cell', (_message.Message,), dict(
  DESCRIPTOR = _CELL,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.Cell)
  ))
_sym_db.RegisterMessage(Cell)

MergeRegionMapArchive = _reflection.GeneratedProtocolMessageType('MergeRegionMapArchive', (_message.Message,), dict(
  DESCRIPTOR = _MERGEREGIONMAPARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.MergeRegionMapArchive)
  ))
_sym_db.RegisterMessage(MergeRegionMapArchive)

CellMapArchive = _reflection.GeneratedProtocolMessageType('CellMapArchive', (_message.Message,), dict(
  DESCRIPTOR = _CELLMAPARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CellMapArchive)
  ))
_sym_db.RegisterMessage(CellMapArchive)

CellListArchive = _reflection.GeneratedProtocolMessageType('CellListArchive', (_message.Message,), dict(

  OptionalCell = _reflection.GeneratedProtocolMessageType('OptionalCell', (_message.Message,), dict(
    DESCRIPTOR = _CELLLISTARCHIVE_OPTIONALCELL,
    __module__ = 'TSTArchives_pb2'
    # @@protoc_insertion_point(class_scope:TST.CellListArchive.OptionalCell)
    ))
  ,
  DESCRIPTOR = _CELLLISTARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CellListArchive)
  ))
_sym_db.RegisterMessage(CellListArchive)
_sym_db.RegisterMessage(CellListArchive.OptionalCell)

ConcurrentCellMapArchive = _reflection.GeneratedProtocolMessageType('ConcurrentCellMapArchive', (_message.Message,), dict(
  DESCRIPTOR = _CONCURRENTCELLMAPARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.ConcurrentCellMapArchive)
  ))
_sym_db.RegisterMessage(ConcurrentCellMapArchive)

ConcurrentCellListArchive = _reflection.GeneratedProtocolMessageType('ConcurrentCellListArchive', (_message.Message,), dict(

  OptionalCell = _reflection.GeneratedProtocolMessageType('OptionalCell', (_message.Message,), dict(
    DESCRIPTOR = _CONCURRENTCELLLISTARCHIVE_OPTIONALCELL,
    __module__ = 'TSTArchives_pb2'
    # @@protoc_insertion_point(class_scope:TST.ConcurrentCellListArchive.OptionalCell)
    ))
  ,
  DESCRIPTOR = _CONCURRENTCELLLISTARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.ConcurrentCellListArchive)
  ))
_sym_db.RegisterMessage(ConcurrentCellListArchive)
_sym_db.RegisterMessage(ConcurrentCellListArchive.OptionalCell)

CellFormatAndValueArchive = _reflection.GeneratedProtocolMessageType('CellFormatAndValueArchive', (_message.Message,), dict(
  DESCRIPTOR = _CELLFORMATANDVALUEARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CellFormatAndValueArchive)
  ))
_sym_db.RegisterMessage(CellFormatAndValueArchive)

CellSpecArchive = _reflection.GeneratedProtocolMessageType('CellSpecArchive', (_message.Message,), dict(
  DESCRIPTOR = _CELLSPECARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CellSpecArchive)
  ))
_sym_db.RegisterMessage(CellSpecArchive)

CommentStorageWrapperArchive = _reflection.GeneratedProtocolMessageType('CommentStorageWrapperArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMENTSTORAGEWRAPPERARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommentStorageWrapperArchive)
  ))
_sym_db.RegisterMessage(CommentStorageWrapperArchive)

CellDiffArchive = _reflection.GeneratedProtocolMessageType('CellDiffArchive', (_message.Message,), dict(
  DESCRIPTOR = _CELLDIFFARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CellDiffArchive)
  ))
_sym_db.RegisterMessage(CellDiffArchive)

CellDiffArray = _reflection.GeneratedProtocolMessageType('CellDiffArray', (_message.Message,), dict(
  DESCRIPTOR = _CELLDIFFARRAY,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CellDiffArray)
  ))
_sym_db.RegisterMessage(CellDiffArray)

CellDiffArraySegment = _reflection.GeneratedProtocolMessageType('CellDiffArraySegment', (_message.Message,), dict(
  DESCRIPTOR = _CELLDIFFARRAYSEGMENT,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CellDiffArraySegment)
  ))
_sym_db.RegisterMessage(CellDiffArraySegment)

CellDiffMapArchive = _reflection.GeneratedProtocolMessageType('CellDiffMapArchive', (_message.Message,), dict(
  DESCRIPTOR = _CELLDIFFMAPARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CellDiffMapArchive)
  ))
_sym_db.RegisterMessage(CellDiffMapArchive)

DoubleStyleMapArchive = _reflection.GeneratedProtocolMessageType('DoubleStyleMapArchive', (_message.Message,), dict(

  DoubleStyleMapEntryArchive = _reflection.GeneratedProtocolMessageType('DoubleStyleMapEntryArchive', (_message.Message,), dict(
    DESCRIPTOR = _DOUBLESTYLEMAPARCHIVE_DOUBLESTYLEMAPENTRYARCHIVE,
    __module__ = 'TSTArchives_pb2'
    # @@protoc_insertion_point(class_scope:TST.DoubleStyleMapArchive.DoubleStyleMapEntryArchive)
    ))
  ,
  DESCRIPTOR = _DOUBLESTYLEMAPARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.DoubleStyleMapArchive)
  ))
_sym_db.RegisterMessage(DoubleStyleMapArchive)
_sym_db.RegisterMessage(DoubleStyleMapArchive.DoubleStyleMapEntryArchive)

StyleTableMapArchive = _reflection.GeneratedProtocolMessageType('StyleTableMapArchive', (_message.Message,), dict(

  StyleTableMapEntryArchive = _reflection.GeneratedProtocolMessageType('StyleTableMapEntryArchive', (_message.Message,), dict(
    DESCRIPTOR = _STYLETABLEMAPARCHIVE_STYLETABLEMAPENTRYARCHIVE,
    __module__ = 'TSTArchives_pb2'
    # @@protoc_insertion_point(class_scope:TST.StyleTableMapArchive.StyleTableMapEntryArchive)
    ))
  ,
  DESCRIPTOR = _STYLETABLEMAPARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.StyleTableMapArchive)
  ))
_sym_db.RegisterMessage(StyleTableMapArchive)
_sym_db.RegisterMessage(StyleTableMapArchive.StyleTableMapEntryArchive)

SelectionArchive = _reflection.GeneratedProtocolMessageType('SelectionArchive', (_message.Message,), dict(
  DESCRIPTOR = _SELECTIONARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.SelectionArchive)
  ))
_sym_db.RegisterMessage(SelectionArchive)

DeathhawkRdar39989167CellSelectionArchive = _reflection.GeneratedProtocolMessageType('DeathhawkRdar39989167CellSelectionArchive', (_message.Message,), dict(
  DESCRIPTOR = _DEATHHAWKRDAR39989167CELLSELECTIONARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.DeathhawkRdar39989167CellSelectionArchive)
  ))
_sym_db.RegisterMessage(DeathhawkRdar39989167CellSelectionArchive)

StrokeSelectionArchive = _reflection.GeneratedProtocolMessageType('StrokeSelectionArchive', (_message.Message,), dict(
  DESCRIPTOR = _STROKESELECTIONARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.StrokeSelectionArchive)
  ))
_sym_db.RegisterMessage(StrokeSelectionArchive)

ControlCellSelectionArchive = _reflection.GeneratedProtocolMessageType('ControlCellSelectionArchive', (_message.Message,), dict(
  DESCRIPTOR = _CONTROLCELLSELECTIONARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.ControlCellSelectionArchive)
  ))
_sym_db.RegisterMessage(ControlCellSelectionArchive)

StockCellSelectionArchive = _reflection.GeneratedProtocolMessageType('StockCellSelectionArchive', (_message.Message,), dict(
  DESCRIPTOR = _STOCKCELLSELECTIONARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.StockCellSelectionArchive)
  ))
_sym_db.RegisterMessage(StockCellSelectionArchive)

TableNameSelectionArchive = _reflection.GeneratedProtocolMessageType('TableNameSelectionArchive', (_message.Message,), dict(
  DESCRIPTOR = _TABLENAMESELECTIONARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.TableNameSelectionArchive)
  ))
_sym_db.RegisterMessage(TableNameSelectionArchive)

AutofillSelectionArchive = _reflection.GeneratedProtocolMessageType('AutofillSelectionArchive', (_message.Message,), dict(
  DESCRIPTOR = _AUTOFILLSELECTIONARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.AutofillSelectionArchive)
  ))
_sym_db.RegisterMessage(AutofillSelectionArchive)

FilterRuleArchive = _reflection.GeneratedProtocolMessageType('FilterRuleArchive', (_message.Message,), dict(
  DESCRIPTOR = _FILTERRULEARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.FilterRuleArchive)
  ))
_sym_db.RegisterMessage(FilterRuleArchive)

TableStyleArchive = _reflection.GeneratedProtocolMessageType('TableStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _TABLESTYLEARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.TableStyleArchive)
  ))
_sym_db.RegisterMessage(TableStyleArchive)

CellStyleArchive = _reflection.GeneratedProtocolMessageType('CellStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _CELLSTYLEARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CellStyleArchive)
  ))
_sym_db.RegisterMessage(CellStyleArchive)

FormulaPredicateArchive = _reflection.GeneratedProtocolMessageType('FormulaPredicateArchive', (_message.Message,), dict(
  DESCRIPTOR = _FORMULAPREDICATEARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.FormulaPredicateArchive)
  ))
_sym_db.RegisterMessage(FormulaPredicateArchive)

ConditionalStyleSetArchive = _reflection.GeneratedProtocolMessageType('ConditionalStyleSetArchive', (_message.Message,), dict(

  ConditionalStyleRule = _reflection.GeneratedProtocolMessageType('ConditionalStyleRule', (_message.Message,), dict(
    DESCRIPTOR = _CONDITIONALSTYLESETARCHIVE_CONDITIONALSTYLERULE,
    __module__ = 'TSTArchives_pb2'
    # @@protoc_insertion_point(class_scope:TST.ConditionalStyleSetArchive.ConditionalStyleRule)
    ))
  ,
  DESCRIPTOR = _CONDITIONALSTYLESETARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.ConditionalStyleSetArchive)
  ))
_sym_db.RegisterMessage(ConditionalStyleSetArchive)
_sym_db.RegisterMessage(ConditionalStyleSetArchive.ConditionalStyleRule)

FilterSetArchive = _reflection.GeneratedProtocolMessageType('FilterSetArchive', (_message.Message,), dict(
  DESCRIPTOR = _FILTERSETARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.FilterSetArchive)
  ))
_sym_db.RegisterMessage(FilterSetArchive)

HiddenStateExtentArchive = _reflection.GeneratedProtocolMessageType('HiddenStateExtentArchive', (_message.Message,), dict(

  RowOrColumnState = _reflection.GeneratedProtocolMessageType('RowOrColumnState', (_message.Message,), dict(
    DESCRIPTOR = _HIDDENSTATEEXTENTARCHIVE_ROWORCOLUMNSTATE,
    __module__ = 'TSTArchives_pb2'
    # @@protoc_insertion_point(class_scope:TST.HiddenStateExtentArchive.RowOrColumnState)
    ))
  ,
  DESCRIPTOR = _HIDDENSTATEEXTENTARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.HiddenStateExtentArchive)
  ))
_sym_db.RegisterMessage(HiddenStateExtentArchive)
_sym_db.RegisterMessage(HiddenStateExtentArchive.RowOrColumnState)

HiddenStatesArchive = _reflection.GeneratedProtocolMessageType('HiddenStatesArchive', (_message.Message,), dict(
  DESCRIPTOR = _HIDDENSTATESARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.HiddenStatesArchive)
  ))
_sym_db.RegisterMessage(HiddenStatesArchive)

HiddenStatesOwnerArchive = _reflection.GeneratedProtocolMessageType('HiddenStatesOwnerArchive', (_message.Message,), dict(
  DESCRIPTOR = _HIDDENSTATESOWNERARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.HiddenStatesOwnerArchive)
  ))
_sym_db.RegisterMessage(HiddenStatesOwnerArchive)

ExpandCollapseStateArchive = _reflection.GeneratedProtocolMessageType('ExpandCollapseStateArchive', (_message.Message,), dict(
  DESCRIPTOR = _EXPANDCOLLAPSESTATEARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.ExpandCollapseStateArchive)
  ))
_sym_db.RegisterMessage(ExpandCollapseStateArchive)

TokenAttachmentArchive = _reflection.GeneratedProtocolMessageType('TokenAttachmentArchive', (_message.Message,), dict(
  DESCRIPTOR = _TOKENATTACHMENTARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.TokenAttachmentArchive)
  ))
_sym_db.RegisterMessage(TokenAttachmentArchive)

FormulaArchive = _reflection.GeneratedProtocolMessageType('FormulaArchive', (_message.Message,), dict(
  DESCRIPTOR = _FORMULAARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.FormulaArchive)
  ))
_sym_db.RegisterMessage(FormulaArchive)

ExpressionNodeArchive = _reflection.GeneratedProtocolMessageType('ExpressionNodeArchive', (_message.Message,), dict(
  DESCRIPTOR = _EXPRESSIONNODEARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.ExpressionNodeArchive)
  ))
_sym_db.RegisterMessage(ExpressionNodeArchive)

BooleanNodeArchive = _reflection.GeneratedProtocolMessageType('BooleanNodeArchive', (_message.Message,), dict(
  DESCRIPTOR = _BOOLEANNODEARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.BooleanNodeArchive)
  ))
_sym_db.RegisterMessage(BooleanNodeArchive)

NumberNodeArchive = _reflection.GeneratedProtocolMessageType('NumberNodeArchive', (_message.Message,), dict(
  DESCRIPTOR = _NUMBERNODEARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.NumberNodeArchive)
  ))
_sym_db.RegisterMessage(NumberNodeArchive)

StringNodeArchive = _reflection.GeneratedProtocolMessageType('StringNodeArchive', (_message.Message,), dict(
  DESCRIPTOR = _STRINGNODEARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.StringNodeArchive)
  ))
_sym_db.RegisterMessage(StringNodeArchive)

IdentifierNodeArchive = _reflection.GeneratedProtocolMessageType('IdentifierNodeArchive', (_message.Message,), dict(
  DESCRIPTOR = _IDENTIFIERNODEARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.IdentifierNodeArchive)
  ))
_sym_db.RegisterMessage(IdentifierNodeArchive)

ArrayNodeArchive = _reflection.GeneratedProtocolMessageType('ArrayNodeArchive', (_message.Message,), dict(
  DESCRIPTOR = _ARRAYNODEARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.ArrayNodeArchive)
  ))
_sym_db.RegisterMessage(ArrayNodeArchive)

ListNodeArchive = _reflection.GeneratedProtocolMessageType('ListNodeArchive', (_message.Message,), dict(
  DESCRIPTOR = _LISTNODEARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.ListNodeArchive)
  ))
_sym_db.RegisterMessage(ListNodeArchive)

OperatorNodeArchive = _reflection.GeneratedProtocolMessageType('OperatorNodeArchive', (_message.Message,), dict(
  DESCRIPTOR = _OPERATORNODEARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.OperatorNodeArchive)
  ))
_sym_db.RegisterMessage(OperatorNodeArchive)

PostfixOperatorNodeArchive = _reflection.GeneratedProtocolMessageType('PostfixOperatorNodeArchive', (_message.Message,), dict(
  DESCRIPTOR = _POSTFIXOPERATORNODEARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.PostfixOperatorNodeArchive)
  ))
_sym_db.RegisterMessage(PostfixOperatorNodeArchive)

PrefixOperatorNodeArchive = _reflection.GeneratedProtocolMessageType('PrefixOperatorNodeArchive', (_message.Message,), dict(
  DESCRIPTOR = _PREFIXOPERATORNODEARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.PrefixOperatorNodeArchive)
  ))
_sym_db.RegisterMessage(PrefixOperatorNodeArchive)

FunctionNodeArchive = _reflection.GeneratedProtocolMessageType('FunctionNodeArchive', (_message.Message,), dict(
  DESCRIPTOR = _FUNCTIONNODEARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.FunctionNodeArchive)
  ))
_sym_db.RegisterMessage(FunctionNodeArchive)

FunctionEndNodeArchive = _reflection.GeneratedProtocolMessageType('FunctionEndNodeArchive', (_message.Message,), dict(
  DESCRIPTOR = _FUNCTIONENDNODEARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.FunctionEndNodeArchive)
  ))
_sym_db.RegisterMessage(FunctionEndNodeArchive)

DateNodeArchive = _reflection.GeneratedProtocolMessageType('DateNodeArchive', (_message.Message,), dict(
  DESCRIPTOR = _DATENODEARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.DateNodeArchive)
  ))
_sym_db.RegisterMessage(DateNodeArchive)

ReferenceNodeArchive = _reflection.GeneratedProtocolMessageType('ReferenceNodeArchive', (_message.Message,), dict(
  DESCRIPTOR = _REFERENCENODEARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.ReferenceNodeArchive)
  ))
_sym_db.RegisterMessage(ReferenceNodeArchive)

DurationNodeArchive = _reflection.GeneratedProtocolMessageType('DurationNodeArchive', (_message.Message,), dict(
  DESCRIPTOR = _DURATIONNODEARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.DurationNodeArchive)
  ))
_sym_db.RegisterMessage(DurationNodeArchive)

ArgumentPlaceholderNodeArchive = _reflection.GeneratedProtocolMessageType('ArgumentPlaceholderNodeArchive', (_message.Message,), dict(
  DESCRIPTOR = _ARGUMENTPLACEHOLDERNODEARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.ArgumentPlaceholderNodeArchive)
  ))
_sym_db.RegisterMessage(ArgumentPlaceholderNodeArchive)

EmptyExpressionNodeArchive = _reflection.GeneratedProtocolMessageType('EmptyExpressionNodeArchive', (_message.Message,), dict(
  DESCRIPTOR = _EMPTYEXPRESSIONNODEARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.EmptyExpressionNodeArchive)
  ))
_sym_db.RegisterMessage(EmptyExpressionNodeArchive)

LetNodeArchive = _reflection.GeneratedProtocolMessageType('LetNodeArchive', (_message.Message,), dict(
  DESCRIPTOR = _LETNODEARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.LetNodeArchive)
  ))
_sym_db.RegisterMessage(LetNodeArchive)

InNodeArchive = _reflection.GeneratedProtocolMessageType('InNodeArchive', (_message.Message,), dict(
  DESCRIPTOR = _INNODEARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.InNodeArchive)
  ))
_sym_db.RegisterMessage(InNodeArchive)

VariableNodeArchive = _reflection.GeneratedProtocolMessageType('VariableNodeArchive', (_message.Message,), dict(
  DESCRIPTOR = _VARIABLENODEARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.VariableNodeArchive)
  ))
_sym_db.RegisterMessage(VariableNodeArchive)

LayoutHintArchive = _reflection.GeneratedProtocolMessageType('LayoutHintArchive', (_message.Message,), dict(
  DESCRIPTOR = _LAYOUTHINTARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.LayoutHintArchive)
  ))
_sym_db.RegisterMessage(LayoutHintArchive)

CompletionTokenAttachmentArchive = _reflection.GeneratedProtocolMessageType('CompletionTokenAttachmentArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMPLETIONTOKENATTACHMENTARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CompletionTokenAttachmentArchive)
  ))
_sym_db.RegisterMessage(CompletionTokenAttachmentArchive)

HiddenStateFormulaOwnerArchive = _reflection.GeneratedProtocolMessageType('HiddenStateFormulaOwnerArchive', (_message.Message,), dict(
  DESCRIPTOR = _HIDDENSTATEFORMULAOWNERARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.HiddenStateFormulaOwnerArchive)
  ))
_sym_db.RegisterMessage(HiddenStateFormulaOwnerArchive)

FormulaStoreArchive = _reflection.GeneratedProtocolMessageType('FormulaStoreArchive', (_message.Message,), dict(

  FormulaStorePair = _reflection.GeneratedProtocolMessageType('FormulaStorePair', (_message.Message,), dict(
    DESCRIPTOR = _FORMULASTOREARCHIVE_FORMULASTOREPAIR,
    __module__ = 'TSTArchives_pb2'
    # @@protoc_insertion_point(class_scope:TST.FormulaStoreArchive.FormulaStorePair)
    ))
  ,
  DESCRIPTOR = _FORMULASTOREARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.FormulaStoreArchive)
  ))
_sym_db.RegisterMessage(FormulaStoreArchive)
_sym_db.RegisterMessage(FormulaStoreArchive.FormulaStorePair)

MergeOperationArchive = _reflection.GeneratedProtocolMessageType('MergeOperationArchive', (_message.Message,), dict(
  DESCRIPTOR = _MERGEOPERATIONARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.MergeOperationArchive)
  ))
_sym_db.RegisterMessage(MergeOperationArchive)

MergeOwnerArchive = _reflection.GeneratedProtocolMessageType('MergeOwnerArchive', (_message.Message,), dict(
  DESCRIPTOR = _MERGEOWNERARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.MergeOwnerArchive)
  ))
_sym_db.RegisterMessage(MergeOwnerArchive)

PencilAnnotationArchive = _reflection.GeneratedProtocolMessageType('PencilAnnotationArchive', (_message.Message,), dict(
  DESCRIPTOR = _PENCILANNOTATIONARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.PencilAnnotationArchive)
  ))
_sym_db.RegisterMessage(PencilAnnotationArchive)

PencilAnnotationOwnerArchive = _reflection.GeneratedProtocolMessageType('PencilAnnotationOwnerArchive', (_message.Message,), dict(
  DESCRIPTOR = _PENCILANNOTATIONOWNERARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.PencilAnnotationOwnerArchive)
  ))
_sym_db.RegisterMessage(PencilAnnotationOwnerArchive)

AccumulatorArchive = _reflection.GeneratedProtocolMessageType('AccumulatorArchive', (_message.Message,), dict(
  DESCRIPTOR = _ACCUMULATORARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.AccumulatorArchive)
  ))
_sym_db.RegisterMessage(AccumulatorArchive)

GroupColumnArchive = _reflection.GeneratedProtocolMessageType('GroupColumnArchive', (_message.Message,), dict(
  DESCRIPTOR = _GROUPCOLUMNARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.GroupColumnArchive)
  ))
_sym_db.RegisterMessage(GroupColumnArchive)

GroupColumnListArchive = _reflection.GeneratedProtocolMessageType('GroupColumnListArchive', (_message.Message,), dict(
  DESCRIPTOR = _GROUPCOLUMNLISTARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.GroupColumnListArchive)
  ))
_sym_db.RegisterMessage(GroupColumnListArchive)

ColumnAggregateArchive = _reflection.GeneratedProtocolMessageType('ColumnAggregateArchive', (_message.Message,), dict(
  DESCRIPTOR = _COLUMNAGGREGATEARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.ColumnAggregateArchive)
  ))
_sym_db.RegisterMessage(ColumnAggregateArchive)

ColumnAggregateListArchive = _reflection.GeneratedProtocolMessageType('ColumnAggregateListArchive', (_message.Message,), dict(
  DESCRIPTOR = _COLUMNAGGREGATELISTARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.ColumnAggregateListArchive)
  ))
_sym_db.RegisterMessage(ColumnAggregateListArchive)

CategoryOwnerArchive = _reflection.GeneratedProtocolMessageType('CategoryOwnerArchive', (_message.Message,), dict(

  GroupByArchive = _reflection.GeneratedProtocolMessageType('GroupByArchive', (_message.Message,), dict(

    AggNodeArchive = _reflection.GeneratedProtocolMessageType('AggNodeArchive', (_message.Message,), dict(
      DESCRIPTOR = _CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_AGGNODEARCHIVE,
      __module__ = 'TSTArchives_pb2'
      # @@protoc_insertion_point(class_scope:TST.CategoryOwnerArchive.GroupByArchive.AggNodeArchive)
      ))
    ,

    GroupNodeArchive = _reflection.GeneratedProtocolMessageType('GroupNodeArchive', (_message.Message,), dict(

      GroupValueTupleArchive = _reflection.GeneratedProtocolMessageType('GroupValueTupleArchive', (_message.Message,), dict(
        DESCRIPTOR = _CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_GROUPNODEARCHIVE_GROUPVALUETUPLEARCHIVE,
        __module__ = 'TSTArchives_pb2'
        # @@protoc_insertion_point(class_scope:TST.CategoryOwnerArchive.GroupByArchive.GroupNodeArchive.GroupValueTupleArchive)
        ))
      ,

      FormatManagerArchive = _reflection.GeneratedProtocolMessageType('FormatManagerArchive', (_message.Message,), dict(

        RowSetArchive = _reflection.GeneratedProtocolMessageType('RowSetArchive', (_message.Message,), dict(
          DESCRIPTOR = _CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_GROUPNODEARCHIVE_FORMATMANAGERARCHIVE_ROWSETARCHIVE,
          __module__ = 'TSTArchives_pb2'
          # @@protoc_insertion_point(class_scope:TST.CategoryOwnerArchive.GroupByArchive.GroupNodeArchive.FormatManagerArchive.RowSetArchive)
          ))
        ,
        DESCRIPTOR = _CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_GROUPNODEARCHIVE_FORMATMANAGERARCHIVE,
        __module__ = 'TSTArchives_pb2'
        # @@protoc_insertion_point(class_scope:TST.CategoryOwnerArchive.GroupByArchive.GroupNodeArchive.FormatManagerArchive)
        ))
      ,
      DESCRIPTOR = _CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_GROUPNODEARCHIVE,
      __module__ = 'TSTArchives_pb2'
      # @@protoc_insertion_point(class_scope:TST.CategoryOwnerArchive.GroupByArchive.GroupNodeArchive)
      ))
    ,

    AggregatorArchive = _reflection.GeneratedProtocolMessageType('AggregatorArchive', (_message.Message,), dict(
      DESCRIPTOR = _CATEGORYOWNERARCHIVE_GROUPBYARCHIVE_AGGREGATORARCHIVE,
      __module__ = 'TSTArchives_pb2'
      # @@protoc_insertion_point(class_scope:TST.CategoryOwnerArchive.GroupByArchive.AggregatorArchive)
      ))
    ,
    DESCRIPTOR = _CATEGORYOWNERARCHIVE_GROUPBYARCHIVE,
    __module__ = 'TSTArchives_pb2'
    # @@protoc_insertion_point(class_scope:TST.CategoryOwnerArchive.GroupByArchive)
    ))
  ,
  DESCRIPTOR = _CATEGORYOWNERARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CategoryOwnerArchive)
  ))
_sym_db.RegisterMessage(CategoryOwnerArchive)
_sym_db.RegisterMessage(CategoryOwnerArchive.GroupByArchive)
_sym_db.RegisterMessage(CategoryOwnerArchive.GroupByArchive.AggNodeArchive)
_sym_db.RegisterMessage(CategoryOwnerArchive.GroupByArchive.GroupNodeArchive)
_sym_db.RegisterMessage(CategoryOwnerArchive.GroupByArchive.GroupNodeArchive.GroupValueTupleArchive)
_sym_db.RegisterMessage(CategoryOwnerArchive.GroupByArchive.GroupNodeArchive.FormatManagerArchive)
_sym_db.RegisterMessage(CategoryOwnerArchive.GroupByArchive.GroupNodeArchive.FormatManagerArchive.RowSetArchive)
_sym_db.RegisterMessage(CategoryOwnerArchive.GroupByArchive.AggregatorArchive)

RichTextPayloadArchive = _reflection.GeneratedProtocolMessageType('RichTextPayloadArchive', (_message.Message,), dict(
  DESCRIPTOR = _RICHTEXTPAYLOADARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.RichTextPayloadArchive)
  ))
_sym_db.RegisterMessage(RichTextPayloadArchive)

FormulaEqualsTokenAttachmentArchive = _reflection.GeneratedProtocolMessageType('FormulaEqualsTokenAttachmentArchive', (_message.Message,), dict(
  DESCRIPTOR = _FORMULAEQUALSTOKENATTACHMENTARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.FormulaEqualsTokenAttachmentArchive)
  ))
_sym_db.RegisterMessage(FormulaEqualsTokenAttachmentArchive)

CellFillStandIn = _reflection.GeneratedProtocolMessageType('CellFillStandIn', (_message.Message,), dict(
  DESCRIPTOR = _CELLFILLSTANDIN,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CellFillStandIn)
  ))
_sym_db.RegisterMessage(CellFillStandIn)

FormulaSelectionArchive = _reflection.GeneratedProtocolMessageType('FormulaSelectionArchive', (_message.Message,), dict(
  DESCRIPTOR = _FORMULASELECTIONARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.FormulaSelectionArchive)
  ))
_sym_db.RegisterMessage(FormulaSelectionArchive)

CellBorderArchive = _reflection.GeneratedProtocolMessageType('CellBorderArchive', (_message.Message,), dict(
  DESCRIPTOR = _CELLBORDERARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CellBorderArchive)
  ))
_sym_db.RegisterMessage(CellBorderArchive)

DefaultCellStylesContainerArchive = _reflection.GeneratedProtocolMessageType('DefaultCellStylesContainerArchive', (_message.Message,), dict(
  DESCRIPTOR = _DEFAULTCELLSTYLESCONTAINERARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.DefaultCellStylesContainerArchive)
  ))
_sym_db.RegisterMessage(DefaultCellStylesContainerArchive)

MultiTableRemapperArchive = _reflection.GeneratedProtocolMessageType('MultiTableRemapperArchive', (_message.Message,), dict(
  DESCRIPTOR = _MULTITABLEREMAPPERARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.MultiTableRemapperArchive)
  ))
_sym_db.RegisterMessage(MultiTableRemapperArchive)

ChangePropagationMapWrapper = _reflection.GeneratedProtocolMessageType('ChangePropagationMapWrapper', (_message.Message,), dict(
  DESCRIPTOR = _CHANGEPROPAGATIONMAPWRAPPER,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.ChangePropagationMapWrapper)
  ))
_sym_db.RegisterMessage(ChangePropagationMapWrapper)

SummaryCellVendorArchive = _reflection.GeneratedProtocolMessageType('SummaryCellVendorArchive', (_message.Message,), dict(

  SummaryCellEntry = _reflection.GeneratedProtocolMessageType('SummaryCellEntry', (_message.Message,), dict(
    DESCRIPTOR = _SUMMARYCELLVENDORARCHIVE_SUMMARYCELLENTRY,
    __module__ = 'TSTArchives_pb2'
    # @@protoc_insertion_point(class_scope:TST.SummaryCellVendorArchive.SummaryCellEntry)
    ))
  ,
  DESCRIPTOR = _SUMMARYCELLVENDORARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.SummaryCellVendorArchive)
  ))
_sym_db.RegisterMessage(SummaryCellVendorArchive)
_sym_db.RegisterMessage(SummaryCellVendorArchive.SummaryCellEntry)

CategoryOrderArchive = _reflection.GeneratedProtocolMessageType('CategoryOrderArchive', (_message.Message,), dict(
  DESCRIPTOR = _CATEGORYORDERARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CategoryOrderArchive)
  ))
_sym_db.RegisterMessage(CategoryOrderArchive)

HeaderNameMgrTileArchive = _reflection.GeneratedProtocolMessageType('HeaderNameMgrTileArchive', (_message.Message,), dict(

  NameFragmentArchive = _reflection.GeneratedProtocolMessageType('NameFragmentArchive', (_message.Message,), dict(
    DESCRIPTOR = _HEADERNAMEMGRTILEARCHIVE_NAMEFRAGMENTARCHIVE,
    __module__ = 'TSTArchives_pb2'
    # @@protoc_insertion_point(class_scope:TST.HeaderNameMgrTileArchive.NameFragmentArchive)
    ))
  ,
  DESCRIPTOR = _HEADERNAMEMGRTILEARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.HeaderNameMgrTileArchive)
  ))
_sym_db.RegisterMessage(HeaderNameMgrTileArchive)
_sym_db.RegisterMessage(HeaderNameMgrTileArchive.NameFragmentArchive)

HeaderNameMgrArchive = _reflection.GeneratedProtocolMessageType('HeaderNameMgrArchive', (_message.Message,), dict(

  PerTableArchive = _reflection.GeneratedProtocolMessageType('PerTableArchive', (_message.Message,), dict(
    DESCRIPTOR = _HEADERNAMEMGRARCHIVE_PERTABLEARCHIVE,
    __module__ = 'TSTArchives_pb2'
    # @@protoc_insertion_point(class_scope:TST.HeaderNameMgrArchive.PerTableArchive)
    ))
  ,
  DESCRIPTOR = _HEADERNAMEMGRARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.HeaderNameMgrArchive)
  ))
_sym_db.RegisterMessage(HeaderNameMgrArchive)
_sym_db.RegisterMessage(HeaderNameMgrArchive.PerTableArchive)

WidthHeightCacheFittingEntry = _reflection.GeneratedProtocolMessageType('WidthHeightCacheFittingEntry', (_message.Message,), dict(
  DESCRIPTOR = _WIDTHHEIGHTCACHEFITTINGENTRY,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.WidthHeightCacheFittingEntry)
  ))
_sym_db.RegisterMessage(WidthHeightCacheFittingEntry)

WidthHeightCache = _reflection.GeneratedProtocolMessageType('WidthHeightCache', (_message.Message,), dict(
  DESCRIPTOR = _WIDTHHEIGHTCACHE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.WidthHeightCache)
  ))
_sym_db.RegisterMessage(WidthHeightCache)

MasterLayoutArchive = _reflection.GeneratedProtocolMessageType('MasterLayoutArchive', (_message.Message,), dict(
  DESCRIPTOR = _MASTERLAYOUTARCHIVE,
  __module__ = 'TSTArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.MasterLayoutArchive)
  ))
_sym_db.RegisterMessage(MasterLayoutArchive)

import_warning_set.message_type = _IMPORTWARNINGSETARCHIVE
TSSArchives__pb2.CommandPropertyEntryArchive.RegisterExtension(import_warning_set)
format_and_value.message_type = _CELLFORMATANDVALUEARCHIVE
TSSArchives__pb2.CommandPropertyEntryArchive.RegisterExtension(format_and_value)
cell_border.message_type = _CELLBORDERARCHIVE
TSSArchives__pb2.CommandPropertyEntryArchive.RegisterExtension(cell_border)
comment_storage.message_type = _COMMENTSTORAGEWRAPPERARCHIVE
TSSArchives__pb2.CommandPropertyEntryArchive.RegisterExtension(comment_storage)
cell_spec.message_type = _CELLSPECARCHIVE
TSSArchives__pb2.CommandPropertyEntryArchive.RegisterExtension(cell_spec)

_POPUPMENUMODEL.fields_by_name['item']._options = None
_TABLEINFOARCHIVE.fields_by_name['editing_state']._options = None
_TABLEINFOARCHIVE.fields_by_name['formula_coord_space_in_pre40']._options = None
_TABLEMODELARCHIVE.fields_by_name['origin_offset']._options = None
_SUMMARYMODELARCHIVE.fields_by_name['summary_row_level_1_height']._options = None
_SUMMARYMODELARCHIVE.fields_by_name['summary_row_level_2_height']._options = None
_SUMMARYMODELARCHIVE.fields_by_name['summary_row_level_3_height']._options = None
_SUMMARYMODELARCHIVE.fields_by_name['summary_row_level_4_height']._options = None
_SUMMARYMODELARCHIVE.fields_by_name['summary_row_level_5_height']._options = None
_SUMMARYMODELARCHIVE.fields_by_name['summary_label_row_level_1_height']._options = None
_SUMMARYMODELARCHIVE.fields_by_name['summary_label_row_level_2_height']._options = None
_SUMMARYMODELARCHIVE.fields_by_name['summary_label_row_level_3_height']._options = None
_SUMMARYMODELARCHIVE.fields_by_name['summary_label_row_level_4_height']._options = None
_SUMMARYMODELARCHIVE.fields_by_name['summary_label_row_level_5_height']._options = None
_SUMMARYMODELARCHIVE.fields_by_name['label_row_visibility_1']._options = None
_SUMMARYMODELARCHIVE.fields_by_name['label_row_visibility_2']._options = None
_SUMMARYMODELARCHIVE.fields_by_name['label_row_visibility_3']._options = None
_SUMMARYMODELARCHIVE.fields_by_name['label_row_visibility_4']._options = None
_SUMMARYMODELARCHIVE.fields_by_name['label_row_visibility_5']._options = None
_CELLSPECARCHIVE.fields_by_name['category_summary_should_display_label']._options = None
_SELECTIONARCHIVE.fields_by_name['tableModel']._options = None
# @@protoc_insertion_point(module_scope)
