from __future__ import absolute_import
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: TSCHArchives_sos.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import TSCH3DArchives_pb2 as TSCH3DArchives__pb2
from . import TSCHArchives_Common_pb2 as TSCHArchives__Common__pb2
from . import TSDArchives_sos_pb2 as TSDArchives__sos__pb2
from . import TSKArchives_pb2 as TSKArchives__pb2
from . import TSSArchives_sos_pb2 as TSSArchives__sos__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='TSCHArchives_sos.proto',
  package='TSCH',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x16TSCHArchives_sos.proto\x12\x04TSCH\x1a\x14TSCH3DArchives.proto\x1a\x19TSCHArchives_Common.proto\x1a\x15TSDArchives_sos.proto\x1a\x11TSKArchives.proto\x1a\x15TSSArchives_sos.proto\"|\n$SpecSetChart3dLightingPackageArchive\x12\x45\n\x18\x63hart3d_lighting_package\x18\x01 \x01(\x0b\x32#.TSCH.Chart3DLightingPackageArchive\x12\r\n\x05unset\x18\x02 \x02(\x08\"`\n\x1bSpecSetChart3dVectorArchive\x12\x32\n\x0e\x63hart3d_vector\x18\x01 \x01(\x0b\x32\x1a.TSCH.Chart3DVectorArchive\x12\r\n\x05unset\x18\x02 \x02(\x08\"\x87\x01\n%SpecSetChartErrorBarCustomDataArchive\x12O\n\x1b\x63hart_error_bar_custom_data\x18\x01 \x01(\x0b\x32*.TSCH.ChartsNSArrayOfNSNumberDoubleArchive\x12\r\n\x05unset\x18\x02 \x02(\x08\"\x85\x01\n)SpecSetChartsOptionalDoubleArchiveArchive\x12I\n\x1e\x63harts_optional_double_archive\x18\x01 \x01(\x0b\x32!.TSCH.ChartsNSNumberDoubleArchive\x12\r\n\x05unset\x18\x02 \x02(\x08\"\\\n\x1aSpecSetFormatObjectArchive\x12/\n\rformat_object\x18\x01 \x01(\x0b\x32\x18.TSK.FormatStructArchive\x12\r\n\x05unset\x18\x02 \x02(\x08\"\\\n\x1aSpecSetNumberFormatArchive\x12/\n\rnumber_format\x18\x01 \x01(\x0b\x32\x18.TSK.FormatStructArchive\x12\r\n\x05unset\x18\x02 \x02(\x08\"z\n!SpecChart3dLightingPackageArchive\x12U\n!spec_set_chart3d_lighting_package\x18\x01 \x01(\x0b\x32*.TSCH.SpecSetChart3dLightingPackageArchive\"^\n\x18SpecChart3dVectorArchive\x12\x42\n\x17spec_set_chart3d_vector\x18\x01 \x01(\x0b\x32!.TSCH.SpecSetChart3dVectorArchive\"\x7f\n\"SpecChartErrorBarCustomDataArchive\x12Y\n$spec_set_chart_error_bar_custom_data\x18\x01 \x01(\x0b\x32+.TSCH.SpecSetChartErrorBarCustomDataArchive\"\x8a\x01\n&SpecChartsOptionalDoubleArchiveArchive\x12`\n\'spec_set_charts_optional_double_archive\x18\x01 \x01(\x0b\x32/.TSCH.SpecSetChartsOptionalDoubleArchiveArchive\"[\n\x17SpecFormatObjectArchive\x12@\n\x16spec_set_format_object\x18\x01 \x01(\x0b\x32 .TSCH.SpecSetFormatObjectArchive\"[\n\x17SpecNumberFormatArchive\x12@\n\x16spec_set_number_format\x18\x01 \x01(\x0b\x32 .TSCH.SpecSetNumberFormatArchive\"\x88\x12\n)ChartAxisNonStylePropertyChangeSetArchive\x12<\n\x15\x64\x65\x66\x61ult10_date_format\x18\x01 \x01(\x0b\x32\x1d.TSCH.SpecFormatObjectArchive\x12\'\n\x1f\x64\x65\x66\x61ult10_date_format_undefined\x18\x02 \x01(\x08\x12>\n\x17\x64\x65\x66\x61ult10_number_format\x18\x03 \x01(\x0b\x32\x1d.TSCH.SpecNumberFormatArchive\x12)\n!default10_number_format_undefined\x18\x04 \x01(\x08\x12\x39\n\x18\x64\x65\x66\x61ult3d_label_position\x18\x05 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12*\n\"default3d_label_position_undefined\x18\x06 \x01(\x08\x12:\n\x13\x64\x65\x66\x61ult_date_format\x18\x07 \x01(\x0b\x32\x1d.TSCH.SpecFormatObjectArchive\x12%\n\x1d\x64\x65\x66\x61ult_date_format_undefined\x18\x08 \x01(\x08\x12>\n\x17\x64\x65\x66\x61ult_duration_format\x18\t \x01(\x0b\x32\x1d.TSCH.SpecFormatObjectArchive\x12)\n!default_duration_format_undefined\x18\n \x01(\x08\x12<\n\x15\x64\x65\x66\x61ult_number_format\x18\x0b \x01(\x0b\x32\x1d.TSCH.SpecNumberFormatArchive\x12\'\n\x1f\x64\x65\x66\x61ult_number_format_undefined\x18\x0c \x01(\x08\x12;\n\x1a\x64\x65\x66\x61ult_number_format_type\x18\r \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12,\n$default_number_format_type_undefined\x18\x0e \x01(\x08\x12\x38\n\x17value_number_of_decades\x18\x0f \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12)\n!value_number_of_decades_undefined\x18\x10 \x01(\x08\x12@\n\x1fvalue_number_of_major_gridlines\x18\x11 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x31\n)value_number_of_major_gridlines_undefined\x18\x12 \x01(\x08\x12@\n\x1fvalue_number_of_minor_gridlines\x18\x13 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x31\n)value_number_of_minor_gridlines_undefined\x18\x14 \x01(\x08\x12\x34\n\x16\x63\x61tegory_plot_to_edges\x18\x15 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12(\n category_plot_to_edges_undefined\x18\x16 \x01(\x08\x12,\n\x0bvalue_scale\x18\x17 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x1d\n\x15value_scale_undefined\x18\x18 \x01(\x08\x12\x32\n\x14\x63\x61tegory_show_labels\x18\x19 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12&\n\x1e\x63\x61tegory_show_labels_undefined\x18\x1a \x01(\x08\x12\x31\n\x13\x64\x65\x66\x61ult_show_labels\x18\x1b \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12%\n\x1d\x64\x65\x66\x61ult_show_labels_undefined\x18\x1c \x01(\x08\x12/\n\x11value_show_labels\x18\x1d \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12#\n\x1bvalue_show_labels_undefined\x18\x1e \x01(\x08\x12\x39\n\x1b\x63\x61tegory_show_series_labels\x18\x1f \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12-\n%category_show_series_labels_undefined\x18  \x01(\x08\x12;\n\x1dmulti_data_show_series_labels\x18! \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12/\n\'multi_data_show_series_labels_undefined\x18\" \x01(\x08\x12\x31\n\x13\x63\x61tegory_show_title\x18# \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12%\n\x1d\x63\x61tegory_show_title_undefined\x18$ \x01(\x08\x12.\n\x10value_show_title\x18% \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12\"\n\x1avalue_show_title_undefined\x18& \x01(\x08\x12.\n\x0e\x63\x61tegory_title\x18\' \x01(\x0b\x32\x16.TSS.SpecStringArchive\x12 \n\x18\x63\x61tegory_title_undefined\x18( \x01(\x08\x12+\n\x0bvalue_title\x18) \x01(\x0b\x32\x16.TSS.SpecStringArchive\x12\x1d\n\x15value_title_undefined\x18* \x01(\x08\x12\x46\n\x10\x64\x65\x66\x61ult_user_max\x18+ \x01(\x0b\x32,.TSCH.SpecChartsOptionalDoubleArchiveArchive\x12\"\n\x1a\x64\x65\x66\x61ult_user_max_undefined\x18, \x01(\x08\x12\x46\n\x10\x64\x65\x66\x61ult_user_min\x18- \x01(\x0b\x32,.TSCH.SpecChartsOptionalDoubleArchiveArchive\x12\"\n\x1a\x64\x65\x66\x61ult_user_min_undefined\x18. \x01(\x08\"\x9a#\n&ChartAxisStylePropertyChangeSetArchive\x12;\n\x1b\x63\x61tegory3d_gridline_opacity\x18\x01 \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12-\n%category3d_gridline_opacity_undefined\x18\x02 \x01(\x08\x12\x38\n\x18value3d_gridline_opacity\x18\x03 \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12*\n\"value3d_gridline_opacity_undefined\x18\x04 \x01(\x08\x12:\n\x1a\x63\x61tegory3d_gridline_stroke\x18\x05 \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12,\n$category3d_gridline_stroke_undefined\x18\x06 \x01(\x08\x12\x37\n\x17value3d_gridline_stroke\x18\x07 \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12)\n!value3d_gridline_stroke_undefined\x18\x08 \x01(\x08\x12<\n\x1b\x63\x61tegory_horizontal_spacing\x18\t \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12-\n%category_horizontal_spacing_undefined\x18\n \x01(\x08\x12\x45\n$category_label_paragraph_style_index\x18\x0b \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x36\n.category_label_paragraph_style_index_undefined\x18\x0c \x01(\x08\x12\x44\n#default_label_paragraph_style_index\x18\r \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x35\n-default_label_paragraph_style_index_undefined\x18\x0e \x01(\x08\x12\x42\n!value_label_paragraph_style_index\x18\x0f \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x33\n+value_label_paragraph_style_index_undefined\x18\x10 \x01(\x08\x12;\n\x1b\x63\x61tegory_labels_orientation\x18\x11 \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12-\n%category_labels_orientation_undefined\x18\x12 \x01(\x08\x12:\n\x1a\x64\x65\x66\x61ult_labels_orientation\x18\x13 \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12,\n$default_labels_orientation_undefined\x18\x14 \x01(\x08\x12\x38\n\x18value_labels_orientation\x18\x15 \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12*\n\"value_labels_orientation_undefined\x18\x16 \x01(\x08\x12?\n\x1f\x63\x61tegory_major_gridline_opacity\x18\x17 \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12\x31\n)category_major_gridline_opacity_undefined\x18\x18 \x01(\x08\x12<\n\x1cvalue_major_gridline_opacity\x18\x19 \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12.\n&value_major_gridline_opacity_undefined\x18\x1a \x01(\x08\x12>\n\x1e\x63\x61tegory_major_gridline_shadow\x18\x1b \x01(\x0b\x32\x16.TSD.SpecShadowArchive\x12\x30\n(category_major_gridline_shadow_undefined\x18\x1c \x01(\x08\x12;\n\x1bvalue_major_gridline_shadow\x18\x1d \x01(\x0b\x32\x16.TSD.SpecShadowArchive\x12-\n%value_major_gridline_shadow_undefined\x18\x1e \x01(\x08\x12>\n\x1e\x63\x61tegory_major_gridline_stroke\x18\x1f \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12\x30\n(category_major_gridline_stroke_undefined\x18  \x01(\x08\x12;\n\x1bvalue_major_gridline_stroke\x18! \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12-\n%value_major_gridline_stroke_undefined\x18\" \x01(\x08\x12?\n\x1f\x63\x61tegory_minor_gridline_opacity\x18# \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12\x31\n)category_minor_gridline_opacity_undefined\x18$ \x01(\x08\x12<\n\x1cvalue_minor_gridline_opacity\x18% \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12.\n&value_minor_gridline_opacity_undefined\x18& \x01(\x08\x12>\n\x1e\x63\x61tegory_minor_gridline_shadow\x18\' \x01(\x0b\x32\x16.TSD.SpecShadowArchive\x12\x30\n(category_minor_gridline_shadow_undefined\x18( \x01(\x08\x12;\n\x1bvalue_minor_gridline_shadow\x18) \x01(\x0b\x32\x16.TSD.SpecShadowArchive\x12-\n%value_minor_gridline_shadow_undefined\x18* \x01(\x08\x12>\n\x1e\x63\x61tegory_minor_gridline_stroke\x18+ \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12\x30\n(category_minor_gridline_stroke_undefined\x18, \x01(\x08\x12;\n\x1bvalue_minor_gridline_stroke\x18- \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12-\n%value_minor_gridline_stroke_undefined\x18. \x01(\x08\x12\x30\n\x12\x63\x61tegory_show_axis\x18/ \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12$\n\x1c\x63\x61tegory_show_axis_undefined\x18\x30 \x01(\x08\x12-\n\x0fvalue_show_axis\x18\x31 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12!\n\x19value_show_axis_undefined\x18\x32 \x01(\x08\x12\x36\n\x18\x63\x61tegory_show_last_label\x18\x33 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12*\n\"category_show_last_label_undefined\x18\x34 \x01(\x08\x12;\n\x1d\x63\x61tegory_show_major_gridlines\x18\x35 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12/\n\'category_show_major_gridlines_undefined\x18\x36 \x01(\x08\x12\x38\n\x1avalue_show_major_gridlines\x18\x37 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12,\n$value_show_major_gridlines_undefined\x18\x38 \x01(\x08\x12;\n\x1d\x63\x61tegory_show_major_tickmarks\x18\x39 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12/\n\'category_show_major_tickmarks_undefined\x18: \x01(\x08\x12\x38\n\x1avalue_show_major_tickmarks\x18; \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12,\n$value_show_major_tickmarks_undefined\x18< \x01(\x08\x12\x36\n\x18value_show_minimum_label\x18= \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12*\n\"value_show_minimum_label_undefined\x18> \x01(\x08\x12;\n\x1d\x63\x61tegory_show_minor_gridlines\x18? \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12/\n\'category_show_minor_gridlines_undefined\x18@ \x01(\x08\x12\x38\n\x1avalue_show_minor_gridlines\x18\x41 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12,\n$value_show_minor_gridlines_undefined\x18\x42 \x01(\x08\x12;\n\x1d\x63\x61tegory_show_minor_tickmarks\x18\x43 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12/\n\'category_show_minor_tickmarks_undefined\x18\x44 \x01(\x08\x12\x38\n\x1avalue_show_minor_tickmarks\x18\x45 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12,\n$value_show_minor_tickmarks_undefined\x18\x46 \x01(\x08\x12;\n\x1a\x63\x61tegory_tickmark_location\x18G \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12,\n$category_tickmark_location_undefined\x18H \x01(\x08\x12\x38\n\x17value_tickmark_location\x18I \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12)\n!value_tickmark_location_undefined\x18J \x01(\x08\x12\x45\n$category_title_paragraph_style_index\x18K \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x36\n.category_title_paragraph_style_index_undefined\x18L \x01(\x08\x12\x44\n#default_title_paragraph_style_index\x18M \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x35\n-default_title_paragraph_style_index_undefined\x18N \x01(\x08\x12\x42\n!value_title_paragraph_style_index\x18O \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x33\n+value_title_paragraph_style_index_undefined\x18P \x01(\x08\x12:\n\x19\x63\x61tegory_vertical_spacing\x18Q \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12+\n#category_vertical_spacing_undefined\x18R \x01(\x08\"-\n+ChartLegendNonStylePropertyChangeSetArchive\"\xeb\x03\n(ChartLegendStylePropertyChangeSetArchive\x12*\n\x0c\x64\x65\x66\x61ult_fill\x18\x01 \x01(\x0b\x32\x14.TSD.SpecFillArchive\x12\x1e\n\x16\x64\x65\x66\x61ult_fill_undefined\x18\x02 \x01(\x08\x12\x44\n#default_label_paragraph_style_index\x18\x03 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x35\n-default_label_paragraph_style_index_undefined\x18\x04 \x01(\x08\x12/\n\x0f\x64\x65\x66\x61ult_opacity\x18\x05 \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12!\n\x19\x64\x65\x66\x61ult_opacity_undefined\x18\x06 \x01(\x08\x12.\n\x0e\x64\x65\x66\x61ult_shadow\x18\x07 \x01(\x0b\x32\x16.TSD.SpecShadowArchive\x12 \n\x18\x64\x65\x66\x61ult_shadow_undefined\x18\x08 \x01(\x08\x12.\n\x0e\x64\x65\x66\x61ult_stroke\x18\t \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12 \n\x18\x64\x65\x66\x61ult_stroke_undefined\x18\n \x01(\x08\"\x8d\x19\n%ChartNonStylePropertyChangeSetArchive\x12\x34\n\x13\x64\x65\x66\x61ult3d_bar_shape\x18\x01 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12%\n\x1d\x64\x65\x66\x61ult3d_bar_shape_undefined\x18\x02 \x01(\x08\x12\x33\n\x15\x64\x65\x66\x61ult3d_bevel_edges\x18\x03 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12\'\n\x1f\x64\x65\x66\x61ult3d_bevel_edges_undefined\x18\x04 \x01(\x08\x12=\n\x1d\x64\x65\x66\x61ult3d_inter_set_depth_gap\x18\x05 \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12/\n\'default3d_inter_set_depth_gap_undefined\x18\x06 \x01(\x08\x12:\n\x12\x64\x65\x66\x61ult3d_rotation\x18\x07 \x01(\x0b\x32\x1e.TSCH.SpecChart3dVectorArchive\x12$\n\x1c\x64\x65\x66\x61ult3d_rotation_undefined\x18\x08 \x01(\x08\x12\x34\n\x0c\x61rea3d_scale\x18\t \x01(\x0b\x32\x1e.TSCH.SpecChart3dVectorArchive\x12\x1e\n\x16\x61rea3d_scale_undefined\x18\n \x01(\x08\x12\x33\n\x0b\x62\x61r3d_scale\x18\x0b \x01(\x0b\x32\x1e.TSCH.SpecChart3dVectorArchive\x12\x1d\n\x15\x62\x61r3d_scale_undefined\x18\x0c \x01(\x08\x12\x36\n\x0e\x63olumn3d_scale\x18\r \x01(\x0b\x32\x1e.TSCH.SpecChart3dVectorArchive\x12 \n\x18\x63olumn3d_scale_undefined\x18\x0e \x01(\x08\x12\x37\n\x0f\x64\x65\x66\x61ult3d_scale\x18\x0f \x01(\x0b\x32\x1e.TSCH.SpecChart3dVectorArchive\x12!\n\x19\x64\x65\x66\x61ult3d_scale_undefined\x18\x10 \x01(\x08\x12\x34\n\x0cline3d_scale\x18\x11 \x01(\x0b\x32\x1e.TSCH.SpecChart3dVectorArchive\x12\x1e\n\x16line3d_scale_undefined\x18\x12 \x01(\x08\x12\x33\n\x0bpie3d_scale\x18\x13 \x01(\x0b\x32\x1e.TSCH.SpecChart3dVectorArchive\x12\x1d\n\x15pie3d_scale_undefined\x18\x14 \x01(\x08\x12:\n\x12\x64\x65\x66\x61ult3d_viewport\x18\x15 \x01(\x0b\x32\x1e.TSCH.SpecChart3dVectorArchive\x12$\n\x1c\x64\x65\x66\x61ult3d_viewport_undefined\x18\x16 \x01(\x08\x12\x37\n\x16\x61rea_callout_line_type\x18\x17 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12(\n area_callout_line_type_undefined\x18\x18 \x01(\x08\x12\x36\n\x15\x62\x61r_callout_line_type\x18\x19 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\'\n\x1f\x62\x61r_callout_line_type_undefined\x18\x1a \x01(\x08\x12\x39\n\x18\x62ubble_callout_line_type\x18\x1b \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12*\n\"bubble_callout_line_type_undefined\x18\x1c \x01(\x08\x12:\n\x19\x64\x65\x66\x61ult_callout_line_type\x18\x1d \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12+\n#default_callout_line_type_undefined\x18\x1e \x01(\x08\x12\x37\n\x16line_callout_line_type\x18\x1f \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12(\n line_callout_line_type_undefined\x18  \x01(\x08\x12\x36\n\x15pie_callout_line_type\x18! \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\'\n\x1fpie_callout_line_type_undefined\x18\" \x01(\x08\x12:\n\x19scatter_callout_line_type\x18# \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12+\n#scatter_callout_line_type_undefined\x18$ \x01(\x08\x12?\n\x1estacked_area_callout_line_type\x18% \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x30\n(stacked_area_callout_line_type_undefined\x18& \x01(\x08\x12>\n\x1dstacked_bar_callout_line_type\x18\' \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12/\n\'stacked_bar_callout_line_type_undefined\x18( \x01(\x08\x12W\n9default_d_e_p_r_e_c_a_t_e_d_rounded_corner_outer_end_only\x18) \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12K\nCdefault_d_e_p_r_e_c_a_t_e_d_rounded_corner_outer_end_only_undefined\x18* \x01(\x08\x12Q\n1default_d_e_p_r_e_c_a_t_e_d_rounded_corner_radius\x18+ \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12\x43\n;default_d_e_p_r_e_c_a_t_e_d_rounded_corner_radius_undefined\x18, \x01(\x08\x12?\n\x1e\x64\x65\x66\x61ult_data_set_name_location\x18- \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x30\n(default_data_set_name_location_undefined\x18. \x01(\x08\x12\x41\n#default_donut_place_title_at_center\x18/ \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12\x35\n-default_donut_place_title_at_center_undefined\x18\x30 \x01(\x08\x12\x34\n\x14\x64\x65\x66\x61ult_inner_radius\x18\x31 \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12&\n\x1e\x64\x65\x66\x61ult_inner_radius_undefined\x18\x32 \x01(\x08\x12@\n\x1f\x64\x65\x66\x61ult_multi_data_control_type\x18\x33 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x31\n)default_multi_data_control_type_undefined\x18\x34 \x01(\x08\x12\x37\n\x17\x64\x65\x66\x61ult_pie_start_angle\x18\x35 \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12)\n!default_pie_start_angle_undefined\x18\x36 \x01(\x08\x12\x31\n\x13\x64\x65\x66\x61ult_show_legend\x18\x37 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12%\n\x1d\x64\x65\x66\x61ult_show_legend_undefined\x18\x38 \x01(\x08\x12\x30\n\x12\x64\x65\x66\x61ult_show_title\x18\x39 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12$\n\x1c\x64\x65\x66\x61ult_show_title_undefined\x18: \x01(\x08\x12\x36\n\x18\x64\x65\x66\x61ult_skip_hidden_data\x18; \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12*\n\"default_skip_hidden_data_undefined\x18< \x01(\x08\x12-\n\rdefault_title\x18= \x01(\x0b\x32\x16.TSS.SpecStringArchive\x12\x1f\n\x17\x64\x65\x66\x61ult_title_undefined\x18> \x01(\x08\"\xd9\x04\n2ChartReferenceLineNonStylePropertyChangeSetArchive\x12J\n\x14\x64\x65\x66\x61ult_custom_value\x18\x01 \x01(\x0b\x32,.TSCH.SpecChartsOptionalDoubleArchiveArchive\x12&\n\x1e\x64\x65\x66\x61ult_custom_value_undefined\x18\x02 \x01(\x08\x12-\n\rdefault_label\x18\x03 \x01(\x0b\x32\x16.TSS.SpecStringArchive\x12\x1f\n\x17\x64\x65\x66\x61ult_label_undefined\x18\x04 \x01(\x08\x12\x30\n\x12\x64\x65\x66\x61ult_show_label\x18\x05 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12$\n\x1c\x64\x65\x66\x61ult_show_label_undefined\x18\x06 \x01(\x08\x12/\n\x11\x64\x65\x66\x61ult_show_line\x18\x07 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12#\n\x1b\x64\x65\x66\x61ult_show_line_undefined\x18\x08 \x01(\x08\x12\x36\n\x18\x64\x65\x66\x61ult_show_value_label\x18\t \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12*\n\"default_show_value_label_undefined\x18\n \x01(\x08\x12-\n\x0c\x64\x65\x66\x61ult_type\x18\x0b \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x1e\n\x16\x64\x65\x66\x61ult_type_undefined\x18\x0c \x01(\x08\"\xdb\x03\n/ChartReferenceLineStylePropertyChangeSetArchive\x12\x44\n#default_label_paragraph_style_index\x18\x01 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x35\n-default_label_paragraph_style_index_undefined\x18\x02 \x01(\x08\x12.\n\x0e\x64\x65\x66\x61ult_shadow\x18\x03 \x01(\x0b\x32\x16.TSD.SpecShadowArchive\x12 \n\x18\x64\x65\x66\x61ult_shadow_undefined\x18\x04 \x01(\x08\x12.\n\x0e\x64\x65\x66\x61ult_stroke\x18\x05 \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12 \n\x18\x64\x65\x66\x61ult_stroke_undefined\x18\x06 \x01(\x08\x12J\n)default_value_label_paragraph_style_index\x18\x07 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12;\n3default_value_label_paragraph_style_index_undefined\x18\x08 \x01(\x08\"\xf6M\n+ChartSeriesNonStylePropertyChangeSetArchive\x12<\n\x15\x64\x65\x66\x61ult10_date_format\x18\x01 \x01(\x0b\x32\x1d.TSCH.SpecFormatObjectArchive\x12\'\n\x1f\x64\x65\x66\x61ult10_date_format_undefined\x18\x02 \x01(\x08\x12>\n\x17\x64\x65\x66\x61ult10_number_format\x18\x03 \x01(\x0b\x32\x1d.TSCH.SpecNumberFormatArchive\x12)\n!default10_number_format_undefined\x18\x04 \x01(\x08\x12:\n\x13pie10_number_format\x18\x05 \x01(\x0b\x32\x1d.TSCH.SpecNumberFormatArchive\x12%\n\x1dpie10_number_format_undefined\x18\x06 \x01(\x08\x12\x35\n\x15pie23_label_explosion\x18\x07 \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12\'\n\x1fpie23_label_explosion_undefined\x18\x08 \x01(\x08\x12\x37\n\x17\x62ubble_adjustment_scale\x18\t \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12)\n!bubble_adjustment_scale_undefined\x18\n \x01(\x08\x12:\n\x13\x64\x65\x66\x61ult_date_format\x18\x0b \x01(\x0b\x32\x1d.TSCH.SpecFormatObjectArchive\x12%\n\x1d\x64\x65\x66\x61ult_date_format_undefined\x18\x0c \x01(\x08\x12>\n\x17\x64\x65\x66\x61ult_duration_format\x18\r \x01(\x0b\x32\x1d.TSCH.SpecFormatObjectArchive\x12)\n!default_duration_format_undefined\x18\x0e \x01(\x08\x12\x39\n\x18\x61rea_enable_callout_line\x18\x0f \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12*\n\"area_enable_callout_line_undefined\x18\x10 \x01(\x08\x12\x38\n\x17\x62\x61r_enable_callout_line\x18\x11 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12)\n!bar_enable_callout_line_undefined\x18\x12 \x01(\x08\x12;\n\x1a\x62ubble_enable_callout_line\x18\x13 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12,\n$bubble_enable_callout_line_undefined\x18\x14 \x01(\x08\x12<\n\x1b\x64\x65\x66\x61ult_enable_callout_line\x18\x15 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12-\n%default_enable_callout_line_undefined\x18\x16 \x01(\x08\x12\x39\n\x18line_enable_callout_line\x18\x17 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12*\n\"line_enable_callout_line_undefined\x18\x18 \x01(\x08\x12\x38\n\x17pie_enable_callout_line\x18\x19 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12)\n!pie_enable_callout_line_undefined\x18\x1a \x01(\x08\x12<\n\x1bscatter_enable_callout_line\x18\x1b \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12-\n%scatter_enable_callout_line_undefined\x18\x1c \x01(\x08\x12\x41\n stacked_area_enable_callout_line\x18\x1d \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x32\n*stacked_area_enable_callout_line_undefined\x18\x1e \x01(\x08\x12@\n\x1fstacked_bar_enable_callout_line\x18\x1f \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x31\n)stacked_bar_enable_callout_line_undefined\x18  \x01(\x08\x12X\n&default_error_bar_custom_negative_data\x18! \x01(\x0b\x32(.TSCH.SpecChartErrorBarCustomDataArchive\x12\x38\n0default_error_bar_custom_negative_data_undefined\x18\" \x01(\x08\x12\x62\n0default_error_bar_custom_negative_data_scatter_x\x18# \x01(\x0b\x32(.TSCH.SpecChartErrorBarCustomDataArchive\x12\x42\n:default_error_bar_custom_negative_data_scatter_x_undefined\x18$ \x01(\x08\x12X\n&default_error_bar_custom_positive_data\x18% \x01(\x0b\x32(.TSCH.SpecChartErrorBarCustomDataArchive\x12\x38\n0default_error_bar_custom_positive_data_undefined\x18& \x01(\x08\x12\x62\n0default_error_bar_custom_positive_data_scatter_x\x18\' \x01(\x0b\x32(.TSCH.SpecChartErrorBarCustomDataArchive\x12\x42\n:default_error_bar_custom_positive_data_scatter_x_undefined\x18( \x01(\x08\x12=\n\x1d\x64\x65\x66\x61ult_error_bar_fixed_value\x18) \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12/\n\'default_error_bar_fixed_value_undefined\x18* \x01(\x08\x12G\n\'default_error_bar_fixed_value_scatter_x\x18+ \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12\x39\n1default_error_bar_fixed_value_scatter_x_undefined\x18, \x01(\x08\x12?\n\x1f\x64\x65\x66\x61ult_error_bar_percent_value\x18- \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12\x31\n)default_error_bar_percent_value_undefined\x18. \x01(\x08\x12I\n)default_error_bar_percent_value_scatter_x\x18/ \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12;\n3default_error_bar_percent_value_scatter_x_undefined\x18\x30 \x01(\x08\x12:\n\x19\x64\x65\x66\x61ult_error_bar_setting\x18\x31 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12+\n#default_error_bar_setting_undefined\x18\x32 \x01(\x08\x12\x44\n#default_error_bar_setting_scatter_x\x18\x33 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x35\n-default_error_bar_setting_scatter_x_undefined\x18\x34 \x01(\x08\x12?\n\x1f\x64\x65\x66\x61ult_error_bar_std_dev_value\x18\x35 \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12\x31\n)default_error_bar_std_dev_value_undefined\x18\x36 \x01(\x08\x12I\n)default_error_bar_std_dev_value_scatter_x\x18\x37 \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12;\n3default_error_bar_std_dev_value_scatter_x_undefined\x18\x38 \x01(\x08\x12\x37\n\x16\x64\x65\x66\x61ult_error_bar_type\x18\x39 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12(\n default_error_bar_type_undefined\x18: \x01(\x08\x12\x41\n default_error_bar_type_scatter_x\x18; \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x32\n*default_error_bar_type_scatter_x_undefined\x18< \x01(\x08\x12\x33\n\x13pie_label_explosion\x18= \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12%\n\x1dpie_label_explosion_undefined\x18> \x01(\x08\x12\x31\n\x10\x62ubble_line_type\x18? \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\"\n\x1a\x62ubble_line_type_undefined\x18@ \x01(\x08\x12/\n\x0eline_line_type\x18\x41 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12 \n\x18line_line_type_undefined\x18\x42 \x01(\x08\x12\x35\n\x14mixed_line_line_type\x18\x43 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12&\n\x1emixed_line_line_type_undefined\x18\x44 \x01(\x08\x12\x32\n\x11scatter_line_type\x18\x45 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12#\n\x1bscatter_line_type_undefined\x18\x46 \x01(\x08\x12<\n\x15\x64\x65\x66\x61ult_number_format\x18G \x01(\x0b\x32\x1d.TSCH.SpecNumberFormatArchive\x12\'\n\x1f\x64\x65\x66\x61ult_number_format_undefined\x18H \x01(\x08\x12\x38\n\x11pie_number_format\x18I \x01(\x0b\x32\x1d.TSCH.SpecNumberFormatArchive\x12#\n\x1bpie_number_format_undefined\x18J \x01(\x08\x12;\n\x1a\x64\x65\x66\x61ult_number_format_type\x18K \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12,\n$default_number_format_type_undefined\x18L \x01(\x08\x12\x37\n\x16pie_number_format_type\x18M \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12(\n pie_number_format_type_undefined\x18N \x01(\x08\x12\x44\n\x1dstacked_percent_number_format\x18O \x01(\x0b\x32\x1d.TSCH.SpecNumberFormatArchive\x12/\n\'stacked_percent_number_format_undefined\x18P \x01(\x08\x12\x34\n\x13\x64\x65\x66\x61ult_series_type\x18Q \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12%\n\x1d\x64\x65\x66\x61ult_series_type_undefined\x18R \x01(\x08\x12\x34\n\x16\x64\x65\x66\x61ult_show_error_bar\x18S \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12(\n default_show_error_bar_undefined\x18T \x01(\x08\x12>\n default_show_error_bar_scatter_x\x18U \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12\x32\n*default_show_error_bar_scatter_x_undefined\x18V \x01(\x08\x12\x39\n\x1b\x62ubble_show_labels_in_front\x18W \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12-\n%bubble_show_labels_in_front_undefined\x18X \x01(\x08\x12:\n\x1c\x64\x65\x66\x61ult_show_labels_in_front\x18Y \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12.\n&default_show_labels_in_front_undefined\x18Z \x01(\x08\x12/\n\x11scatter_show_line\x18[ \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12#\n\x1bscatter_show_line_undefined\x18\\ \x01(\x08\x12\x37\n\x19\x62ubble_show_negative_data\x18] \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12+\n#bubble_show_negative_data_undefined\x18^ \x01(\x08\x12\x37\n\x19\x62ubble_show_series_labels\x18_ \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12+\n#bubble_show_series_labels_undefined\x18` \x01(\x08\x12\x34\n\x16pie_show_series_labels\x18\x61 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12(\n pie_show_series_labels_undefined\x18\x62 \x01(\x08\x12\x38\n\x1ascatter_show_series_labels\x18\x63 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12,\n$scatter_show_series_labels_undefined\x18\x64 \x01(\x08\x12.\n\x10\x61rea_show_symbol\x18\x65 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12\"\n\x1a\x61rea_show_symbol_undefined\x18\x66 \x01(\x08\x12.\n\x10line_show_symbol\x18g \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12\"\n\x1aline_show_symbol_undefined\x18h \x01(\x08\x12\x34\n\x16mixed_area_show_symbol\x18i \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12(\n mixed_area_show_symbol_undefined\x18j \x01(\x08\x12\x34\n\x16mixed_line_show_symbol\x18k \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12(\n mixed_line_show_symbol_undefined\x18l \x01(\x08\x12\x31\n\x13scatter_show_symbol\x18m \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12%\n\x1dscatter_show_symbol_undefined\x18n \x01(\x08\x12\x35\n\x17\x64\x65\x66\x61ult_show_trend_line\x18o \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12)\n!default_show_trend_line_undefined\x18p \x01(\x08\x12\x34\n\x16\x61rea_show_value_labels\x18q \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12(\n area_show_value_labels_undefined\x18r \x01(\x08\x12\x33\n\x15\x62\x61r_show_value_labels\x18s \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12\'\n\x1f\x62\x61r_show_value_labels_undefined\x18t \x01(\x08\x12\x36\n\x18\x62ubble_show_value_labels\x18u \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12*\n\"bubble_show_value_labels_undefined\x18v \x01(\x08\x12\x37\n\x19\x64\x65\x66\x61ult_show_value_labels\x18w \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12+\n#default_show_value_labels_undefined\x18x \x01(\x08\x12\x34\n\x16line_show_value_labels\x18y \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12(\n line_show_value_labels_undefined\x18z \x01(\x08\x12\x35\n\x17mixed_show_value_labels\x18{ \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12)\n!mixed_show_value_labels_undefined\x18| \x01(\x08\x12\x33\n\x15pie_show_value_labels\x18} \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12\'\n\x1fpie_show_value_labels_undefined\x18~ \x01(\x08\x12\x37\n\x19scatter_show_value_labels\x18\x7f \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12,\n#scatter_show_value_labels_undefined\x18\x80\x01 \x01(\x08\x12\x37\n\x15\x62ubble_size_dimension\x18\x81\x01 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12(\n\x1f\x62ubble_size_dimension_undefined\x18\x82\x01 \x01(\x08\x12\x30\n\x11\x61rea_stack_labels\x18\x83\x01 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12$\n\x1b\x61rea_stack_labels_undefined\x18\x84\x01 \x01(\x08\x12/\n\x10\x62\x61r_stack_labels\x18\x85\x01 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12#\n\x1a\x62\x61r_stack_labels_undefined\x18\x86\x01 \x01(\x08\x12\x32\n\x13\x62ubble_stack_labels\x18\x87\x01 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12&\n\x1d\x62ubble_stack_labels_undefined\x18\x88\x01 \x01(\x08\x12\x33\n\x14\x64\x65\x66\x61ult_stack_labels\x18\x89\x01 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12\'\n\x1e\x64\x65\x66\x61ult_stack_labels_undefined\x18\x8a\x01 \x01(\x08\x12\x30\n\x11line_stack_labels\x18\x8b\x01 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12$\n\x1bline_stack_labels_undefined\x18\x8c\x01 \x01(\x08\x12/\n\x10pie_stack_labels\x18\x8d\x01 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12#\n\x1apie_stack_labels_undefined\x18\x8e\x01 \x01(\x08\x12\x33\n\x14scatter_stack_labels\x18\x8f\x01 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12\'\n\x1escatter_stack_labels_undefined\x18\x90\x01 \x01(\x08\x12\x38\n\x19stacked_area_stack_labels\x18\x91\x01 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12,\n#stacked_area_stack_labels_undefined\x18\x92\x01 \x01(\x08\x12\x37\n\x18stacked_bar_stack_labels\x18\x93\x01 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12+\n\"stacked_bar_stack_labels_undefined\x18\x94\x01 \x01(\x08\x12\x32\n\x10\x61rea_symbol_type\x18\x95\x01 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12#\n\x1a\x61rea_symbol_type_undefined\x18\x96\x01 \x01(\x08\x12\x32\n\x10line_symbol_type\x18\x97\x01 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12#\n\x1aline_symbol_type_undefined\x18\x98\x01 \x01(\x08\x12\x38\n\x16mixed_area_symbol_type\x18\x99\x01 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12)\n mixed_area_symbol_type_undefined\x18\x9a\x01 \x01(\x08\x12\x38\n\x16mixed_line_symbol_type\x18\x9b\x01 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12)\n mixed_line_symbol_type_undefined\x18\x9c\x01 \x01(\x08\x12\x35\n\x13scatter_symbol_type\x18\x9d\x01 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12&\n\x1dscatter_symbol_type_undefined\x18\x9e\x01 \x01(\x08\x12\x45\n$default_trend_line_equation_offset_x\x18\x9f\x01 \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12\x37\n.default_trend_line_equation_offset_x_undefined\x18\xa0\x01 \x01(\x08\x12\x45\n$default_trend_line_equation_offset_y\x18\xa1\x01 \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12\x37\n.default_trend_line_equation_offset_y_undefined\x18\xa2\x01 \x01(\x08\x12@\n\x1f\x64\x65\x66\x61ult_trend_line_label_string\x18\xa3\x01 \x01(\x0b\x32\x16.TSS.SpecStringArchive\x12\x32\n)default_trend_line_label_string_undefined\x18\xa4\x01 \x01(\x08\x12:\n\x18\x64\x65\x66\x61ult_trend_line_order\x18\xa5\x01 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12+\n\"default_trend_line_order_undefined\x18\xa6\x01 \x01(\x08\x12;\n\x19\x64\x65\x66\x61ult_trend_line_period\x18\xa7\x01 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12,\n#default_trend_line_period_undefined\x18\xa8\x01 \x01(\x08\x12\x46\n%default_trend_line_r_squared_offset_x\x18\xa9\x01 \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12\x38\n/default_trend_line_r_squared_offset_x_undefined\x18\xaa\x01 \x01(\x08\x12\x46\n%default_trend_line_r_squared_offset_y\x18\xab\x01 \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12\x38\n/default_trend_line_r_squared_offset_y_undefined\x18\xac\x01 \x01(\x08\x12?\n default_trend_line_show_equation\x18\xad\x01 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12\x33\n*default_trend_line_show_equation_undefined\x18\xae\x01 \x01(\x08\x12<\n\x1d\x64\x65\x66\x61ult_trend_line_show_label\x18\xaf\x01 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12\x30\n\'default_trend_line_show_label_undefined\x18\xb0\x01 \x01(\x08\x12?\n default_trend_line_show_r2_value\x18\xb1\x01 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12\x33\n*default_trend_line_show_r2_value_undefined\x18\xb2\x01 \x01(\x08\x12\x39\n\x17\x64\x65\x66\x61ult_trend_line_type\x18\xb3\x01 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12*\n!default_trend_line_type_undefined\x18\xb4\x01 \x01(\x08\x12:\n\x18\x62ubble_value_labels_axis\x18\xb5\x01 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12+\n\"bubble_value_labels_axis_undefined\x18\xb6\x01 \x01(\x08\x12;\n\x19scatter_value_labels_axis\x18\xb7\x01 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12,\n#scatter_value_labels_axis_undefined\x18\xb8\x01 \x01(\x08\x12\x34\n\x13pie_wedge_explosion\x18\xb9\x01 \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12&\n\x1dpie_wedge_explosion_undefined\x18\xba\x01 \x01(\x08\x12\x38\n\x16\x64\x65\x66\x61ult_y_axis_ordinal\x18\xbb\x01 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12)\n default_y_axis_ordinal_undefined\x18\xbc\x01 \x01(\x08\"\x98T\n(ChartSeriesStylePropertyChangeSetArchive\x12\x42\n!default_callout_line_end_line_end\x18\x01 \x01(\x0b\x32\x17.TSD.SpecLineEndArchive\x12\x33\n+default_callout_line_end_line_end_undefined\x18\x02 \x01(\x08\x12\x44\n#default_callout_line_start_line_end\x18\x03 \x01(\x0b\x32\x17.TSD.SpecLineEndArchive\x12\x35\n-default_callout_line_start_line_end_undefined\x18\x04 \x01(\x08\x12\x41\n!default_callout_line_stroke_style\x18\x05 \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12\x33\n+default_callout_line_stroke_style_undefined\x18\x06 \x01(\x08\x12;\n\x1a\x64\x65\x66\x61ult_error_bar_line_end\x18\x07 \x01(\x0b\x32\x17.TSD.SpecLineEndArchive\x12,\n$default_error_bar_line_end_undefined\x18\x08 \x01(\x08\x12\x45\n$default_error_bar_line_end_scatter_x\x18\t \x01(\x0b\x32\x17.TSD.SpecLineEndArchive\x12\x36\n.default_error_bar_line_end_scatter_x_undefined\x18\n \x01(\x08\x12\x38\n\x18\x64\x65\x66\x61ult_error_bar_shadow\x18\x0b \x01(\x0b\x32\x16.TSD.SpecShadowArchive\x12*\n\"default_error_bar_shadow_undefined\x18\x0c \x01(\x08\x12:\n\x19\x64\x65\x66\x61ult_error_bar_spacing\x18\r \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12+\n#default_error_bar_spacing_undefined\x18\x0e \x01(\x08\x12\x44\n#default_error_bar_spacing_scatter_x\x18\x0f \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x35\n-default_error_bar_spacing_scatter_x_undefined\x18\x10 \x01(\x08\x12\x38\n\x18\x64\x65\x66\x61ult_error_bar_stroke\x18\x11 \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12*\n\"default_error_bar_stroke_undefined\x18\x12 \x01(\x08\x12\x42\n\"default_error_bar_stroke_scatter_x\x18\x13 \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12\x34\n,default_error_bar_stroke_scatter_x_undefined\x18\x14 \x01(\x08\x12)\n\x0b\x61rea3d_fill\x18\x15 \x01(\x0b\x32\x14.TSD.SpecFillArchive\x12\x1d\n\x15\x61rea3d_fill_undefined\x18\x16 \x01(\x08\x12(\n\nbar3d_fill\x18\x17 \x01(\x0b\x32\x14.TSD.SpecFillArchive\x12\x1c\n\x14\x62\x61r3d_fill_undefined\x18\x18 \x01(\x08\x12+\n\rcolumn3d_fill\x18\x19 \x01(\x0b\x32\x14.TSD.SpecFillArchive\x12\x1f\n\x17\x63olumn3d_fill_undefined\x18\x1a \x01(\x08\x12)\n\x0bline3d_fill\x18\x1b \x01(\x0b\x32\x14.TSD.SpecFillArchive\x12\x1d\n\x15line3d_fill_undefined\x18\x1c \x01(\x08\x12(\n\npie3d_fill\x18\x1d \x01(\x0b\x32\x14.TSD.SpecFillArchive\x12\x1c\n\x14pie3d_fill_undefined\x18\x1e \x01(\x08\x12\'\n\tarea_fill\x18\x1f \x01(\x0b\x32\x14.TSD.SpecFillArchive\x12\x1b\n\x13\x61rea_fill_undefined\x18  \x01(\x08\x12&\n\x08\x62\x61r_fill\x18! \x01(\x0b\x32\x14.TSD.SpecFillArchive\x12\x1a\n\x12\x62\x61r_fill_undefined\x18\" \x01(\x08\x12)\n\x0b\x63olumn_fill\x18# \x01(\x0b\x32\x14.TSD.SpecFillArchive\x12\x1d\n\x15\x63olumn_fill_undefined\x18$ \x01(\x08\x12*\n\x0c\x64\x65\x66\x61ult_fill\x18% \x01(\x0b\x32\x14.TSD.SpecFillArchive\x12\x1e\n\x16\x64\x65\x66\x61ult_fill_undefined\x18& \x01(\x08\x12-\n\x0fmixed_area_fill\x18\' \x01(\x0b\x32\x14.TSD.SpecFillArchive\x12!\n\x19mixed_area_fill_undefined\x18( \x01(\x08\x12/\n\x11mixed_column_fill\x18) \x01(\x0b\x32\x14.TSD.SpecFillArchive\x12#\n\x1bmixed_column_fill_undefined\x18* \x01(\x08\x12&\n\x08pie_fill\x18+ \x01(\x0b\x32\x14.TSD.SpecFillArchive\x12\x1a\n\x12pie_fill_undefined\x18, \x01(\x08\x12\x41\n area_label_paragraph_style_index\x18- \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x32\n*area_label_paragraph_style_index_undefined\x18. \x01(\x08\x12@\n\x1f\x62\x61r_label_paragraph_style_index\x18/ \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x31\n)bar_label_paragraph_style_index_undefined\x18\x30 \x01(\x08\x12\x44\n#default_label_paragraph_style_index\x18\x31 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x35\n-default_label_paragraph_style_index_undefined\x18\x32 \x01(\x08\x12\x42\n!donut_label_paragraph_style_index\x18\x33 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x33\n+donut_label_paragraph_style_index_undefined\x18\x34 \x01(\x08\x12\x41\n line_label_paragraph_style_index\x18\x35 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x32\n*line_label_paragraph_style_index_undefined\x18\x36 \x01(\x08\x12\x42\n!mixed_label_paragraph_style_index\x18\x37 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x33\n+mixed_label_paragraph_style_index_undefined\x18\x38 \x01(\x08\x12@\n\x1fpie_label_paragraph_style_index\x18\x39 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x31\n)pie_label_paragraph_style_index_undefined\x18: \x01(\x08\x12/\n\x0f\x64\x65\x66\x61ult_opacity\x18; \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12!\n\x19\x64\x65\x66\x61ult_opacity_undefined\x18< \x01(\x08\x12I\n(area_outside_label_paragraph_style_index\x18= \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12:\n2area_outside_label_paragraph_style_index_undefined\x18> \x01(\x08\x12H\n\'bar_outside_label_paragraph_style_index\x18? \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x39\n1bar_outside_label_paragraph_style_index_undefined\x18@ \x01(\x08\x12L\n+default_outside_label_paragraph_style_index\x18\x41 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12=\n5default_outside_label_paragraph_style_index_undefined\x18\x42 \x01(\x08\x12J\n)donut_outside_label_paragraph_style_index\x18\x43 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12;\n3donut_outside_label_paragraph_style_index_undefined\x18\x44 \x01(\x08\x12J\n)mixed_outside_label_paragraph_style_index\x18\x45 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12;\n3mixed_outside_label_paragraph_style_index_undefined\x18\x46 \x01(\x08\x12H\n\'pie_outside_label_paragraph_style_index\x18G \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x39\n1pie_outside_label_paragraph_style_index_undefined\x18H \x01(\x08\x12-\n\rarea3d_shadow\x18I \x01(\x0b\x32\x16.TSD.SpecShadowArchive\x12\x1f\n\x17\x61rea3d_shadow_undefined\x18J \x01(\x08\x12,\n\x0c\x62\x61r3d_shadow\x18K \x01(\x0b\x32\x16.TSD.SpecShadowArchive\x12\x1e\n\x16\x62\x61r3d_shadow_undefined\x18L \x01(\x08\x12/\n\x0f\x63olumn3d_shadow\x18M \x01(\x0b\x32\x16.TSD.SpecShadowArchive\x12!\n\x19\x63olumn3d_shadow_undefined\x18N \x01(\x08\x12-\n\rline3d_shadow\x18O \x01(\x0b\x32\x16.TSD.SpecShadowArchive\x12\x1f\n\x17line3d_shadow_undefined\x18P \x01(\x08\x12,\n\x0cpie3d_shadow\x18Q \x01(\x0b\x32\x16.TSD.SpecShadowArchive\x12\x1e\n\x16pie3d_shadow_undefined\x18R \x01(\x08\x12+\n\x0b\x61rea_shadow\x18S \x01(\x0b\x32\x16.TSD.SpecShadowArchive\x12\x1d\n\x15\x61rea_shadow_undefined\x18T \x01(\x08\x12*\n\nbar_shadow\x18U \x01(\x0b\x32\x16.TSD.SpecShadowArchive\x12\x1c\n\x14\x62\x61r_shadow_undefined\x18V \x01(\x08\x12-\n\rbubble_shadow\x18W \x01(\x0b\x32\x16.TSD.SpecShadowArchive\x12\x1f\n\x17\x62ubble_shadow_undefined\x18X \x01(\x08\x12.\n\x0e\x64\x65\x66\x61ult_shadow\x18Y \x01(\x0b\x32\x16.TSD.SpecShadowArchive\x12 \n\x18\x64\x65\x66\x61ult_shadow_undefined\x18Z \x01(\x08\x12+\n\x0bline_shadow\x18[ \x01(\x0b\x32\x16.TSD.SpecShadowArchive\x12\x1d\n\x15line_shadow_undefined\x18\\ \x01(\x08\x12\x31\n\x11mixed_area_shadow\x18] \x01(\x0b\x32\x16.TSD.SpecShadowArchive\x12#\n\x1bmixed_area_shadow_undefined\x18^ \x01(\x08\x12\x33\n\x13mixed_column_shadow\x18_ \x01(\x0b\x32\x16.TSD.SpecShadowArchive\x12%\n\x1dmixed_column_shadow_undefined\x18` \x01(\x08\x12\x31\n\x11mixed_line_shadow\x18\x61 \x01(\x0b\x32\x16.TSD.SpecShadowArchive\x12#\n\x1bmixed_line_shadow_undefined\x18\x62 \x01(\x08\x12*\n\npie_shadow\x18\x63 \x01(\x0b\x32\x16.TSD.SpecShadowArchive\x12\x1c\n\x14pie_shadow_undefined\x18\x64 \x01(\x08\x12.\n\x0escatter_shadow\x18\x65 \x01(\x0b\x32\x16.TSD.SpecShadowArchive\x12 \n\x18scatter_shadow_undefined\x18\x66 \x01(\x08\x12+\n\x0b\x61rea_stroke\x18g \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12\x1d\n\x15\x61rea_stroke_undefined\x18h \x01(\x08\x12*\n\nbar_stroke\x18i \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12\x1c\n\x14\x62\x61r_stroke_undefined\x18j \x01(\x08\x12-\n\rbubble_stroke\x18k \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12\x1f\n\x17\x62ubble_stroke_undefined\x18l \x01(\x08\x12+\n\x0bline_stroke\x18m \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12\x1d\n\x15line_stroke_undefined\x18n \x01(\x08\x12\x31\n\x11mixed_area_stroke\x18o \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12#\n\x1bmixed_area_stroke_undefined\x18p \x01(\x08\x12\x33\n\x13mixed_column_stroke\x18q \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12%\n\x1dmixed_column_stroke_undefined\x18r \x01(\x08\x12\x31\n\x11mixed_line_stroke\x18s \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12#\n\x1bmixed_line_stroke_undefined\x18t \x01(\x08\x12*\n\npie_stroke\x18u \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12\x1c\n\x14pie_stroke_undefined\x18v \x01(\x08\x12.\n\x0escatter_stroke\x18w \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12 \n\x18scatter_stroke_undefined\x18x \x01(\x08\x12.\n\x10\x61rea_symbol_fill\x18y \x01(\x0b\x32\x14.TSD.SpecFillArchive\x12\"\n\x1a\x61rea_symbol_fill_undefined\x18z \x01(\x08\x12\x30\n\x12\x62ubble_symbol_fill\x18{ \x01(\x0b\x32\x14.TSD.SpecFillArchive\x12$\n\x1c\x62ubble_symbol_fill_undefined\x18| \x01(\x08\x12.\n\x10line_symbol_fill\x18} \x01(\x0b\x32\x14.TSD.SpecFillArchive\x12\"\n\x1aline_symbol_fill_undefined\x18~ \x01(\x08\x12\x34\n\x16mixed_area_symbol_fill\x18\x7f \x01(\x0b\x32\x14.TSD.SpecFillArchive\x12)\n mixed_area_symbol_fill_undefined\x18\x80\x01 \x01(\x08\x12\x35\n\x16mixed_line_symbol_fill\x18\x81\x01 \x01(\x0b\x32\x14.TSD.SpecFillArchive\x12)\n mixed_line_symbol_fill_undefined\x18\x82\x01 \x01(\x08\x12\x32\n\x13scatter_symbol_fill\x18\x83\x01 \x01(\x0b\x32\x14.TSD.SpecFillArchive\x12&\n\x1dscatter_symbol_fill_undefined\x18\x84\x01 \x01(\x08\x12?\n area_symbol_fill_use_series_fill\x18\x85\x01 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12\x33\n*area_symbol_fill_use_series_fill_undefined\x18\x86\x01 \x01(\x08\x12?\n line_symbol_fill_use_series_fill\x18\x87\x01 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12\x33\n*line_symbol_fill_use_series_fill_undefined\x18\x88\x01 \x01(\x08\x12\x45\n&mixed_area_symbol_fill_use_series_fill\x18\x89\x01 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12\x39\n0mixed_area_symbol_fill_use_series_fill_undefined\x18\x8a\x01 \x01(\x08\x12\x45\n&mixed_line_symbol_fill_use_series_fill\x18\x8b\x01 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12\x39\n0mixed_line_symbol_fill_use_series_fill_undefined\x18\x8c\x01 \x01(\x08\x12\x41\n\"area_symbol_fill_use_series_stroke\x18\x8d\x01 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12\x35\n,area_symbol_fill_use_series_stroke_undefined\x18\x8e\x01 \x01(\x08\x12\x43\n$bubble_symbol_fill_use_series_stroke\x18\x8f\x01 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12\x37\n.bubble_symbol_fill_use_series_stroke_undefined\x18\x90\x01 \x01(\x08\x12\x41\n\"line_symbol_fill_use_series_stroke\x18\x91\x01 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12\x35\n,line_symbol_fill_use_series_stroke_undefined\x18\x92\x01 \x01(\x08\x12G\n(mixed_area_symbol_fill_use_series_stroke\x18\x93\x01 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12;\n2mixed_area_symbol_fill_use_series_stroke_undefined\x18\x94\x01 \x01(\x08\x12G\n(mixed_line_symbol_fill_use_series_stroke\x18\x95\x01 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12;\n2mixed_line_symbol_fill_use_series_stroke_undefined\x18\x96\x01 \x01(\x08\x12\x44\n%scatter_symbol_fill_use_series_stroke\x18\x97\x01 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12\x38\n/scatter_symbol_fill_use_series_stroke_undefined\x18\x98\x01 \x01(\x08\x12\x31\n\x10\x61rea_symbol_size\x18\x99\x01 \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12#\n\x1a\x61rea_symbol_size_undefined\x18\x9a\x01 \x01(\x08\x12\x31\n\x10line_symbol_size\x18\x9b\x01 \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12#\n\x1aline_symbol_size_undefined\x18\x9c\x01 \x01(\x08\x12\x37\n\x16mixed_area_symbol_size\x18\x9d\x01 \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12)\n mixed_area_symbol_size_undefined\x18\x9e\x01 \x01(\x08\x12\x37\n\x16mixed_line_symbol_size\x18\x9f\x01 \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12)\n mixed_line_symbol_size_undefined\x18\xa0\x01 \x01(\x08\x12\x34\n\x13scatter_symbol_size\x18\xa1\x01 \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12&\n\x1dscatter_symbol_size_undefined\x18\xa2\x01 \x01(\x08\x12\x33\n\x12\x61rea_symbol_stroke\x18\xa3\x01 \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12%\n\x1c\x61rea_symbol_stroke_undefined\x18\xa4\x01 \x01(\x08\x12\x35\n\x14\x62ubble_symbol_stroke\x18\xa5\x01 \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12\'\n\x1e\x62ubble_symbol_stroke_undefined\x18\xa6\x01 \x01(\x08\x12\x33\n\x12line_symbol_stroke\x18\xa7\x01 \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12%\n\x1cline_symbol_stroke_undefined\x18\xa8\x01 \x01(\x08\x12\x39\n\x18mixed_area_symbol_stroke\x18\xa9\x01 \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12+\n\"mixed_area_symbol_stroke_undefined\x18\xaa\x01 \x01(\x08\x12\x39\n\x18mixed_line_symbol_stroke\x18\xab\x01 \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12+\n\"mixed_line_symbol_stroke_undefined\x18\xac\x01 \x01(\x08\x12\x36\n\x15scatter_symbol_stroke\x18\xad\x01 \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12(\n\x1fscatter_symbol_stroke_undefined\x18\xae\x01 \x01(\x08\x12:\n\x19\x64\x65\x66\x61ult_trend_line_shadow\x18\xaf\x01 \x01(\x0b\x32\x16.TSD.SpecShadowArchive\x12,\n#default_trend_line_shadow_undefined\x18\xb0\x01 \x01(\x08\x12:\n\x19\x64\x65\x66\x61ult_trend_line_stroke\x18\xb1\x01 \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12,\n#default_trend_line_stroke_undefined\x18\xb2\x01 \x01(\x08\x12\x43\n\"default_trendline_equation_opacity\x18\xb3\x01 \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12\x35\n,default_trendline_equation_opacity_undefined\x18\xb4\x01 \x01(\x08\x12R\n0default_trendline_equation_paragraph_style_index\x18\xb5\x01 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x43\n:default_trendline_equation_paragraph_style_index_undefined\x18\xb6\x01 \x01(\x08\x12\x44\n#default_trendline_r_squared_opacity\x18\xb7\x01 \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12\x36\n-default_trendline_r_squared_opacity_undefined\x18\xb8\x01 \x01(\x08\x12S\n1default_trendline_r_squared_paragraph_style_index\x18\xb9\x01 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x44\n;default_trendline_r_squared_paragraph_style_index_undefined\x18\xba\x01 \x01(\x08\x12;\n\x19\x61rea_value_label_position\x18\xbb\x01 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12,\n#area_value_label_position_undefined\x18\xbc\x01 \x01(\x08\x12:\n\x18\x62\x61r_value_label_position\x18\xbd\x01 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12+\n\"bar_value_label_position_undefined\x18\xbe\x01 \x01(\x08\x12=\n\x1b\x62ubble_value_label_position\x18\xbf\x01 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12.\n%bubble_value_label_position_undefined\x18\xc0\x01 \x01(\x08\x12>\n\x1c\x64\x65\x66\x61ult_value_label_position\x18\xc1\x01 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12/\n&default_value_label_position_undefined\x18\xc2\x01 \x01(\x08\x12;\n\x19line_value_label_position\x18\xc3\x01 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12,\n#line_value_label_position_undefined\x18\xc4\x01 \x01(\x08\x12\x41\n\x1fmixed_area_value_label_position\x18\xc5\x01 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x32\n)mixed_area_value_label_position_undefined\x18\xc6\x01 \x01(\x08\x12\x43\n!mixed_column_value_label_position\x18\xc7\x01 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x34\n+mixed_column_value_label_position_undefined\x18\xc8\x01 \x01(\x08\x12\x41\n\x1fmixed_line_value_label_position\x18\xc9\x01 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x32\n)mixed_line_value_label_position_undefined\x18\xca\x01 \x01(\x08\x12>\n\x1cscatter_value_label_position\x18\xcb\x01 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12/\n&scatter_value_label_position_undefined\x18\xcc\x01 \x01(\x08\x12\x43\n!stacked_area_value_label_position\x18\xcd\x01 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x34\n+stacked_area_value_label_position_undefined\x18\xce\x01 \x01(\x08\x12\x42\n stacked_bar_value_label_position\x18\xcf\x01 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x33\n*stacked_bar_value_label_position_undefined\x18\xd0\x01 \x01(\x08\x12=\n\x1b\x64\x65\x66\x61ult_value_label_spacing\x18\xd1\x01 \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12.\n%default_value_label_spacing_undefined\x18\xd2\x01 \x01(\x08\"\xe5\x13\n\"ChartStylePropertyChangeSetArchive\x12\x37\n\x17\x64\x65\x66\x61ult3d_chart_opacity\x18\x01 \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12)\n!default3d_chart_opacity_undefined\x18\x02 \x01(\x08\x12H\n\x17\x61rea3d_lighting_package\x18\x03 \x01(\x0b\x32\'.TSCH.SpecChart3dLightingPackageArchive\x12)\n!area3d_lighting_package_undefined\x18\x04 \x01(\x08\x12G\n\x16\x62\x61r3d_lighting_package\x18\x05 \x01(\x0b\x32\'.TSCH.SpecChart3dLightingPackageArchive\x12(\n bar3d_lighting_package_undefined\x18\x06 \x01(\x08\x12J\n\x19\x63olumn3d_lighting_package\x18\x07 \x01(\x0b\x32\'.TSCH.SpecChart3dLightingPackageArchive\x12+\n#column3d_lighting_package_undefined\x18\x08 \x01(\x08\x12K\n\x1a\x64\x65\x66\x61ult3d_lighting_package\x18\t \x01(\x0b\x32\'.TSCH.SpecChart3dLightingPackageArchive\x12,\n$default3d_lighting_package_undefined\x18\n \x01(\x08\x12H\n\x17line3d_lighting_package\x18\x0b \x01(\x0b\x32\'.TSCH.SpecChart3dLightingPackageArchive\x12)\n!line3d_lighting_package_undefined\x18\x0c \x01(\x08\x12G\n\x16pie3d_lighting_package\x18\r \x01(\x0b\x32\'.TSCH.SpecChart3dLightingPackageArchive\x12(\n pie3d_lighting_package_undefined\x18\x0e \x01(\x08\x12\x35\n\x17\x64\x65\x66\x61ult_background_fill\x18\x0f \x01(\x0b\x32\x14.TSD.SpecFillArchive\x12)\n!default_background_fill_undefined\x18\x10 \x01(\x08\x12\x39\n\x19\x64\x65\x66\x61ult_background_stroke\x18\x11 \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12+\n#default_background_stroke_undefined\x18\x12 \x01(\x08\x12\x36\n\x16\x64\x65\x66\x61ult_border_opacity\x18\x13 \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12(\n default_border_opacity_undefined\x18\x14 \x01(\x08\x12\x35\n\x15\x64\x65\x66\x61ult_border_shadow\x18\x15 \x01(\x0b\x32\x16.TSD.SpecShadowArchive\x12\'\n\x1f\x64\x65\x66\x61ult_border_shadow_undefined\x18\x16 \x01(\x08\x12\x35\n\x15\x64\x65\x66\x61ult_border_stroke\x18\x17 \x01(\x0b\x32\x16.TSD.SpecStrokeArchive\x12\'\n\x1f\x64\x65\x66\x61ult_border_stroke_undefined\x18\x18 \x01(\x08\x12\x34\n\x16\x64\x65\x66\x61ult_combine_layers\x18\x19 \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12(\n default_combine_layers_undefined\x18\x1a \x01(\x08\x12L\n+default_data_set_name_paragraph_style_index\x18\x1b \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12=\n5default_data_set_name_paragraph_style_index_undefined\x18\x1c \x01(\x08\x12:\n\x1c\x64\x65\x66\x61ult_grid_background_fill\x18\x1d \x01(\x0b\x32\x14.TSD.SpecFillArchive\x12.\n&default_grid_background_fill_undefined\x18\x1e \x01(\x08\x12?\n\x1f\x64\x65\x66\x61ult_grid_background_opacity\x18\x1f \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12\x31\n)default_grid_background_opacity_undefined\x18  \x01(\x08\x12\x35\n\x15\x64\x65\x66\x61ult_inter_bar_gap\x18! \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12\'\n\x1f\x64\x65\x66\x61ult_inter_bar_gap_undefined\x18\" \x01(\x08\x12\x35\n\x15\x64\x65\x66\x61ult_inter_set_gap\x18# \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12\'\n\x1f\x64\x65\x66\x61ult_inter_set_gap_undefined\x18$ \x01(\x08\x12\x43\n%default_rounded_corner_outer_end_only\x18% \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12\x37\n/default_rounded_corner_outer_end_only_undefined\x18& \x01(\x08\x12=\n\x1d\x64\x65\x66\x61ult_rounded_corner_radius\x18\' \x01(\x0b\x32\x16.TSS.SpecDoubleArchive\x12/\n\'default_rounded_corner_radius_undefined\x18( \x01(\x08\x12\x31\n\x13\x64\x65\x66\x61ult_show_border\x18) \x01(\x0b\x32\x14.TSS.SpecBoolArchive\x12%\n\x1d\x64\x65\x66\x61ult_show_border_undefined\x18* \x01(\x08\x12\x32\n\x13\x64\x65\x66\x61ult_title_color\x18+ \x01(\x0b\x32\x15.TSS.SpecColorArchive\x12%\n\x1d\x64\x65\x66\x61ult_title_color_undefined\x18, \x01(\x08\x12\x44\n#default_title_paragraph_style_index\x18- \x01(\x0b\x32\x17.TSS.SpecIntegerArchive\x12\x35\n-default_title_paragraph_style_index_undefined\x18. \x01(\x08')
  ,
  dependencies=[TSCH3DArchives__pb2.DESCRIPTOR,TSCHArchives__Common__pb2.DESCRIPTOR,TSDArchives__sos__pb2.DESCRIPTOR,TSKArchives__pb2.DESCRIPTOR,TSSArchives__sos__pb2.DESCRIPTOR,])




_SPECSETCHART3DLIGHTINGPACKAGEARCHIVE = _descriptor.Descriptor(
  name='SpecSetChart3dLightingPackageArchive',
  full_name='TSCH.SpecSetChart3dLightingPackageArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='chart3d_lighting_package', full_name='TSCH.SpecSetChart3dLightingPackageArchive.chart3d_lighting_package', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unset', full_name='TSCH.SpecSetChart3dLightingPackageArchive.unset', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=146,
  serialized_end=270,
)


_SPECSETCHART3DVECTORARCHIVE = _descriptor.Descriptor(
  name='SpecSetChart3dVectorArchive',
  full_name='TSCH.SpecSetChart3dVectorArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='chart3d_vector', full_name='TSCH.SpecSetChart3dVectorArchive.chart3d_vector', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unset', full_name='TSCH.SpecSetChart3dVectorArchive.unset', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=272,
  serialized_end=368,
)


_SPECSETCHARTERRORBARCUSTOMDATAARCHIVE = _descriptor.Descriptor(
  name='SpecSetChartErrorBarCustomDataArchive',
  full_name='TSCH.SpecSetChartErrorBarCustomDataArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='chart_error_bar_custom_data', full_name='TSCH.SpecSetChartErrorBarCustomDataArchive.chart_error_bar_custom_data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unset', full_name='TSCH.SpecSetChartErrorBarCustomDataArchive.unset', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=371,
  serialized_end=506,
)


_SPECSETCHARTSOPTIONALDOUBLEARCHIVEARCHIVE = _descriptor.Descriptor(
  name='SpecSetChartsOptionalDoubleArchiveArchive',
  full_name='TSCH.SpecSetChartsOptionalDoubleArchiveArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='charts_optional_double_archive', full_name='TSCH.SpecSetChartsOptionalDoubleArchiveArchive.charts_optional_double_archive', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unset', full_name='TSCH.SpecSetChartsOptionalDoubleArchiveArchive.unset', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=509,
  serialized_end=642,
)


_SPECSETFORMATOBJECTARCHIVE = _descriptor.Descriptor(
  name='SpecSetFormatObjectArchive',
  full_name='TSCH.SpecSetFormatObjectArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='format_object', full_name='TSCH.SpecSetFormatObjectArchive.format_object', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unset', full_name='TSCH.SpecSetFormatObjectArchive.unset', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=644,
  serialized_end=736,
)


_SPECSETNUMBERFORMATARCHIVE = _descriptor.Descriptor(
  name='SpecSetNumberFormatArchive',
  full_name='TSCH.SpecSetNumberFormatArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='number_format', full_name='TSCH.SpecSetNumberFormatArchive.number_format', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unset', full_name='TSCH.SpecSetNumberFormatArchive.unset', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=738,
  serialized_end=830,
)


_SPECCHART3DLIGHTINGPACKAGEARCHIVE = _descriptor.Descriptor(
  name='SpecChart3dLightingPackageArchive',
  full_name='TSCH.SpecChart3dLightingPackageArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spec_set_chart3d_lighting_package', full_name='TSCH.SpecChart3dLightingPackageArchive.spec_set_chart3d_lighting_package', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=832,
  serialized_end=954,
)


_SPECCHART3DVECTORARCHIVE = _descriptor.Descriptor(
  name='SpecChart3dVectorArchive',
  full_name='TSCH.SpecChart3dVectorArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spec_set_chart3d_vector', full_name='TSCH.SpecChart3dVectorArchive.spec_set_chart3d_vector', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=956,
  serialized_end=1050,
)


_SPECCHARTERRORBARCUSTOMDATAARCHIVE = _descriptor.Descriptor(
  name='SpecChartErrorBarCustomDataArchive',
  full_name='TSCH.SpecChartErrorBarCustomDataArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spec_set_chart_error_bar_custom_data', full_name='TSCH.SpecChartErrorBarCustomDataArchive.spec_set_chart_error_bar_custom_data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1052,
  serialized_end=1179,
)


_SPECCHARTSOPTIONALDOUBLEARCHIVEARCHIVE = _descriptor.Descriptor(
  name='SpecChartsOptionalDoubleArchiveArchive',
  full_name='TSCH.SpecChartsOptionalDoubleArchiveArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spec_set_charts_optional_double_archive', full_name='TSCH.SpecChartsOptionalDoubleArchiveArchive.spec_set_charts_optional_double_archive', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1182,
  serialized_end=1320,
)


_SPECFORMATOBJECTARCHIVE = _descriptor.Descriptor(
  name='SpecFormatObjectArchive',
  full_name='TSCH.SpecFormatObjectArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spec_set_format_object', full_name='TSCH.SpecFormatObjectArchive.spec_set_format_object', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1322,
  serialized_end=1413,
)


_SPECNUMBERFORMATARCHIVE = _descriptor.Descriptor(
  name='SpecNumberFormatArchive',
  full_name='TSCH.SpecNumberFormatArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spec_set_number_format', full_name='TSCH.SpecNumberFormatArchive.spec_set_number_format', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1415,
  serialized_end=1506,
)


_CHARTAXISNONSTYLEPROPERTYCHANGESETARCHIVE = _descriptor.Descriptor(
  name='ChartAxisNonStylePropertyChangeSetArchive',
  full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='default10_date_format', full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive.default10_date_format', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default10_date_format_undefined', full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive.default10_date_format_undefined', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default10_number_format', full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive.default10_number_format', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default10_number_format_undefined', full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive.default10_number_format_undefined', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default3d_label_position', full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive.default3d_label_position', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default3d_label_position_undefined', full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive.default3d_label_position_undefined', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_date_format', full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive.default_date_format', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_date_format_undefined', full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive.default_date_format_undefined', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_duration_format', full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive.default_duration_format', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_duration_format_undefined', full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive.default_duration_format_undefined', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_number_format', full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive.default_number_format', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_number_format_undefined', full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive.default_number_format_undefined', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_number_format_type', full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive.default_number_format_type', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_number_format_type_undefined', full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive.default_number_format_type_undefined', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_number_of_decades', full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive.value_number_of_decades', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_number_of_decades_undefined', full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive.value_number_of_decades_undefined', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_number_of_major_gridlines', full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive.value_number_of_major_gridlines', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_number_of_major_gridlines_undefined', full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive.value_number_of_major_gridlines_undefined', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_number_of_minor_gridlines', full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive.value_number_of_minor_gridlines', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_number_of_minor_gridlines_undefined', full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive.value_number_of_minor_gridlines_undefined', index=19,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_plot_to_edges', full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive.category_plot_to_edges', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_plot_to_edges_undefined', full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive.category_plot_to_edges_undefined', index=21,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_scale', full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive.value_scale', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_scale_undefined', full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive.value_scale_undefined', index=23,
      number=24, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_show_labels', full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive.category_show_labels', index=24,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_show_labels_undefined', full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive.category_show_labels_undefined', index=25,
      number=26, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_show_labels', full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive.default_show_labels', index=26,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_show_labels_undefined', full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive.default_show_labels_undefined', index=27,
      number=28, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_show_labels', full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive.value_show_labels', index=28,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_show_labels_undefined', full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive.value_show_labels_undefined', index=29,
      number=30, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_show_series_labels', full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive.category_show_series_labels', index=30,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_show_series_labels_undefined', full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive.category_show_series_labels_undefined', index=31,
      number=32, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='multi_data_show_series_labels', full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive.multi_data_show_series_labels', index=32,
      number=33, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='multi_data_show_series_labels_undefined', full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive.multi_data_show_series_labels_undefined', index=33,
      number=34, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_show_title', full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive.category_show_title', index=34,
      number=35, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_show_title_undefined', full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive.category_show_title_undefined', index=35,
      number=36, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_show_title', full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive.value_show_title', index=36,
      number=37, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_show_title_undefined', full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive.value_show_title_undefined', index=37,
      number=38, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_title', full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive.category_title', index=38,
      number=39, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_title_undefined', full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive.category_title_undefined', index=39,
      number=40, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_title', full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive.value_title', index=40,
      number=41, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_title_undefined', full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive.value_title_undefined', index=41,
      number=42, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_user_max', full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive.default_user_max', index=42,
      number=43, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_user_max_undefined', full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive.default_user_max_undefined', index=43,
      number=44, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_user_min', full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive.default_user_min', index=44,
      number=45, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_user_min_undefined', full_name='TSCH.ChartAxisNonStylePropertyChangeSetArchive.default_user_min_undefined', index=45,
      number=46, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1509,
  serialized_end=3821,
)


_CHARTAXISSTYLEPROPERTYCHANGESETARCHIVE = _descriptor.Descriptor(
  name='ChartAxisStylePropertyChangeSetArchive',
  full_name='TSCH.ChartAxisStylePropertyChangeSetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='category3d_gridline_opacity', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.category3d_gridline_opacity', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category3d_gridline_opacity_undefined', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.category3d_gridline_opacity_undefined', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value3d_gridline_opacity', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.value3d_gridline_opacity', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value3d_gridline_opacity_undefined', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.value3d_gridline_opacity_undefined', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category3d_gridline_stroke', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.category3d_gridline_stroke', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category3d_gridline_stroke_undefined', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.category3d_gridline_stroke_undefined', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value3d_gridline_stroke', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.value3d_gridline_stroke', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value3d_gridline_stroke_undefined', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.value3d_gridline_stroke_undefined', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_horizontal_spacing', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.category_horizontal_spacing', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_horizontal_spacing_undefined', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.category_horizontal_spacing_undefined', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_label_paragraph_style_index', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.category_label_paragraph_style_index', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_label_paragraph_style_index_undefined', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.category_label_paragraph_style_index_undefined', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_label_paragraph_style_index', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.default_label_paragraph_style_index', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_label_paragraph_style_index_undefined', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.default_label_paragraph_style_index_undefined', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_label_paragraph_style_index', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.value_label_paragraph_style_index', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_label_paragraph_style_index_undefined', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.value_label_paragraph_style_index_undefined', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_labels_orientation', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.category_labels_orientation', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_labels_orientation_undefined', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.category_labels_orientation_undefined', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_labels_orientation', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.default_labels_orientation', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_labels_orientation_undefined', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.default_labels_orientation_undefined', index=19,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_labels_orientation', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.value_labels_orientation', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_labels_orientation_undefined', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.value_labels_orientation_undefined', index=21,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_major_gridline_opacity', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.category_major_gridline_opacity', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_major_gridline_opacity_undefined', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.category_major_gridline_opacity_undefined', index=23,
      number=24, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_major_gridline_opacity', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.value_major_gridline_opacity', index=24,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_major_gridline_opacity_undefined', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.value_major_gridline_opacity_undefined', index=25,
      number=26, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_major_gridline_shadow', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.category_major_gridline_shadow', index=26,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_major_gridline_shadow_undefined', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.category_major_gridline_shadow_undefined', index=27,
      number=28, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_major_gridline_shadow', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.value_major_gridline_shadow', index=28,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_major_gridline_shadow_undefined', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.value_major_gridline_shadow_undefined', index=29,
      number=30, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_major_gridline_stroke', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.category_major_gridline_stroke', index=30,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_major_gridline_stroke_undefined', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.category_major_gridline_stroke_undefined', index=31,
      number=32, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_major_gridline_stroke', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.value_major_gridline_stroke', index=32,
      number=33, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_major_gridline_stroke_undefined', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.value_major_gridline_stroke_undefined', index=33,
      number=34, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_minor_gridline_opacity', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.category_minor_gridline_opacity', index=34,
      number=35, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_minor_gridline_opacity_undefined', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.category_minor_gridline_opacity_undefined', index=35,
      number=36, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_minor_gridline_opacity', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.value_minor_gridline_opacity', index=36,
      number=37, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_minor_gridline_opacity_undefined', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.value_minor_gridline_opacity_undefined', index=37,
      number=38, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_minor_gridline_shadow', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.category_minor_gridline_shadow', index=38,
      number=39, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_minor_gridline_shadow_undefined', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.category_minor_gridline_shadow_undefined', index=39,
      number=40, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_minor_gridline_shadow', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.value_minor_gridline_shadow', index=40,
      number=41, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_minor_gridline_shadow_undefined', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.value_minor_gridline_shadow_undefined', index=41,
      number=42, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_minor_gridline_stroke', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.category_minor_gridline_stroke', index=42,
      number=43, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_minor_gridline_stroke_undefined', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.category_minor_gridline_stroke_undefined', index=43,
      number=44, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_minor_gridline_stroke', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.value_minor_gridline_stroke', index=44,
      number=45, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_minor_gridline_stroke_undefined', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.value_minor_gridline_stroke_undefined', index=45,
      number=46, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_show_axis', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.category_show_axis', index=46,
      number=47, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_show_axis_undefined', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.category_show_axis_undefined', index=47,
      number=48, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_show_axis', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.value_show_axis', index=48,
      number=49, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_show_axis_undefined', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.value_show_axis_undefined', index=49,
      number=50, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_show_last_label', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.category_show_last_label', index=50,
      number=51, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_show_last_label_undefined', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.category_show_last_label_undefined', index=51,
      number=52, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_show_major_gridlines', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.category_show_major_gridlines', index=52,
      number=53, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_show_major_gridlines_undefined', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.category_show_major_gridlines_undefined', index=53,
      number=54, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_show_major_gridlines', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.value_show_major_gridlines', index=54,
      number=55, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_show_major_gridlines_undefined', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.value_show_major_gridlines_undefined', index=55,
      number=56, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_show_major_tickmarks', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.category_show_major_tickmarks', index=56,
      number=57, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_show_major_tickmarks_undefined', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.category_show_major_tickmarks_undefined', index=57,
      number=58, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_show_major_tickmarks', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.value_show_major_tickmarks', index=58,
      number=59, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_show_major_tickmarks_undefined', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.value_show_major_tickmarks_undefined', index=59,
      number=60, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_show_minimum_label', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.value_show_minimum_label', index=60,
      number=61, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_show_minimum_label_undefined', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.value_show_minimum_label_undefined', index=61,
      number=62, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_show_minor_gridlines', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.category_show_minor_gridlines', index=62,
      number=63, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_show_minor_gridlines_undefined', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.category_show_minor_gridlines_undefined', index=63,
      number=64, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_show_minor_gridlines', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.value_show_minor_gridlines', index=64,
      number=65, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_show_minor_gridlines_undefined', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.value_show_minor_gridlines_undefined', index=65,
      number=66, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_show_minor_tickmarks', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.category_show_minor_tickmarks', index=66,
      number=67, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_show_minor_tickmarks_undefined', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.category_show_minor_tickmarks_undefined', index=67,
      number=68, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_show_minor_tickmarks', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.value_show_minor_tickmarks', index=68,
      number=69, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_show_minor_tickmarks_undefined', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.value_show_minor_tickmarks_undefined', index=69,
      number=70, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_tickmark_location', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.category_tickmark_location', index=70,
      number=71, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_tickmark_location_undefined', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.category_tickmark_location_undefined', index=71,
      number=72, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_tickmark_location', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.value_tickmark_location', index=72,
      number=73, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_tickmark_location_undefined', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.value_tickmark_location_undefined', index=73,
      number=74, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_title_paragraph_style_index', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.category_title_paragraph_style_index', index=74,
      number=75, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_title_paragraph_style_index_undefined', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.category_title_paragraph_style_index_undefined', index=75,
      number=76, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_title_paragraph_style_index', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.default_title_paragraph_style_index', index=76,
      number=77, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_title_paragraph_style_index_undefined', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.default_title_paragraph_style_index_undefined', index=77,
      number=78, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_title_paragraph_style_index', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.value_title_paragraph_style_index', index=78,
      number=79, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_title_paragraph_style_index_undefined', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.value_title_paragraph_style_index_undefined', index=79,
      number=80, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_vertical_spacing', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.category_vertical_spacing', index=80,
      number=81, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_vertical_spacing_undefined', full_name='TSCH.ChartAxisStylePropertyChangeSetArchive.category_vertical_spacing_undefined', index=81,
      number=82, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3824,
  serialized_end=8330,
)


_CHARTLEGENDNONSTYLEPROPERTYCHANGESETARCHIVE = _descriptor.Descriptor(
  name='ChartLegendNonStylePropertyChangeSetArchive',
  full_name='TSCH.ChartLegendNonStylePropertyChangeSetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8332,
  serialized_end=8377,
)


_CHARTLEGENDSTYLEPROPERTYCHANGESETARCHIVE = _descriptor.Descriptor(
  name='ChartLegendStylePropertyChangeSetArchive',
  full_name='TSCH.ChartLegendStylePropertyChangeSetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='default_fill', full_name='TSCH.ChartLegendStylePropertyChangeSetArchive.default_fill', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_fill_undefined', full_name='TSCH.ChartLegendStylePropertyChangeSetArchive.default_fill_undefined', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_label_paragraph_style_index', full_name='TSCH.ChartLegendStylePropertyChangeSetArchive.default_label_paragraph_style_index', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_label_paragraph_style_index_undefined', full_name='TSCH.ChartLegendStylePropertyChangeSetArchive.default_label_paragraph_style_index_undefined', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_opacity', full_name='TSCH.ChartLegendStylePropertyChangeSetArchive.default_opacity', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_opacity_undefined', full_name='TSCH.ChartLegendStylePropertyChangeSetArchive.default_opacity_undefined', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_shadow', full_name='TSCH.ChartLegendStylePropertyChangeSetArchive.default_shadow', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_shadow_undefined', full_name='TSCH.ChartLegendStylePropertyChangeSetArchive.default_shadow_undefined', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_stroke', full_name='TSCH.ChartLegendStylePropertyChangeSetArchive.default_stroke', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_stroke_undefined', full_name='TSCH.ChartLegendStylePropertyChangeSetArchive.default_stroke_undefined', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8380,
  serialized_end=8871,
)


_CHARTNONSTYLEPROPERTYCHANGESETARCHIVE = _descriptor.Descriptor(
  name='ChartNonStylePropertyChangeSetArchive',
  full_name='TSCH.ChartNonStylePropertyChangeSetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='default3d_bar_shape', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.default3d_bar_shape', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default3d_bar_shape_undefined', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.default3d_bar_shape_undefined', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default3d_bevel_edges', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.default3d_bevel_edges', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default3d_bevel_edges_undefined', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.default3d_bevel_edges_undefined', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default3d_inter_set_depth_gap', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.default3d_inter_set_depth_gap', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default3d_inter_set_depth_gap_undefined', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.default3d_inter_set_depth_gap_undefined', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default3d_rotation', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.default3d_rotation', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default3d_rotation_undefined', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.default3d_rotation_undefined', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='area3d_scale', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.area3d_scale', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='area3d_scale_undefined', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.area3d_scale_undefined', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bar3d_scale', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.bar3d_scale', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bar3d_scale_undefined', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.bar3d_scale_undefined', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column3d_scale', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.column3d_scale', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column3d_scale_undefined', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.column3d_scale_undefined', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default3d_scale', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.default3d_scale', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default3d_scale_undefined', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.default3d_scale_undefined', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line3d_scale', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.line3d_scale', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line3d_scale_undefined', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.line3d_scale_undefined', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pie3d_scale', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.pie3d_scale', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pie3d_scale_undefined', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.pie3d_scale_undefined', index=19,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default3d_viewport', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.default3d_viewport', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default3d_viewport_undefined', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.default3d_viewport_undefined', index=21,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='area_callout_line_type', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.area_callout_line_type', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='area_callout_line_type_undefined', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.area_callout_line_type_undefined', index=23,
      number=24, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bar_callout_line_type', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.bar_callout_line_type', index=24,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bar_callout_line_type_undefined', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.bar_callout_line_type_undefined', index=25,
      number=26, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bubble_callout_line_type', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.bubble_callout_line_type', index=26,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bubble_callout_line_type_undefined', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.bubble_callout_line_type_undefined', index=27,
      number=28, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_callout_line_type', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.default_callout_line_type', index=28,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_callout_line_type_undefined', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.default_callout_line_type_undefined', index=29,
      number=30, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_callout_line_type', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.line_callout_line_type', index=30,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_callout_line_type_undefined', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.line_callout_line_type_undefined', index=31,
      number=32, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pie_callout_line_type', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.pie_callout_line_type', index=32,
      number=33, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pie_callout_line_type_undefined', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.pie_callout_line_type_undefined', index=33,
      number=34, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scatter_callout_line_type', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.scatter_callout_line_type', index=34,
      number=35, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scatter_callout_line_type_undefined', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.scatter_callout_line_type_undefined', index=35,
      number=36, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stacked_area_callout_line_type', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.stacked_area_callout_line_type', index=36,
      number=37, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stacked_area_callout_line_type_undefined', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.stacked_area_callout_line_type_undefined', index=37,
      number=38, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stacked_bar_callout_line_type', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.stacked_bar_callout_line_type', index=38,
      number=39, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stacked_bar_callout_line_type_undefined', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.stacked_bar_callout_line_type_undefined', index=39,
      number=40, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_d_e_p_r_e_c_a_t_e_d_rounded_corner_outer_end_only', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.default_d_e_p_r_e_c_a_t_e_d_rounded_corner_outer_end_only', index=40,
      number=41, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_d_e_p_r_e_c_a_t_e_d_rounded_corner_outer_end_only_undefined', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.default_d_e_p_r_e_c_a_t_e_d_rounded_corner_outer_end_only_undefined', index=41,
      number=42, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_d_e_p_r_e_c_a_t_e_d_rounded_corner_radius', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.default_d_e_p_r_e_c_a_t_e_d_rounded_corner_radius', index=42,
      number=43, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_d_e_p_r_e_c_a_t_e_d_rounded_corner_radius_undefined', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.default_d_e_p_r_e_c_a_t_e_d_rounded_corner_radius_undefined', index=43,
      number=44, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_data_set_name_location', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.default_data_set_name_location', index=44,
      number=45, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_data_set_name_location_undefined', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.default_data_set_name_location_undefined', index=45,
      number=46, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_donut_place_title_at_center', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.default_donut_place_title_at_center', index=46,
      number=47, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_donut_place_title_at_center_undefined', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.default_donut_place_title_at_center_undefined', index=47,
      number=48, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_inner_radius', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.default_inner_radius', index=48,
      number=49, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_inner_radius_undefined', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.default_inner_radius_undefined', index=49,
      number=50, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_multi_data_control_type', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.default_multi_data_control_type', index=50,
      number=51, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_multi_data_control_type_undefined', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.default_multi_data_control_type_undefined', index=51,
      number=52, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_pie_start_angle', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.default_pie_start_angle', index=52,
      number=53, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_pie_start_angle_undefined', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.default_pie_start_angle_undefined', index=53,
      number=54, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_show_legend', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.default_show_legend', index=54,
      number=55, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_show_legend_undefined', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.default_show_legend_undefined', index=55,
      number=56, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_show_title', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.default_show_title', index=56,
      number=57, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_show_title_undefined', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.default_show_title_undefined', index=57,
      number=58, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_skip_hidden_data', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.default_skip_hidden_data', index=58,
      number=59, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_skip_hidden_data_undefined', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.default_skip_hidden_data_undefined', index=59,
      number=60, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_title', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.default_title', index=60,
      number=61, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_title_undefined', full_name='TSCH.ChartNonStylePropertyChangeSetArchive.default_title_undefined', index=61,
      number=62, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8874,
  serialized_end=12087,
)


_CHARTREFERENCELINENONSTYLEPROPERTYCHANGESETARCHIVE = _descriptor.Descriptor(
  name='ChartReferenceLineNonStylePropertyChangeSetArchive',
  full_name='TSCH.ChartReferenceLineNonStylePropertyChangeSetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='default_custom_value', full_name='TSCH.ChartReferenceLineNonStylePropertyChangeSetArchive.default_custom_value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_custom_value_undefined', full_name='TSCH.ChartReferenceLineNonStylePropertyChangeSetArchive.default_custom_value_undefined', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_label', full_name='TSCH.ChartReferenceLineNonStylePropertyChangeSetArchive.default_label', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_label_undefined', full_name='TSCH.ChartReferenceLineNonStylePropertyChangeSetArchive.default_label_undefined', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_show_label', full_name='TSCH.ChartReferenceLineNonStylePropertyChangeSetArchive.default_show_label', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_show_label_undefined', full_name='TSCH.ChartReferenceLineNonStylePropertyChangeSetArchive.default_show_label_undefined', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_show_line', full_name='TSCH.ChartReferenceLineNonStylePropertyChangeSetArchive.default_show_line', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_show_line_undefined', full_name='TSCH.ChartReferenceLineNonStylePropertyChangeSetArchive.default_show_line_undefined', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_show_value_label', full_name='TSCH.ChartReferenceLineNonStylePropertyChangeSetArchive.default_show_value_label', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_show_value_label_undefined', full_name='TSCH.ChartReferenceLineNonStylePropertyChangeSetArchive.default_show_value_label_undefined', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_type', full_name='TSCH.ChartReferenceLineNonStylePropertyChangeSetArchive.default_type', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_type_undefined', full_name='TSCH.ChartReferenceLineNonStylePropertyChangeSetArchive.default_type_undefined', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12090,
  serialized_end=12691,
)


_CHARTREFERENCELINESTYLEPROPERTYCHANGESETARCHIVE = _descriptor.Descriptor(
  name='ChartReferenceLineStylePropertyChangeSetArchive',
  full_name='TSCH.ChartReferenceLineStylePropertyChangeSetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='default_label_paragraph_style_index', full_name='TSCH.ChartReferenceLineStylePropertyChangeSetArchive.default_label_paragraph_style_index', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_label_paragraph_style_index_undefined', full_name='TSCH.ChartReferenceLineStylePropertyChangeSetArchive.default_label_paragraph_style_index_undefined', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_shadow', full_name='TSCH.ChartReferenceLineStylePropertyChangeSetArchive.default_shadow', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_shadow_undefined', full_name='TSCH.ChartReferenceLineStylePropertyChangeSetArchive.default_shadow_undefined', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_stroke', full_name='TSCH.ChartReferenceLineStylePropertyChangeSetArchive.default_stroke', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_stroke_undefined', full_name='TSCH.ChartReferenceLineStylePropertyChangeSetArchive.default_stroke_undefined', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_value_label_paragraph_style_index', full_name='TSCH.ChartReferenceLineStylePropertyChangeSetArchive.default_value_label_paragraph_style_index', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_value_label_paragraph_style_index_undefined', full_name='TSCH.ChartReferenceLineStylePropertyChangeSetArchive.default_value_label_paragraph_style_index_undefined', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12694,
  serialized_end=13169,
)


_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE = _descriptor.Descriptor(
  name='ChartSeriesNonStylePropertyChangeSetArchive',
  full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='default10_date_format', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default10_date_format', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default10_date_format_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default10_date_format_undefined', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default10_number_format', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default10_number_format', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default10_number_format_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default10_number_format_undefined', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pie10_number_format', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.pie10_number_format', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pie10_number_format_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.pie10_number_format_undefined', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pie23_label_explosion', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.pie23_label_explosion', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pie23_label_explosion_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.pie23_label_explosion_undefined', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bubble_adjustment_scale', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.bubble_adjustment_scale', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bubble_adjustment_scale_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.bubble_adjustment_scale_undefined', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_date_format', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_date_format', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_date_format_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_date_format_undefined', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_duration_format', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_duration_format', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_duration_format_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_duration_format_undefined', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='area_enable_callout_line', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.area_enable_callout_line', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='area_enable_callout_line_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.area_enable_callout_line_undefined', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bar_enable_callout_line', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.bar_enable_callout_line', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bar_enable_callout_line_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.bar_enable_callout_line_undefined', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bubble_enable_callout_line', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.bubble_enable_callout_line', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bubble_enable_callout_line_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.bubble_enable_callout_line_undefined', index=19,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_enable_callout_line', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_enable_callout_line', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_enable_callout_line_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_enable_callout_line_undefined', index=21,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_enable_callout_line', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.line_enable_callout_line', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_enable_callout_line_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.line_enable_callout_line_undefined', index=23,
      number=24, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pie_enable_callout_line', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.pie_enable_callout_line', index=24,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pie_enable_callout_line_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.pie_enable_callout_line_undefined', index=25,
      number=26, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scatter_enable_callout_line', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.scatter_enable_callout_line', index=26,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scatter_enable_callout_line_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.scatter_enable_callout_line_undefined', index=27,
      number=28, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stacked_area_enable_callout_line', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.stacked_area_enable_callout_line', index=28,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stacked_area_enable_callout_line_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.stacked_area_enable_callout_line_undefined', index=29,
      number=30, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stacked_bar_enable_callout_line', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.stacked_bar_enable_callout_line', index=30,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stacked_bar_enable_callout_line_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.stacked_bar_enable_callout_line_undefined', index=31,
      number=32, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_error_bar_custom_negative_data', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_error_bar_custom_negative_data', index=32,
      number=33, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_error_bar_custom_negative_data_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_error_bar_custom_negative_data_undefined', index=33,
      number=34, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_error_bar_custom_negative_data_scatter_x', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_error_bar_custom_negative_data_scatter_x', index=34,
      number=35, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_error_bar_custom_negative_data_scatter_x_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_error_bar_custom_negative_data_scatter_x_undefined', index=35,
      number=36, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_error_bar_custom_positive_data', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_error_bar_custom_positive_data', index=36,
      number=37, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_error_bar_custom_positive_data_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_error_bar_custom_positive_data_undefined', index=37,
      number=38, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_error_bar_custom_positive_data_scatter_x', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_error_bar_custom_positive_data_scatter_x', index=38,
      number=39, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_error_bar_custom_positive_data_scatter_x_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_error_bar_custom_positive_data_scatter_x_undefined', index=39,
      number=40, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_error_bar_fixed_value', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_error_bar_fixed_value', index=40,
      number=41, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_error_bar_fixed_value_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_error_bar_fixed_value_undefined', index=41,
      number=42, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_error_bar_fixed_value_scatter_x', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_error_bar_fixed_value_scatter_x', index=42,
      number=43, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_error_bar_fixed_value_scatter_x_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_error_bar_fixed_value_scatter_x_undefined', index=43,
      number=44, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_error_bar_percent_value', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_error_bar_percent_value', index=44,
      number=45, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_error_bar_percent_value_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_error_bar_percent_value_undefined', index=45,
      number=46, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_error_bar_percent_value_scatter_x', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_error_bar_percent_value_scatter_x', index=46,
      number=47, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_error_bar_percent_value_scatter_x_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_error_bar_percent_value_scatter_x_undefined', index=47,
      number=48, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_error_bar_setting', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_error_bar_setting', index=48,
      number=49, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_error_bar_setting_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_error_bar_setting_undefined', index=49,
      number=50, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_error_bar_setting_scatter_x', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_error_bar_setting_scatter_x', index=50,
      number=51, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_error_bar_setting_scatter_x_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_error_bar_setting_scatter_x_undefined', index=51,
      number=52, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_error_bar_std_dev_value', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_error_bar_std_dev_value', index=52,
      number=53, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_error_bar_std_dev_value_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_error_bar_std_dev_value_undefined', index=53,
      number=54, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_error_bar_std_dev_value_scatter_x', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_error_bar_std_dev_value_scatter_x', index=54,
      number=55, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_error_bar_std_dev_value_scatter_x_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_error_bar_std_dev_value_scatter_x_undefined', index=55,
      number=56, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_error_bar_type', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_error_bar_type', index=56,
      number=57, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_error_bar_type_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_error_bar_type_undefined', index=57,
      number=58, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_error_bar_type_scatter_x', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_error_bar_type_scatter_x', index=58,
      number=59, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_error_bar_type_scatter_x_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_error_bar_type_scatter_x_undefined', index=59,
      number=60, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pie_label_explosion', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.pie_label_explosion', index=60,
      number=61, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pie_label_explosion_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.pie_label_explosion_undefined', index=61,
      number=62, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bubble_line_type', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.bubble_line_type', index=62,
      number=63, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bubble_line_type_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.bubble_line_type_undefined', index=63,
      number=64, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_line_type', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.line_line_type', index=64,
      number=65, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_line_type_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.line_line_type_undefined', index=65,
      number=66, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_line_line_type', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.mixed_line_line_type', index=66,
      number=67, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_line_line_type_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.mixed_line_line_type_undefined', index=67,
      number=68, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scatter_line_type', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.scatter_line_type', index=68,
      number=69, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scatter_line_type_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.scatter_line_type_undefined', index=69,
      number=70, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_number_format', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_number_format', index=70,
      number=71, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_number_format_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_number_format_undefined', index=71,
      number=72, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pie_number_format', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.pie_number_format', index=72,
      number=73, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pie_number_format_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.pie_number_format_undefined', index=73,
      number=74, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_number_format_type', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_number_format_type', index=74,
      number=75, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_number_format_type_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_number_format_type_undefined', index=75,
      number=76, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pie_number_format_type', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.pie_number_format_type', index=76,
      number=77, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pie_number_format_type_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.pie_number_format_type_undefined', index=77,
      number=78, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stacked_percent_number_format', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.stacked_percent_number_format', index=78,
      number=79, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stacked_percent_number_format_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.stacked_percent_number_format_undefined', index=79,
      number=80, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_series_type', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_series_type', index=80,
      number=81, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_series_type_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_series_type_undefined', index=81,
      number=82, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_show_error_bar', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_show_error_bar', index=82,
      number=83, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_show_error_bar_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_show_error_bar_undefined', index=83,
      number=84, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_show_error_bar_scatter_x', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_show_error_bar_scatter_x', index=84,
      number=85, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_show_error_bar_scatter_x_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_show_error_bar_scatter_x_undefined', index=85,
      number=86, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bubble_show_labels_in_front', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.bubble_show_labels_in_front', index=86,
      number=87, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bubble_show_labels_in_front_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.bubble_show_labels_in_front_undefined', index=87,
      number=88, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_show_labels_in_front', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_show_labels_in_front', index=88,
      number=89, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_show_labels_in_front_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_show_labels_in_front_undefined', index=89,
      number=90, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scatter_show_line', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.scatter_show_line', index=90,
      number=91, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scatter_show_line_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.scatter_show_line_undefined', index=91,
      number=92, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bubble_show_negative_data', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.bubble_show_negative_data', index=92,
      number=93, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bubble_show_negative_data_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.bubble_show_negative_data_undefined', index=93,
      number=94, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bubble_show_series_labels', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.bubble_show_series_labels', index=94,
      number=95, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bubble_show_series_labels_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.bubble_show_series_labels_undefined', index=95,
      number=96, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pie_show_series_labels', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.pie_show_series_labels', index=96,
      number=97, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pie_show_series_labels_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.pie_show_series_labels_undefined', index=97,
      number=98, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scatter_show_series_labels', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.scatter_show_series_labels', index=98,
      number=99, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scatter_show_series_labels_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.scatter_show_series_labels_undefined', index=99,
      number=100, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='area_show_symbol', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.area_show_symbol', index=100,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='area_show_symbol_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.area_show_symbol_undefined', index=101,
      number=102, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_show_symbol', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.line_show_symbol', index=102,
      number=103, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_show_symbol_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.line_show_symbol_undefined', index=103,
      number=104, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_area_show_symbol', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.mixed_area_show_symbol', index=104,
      number=105, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_area_show_symbol_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.mixed_area_show_symbol_undefined', index=105,
      number=106, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_line_show_symbol', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.mixed_line_show_symbol', index=106,
      number=107, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_line_show_symbol_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.mixed_line_show_symbol_undefined', index=107,
      number=108, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scatter_show_symbol', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.scatter_show_symbol', index=108,
      number=109, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scatter_show_symbol_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.scatter_show_symbol_undefined', index=109,
      number=110, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_show_trend_line', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_show_trend_line', index=110,
      number=111, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_show_trend_line_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_show_trend_line_undefined', index=111,
      number=112, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='area_show_value_labels', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.area_show_value_labels', index=112,
      number=113, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='area_show_value_labels_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.area_show_value_labels_undefined', index=113,
      number=114, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bar_show_value_labels', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.bar_show_value_labels', index=114,
      number=115, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bar_show_value_labels_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.bar_show_value_labels_undefined', index=115,
      number=116, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bubble_show_value_labels', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.bubble_show_value_labels', index=116,
      number=117, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bubble_show_value_labels_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.bubble_show_value_labels_undefined', index=117,
      number=118, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_show_value_labels', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_show_value_labels', index=118,
      number=119, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_show_value_labels_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_show_value_labels_undefined', index=119,
      number=120, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_show_value_labels', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.line_show_value_labels', index=120,
      number=121, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_show_value_labels_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.line_show_value_labels_undefined', index=121,
      number=122, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_show_value_labels', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.mixed_show_value_labels', index=122,
      number=123, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_show_value_labels_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.mixed_show_value_labels_undefined', index=123,
      number=124, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pie_show_value_labels', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.pie_show_value_labels', index=124,
      number=125, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pie_show_value_labels_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.pie_show_value_labels_undefined', index=125,
      number=126, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scatter_show_value_labels', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.scatter_show_value_labels', index=126,
      number=127, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scatter_show_value_labels_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.scatter_show_value_labels_undefined', index=127,
      number=128, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bubble_size_dimension', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.bubble_size_dimension', index=128,
      number=129, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bubble_size_dimension_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.bubble_size_dimension_undefined', index=129,
      number=130, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='area_stack_labels', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.area_stack_labels', index=130,
      number=131, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='area_stack_labels_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.area_stack_labels_undefined', index=131,
      number=132, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bar_stack_labels', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.bar_stack_labels', index=132,
      number=133, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bar_stack_labels_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.bar_stack_labels_undefined', index=133,
      number=134, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bubble_stack_labels', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.bubble_stack_labels', index=134,
      number=135, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bubble_stack_labels_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.bubble_stack_labels_undefined', index=135,
      number=136, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_stack_labels', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_stack_labels', index=136,
      number=137, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_stack_labels_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_stack_labels_undefined', index=137,
      number=138, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_stack_labels', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.line_stack_labels', index=138,
      number=139, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_stack_labels_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.line_stack_labels_undefined', index=139,
      number=140, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pie_stack_labels', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.pie_stack_labels', index=140,
      number=141, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pie_stack_labels_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.pie_stack_labels_undefined', index=141,
      number=142, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scatter_stack_labels', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.scatter_stack_labels', index=142,
      number=143, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scatter_stack_labels_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.scatter_stack_labels_undefined', index=143,
      number=144, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stacked_area_stack_labels', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.stacked_area_stack_labels', index=144,
      number=145, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stacked_area_stack_labels_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.stacked_area_stack_labels_undefined', index=145,
      number=146, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stacked_bar_stack_labels', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.stacked_bar_stack_labels', index=146,
      number=147, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stacked_bar_stack_labels_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.stacked_bar_stack_labels_undefined', index=147,
      number=148, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='area_symbol_type', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.area_symbol_type', index=148,
      number=149, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='area_symbol_type_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.area_symbol_type_undefined', index=149,
      number=150, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_symbol_type', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.line_symbol_type', index=150,
      number=151, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_symbol_type_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.line_symbol_type_undefined', index=151,
      number=152, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_area_symbol_type', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.mixed_area_symbol_type', index=152,
      number=153, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_area_symbol_type_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.mixed_area_symbol_type_undefined', index=153,
      number=154, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_line_symbol_type', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.mixed_line_symbol_type', index=154,
      number=155, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_line_symbol_type_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.mixed_line_symbol_type_undefined', index=155,
      number=156, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scatter_symbol_type', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.scatter_symbol_type', index=156,
      number=157, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scatter_symbol_type_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.scatter_symbol_type_undefined', index=157,
      number=158, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_trend_line_equation_offset_x', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_trend_line_equation_offset_x', index=158,
      number=159, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_trend_line_equation_offset_x_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_trend_line_equation_offset_x_undefined', index=159,
      number=160, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_trend_line_equation_offset_y', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_trend_line_equation_offset_y', index=160,
      number=161, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_trend_line_equation_offset_y_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_trend_line_equation_offset_y_undefined', index=161,
      number=162, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_trend_line_label_string', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_trend_line_label_string', index=162,
      number=163, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_trend_line_label_string_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_trend_line_label_string_undefined', index=163,
      number=164, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_trend_line_order', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_trend_line_order', index=164,
      number=165, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_trend_line_order_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_trend_line_order_undefined', index=165,
      number=166, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_trend_line_period', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_trend_line_period', index=166,
      number=167, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_trend_line_period_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_trend_line_period_undefined', index=167,
      number=168, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_trend_line_r_squared_offset_x', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_trend_line_r_squared_offset_x', index=168,
      number=169, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_trend_line_r_squared_offset_x_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_trend_line_r_squared_offset_x_undefined', index=169,
      number=170, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_trend_line_r_squared_offset_y', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_trend_line_r_squared_offset_y', index=170,
      number=171, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_trend_line_r_squared_offset_y_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_trend_line_r_squared_offset_y_undefined', index=171,
      number=172, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_trend_line_show_equation', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_trend_line_show_equation', index=172,
      number=173, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_trend_line_show_equation_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_trend_line_show_equation_undefined', index=173,
      number=174, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_trend_line_show_label', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_trend_line_show_label', index=174,
      number=175, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_trend_line_show_label_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_trend_line_show_label_undefined', index=175,
      number=176, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_trend_line_show_r2_value', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_trend_line_show_r2_value', index=176,
      number=177, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_trend_line_show_r2_value_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_trend_line_show_r2_value_undefined', index=177,
      number=178, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_trend_line_type', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_trend_line_type', index=178,
      number=179, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_trend_line_type_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_trend_line_type_undefined', index=179,
      number=180, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bubble_value_labels_axis', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.bubble_value_labels_axis', index=180,
      number=181, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bubble_value_labels_axis_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.bubble_value_labels_axis_undefined', index=181,
      number=182, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scatter_value_labels_axis', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.scatter_value_labels_axis', index=182,
      number=183, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scatter_value_labels_axis_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.scatter_value_labels_axis_undefined', index=183,
      number=184, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pie_wedge_explosion', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.pie_wedge_explosion', index=184,
      number=185, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pie_wedge_explosion_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.pie_wedge_explosion_undefined', index=185,
      number=186, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_y_axis_ordinal', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_y_axis_ordinal', index=186,
      number=187, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_y_axis_ordinal_undefined', full_name='TSCH.ChartSeriesNonStylePropertyChangeSetArchive.default_y_axis_ordinal_undefined', index=187,
      number=188, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13172,
  serialized_end=23146,
)


_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE = _descriptor.Descriptor(
  name='ChartSeriesStylePropertyChangeSetArchive',
  full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='default_callout_line_end_line_end', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.default_callout_line_end_line_end', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_callout_line_end_line_end_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.default_callout_line_end_line_end_undefined', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_callout_line_start_line_end', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.default_callout_line_start_line_end', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_callout_line_start_line_end_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.default_callout_line_start_line_end_undefined', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_callout_line_stroke_style', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.default_callout_line_stroke_style', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_callout_line_stroke_style_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.default_callout_line_stroke_style_undefined', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_error_bar_line_end', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.default_error_bar_line_end', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_error_bar_line_end_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.default_error_bar_line_end_undefined', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_error_bar_line_end_scatter_x', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.default_error_bar_line_end_scatter_x', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_error_bar_line_end_scatter_x_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.default_error_bar_line_end_scatter_x_undefined', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_error_bar_shadow', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.default_error_bar_shadow', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_error_bar_shadow_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.default_error_bar_shadow_undefined', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_error_bar_spacing', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.default_error_bar_spacing', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_error_bar_spacing_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.default_error_bar_spacing_undefined', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_error_bar_spacing_scatter_x', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.default_error_bar_spacing_scatter_x', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_error_bar_spacing_scatter_x_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.default_error_bar_spacing_scatter_x_undefined', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_error_bar_stroke', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.default_error_bar_stroke', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_error_bar_stroke_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.default_error_bar_stroke_undefined', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_error_bar_stroke_scatter_x', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.default_error_bar_stroke_scatter_x', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_error_bar_stroke_scatter_x_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.default_error_bar_stroke_scatter_x_undefined', index=19,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='area3d_fill', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.area3d_fill', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='area3d_fill_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.area3d_fill_undefined', index=21,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bar3d_fill', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.bar3d_fill', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bar3d_fill_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.bar3d_fill_undefined', index=23,
      number=24, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column3d_fill', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.column3d_fill', index=24,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column3d_fill_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.column3d_fill_undefined', index=25,
      number=26, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line3d_fill', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.line3d_fill', index=26,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line3d_fill_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.line3d_fill_undefined', index=27,
      number=28, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pie3d_fill', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.pie3d_fill', index=28,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pie3d_fill_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.pie3d_fill_undefined', index=29,
      number=30, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='area_fill', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.area_fill', index=30,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='area_fill_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.area_fill_undefined', index=31,
      number=32, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bar_fill', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.bar_fill', index=32,
      number=33, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bar_fill_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.bar_fill_undefined', index=33,
      number=34, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column_fill', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.column_fill', index=34,
      number=35, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column_fill_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.column_fill_undefined', index=35,
      number=36, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_fill', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.default_fill', index=36,
      number=37, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_fill_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.default_fill_undefined', index=37,
      number=38, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_area_fill', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.mixed_area_fill', index=38,
      number=39, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_area_fill_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.mixed_area_fill_undefined', index=39,
      number=40, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_column_fill', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.mixed_column_fill', index=40,
      number=41, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_column_fill_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.mixed_column_fill_undefined', index=41,
      number=42, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pie_fill', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.pie_fill', index=42,
      number=43, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pie_fill_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.pie_fill_undefined', index=43,
      number=44, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='area_label_paragraph_style_index', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.area_label_paragraph_style_index', index=44,
      number=45, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='area_label_paragraph_style_index_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.area_label_paragraph_style_index_undefined', index=45,
      number=46, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bar_label_paragraph_style_index', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.bar_label_paragraph_style_index', index=46,
      number=47, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bar_label_paragraph_style_index_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.bar_label_paragraph_style_index_undefined', index=47,
      number=48, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_label_paragraph_style_index', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.default_label_paragraph_style_index', index=48,
      number=49, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_label_paragraph_style_index_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.default_label_paragraph_style_index_undefined', index=49,
      number=50, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='donut_label_paragraph_style_index', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.donut_label_paragraph_style_index', index=50,
      number=51, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='donut_label_paragraph_style_index_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.donut_label_paragraph_style_index_undefined', index=51,
      number=52, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_label_paragraph_style_index', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.line_label_paragraph_style_index', index=52,
      number=53, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_label_paragraph_style_index_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.line_label_paragraph_style_index_undefined', index=53,
      number=54, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_label_paragraph_style_index', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.mixed_label_paragraph_style_index', index=54,
      number=55, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_label_paragraph_style_index_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.mixed_label_paragraph_style_index_undefined', index=55,
      number=56, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pie_label_paragraph_style_index', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.pie_label_paragraph_style_index', index=56,
      number=57, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pie_label_paragraph_style_index_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.pie_label_paragraph_style_index_undefined', index=57,
      number=58, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_opacity', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.default_opacity', index=58,
      number=59, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_opacity_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.default_opacity_undefined', index=59,
      number=60, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='area_outside_label_paragraph_style_index', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.area_outside_label_paragraph_style_index', index=60,
      number=61, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='area_outside_label_paragraph_style_index_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.area_outside_label_paragraph_style_index_undefined', index=61,
      number=62, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bar_outside_label_paragraph_style_index', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.bar_outside_label_paragraph_style_index', index=62,
      number=63, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bar_outside_label_paragraph_style_index_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.bar_outside_label_paragraph_style_index_undefined', index=63,
      number=64, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_outside_label_paragraph_style_index', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.default_outside_label_paragraph_style_index', index=64,
      number=65, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_outside_label_paragraph_style_index_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.default_outside_label_paragraph_style_index_undefined', index=65,
      number=66, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='donut_outside_label_paragraph_style_index', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.donut_outside_label_paragraph_style_index', index=66,
      number=67, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='donut_outside_label_paragraph_style_index_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.donut_outside_label_paragraph_style_index_undefined', index=67,
      number=68, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_outside_label_paragraph_style_index', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.mixed_outside_label_paragraph_style_index', index=68,
      number=69, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_outside_label_paragraph_style_index_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.mixed_outside_label_paragraph_style_index_undefined', index=69,
      number=70, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pie_outside_label_paragraph_style_index', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.pie_outside_label_paragraph_style_index', index=70,
      number=71, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pie_outside_label_paragraph_style_index_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.pie_outside_label_paragraph_style_index_undefined', index=71,
      number=72, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='area3d_shadow', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.area3d_shadow', index=72,
      number=73, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='area3d_shadow_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.area3d_shadow_undefined', index=73,
      number=74, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bar3d_shadow', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.bar3d_shadow', index=74,
      number=75, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bar3d_shadow_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.bar3d_shadow_undefined', index=75,
      number=76, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column3d_shadow', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.column3d_shadow', index=76,
      number=77, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column3d_shadow_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.column3d_shadow_undefined', index=77,
      number=78, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line3d_shadow', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.line3d_shadow', index=78,
      number=79, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line3d_shadow_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.line3d_shadow_undefined', index=79,
      number=80, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pie3d_shadow', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.pie3d_shadow', index=80,
      number=81, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pie3d_shadow_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.pie3d_shadow_undefined', index=81,
      number=82, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='area_shadow', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.area_shadow', index=82,
      number=83, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='area_shadow_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.area_shadow_undefined', index=83,
      number=84, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bar_shadow', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.bar_shadow', index=84,
      number=85, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bar_shadow_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.bar_shadow_undefined', index=85,
      number=86, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bubble_shadow', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.bubble_shadow', index=86,
      number=87, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bubble_shadow_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.bubble_shadow_undefined', index=87,
      number=88, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_shadow', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.default_shadow', index=88,
      number=89, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_shadow_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.default_shadow_undefined', index=89,
      number=90, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_shadow', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.line_shadow', index=90,
      number=91, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_shadow_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.line_shadow_undefined', index=91,
      number=92, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_area_shadow', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.mixed_area_shadow', index=92,
      number=93, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_area_shadow_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.mixed_area_shadow_undefined', index=93,
      number=94, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_column_shadow', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.mixed_column_shadow', index=94,
      number=95, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_column_shadow_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.mixed_column_shadow_undefined', index=95,
      number=96, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_line_shadow', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.mixed_line_shadow', index=96,
      number=97, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_line_shadow_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.mixed_line_shadow_undefined', index=97,
      number=98, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pie_shadow', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.pie_shadow', index=98,
      number=99, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pie_shadow_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.pie_shadow_undefined', index=99,
      number=100, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scatter_shadow', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.scatter_shadow', index=100,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scatter_shadow_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.scatter_shadow_undefined', index=101,
      number=102, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='area_stroke', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.area_stroke', index=102,
      number=103, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='area_stroke_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.area_stroke_undefined', index=103,
      number=104, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bar_stroke', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.bar_stroke', index=104,
      number=105, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bar_stroke_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.bar_stroke_undefined', index=105,
      number=106, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bubble_stroke', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.bubble_stroke', index=106,
      number=107, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bubble_stroke_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.bubble_stroke_undefined', index=107,
      number=108, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_stroke', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.line_stroke', index=108,
      number=109, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_stroke_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.line_stroke_undefined', index=109,
      number=110, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_area_stroke', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.mixed_area_stroke', index=110,
      number=111, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_area_stroke_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.mixed_area_stroke_undefined', index=111,
      number=112, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_column_stroke', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.mixed_column_stroke', index=112,
      number=113, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_column_stroke_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.mixed_column_stroke_undefined', index=113,
      number=114, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_line_stroke', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.mixed_line_stroke', index=114,
      number=115, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_line_stroke_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.mixed_line_stroke_undefined', index=115,
      number=116, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pie_stroke', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.pie_stroke', index=116,
      number=117, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pie_stroke_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.pie_stroke_undefined', index=117,
      number=118, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scatter_stroke', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.scatter_stroke', index=118,
      number=119, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scatter_stroke_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.scatter_stroke_undefined', index=119,
      number=120, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='area_symbol_fill', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.area_symbol_fill', index=120,
      number=121, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='area_symbol_fill_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.area_symbol_fill_undefined', index=121,
      number=122, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bubble_symbol_fill', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.bubble_symbol_fill', index=122,
      number=123, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bubble_symbol_fill_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.bubble_symbol_fill_undefined', index=123,
      number=124, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_symbol_fill', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.line_symbol_fill', index=124,
      number=125, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_symbol_fill_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.line_symbol_fill_undefined', index=125,
      number=126, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_area_symbol_fill', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.mixed_area_symbol_fill', index=126,
      number=127, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_area_symbol_fill_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.mixed_area_symbol_fill_undefined', index=127,
      number=128, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_line_symbol_fill', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.mixed_line_symbol_fill', index=128,
      number=129, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_line_symbol_fill_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.mixed_line_symbol_fill_undefined', index=129,
      number=130, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scatter_symbol_fill', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.scatter_symbol_fill', index=130,
      number=131, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scatter_symbol_fill_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.scatter_symbol_fill_undefined', index=131,
      number=132, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='area_symbol_fill_use_series_fill', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.area_symbol_fill_use_series_fill', index=132,
      number=133, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='area_symbol_fill_use_series_fill_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.area_symbol_fill_use_series_fill_undefined', index=133,
      number=134, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_symbol_fill_use_series_fill', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.line_symbol_fill_use_series_fill', index=134,
      number=135, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_symbol_fill_use_series_fill_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.line_symbol_fill_use_series_fill_undefined', index=135,
      number=136, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_area_symbol_fill_use_series_fill', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.mixed_area_symbol_fill_use_series_fill', index=136,
      number=137, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_area_symbol_fill_use_series_fill_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.mixed_area_symbol_fill_use_series_fill_undefined', index=137,
      number=138, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_line_symbol_fill_use_series_fill', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.mixed_line_symbol_fill_use_series_fill', index=138,
      number=139, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_line_symbol_fill_use_series_fill_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.mixed_line_symbol_fill_use_series_fill_undefined', index=139,
      number=140, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='area_symbol_fill_use_series_stroke', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.area_symbol_fill_use_series_stroke', index=140,
      number=141, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='area_symbol_fill_use_series_stroke_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.area_symbol_fill_use_series_stroke_undefined', index=141,
      number=142, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bubble_symbol_fill_use_series_stroke', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.bubble_symbol_fill_use_series_stroke', index=142,
      number=143, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bubble_symbol_fill_use_series_stroke_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.bubble_symbol_fill_use_series_stroke_undefined', index=143,
      number=144, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_symbol_fill_use_series_stroke', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.line_symbol_fill_use_series_stroke', index=144,
      number=145, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_symbol_fill_use_series_stroke_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.line_symbol_fill_use_series_stroke_undefined', index=145,
      number=146, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_area_symbol_fill_use_series_stroke', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.mixed_area_symbol_fill_use_series_stroke', index=146,
      number=147, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_area_symbol_fill_use_series_stroke_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.mixed_area_symbol_fill_use_series_stroke_undefined', index=147,
      number=148, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_line_symbol_fill_use_series_stroke', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.mixed_line_symbol_fill_use_series_stroke', index=148,
      number=149, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_line_symbol_fill_use_series_stroke_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.mixed_line_symbol_fill_use_series_stroke_undefined', index=149,
      number=150, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scatter_symbol_fill_use_series_stroke', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.scatter_symbol_fill_use_series_stroke', index=150,
      number=151, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scatter_symbol_fill_use_series_stroke_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.scatter_symbol_fill_use_series_stroke_undefined', index=151,
      number=152, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='area_symbol_size', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.area_symbol_size', index=152,
      number=153, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='area_symbol_size_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.area_symbol_size_undefined', index=153,
      number=154, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_symbol_size', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.line_symbol_size', index=154,
      number=155, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_symbol_size_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.line_symbol_size_undefined', index=155,
      number=156, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_area_symbol_size', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.mixed_area_symbol_size', index=156,
      number=157, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_area_symbol_size_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.mixed_area_symbol_size_undefined', index=157,
      number=158, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_line_symbol_size', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.mixed_line_symbol_size', index=158,
      number=159, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_line_symbol_size_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.mixed_line_symbol_size_undefined', index=159,
      number=160, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scatter_symbol_size', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.scatter_symbol_size', index=160,
      number=161, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scatter_symbol_size_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.scatter_symbol_size_undefined', index=161,
      number=162, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='area_symbol_stroke', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.area_symbol_stroke', index=162,
      number=163, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='area_symbol_stroke_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.area_symbol_stroke_undefined', index=163,
      number=164, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bubble_symbol_stroke', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.bubble_symbol_stroke', index=164,
      number=165, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bubble_symbol_stroke_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.bubble_symbol_stroke_undefined', index=165,
      number=166, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_symbol_stroke', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.line_symbol_stroke', index=166,
      number=167, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_symbol_stroke_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.line_symbol_stroke_undefined', index=167,
      number=168, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_area_symbol_stroke', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.mixed_area_symbol_stroke', index=168,
      number=169, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_area_symbol_stroke_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.mixed_area_symbol_stroke_undefined', index=169,
      number=170, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_line_symbol_stroke', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.mixed_line_symbol_stroke', index=170,
      number=171, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_line_symbol_stroke_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.mixed_line_symbol_stroke_undefined', index=171,
      number=172, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scatter_symbol_stroke', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.scatter_symbol_stroke', index=172,
      number=173, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scatter_symbol_stroke_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.scatter_symbol_stroke_undefined', index=173,
      number=174, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_trend_line_shadow', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.default_trend_line_shadow', index=174,
      number=175, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_trend_line_shadow_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.default_trend_line_shadow_undefined', index=175,
      number=176, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_trend_line_stroke', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.default_trend_line_stroke', index=176,
      number=177, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_trend_line_stroke_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.default_trend_line_stroke_undefined', index=177,
      number=178, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_trendline_equation_opacity', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.default_trendline_equation_opacity', index=178,
      number=179, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_trendline_equation_opacity_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.default_trendline_equation_opacity_undefined', index=179,
      number=180, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_trendline_equation_paragraph_style_index', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.default_trendline_equation_paragraph_style_index', index=180,
      number=181, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_trendline_equation_paragraph_style_index_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.default_trendline_equation_paragraph_style_index_undefined', index=181,
      number=182, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_trendline_r_squared_opacity', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.default_trendline_r_squared_opacity', index=182,
      number=183, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_trendline_r_squared_opacity_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.default_trendline_r_squared_opacity_undefined', index=183,
      number=184, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_trendline_r_squared_paragraph_style_index', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.default_trendline_r_squared_paragraph_style_index', index=184,
      number=185, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_trendline_r_squared_paragraph_style_index_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.default_trendline_r_squared_paragraph_style_index_undefined', index=185,
      number=186, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='area_value_label_position', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.area_value_label_position', index=186,
      number=187, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='area_value_label_position_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.area_value_label_position_undefined', index=187,
      number=188, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bar_value_label_position', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.bar_value_label_position', index=188,
      number=189, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bar_value_label_position_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.bar_value_label_position_undefined', index=189,
      number=190, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bubble_value_label_position', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.bubble_value_label_position', index=190,
      number=191, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bubble_value_label_position_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.bubble_value_label_position_undefined', index=191,
      number=192, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_value_label_position', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.default_value_label_position', index=192,
      number=193, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_value_label_position_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.default_value_label_position_undefined', index=193,
      number=194, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_value_label_position', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.line_value_label_position', index=194,
      number=195, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_value_label_position_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.line_value_label_position_undefined', index=195,
      number=196, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_area_value_label_position', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.mixed_area_value_label_position', index=196,
      number=197, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_area_value_label_position_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.mixed_area_value_label_position_undefined', index=197,
      number=198, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_column_value_label_position', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.mixed_column_value_label_position', index=198,
      number=199, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_column_value_label_position_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.mixed_column_value_label_position_undefined', index=199,
      number=200, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_line_value_label_position', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.mixed_line_value_label_position', index=200,
      number=201, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mixed_line_value_label_position_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.mixed_line_value_label_position_undefined', index=201,
      number=202, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scatter_value_label_position', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.scatter_value_label_position', index=202,
      number=203, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scatter_value_label_position_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.scatter_value_label_position_undefined', index=203,
      number=204, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stacked_area_value_label_position', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.stacked_area_value_label_position', index=204,
      number=205, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stacked_area_value_label_position_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.stacked_area_value_label_position_undefined', index=205,
      number=206, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stacked_bar_value_label_position', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.stacked_bar_value_label_position', index=206,
      number=207, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stacked_bar_value_label_position_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.stacked_bar_value_label_position_undefined', index=207,
      number=208, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_value_label_spacing', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.default_value_label_spacing', index=208,
      number=209, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_value_label_spacing_undefined', full_name='TSCH.ChartSeriesStylePropertyChangeSetArchive.default_value_label_spacing_undefined', index=209,
      number=210, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23149,
  serialized_end=33925,
)


_CHARTSTYLEPROPERTYCHANGESETARCHIVE = _descriptor.Descriptor(
  name='ChartStylePropertyChangeSetArchive',
  full_name='TSCH.ChartStylePropertyChangeSetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='default3d_chart_opacity', full_name='TSCH.ChartStylePropertyChangeSetArchive.default3d_chart_opacity', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default3d_chart_opacity_undefined', full_name='TSCH.ChartStylePropertyChangeSetArchive.default3d_chart_opacity_undefined', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='area3d_lighting_package', full_name='TSCH.ChartStylePropertyChangeSetArchive.area3d_lighting_package', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='area3d_lighting_package_undefined', full_name='TSCH.ChartStylePropertyChangeSetArchive.area3d_lighting_package_undefined', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bar3d_lighting_package', full_name='TSCH.ChartStylePropertyChangeSetArchive.bar3d_lighting_package', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bar3d_lighting_package_undefined', full_name='TSCH.ChartStylePropertyChangeSetArchive.bar3d_lighting_package_undefined', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column3d_lighting_package', full_name='TSCH.ChartStylePropertyChangeSetArchive.column3d_lighting_package', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column3d_lighting_package_undefined', full_name='TSCH.ChartStylePropertyChangeSetArchive.column3d_lighting_package_undefined', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default3d_lighting_package', full_name='TSCH.ChartStylePropertyChangeSetArchive.default3d_lighting_package', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default3d_lighting_package_undefined', full_name='TSCH.ChartStylePropertyChangeSetArchive.default3d_lighting_package_undefined', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line3d_lighting_package', full_name='TSCH.ChartStylePropertyChangeSetArchive.line3d_lighting_package', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line3d_lighting_package_undefined', full_name='TSCH.ChartStylePropertyChangeSetArchive.line3d_lighting_package_undefined', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pie3d_lighting_package', full_name='TSCH.ChartStylePropertyChangeSetArchive.pie3d_lighting_package', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pie3d_lighting_package_undefined', full_name='TSCH.ChartStylePropertyChangeSetArchive.pie3d_lighting_package_undefined', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_background_fill', full_name='TSCH.ChartStylePropertyChangeSetArchive.default_background_fill', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_background_fill_undefined', full_name='TSCH.ChartStylePropertyChangeSetArchive.default_background_fill_undefined', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_background_stroke', full_name='TSCH.ChartStylePropertyChangeSetArchive.default_background_stroke', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_background_stroke_undefined', full_name='TSCH.ChartStylePropertyChangeSetArchive.default_background_stroke_undefined', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_border_opacity', full_name='TSCH.ChartStylePropertyChangeSetArchive.default_border_opacity', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_border_opacity_undefined', full_name='TSCH.ChartStylePropertyChangeSetArchive.default_border_opacity_undefined', index=19,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_border_shadow', full_name='TSCH.ChartStylePropertyChangeSetArchive.default_border_shadow', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_border_shadow_undefined', full_name='TSCH.ChartStylePropertyChangeSetArchive.default_border_shadow_undefined', index=21,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_border_stroke', full_name='TSCH.ChartStylePropertyChangeSetArchive.default_border_stroke', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_border_stroke_undefined', full_name='TSCH.ChartStylePropertyChangeSetArchive.default_border_stroke_undefined', index=23,
      number=24, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_combine_layers', full_name='TSCH.ChartStylePropertyChangeSetArchive.default_combine_layers', index=24,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_combine_layers_undefined', full_name='TSCH.ChartStylePropertyChangeSetArchive.default_combine_layers_undefined', index=25,
      number=26, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_data_set_name_paragraph_style_index', full_name='TSCH.ChartStylePropertyChangeSetArchive.default_data_set_name_paragraph_style_index', index=26,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_data_set_name_paragraph_style_index_undefined', full_name='TSCH.ChartStylePropertyChangeSetArchive.default_data_set_name_paragraph_style_index_undefined', index=27,
      number=28, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_grid_background_fill', full_name='TSCH.ChartStylePropertyChangeSetArchive.default_grid_background_fill', index=28,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_grid_background_fill_undefined', full_name='TSCH.ChartStylePropertyChangeSetArchive.default_grid_background_fill_undefined', index=29,
      number=30, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_grid_background_opacity', full_name='TSCH.ChartStylePropertyChangeSetArchive.default_grid_background_opacity', index=30,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_grid_background_opacity_undefined', full_name='TSCH.ChartStylePropertyChangeSetArchive.default_grid_background_opacity_undefined', index=31,
      number=32, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_inter_bar_gap', full_name='TSCH.ChartStylePropertyChangeSetArchive.default_inter_bar_gap', index=32,
      number=33, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_inter_bar_gap_undefined', full_name='TSCH.ChartStylePropertyChangeSetArchive.default_inter_bar_gap_undefined', index=33,
      number=34, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_inter_set_gap', full_name='TSCH.ChartStylePropertyChangeSetArchive.default_inter_set_gap', index=34,
      number=35, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_inter_set_gap_undefined', full_name='TSCH.ChartStylePropertyChangeSetArchive.default_inter_set_gap_undefined', index=35,
      number=36, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_rounded_corner_outer_end_only', full_name='TSCH.ChartStylePropertyChangeSetArchive.default_rounded_corner_outer_end_only', index=36,
      number=37, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_rounded_corner_outer_end_only_undefined', full_name='TSCH.ChartStylePropertyChangeSetArchive.default_rounded_corner_outer_end_only_undefined', index=37,
      number=38, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_rounded_corner_radius', full_name='TSCH.ChartStylePropertyChangeSetArchive.default_rounded_corner_radius', index=38,
      number=39, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_rounded_corner_radius_undefined', full_name='TSCH.ChartStylePropertyChangeSetArchive.default_rounded_corner_radius_undefined', index=39,
      number=40, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_show_border', full_name='TSCH.ChartStylePropertyChangeSetArchive.default_show_border', index=40,
      number=41, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_show_border_undefined', full_name='TSCH.ChartStylePropertyChangeSetArchive.default_show_border_undefined', index=41,
      number=42, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_title_color', full_name='TSCH.ChartStylePropertyChangeSetArchive.default_title_color', index=42,
      number=43, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_title_color_undefined', full_name='TSCH.ChartStylePropertyChangeSetArchive.default_title_color_undefined', index=43,
      number=44, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_title_paragraph_style_index', full_name='TSCH.ChartStylePropertyChangeSetArchive.default_title_paragraph_style_index', index=44,
      number=45, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_title_paragraph_style_index_undefined', full_name='TSCH.ChartStylePropertyChangeSetArchive.default_title_paragraph_style_index_undefined', index=45,
      number=46, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33928,
  serialized_end=36461,
)

_SPECSETCHART3DLIGHTINGPACKAGEARCHIVE.fields_by_name['chart3d_lighting_package'].message_type = TSCH3DArchives__pb2._CHART3DLIGHTINGPACKAGEARCHIVE
_SPECSETCHART3DVECTORARCHIVE.fields_by_name['chart3d_vector'].message_type = TSCH3DArchives__pb2._CHART3DVECTORARCHIVE
_SPECSETCHARTERRORBARCUSTOMDATAARCHIVE.fields_by_name['chart_error_bar_custom_data'].message_type = TSCHArchives__Common__pb2._CHARTSNSARRAYOFNSNUMBERDOUBLEARCHIVE
_SPECSETCHARTSOPTIONALDOUBLEARCHIVEARCHIVE.fields_by_name['charts_optional_double_archive'].message_type = TSCHArchives__Common__pb2._CHARTSNSNUMBERDOUBLEARCHIVE
_SPECSETFORMATOBJECTARCHIVE.fields_by_name['format_object'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_SPECSETNUMBERFORMATARCHIVE.fields_by_name['number_format'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_SPECCHART3DLIGHTINGPACKAGEARCHIVE.fields_by_name['spec_set_chart3d_lighting_package'].message_type = _SPECSETCHART3DLIGHTINGPACKAGEARCHIVE
_SPECCHART3DVECTORARCHIVE.fields_by_name['spec_set_chart3d_vector'].message_type = _SPECSETCHART3DVECTORARCHIVE
_SPECCHARTERRORBARCUSTOMDATAARCHIVE.fields_by_name['spec_set_chart_error_bar_custom_data'].message_type = _SPECSETCHARTERRORBARCUSTOMDATAARCHIVE
_SPECCHARTSOPTIONALDOUBLEARCHIVEARCHIVE.fields_by_name['spec_set_charts_optional_double_archive'].message_type = _SPECSETCHARTSOPTIONALDOUBLEARCHIVEARCHIVE
_SPECFORMATOBJECTARCHIVE.fields_by_name['spec_set_format_object'].message_type = _SPECSETFORMATOBJECTARCHIVE
_SPECNUMBERFORMATARCHIVE.fields_by_name['spec_set_number_format'].message_type = _SPECSETNUMBERFORMATARCHIVE
_CHARTAXISNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default10_date_format'].message_type = _SPECFORMATOBJECTARCHIVE
_CHARTAXISNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default10_number_format'].message_type = _SPECNUMBERFORMATARCHIVE
_CHARTAXISNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default3d_label_position'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTAXISNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_date_format'].message_type = _SPECFORMATOBJECTARCHIVE
_CHARTAXISNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_duration_format'].message_type = _SPECFORMATOBJECTARCHIVE
_CHARTAXISNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_number_format'].message_type = _SPECNUMBERFORMATARCHIVE
_CHARTAXISNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_number_format_type'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTAXISNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['value_number_of_decades'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTAXISNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['value_number_of_major_gridlines'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTAXISNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['value_number_of_minor_gridlines'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTAXISNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['category_plot_to_edges'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTAXISNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['value_scale'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTAXISNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['category_show_labels'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTAXISNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_show_labels'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTAXISNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['value_show_labels'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTAXISNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['category_show_series_labels'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTAXISNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['multi_data_show_series_labels'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTAXISNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['category_show_title'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTAXISNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['value_show_title'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTAXISNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['category_title'].message_type = TSSArchives__sos__pb2._SPECSTRINGARCHIVE
_CHARTAXISNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['value_title'].message_type = TSSArchives__sos__pb2._SPECSTRINGARCHIVE
_CHARTAXISNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_user_max'].message_type = _SPECCHARTSOPTIONALDOUBLEARCHIVEARCHIVE
_CHARTAXISNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_user_min'].message_type = _SPECCHARTSOPTIONALDOUBLEARCHIVEARCHIVE
_CHARTAXISSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['category3d_gridline_opacity'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARTAXISSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['value3d_gridline_opacity'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARTAXISSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['category3d_gridline_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_CHARTAXISSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['value3d_gridline_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_CHARTAXISSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['category_horizontal_spacing'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTAXISSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['category_label_paragraph_style_index'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTAXISSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_label_paragraph_style_index'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTAXISSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['value_label_paragraph_style_index'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTAXISSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['category_labels_orientation'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARTAXISSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_labels_orientation'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARTAXISSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['value_labels_orientation'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARTAXISSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['category_major_gridline_opacity'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARTAXISSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['value_major_gridline_opacity'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARTAXISSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['category_major_gridline_shadow'].message_type = TSDArchives__sos__pb2._SPECSHADOWARCHIVE
_CHARTAXISSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['value_major_gridline_shadow'].message_type = TSDArchives__sos__pb2._SPECSHADOWARCHIVE
_CHARTAXISSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['category_major_gridline_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_CHARTAXISSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['value_major_gridline_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_CHARTAXISSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['category_minor_gridline_opacity'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARTAXISSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['value_minor_gridline_opacity'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARTAXISSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['category_minor_gridline_shadow'].message_type = TSDArchives__sos__pb2._SPECSHADOWARCHIVE
_CHARTAXISSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['value_minor_gridline_shadow'].message_type = TSDArchives__sos__pb2._SPECSHADOWARCHIVE
_CHARTAXISSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['category_minor_gridline_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_CHARTAXISSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['value_minor_gridline_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_CHARTAXISSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['category_show_axis'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTAXISSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['value_show_axis'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTAXISSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['category_show_last_label'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTAXISSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['category_show_major_gridlines'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTAXISSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['value_show_major_gridlines'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTAXISSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['category_show_major_tickmarks'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTAXISSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['value_show_major_tickmarks'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTAXISSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['value_show_minimum_label'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTAXISSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['category_show_minor_gridlines'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTAXISSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['value_show_minor_gridlines'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTAXISSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['category_show_minor_tickmarks'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTAXISSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['value_show_minor_tickmarks'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTAXISSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['category_tickmark_location'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTAXISSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['value_tickmark_location'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTAXISSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['category_title_paragraph_style_index'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTAXISSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_title_paragraph_style_index'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTAXISSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['value_title_paragraph_style_index'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTAXISSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['category_vertical_spacing'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTLEGENDSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_fill'].message_type = TSDArchives__sos__pb2._SPECFILLARCHIVE
_CHARTLEGENDSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_label_paragraph_style_index'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTLEGENDSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_opacity'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARTLEGENDSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_shadow'].message_type = TSDArchives__sos__pb2._SPECSHADOWARCHIVE
_CHARTLEGENDSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_CHARTNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default3d_bar_shape'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default3d_bevel_edges'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default3d_inter_set_depth_gap'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARTNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default3d_rotation'].message_type = _SPECCHART3DVECTORARCHIVE
_CHARTNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['area3d_scale'].message_type = _SPECCHART3DVECTORARCHIVE
_CHARTNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['bar3d_scale'].message_type = _SPECCHART3DVECTORARCHIVE
_CHARTNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['column3d_scale'].message_type = _SPECCHART3DVECTORARCHIVE
_CHARTNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default3d_scale'].message_type = _SPECCHART3DVECTORARCHIVE
_CHARTNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['line3d_scale'].message_type = _SPECCHART3DVECTORARCHIVE
_CHARTNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['pie3d_scale'].message_type = _SPECCHART3DVECTORARCHIVE
_CHARTNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default3d_viewport'].message_type = _SPECCHART3DVECTORARCHIVE
_CHARTNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['area_callout_line_type'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['bar_callout_line_type'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['bubble_callout_line_type'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_callout_line_type'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['line_callout_line_type'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['pie_callout_line_type'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['scatter_callout_line_type'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['stacked_area_callout_line_type'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['stacked_bar_callout_line_type'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_d_e_p_r_e_c_a_t_e_d_rounded_corner_outer_end_only'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_d_e_p_r_e_c_a_t_e_d_rounded_corner_radius'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARTNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_data_set_name_location'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_donut_place_title_at_center'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_inner_radius'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARTNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_multi_data_control_type'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_pie_start_angle'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARTNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_show_legend'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_show_title'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_skip_hidden_data'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_title'].message_type = TSSArchives__sos__pb2._SPECSTRINGARCHIVE
_CHARTREFERENCELINENONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_custom_value'].message_type = _SPECCHARTSOPTIONALDOUBLEARCHIVEARCHIVE
_CHARTREFERENCELINENONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_label'].message_type = TSSArchives__sos__pb2._SPECSTRINGARCHIVE
_CHARTREFERENCELINENONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_show_label'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTREFERENCELINENONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_show_line'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTREFERENCELINENONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_show_value_label'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTREFERENCELINENONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_type'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTREFERENCELINESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_label_paragraph_style_index'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTREFERENCELINESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_shadow'].message_type = TSDArchives__sos__pb2._SPECSHADOWARCHIVE
_CHARTREFERENCELINESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_CHARTREFERENCELINESTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_value_label_paragraph_style_index'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default10_date_format'].message_type = _SPECFORMATOBJECTARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default10_number_format'].message_type = _SPECNUMBERFORMATARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['pie10_number_format'].message_type = _SPECNUMBERFORMATARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['pie23_label_explosion'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['bubble_adjustment_scale'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_date_format'].message_type = _SPECFORMATOBJECTARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_duration_format'].message_type = _SPECFORMATOBJECTARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['area_enable_callout_line'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['bar_enable_callout_line'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['bubble_enable_callout_line'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_enable_callout_line'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['line_enable_callout_line'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['pie_enable_callout_line'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['scatter_enable_callout_line'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['stacked_area_enable_callout_line'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['stacked_bar_enable_callout_line'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_error_bar_custom_negative_data'].message_type = _SPECCHARTERRORBARCUSTOMDATAARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_error_bar_custom_negative_data_scatter_x'].message_type = _SPECCHARTERRORBARCUSTOMDATAARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_error_bar_custom_positive_data'].message_type = _SPECCHARTERRORBARCUSTOMDATAARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_error_bar_custom_positive_data_scatter_x'].message_type = _SPECCHARTERRORBARCUSTOMDATAARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_error_bar_fixed_value'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_error_bar_fixed_value_scatter_x'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_error_bar_percent_value'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_error_bar_percent_value_scatter_x'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_error_bar_setting'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_error_bar_setting_scatter_x'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_error_bar_std_dev_value'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_error_bar_std_dev_value_scatter_x'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_error_bar_type'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_error_bar_type_scatter_x'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['pie_label_explosion'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['bubble_line_type'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['line_line_type'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['mixed_line_line_type'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['scatter_line_type'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_number_format'].message_type = _SPECNUMBERFORMATARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['pie_number_format'].message_type = _SPECNUMBERFORMATARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_number_format_type'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['pie_number_format_type'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['stacked_percent_number_format'].message_type = _SPECNUMBERFORMATARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_series_type'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_show_error_bar'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_show_error_bar_scatter_x'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['bubble_show_labels_in_front'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_show_labels_in_front'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['scatter_show_line'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['bubble_show_negative_data'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['bubble_show_series_labels'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['pie_show_series_labels'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['scatter_show_series_labels'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['area_show_symbol'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['line_show_symbol'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['mixed_area_show_symbol'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['mixed_line_show_symbol'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['scatter_show_symbol'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_show_trend_line'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['area_show_value_labels'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['bar_show_value_labels'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['bubble_show_value_labels'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_show_value_labels'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['line_show_value_labels'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['mixed_show_value_labels'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['pie_show_value_labels'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['scatter_show_value_labels'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['bubble_size_dimension'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['area_stack_labels'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['bar_stack_labels'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['bubble_stack_labels'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_stack_labels'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['line_stack_labels'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['pie_stack_labels'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['scatter_stack_labels'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['stacked_area_stack_labels'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['stacked_bar_stack_labels'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['area_symbol_type'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['line_symbol_type'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['mixed_area_symbol_type'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['mixed_line_symbol_type'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['scatter_symbol_type'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_trend_line_equation_offset_x'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_trend_line_equation_offset_y'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_trend_line_label_string'].message_type = TSSArchives__sos__pb2._SPECSTRINGARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_trend_line_order'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_trend_line_period'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_trend_line_r_squared_offset_x'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_trend_line_r_squared_offset_y'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_trend_line_show_equation'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_trend_line_show_label'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_trend_line_show_r2_value'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_trend_line_type'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['bubble_value_labels_axis'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['scatter_value_labels_axis'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['pie_wedge_explosion'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_y_axis_ordinal'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_callout_line_end_line_end'].message_type = TSDArchives__sos__pb2._SPECLINEENDARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_callout_line_start_line_end'].message_type = TSDArchives__sos__pb2._SPECLINEENDARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_callout_line_stroke_style'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_error_bar_line_end'].message_type = TSDArchives__sos__pb2._SPECLINEENDARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_error_bar_line_end_scatter_x'].message_type = TSDArchives__sos__pb2._SPECLINEENDARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_error_bar_shadow'].message_type = TSDArchives__sos__pb2._SPECSHADOWARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_error_bar_spacing'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_error_bar_spacing_scatter_x'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_error_bar_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_error_bar_stroke_scatter_x'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['area3d_fill'].message_type = TSDArchives__sos__pb2._SPECFILLARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['bar3d_fill'].message_type = TSDArchives__sos__pb2._SPECFILLARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['column3d_fill'].message_type = TSDArchives__sos__pb2._SPECFILLARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['line3d_fill'].message_type = TSDArchives__sos__pb2._SPECFILLARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['pie3d_fill'].message_type = TSDArchives__sos__pb2._SPECFILLARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['area_fill'].message_type = TSDArchives__sos__pb2._SPECFILLARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['bar_fill'].message_type = TSDArchives__sos__pb2._SPECFILLARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['column_fill'].message_type = TSDArchives__sos__pb2._SPECFILLARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_fill'].message_type = TSDArchives__sos__pb2._SPECFILLARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['mixed_area_fill'].message_type = TSDArchives__sos__pb2._SPECFILLARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['mixed_column_fill'].message_type = TSDArchives__sos__pb2._SPECFILLARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['pie_fill'].message_type = TSDArchives__sos__pb2._SPECFILLARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['area_label_paragraph_style_index'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['bar_label_paragraph_style_index'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_label_paragraph_style_index'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['donut_label_paragraph_style_index'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['line_label_paragraph_style_index'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['mixed_label_paragraph_style_index'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['pie_label_paragraph_style_index'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_opacity'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['area_outside_label_paragraph_style_index'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['bar_outside_label_paragraph_style_index'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_outside_label_paragraph_style_index'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['donut_outside_label_paragraph_style_index'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['mixed_outside_label_paragraph_style_index'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['pie_outside_label_paragraph_style_index'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['area3d_shadow'].message_type = TSDArchives__sos__pb2._SPECSHADOWARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['bar3d_shadow'].message_type = TSDArchives__sos__pb2._SPECSHADOWARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['column3d_shadow'].message_type = TSDArchives__sos__pb2._SPECSHADOWARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['line3d_shadow'].message_type = TSDArchives__sos__pb2._SPECSHADOWARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['pie3d_shadow'].message_type = TSDArchives__sos__pb2._SPECSHADOWARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['area_shadow'].message_type = TSDArchives__sos__pb2._SPECSHADOWARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['bar_shadow'].message_type = TSDArchives__sos__pb2._SPECSHADOWARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['bubble_shadow'].message_type = TSDArchives__sos__pb2._SPECSHADOWARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_shadow'].message_type = TSDArchives__sos__pb2._SPECSHADOWARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['line_shadow'].message_type = TSDArchives__sos__pb2._SPECSHADOWARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['mixed_area_shadow'].message_type = TSDArchives__sos__pb2._SPECSHADOWARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['mixed_column_shadow'].message_type = TSDArchives__sos__pb2._SPECSHADOWARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['mixed_line_shadow'].message_type = TSDArchives__sos__pb2._SPECSHADOWARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['pie_shadow'].message_type = TSDArchives__sos__pb2._SPECSHADOWARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['scatter_shadow'].message_type = TSDArchives__sos__pb2._SPECSHADOWARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['area_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['bar_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['bubble_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['line_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['mixed_area_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['mixed_column_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['mixed_line_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['pie_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['scatter_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['area_symbol_fill'].message_type = TSDArchives__sos__pb2._SPECFILLARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['bubble_symbol_fill'].message_type = TSDArchives__sos__pb2._SPECFILLARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['line_symbol_fill'].message_type = TSDArchives__sos__pb2._SPECFILLARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['mixed_area_symbol_fill'].message_type = TSDArchives__sos__pb2._SPECFILLARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['mixed_line_symbol_fill'].message_type = TSDArchives__sos__pb2._SPECFILLARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['scatter_symbol_fill'].message_type = TSDArchives__sos__pb2._SPECFILLARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['area_symbol_fill_use_series_fill'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['line_symbol_fill_use_series_fill'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['mixed_area_symbol_fill_use_series_fill'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['mixed_line_symbol_fill_use_series_fill'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['area_symbol_fill_use_series_stroke'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['bubble_symbol_fill_use_series_stroke'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['line_symbol_fill_use_series_stroke'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['mixed_area_symbol_fill_use_series_stroke'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['mixed_line_symbol_fill_use_series_stroke'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['scatter_symbol_fill_use_series_stroke'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['area_symbol_size'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['line_symbol_size'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['mixed_area_symbol_size'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['mixed_line_symbol_size'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['scatter_symbol_size'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['area_symbol_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['bubble_symbol_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['line_symbol_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['mixed_area_symbol_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['mixed_line_symbol_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['scatter_symbol_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_trend_line_shadow'].message_type = TSDArchives__sos__pb2._SPECSHADOWARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_trend_line_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_trendline_equation_opacity'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_trendline_equation_paragraph_style_index'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_trendline_r_squared_opacity'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_trendline_r_squared_paragraph_style_index'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['area_value_label_position'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['bar_value_label_position'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['bubble_value_label_position'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_value_label_position'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['line_value_label_position'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['mixed_area_value_label_position'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['mixed_column_value_label_position'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['mixed_line_value_label_position'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['scatter_value_label_position'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['stacked_area_value_label_position'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['stacked_bar_value_label_position'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_value_label_spacing'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default3d_chart_opacity'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARTSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['area3d_lighting_package'].message_type = _SPECCHART3DLIGHTINGPACKAGEARCHIVE
_CHARTSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['bar3d_lighting_package'].message_type = _SPECCHART3DLIGHTINGPACKAGEARCHIVE
_CHARTSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['column3d_lighting_package'].message_type = _SPECCHART3DLIGHTINGPACKAGEARCHIVE
_CHARTSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default3d_lighting_package'].message_type = _SPECCHART3DLIGHTINGPACKAGEARCHIVE
_CHARTSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['line3d_lighting_package'].message_type = _SPECCHART3DLIGHTINGPACKAGEARCHIVE
_CHARTSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['pie3d_lighting_package'].message_type = _SPECCHART3DLIGHTINGPACKAGEARCHIVE
_CHARTSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_background_fill'].message_type = TSDArchives__sos__pb2._SPECFILLARCHIVE
_CHARTSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_background_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_CHARTSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_border_opacity'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARTSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_border_shadow'].message_type = TSDArchives__sos__pb2._SPECSHADOWARCHIVE
_CHARTSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_border_stroke'].message_type = TSDArchives__sos__pb2._SPECSTROKEARCHIVE
_CHARTSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_combine_layers'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_data_set_name_paragraph_style_index'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
_CHARTSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_grid_background_fill'].message_type = TSDArchives__sos__pb2._SPECFILLARCHIVE
_CHARTSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_grid_background_opacity'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARTSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_inter_bar_gap'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARTSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_inter_set_gap'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARTSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_rounded_corner_outer_end_only'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_rounded_corner_radius'].message_type = TSSArchives__sos__pb2._SPECDOUBLEARCHIVE
_CHARTSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_show_border'].message_type = TSSArchives__sos__pb2._SPECBOOLARCHIVE
_CHARTSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_title_color'].message_type = TSSArchives__sos__pb2._SPECCOLORARCHIVE
_CHARTSTYLEPROPERTYCHANGESETARCHIVE.fields_by_name['default_title_paragraph_style_index'].message_type = TSSArchives__sos__pb2._SPECINTEGERARCHIVE
DESCRIPTOR.message_types_by_name['SpecSetChart3dLightingPackageArchive'] = _SPECSETCHART3DLIGHTINGPACKAGEARCHIVE
DESCRIPTOR.message_types_by_name['SpecSetChart3dVectorArchive'] = _SPECSETCHART3DVECTORARCHIVE
DESCRIPTOR.message_types_by_name['SpecSetChartErrorBarCustomDataArchive'] = _SPECSETCHARTERRORBARCUSTOMDATAARCHIVE
DESCRIPTOR.message_types_by_name['SpecSetChartsOptionalDoubleArchiveArchive'] = _SPECSETCHARTSOPTIONALDOUBLEARCHIVEARCHIVE
DESCRIPTOR.message_types_by_name['SpecSetFormatObjectArchive'] = _SPECSETFORMATOBJECTARCHIVE
DESCRIPTOR.message_types_by_name['SpecSetNumberFormatArchive'] = _SPECSETNUMBERFORMATARCHIVE
DESCRIPTOR.message_types_by_name['SpecChart3dLightingPackageArchive'] = _SPECCHART3DLIGHTINGPACKAGEARCHIVE
DESCRIPTOR.message_types_by_name['SpecChart3dVectorArchive'] = _SPECCHART3DVECTORARCHIVE
DESCRIPTOR.message_types_by_name['SpecChartErrorBarCustomDataArchive'] = _SPECCHARTERRORBARCUSTOMDATAARCHIVE
DESCRIPTOR.message_types_by_name['SpecChartsOptionalDoubleArchiveArchive'] = _SPECCHARTSOPTIONALDOUBLEARCHIVEARCHIVE
DESCRIPTOR.message_types_by_name['SpecFormatObjectArchive'] = _SPECFORMATOBJECTARCHIVE
DESCRIPTOR.message_types_by_name['SpecNumberFormatArchive'] = _SPECNUMBERFORMATARCHIVE
DESCRIPTOR.message_types_by_name['ChartAxisNonStylePropertyChangeSetArchive'] = _CHARTAXISNONSTYLEPROPERTYCHANGESETARCHIVE
DESCRIPTOR.message_types_by_name['ChartAxisStylePropertyChangeSetArchive'] = _CHARTAXISSTYLEPROPERTYCHANGESETARCHIVE
DESCRIPTOR.message_types_by_name['ChartLegendNonStylePropertyChangeSetArchive'] = _CHARTLEGENDNONSTYLEPROPERTYCHANGESETARCHIVE
DESCRIPTOR.message_types_by_name['ChartLegendStylePropertyChangeSetArchive'] = _CHARTLEGENDSTYLEPROPERTYCHANGESETARCHIVE
DESCRIPTOR.message_types_by_name['ChartNonStylePropertyChangeSetArchive'] = _CHARTNONSTYLEPROPERTYCHANGESETARCHIVE
DESCRIPTOR.message_types_by_name['ChartReferenceLineNonStylePropertyChangeSetArchive'] = _CHARTREFERENCELINENONSTYLEPROPERTYCHANGESETARCHIVE
DESCRIPTOR.message_types_by_name['ChartReferenceLineStylePropertyChangeSetArchive'] = _CHARTREFERENCELINESTYLEPROPERTYCHANGESETARCHIVE
DESCRIPTOR.message_types_by_name['ChartSeriesNonStylePropertyChangeSetArchive'] = _CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE
DESCRIPTOR.message_types_by_name['ChartSeriesStylePropertyChangeSetArchive'] = _CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE
DESCRIPTOR.message_types_by_name['ChartStylePropertyChangeSetArchive'] = _CHARTSTYLEPROPERTYCHANGESETARCHIVE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SpecSetChart3dLightingPackageArchive = _reflection.GeneratedProtocolMessageType('SpecSetChart3dLightingPackageArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECSETCHART3DLIGHTINGPACKAGEARCHIVE,
  __module__ = 'TSCHArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.SpecSetChart3dLightingPackageArchive)
  ))
_sym_db.RegisterMessage(SpecSetChart3dLightingPackageArchive)

SpecSetChart3dVectorArchive = _reflection.GeneratedProtocolMessageType('SpecSetChart3dVectorArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECSETCHART3DVECTORARCHIVE,
  __module__ = 'TSCHArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.SpecSetChart3dVectorArchive)
  ))
_sym_db.RegisterMessage(SpecSetChart3dVectorArchive)

SpecSetChartErrorBarCustomDataArchive = _reflection.GeneratedProtocolMessageType('SpecSetChartErrorBarCustomDataArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECSETCHARTERRORBARCUSTOMDATAARCHIVE,
  __module__ = 'TSCHArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.SpecSetChartErrorBarCustomDataArchive)
  ))
_sym_db.RegisterMessage(SpecSetChartErrorBarCustomDataArchive)

SpecSetChartsOptionalDoubleArchiveArchive = _reflection.GeneratedProtocolMessageType('SpecSetChartsOptionalDoubleArchiveArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECSETCHARTSOPTIONALDOUBLEARCHIVEARCHIVE,
  __module__ = 'TSCHArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.SpecSetChartsOptionalDoubleArchiveArchive)
  ))
_sym_db.RegisterMessage(SpecSetChartsOptionalDoubleArchiveArchive)

SpecSetFormatObjectArchive = _reflection.GeneratedProtocolMessageType('SpecSetFormatObjectArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECSETFORMATOBJECTARCHIVE,
  __module__ = 'TSCHArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.SpecSetFormatObjectArchive)
  ))
_sym_db.RegisterMessage(SpecSetFormatObjectArchive)

SpecSetNumberFormatArchive = _reflection.GeneratedProtocolMessageType('SpecSetNumberFormatArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECSETNUMBERFORMATARCHIVE,
  __module__ = 'TSCHArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.SpecSetNumberFormatArchive)
  ))
_sym_db.RegisterMessage(SpecSetNumberFormatArchive)

SpecChart3dLightingPackageArchive = _reflection.GeneratedProtocolMessageType('SpecChart3dLightingPackageArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECCHART3DLIGHTINGPACKAGEARCHIVE,
  __module__ = 'TSCHArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.SpecChart3dLightingPackageArchive)
  ))
_sym_db.RegisterMessage(SpecChart3dLightingPackageArchive)

SpecChart3dVectorArchive = _reflection.GeneratedProtocolMessageType('SpecChart3dVectorArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECCHART3DVECTORARCHIVE,
  __module__ = 'TSCHArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.SpecChart3dVectorArchive)
  ))
_sym_db.RegisterMessage(SpecChart3dVectorArchive)

SpecChartErrorBarCustomDataArchive = _reflection.GeneratedProtocolMessageType('SpecChartErrorBarCustomDataArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECCHARTERRORBARCUSTOMDATAARCHIVE,
  __module__ = 'TSCHArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.SpecChartErrorBarCustomDataArchive)
  ))
_sym_db.RegisterMessage(SpecChartErrorBarCustomDataArchive)

SpecChartsOptionalDoubleArchiveArchive = _reflection.GeneratedProtocolMessageType('SpecChartsOptionalDoubleArchiveArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECCHARTSOPTIONALDOUBLEARCHIVEARCHIVE,
  __module__ = 'TSCHArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.SpecChartsOptionalDoubleArchiveArchive)
  ))
_sym_db.RegisterMessage(SpecChartsOptionalDoubleArchiveArchive)

SpecFormatObjectArchive = _reflection.GeneratedProtocolMessageType('SpecFormatObjectArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECFORMATOBJECTARCHIVE,
  __module__ = 'TSCHArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.SpecFormatObjectArchive)
  ))
_sym_db.RegisterMessage(SpecFormatObjectArchive)

SpecNumberFormatArchive = _reflection.GeneratedProtocolMessageType('SpecNumberFormatArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECNUMBERFORMATARCHIVE,
  __module__ = 'TSCHArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.SpecNumberFormatArchive)
  ))
_sym_db.RegisterMessage(SpecNumberFormatArchive)

ChartAxisNonStylePropertyChangeSetArchive = _reflection.GeneratedProtocolMessageType('ChartAxisNonStylePropertyChangeSetArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTAXISNONSTYLEPROPERTYCHANGESETARCHIVE,
  __module__ = 'TSCHArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartAxisNonStylePropertyChangeSetArchive)
  ))
_sym_db.RegisterMessage(ChartAxisNonStylePropertyChangeSetArchive)

ChartAxisStylePropertyChangeSetArchive = _reflection.GeneratedProtocolMessageType('ChartAxisStylePropertyChangeSetArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTAXISSTYLEPROPERTYCHANGESETARCHIVE,
  __module__ = 'TSCHArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartAxisStylePropertyChangeSetArchive)
  ))
_sym_db.RegisterMessage(ChartAxisStylePropertyChangeSetArchive)

ChartLegendNonStylePropertyChangeSetArchive = _reflection.GeneratedProtocolMessageType('ChartLegendNonStylePropertyChangeSetArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTLEGENDNONSTYLEPROPERTYCHANGESETARCHIVE,
  __module__ = 'TSCHArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartLegendNonStylePropertyChangeSetArchive)
  ))
_sym_db.RegisterMessage(ChartLegendNonStylePropertyChangeSetArchive)

ChartLegendStylePropertyChangeSetArchive = _reflection.GeneratedProtocolMessageType('ChartLegendStylePropertyChangeSetArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTLEGENDSTYLEPROPERTYCHANGESETARCHIVE,
  __module__ = 'TSCHArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartLegendStylePropertyChangeSetArchive)
  ))
_sym_db.RegisterMessage(ChartLegendStylePropertyChangeSetArchive)

ChartNonStylePropertyChangeSetArchive = _reflection.GeneratedProtocolMessageType('ChartNonStylePropertyChangeSetArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTNONSTYLEPROPERTYCHANGESETARCHIVE,
  __module__ = 'TSCHArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartNonStylePropertyChangeSetArchive)
  ))
_sym_db.RegisterMessage(ChartNonStylePropertyChangeSetArchive)

ChartReferenceLineNonStylePropertyChangeSetArchive = _reflection.GeneratedProtocolMessageType('ChartReferenceLineNonStylePropertyChangeSetArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTREFERENCELINENONSTYLEPROPERTYCHANGESETARCHIVE,
  __module__ = 'TSCHArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartReferenceLineNonStylePropertyChangeSetArchive)
  ))
_sym_db.RegisterMessage(ChartReferenceLineNonStylePropertyChangeSetArchive)

ChartReferenceLineStylePropertyChangeSetArchive = _reflection.GeneratedProtocolMessageType('ChartReferenceLineStylePropertyChangeSetArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTREFERENCELINESTYLEPROPERTYCHANGESETARCHIVE,
  __module__ = 'TSCHArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartReferenceLineStylePropertyChangeSetArchive)
  ))
_sym_db.RegisterMessage(ChartReferenceLineStylePropertyChangeSetArchive)

ChartSeriesNonStylePropertyChangeSetArchive = _reflection.GeneratedProtocolMessageType('ChartSeriesNonStylePropertyChangeSetArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTSERIESNONSTYLEPROPERTYCHANGESETARCHIVE,
  __module__ = 'TSCHArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartSeriesNonStylePropertyChangeSetArchive)
  ))
_sym_db.RegisterMessage(ChartSeriesNonStylePropertyChangeSetArchive)

ChartSeriesStylePropertyChangeSetArchive = _reflection.GeneratedProtocolMessageType('ChartSeriesStylePropertyChangeSetArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTSERIESSTYLEPROPERTYCHANGESETARCHIVE,
  __module__ = 'TSCHArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartSeriesStylePropertyChangeSetArchive)
  ))
_sym_db.RegisterMessage(ChartSeriesStylePropertyChangeSetArchive)

ChartStylePropertyChangeSetArchive = _reflection.GeneratedProtocolMessageType('ChartStylePropertyChangeSetArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTSTYLEPROPERTYCHANGESETARCHIVE,
  __module__ = 'TSCHArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartStylePropertyChangeSetArchive)
  ))
_sym_db.RegisterMessage(ChartStylePropertyChangeSetArchive)


# @@protoc_insertion_point(module_scope)
