from __future__ import absolute_import
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: TSCHArchives_GEN.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import TSPMessages_pb2 as TSPMessages__pb2
from . import TSKArchives_pb2 as TSKArchives__pb2
from . import TSDArchives_pb2 as TSDArchives__pb2
from . import TSSArchives_pb2 as TSSArchives__pb2
from . import TSCHArchives_Common_pb2 as TSCHArchives__Common__pb2
from . import TSCH3DArchives_pb2 as TSCH3DArchives__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='TSCHArchives_GEN.proto',
  package='TSCH.Generated',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x16TSCHArchives_GEN.proto\x12\x0eTSCH.Generated\x1a\x11TSPMessages.proto\x1a\x11TSKArchives.proto\x1a\x11TSDArchives.proto\x1a\x11TSSArchives.proto\x1a\x19TSCHArchives_Common.proto\x1a\x14TSCH3DArchives.proto\"\xc5\x0b\n\x11\x43hartStyleArchive\x12*\n\"tschchartinfodefault3dchartopacity\x18\x01 \x01(\x02\x12O\n\"tschchartinfoarea3dlightingpackage\x18\x02 \x01(\x0b\x32#.TSCH.Chart3DLightingPackageArchive\x12N\n!tschchartinfobar3dlightingpackage\x18\x03 \x01(\x0b\x32#.TSCH.Chart3DLightingPackageArchive\x12Q\n$tschchartinfocolumn3dlightingpackage\x18\x04 \x01(\x0b\x32#.TSCH.Chart3DLightingPackageArchive\x12R\n%tschchartinfodefault3dlightingpackage\x18\x05 \x01(\x0b\x32#.TSCH.Chart3DLightingPackageArchive\x12O\n\"tschchartinfoline3dlightingpackage\x18\x06 \x01(\x0b\x32#.TSCH.Chart3DLightingPackageArchive\x12N\n!tschchartinfopie3dlightingpackage\x18\x07 \x01(\x0b\x32#.TSCH.Chart3DLightingPackageArchive\x12<\n\"tschchartinfodefaultbackgroundfill\x18\x08 \x01(\x0b\x32\x10.TSD.FillArchive\x12@\n$tschchartinfodefaultbackgroundstroke\x18\t \x01(\x0b\x32\x12.TSD.StrokeArchive\x12)\n!tschchartinfodefaultborderopacity\x18\n \x01(\x02\x12<\n tschchartinfodefaultbordershadow\x18\x0b \x01(\x0b\x32\x12.TSD.ShadowArchive\x12<\n tschchartinfodefaultborderstroke\x18\x0c \x01(\x0b\x32\x12.TSD.StrokeArchive\x12)\n!tschchartinfodefaultcombinelayers\x18\r \x01(\x08\x12:\n2tschchartinfodefaultdatasetnameparagraphstyleindex\x18\x15 \x01(\x05\x12@\n&tschchartinfodefaultgridbackgroundfill\x18\x0e \x01(\x0b\x32\x10.TSD.FillArchive\x12\x31\n)tschchartinfodefaultgridbackgroundopacity\x18\x0f \x01(\x02\x12\'\n\x1ftschchartinfodefaultinterbargap\x18\x10 \x01(\x02\x12\'\n\x1ftschchartinfodefaultintersetgap\x18\x11 \x01(\x02\x12\x35\n-tschchartinfodefaultroundedcornerouterendonly\x18{ \x01(\x08\x12/\n\'tschchartinfodefaultroundedcornerradius\x18z \x01(\x02\x12&\n\x1etschchartinfodefaultshowborder\x18\x12 \x01(\x08\x12\x32\n\x1etschchartinfodefaulttitlecolor\x18\x13 \x01(\x0b\x32\n.TSP.Color\x12\x34\n,tschchartinfodefaulttitleparagraphstyleindex\x18\x14 \x01(\x05\x32L\n\x07\x63urrent\x12\x17.TSCH.ChartStyleArchive\x18\x90N \x01(\x0b\x32!.TSCH.Generated.ChartStyleArchive\"\xfe\x0c\n\x14\x43hartNonStyleArchive\x12&\n\x1etschchartinfodefault3dbarshape\x18\x01 \x01(\x05\x12(\n tschchartinfodefault3dbeveledges\x18\x02 \x01(\x08\x12.\n&tschchartinfodefault3dintersetdepthgap\x18\x03 \x01(\x02\x12\x42\n\x1etschchartinfodefault3drotation\x18\x04 \x01(\x0b\x32\x1a.TSCH.Chart3DVectorArchive\x12<\n\x18tschchartinfoarea3dscale\x18\x05 \x01(\x0b\x32\x1a.TSCH.Chart3DVectorArchive\x12;\n\x17tschchartinfobar3dscale\x18\x06 \x01(\x0b\x32\x1a.TSCH.Chart3DVectorArchive\x12>\n\x1atschchartinfocolumn3dscale\x18\x07 \x01(\x0b\x32\x1a.TSCH.Chart3DVectorArchive\x12?\n\x1btschchartinfodefault3dscale\x18\x08 \x01(\x0b\x32\x1a.TSCH.Chart3DVectorArchive\x12<\n\x18tschchartinfoline3dscale\x18\t \x01(\x0b\x32\x1a.TSCH.Chart3DVectorArchive\x12;\n\x17tschchartinfopie3dscale\x18\n \x01(\x0b\x32\x1a.TSCH.Chart3DVectorArchive\x12\x42\n\x1etschchartinfodefault3dviewport\x18\x0b \x01(\x0b\x32\x1a.TSCH.Chart3DVectorArchive\x12(\n tschchartinfoareacalloutlinetype\x18p \x01(\x05\x12\'\n\x1ftschchartinfobarcalloutlinetype\x18q \x01(\x05\x12*\n\"tschchartinfobubblecalloutlinetype\x18r \x01(\x05\x12+\n#tschchartinfodefaultcalloutlinetype\x18w \x01(\x05\x12(\n tschchartinfolinecalloutlinetype\x18s \x01(\x05\x12\'\n\x1ftschchartinfopiecalloutlinetype\x18o \x01(\x05\x12+\n#tschchartinfoscattercalloutlinetype\x18t \x01(\x05\x12/\n\'tschchartinfostackedareacalloutlinetype\x18u \x01(\x05\x12.\n&tschchartinfostackedbarcalloutlinetype\x18v \x01(\x05\x12?\n7tschchartinfodefaultdeprecatedroundedcornerouterendonly\x18y \x01(\x08\x12\x39\n1tschchartinfodefaultdeprecatedroundedcornerradius\x18x \x01(\x02\x12/\n\'tschchartinfodefaultdatasetnamelocation\x18\x18 \x01(\x05\x12\x33\n+tschchartinfodefaultdonutplacetitleatcenter\x18\x1c \x01(\x08\x12\'\n\x1ftschchartinfodefaultinnerradius\x18\x1b \x01(\x02\x12\x30\n(tschchartinfodefaultmultidatacontroltype\x18\x19 \x01(\x05\x12)\n!tschchartinfodefaultpiestartangle\x18\x13 \x01(\x02\x12&\n\x1etschchartinfodefaultshowlegend\x18\x14 \x01(\x08\x12%\n\x1dtschchartinfodefaultshowtitle\x18\x15 \x01(\x08\x12*\n\"tschchartinfodefaultskiphiddendata\x18\x16 \x01(\x08\x12!\n\x19tschchartinfodefaulttitle\x18\x17 \x01(\t2R\n\x07\x63urrent\x12\x1a.TSCH.ChartNonStyleArchive\x18\x90N \x01(\x0b\x32$.TSCH.Generated.ChartNonStyleArchive\"\xed\x02\n\x12LegendStyleArchive\x12\x34\n\x1atschlegendmodeldefaultfill\x18\x01 \x01(\x0b\x32\x10.TSD.FillArchive\x12\x36\n.tschlegendmodeldefaultlabelparagraphstyleindex\x18\x02 \x01(\x05\x12%\n\x1dtschlegendmodeldefaultopacity\x18\x03 \x01(\x02\x12\x38\n\x1ctschlegendmodeldefaultshadow\x18\x04 \x01(\x0b\x32\x12.TSD.ShadowArchive\x12\x38\n\x1ctschlegendmodeldefaultstroke\x18\x05 \x01(\x0b\x32\x12.TSD.StrokeArchive2N\n\x07\x63urrent\x12\x18.TSCH.LegendStyleArchive\x18\x90N \x01(\x0b\x32\".TSCH.Generated.LegendStyleArchive\"m\n\x15LegendNonStyleArchive2T\n\x07\x63urrent\x12\x1b.TSCH.LegendNonStyleArchive\x18\x90N \x01(\x0b\x32%.TSCH.Generated.LegendNonStyleArchive\"\xdd\x11\n\x15\x43hartAxisStyleArchive\x12.\n&tschchartaxiscategory3dgridlineopacity\x18\x01 \x01(\x02\x12+\n#tschchartaxisvalue3dgridlineopacity\x18\x02 \x01(\x02\x12\x41\n%tschchartaxiscategory3dgridlinestroke\x18\x03 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12>\n\"tschchartaxisvalue3dgridlinestroke\x18\x04 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12.\n&tschchartaxiscategoryhorizontalspacing\x18\x05 \x01(\x05\x12\x35\n-tschchartaxiscategorylabelparagraphstyleindex\x18\x06 \x01(\x05\x12\x34\n,tschchartaxisdefaultlabelparagraphstyleindex\x18\x07 \x01(\x05\x12\x32\n*tschchartaxisvaluelabelparagraphstyleindex\x18\x08 \x01(\x05\x12.\n&tschchartaxiscategorylabelsorientation\x18\t \x01(\x02\x12-\n%tschchartaxisdefaultlabelsorientation\x18\n \x01(\x02\x12+\n#tschchartaxisvaluelabelsorientation\x18\x0b \x01(\x02\x12\x31\n)tschchartaxiscategorymajorgridlineopacity\x18\x0c \x01(\x02\x12.\n&tschchartaxisvaluemajorgridlineopacity\x18\r \x01(\x02\x12\x44\n(tschchartaxiscategorymajorgridlineshadow\x18\x0e \x01(\x0b\x32\x12.TSD.ShadowArchive\x12\x41\n%tschchartaxisvaluemajorgridlineshadow\x18\x0f \x01(\x0b\x32\x12.TSD.ShadowArchive\x12\x44\n(tschchartaxiscategorymajorgridlinestroke\x18\x10 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x41\n%tschchartaxisvaluemajorgridlinestroke\x18\x11 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x31\n)tschchartaxiscategoryminorgridlineopacity\x18\x12 \x01(\x02\x12.\n&tschchartaxisvalueminorgridlineopacity\x18\x13 \x01(\x02\x12\x44\n(tschchartaxiscategoryminorgridlineshadow\x18\x14 \x01(\x0b\x32\x12.TSD.ShadowArchive\x12\x41\n%tschchartaxisvalueminorgridlineshadow\x18\x15 \x01(\x0b\x32\x12.TSD.ShadowArchive\x12\x44\n(tschchartaxiscategoryminorgridlinestroke\x18\x16 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x41\n%tschchartaxisvalueminorgridlinestroke\x18\x17 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12%\n\x1dtschchartaxiscategoryshowaxis\x18\x18 \x01(\x08\x12\"\n\x1atschchartaxisvalueshowaxis\x18\x19 \x01(\x08\x12*\n\"tschchartaxiscategoryshowlastlabel\x18\x1a \x01(\x08\x12/\n\'tschchartaxiscategoryshowmajorgridlines\x18\x1b \x01(\x08\x12,\n$tschchartaxisvalueshowmajorgridlines\x18\x1c \x01(\x08\x12/\n\'tschchartaxiscategoryshowmajortickmarks\x18\x1d \x01(\x08\x12,\n$tschchartaxisvalueshowmajortickmarks\x18\x1e \x01(\x08\x12*\n\"tschchartaxisvalueshowminimumlabel\x18\x1f \x01(\x08\x12/\n\'tschchartaxiscategoryshowminorgridlines\x18  \x01(\x08\x12,\n$tschchartaxisvalueshowminorgridlines\x18! \x01(\x08\x12/\n\'tschchartaxiscategoryshowminortickmarks\x18\" \x01(\x08\x12,\n$tschchartaxisvalueshowminortickmarks\x18# \x01(\x08\x12-\n%tschchartaxiscategorytickmarklocation\x18$ \x01(\x05\x12*\n\"tschchartaxisvaluetickmarklocation\x18% \x01(\x05\x12\x35\n-tschchartaxiscategorytitleparagraphstyleindex\x18& \x01(\x05\x12\x34\n,tschchartaxisdefaulttitleparagraphstyleindex\x18\' \x01(\x05\x12\x32\n*tschchartaxisvaluetitleparagraphstyleindex\x18( \x01(\x05\x12,\n$tschchartaxiscategoryverticalspacing\x18) \x01(\x05\x32T\n\x07\x63urrent\x12\x1b.TSCH.ChartAxisStyleArchive\x18\x90N \x01(\x0b\x32%.TSCH.Generated.ChartAxisStyleArchive\"\xfb\t\n\x18\x43hartAxisNonStyleArchive\x12\x43\n!tschchartaxisdefault1_0dateformat\x18\x14 \x01(\x0b\x32\x18.TSK.FormatStructArchive\x12\x45\n#tschchartaxisdefault1_0numberformat\x18\x02 \x01(\x0b\x32\x18.TSK.FormatStructArchive\x12+\n#tschchartaxisdefault3dlabelposition\x18\x01 \x01(\x05\x12@\n\x1etschchartaxisdefaultdateformat\x18\x16 \x01(\x0b\x32\x18.TSK.FormatStructArchive\x12\x44\n\"tschchartaxisdefaultdurationformat\x18\x15 \x01(\x0b\x32\x18.TSK.FormatStructArchive\x12\x42\n tschchartaxisdefaultnumberformat\x18* \x01(\x0b\x32\x18.TSK.FormatStructArchive\x12,\n$tschchartaxisdefaultnumberformattype\x18\x03 \x01(\x05\x12)\n!tschchartaxisvaluenumberofdecades\x18\x04 \x01(\x05\x12\x30\n(tschchartaxisvaluenumberofmajorgridlines\x18\x05 \x01(\x05\x12\x30\n(tschchartaxisvaluenumberofminorgridlines\x18\x06 \x01(\x05\x12(\n tschchartaxiscategoryplottoedges\x18\x07 \x01(\x08\x12\x1f\n\x17tschchartaxisvaluescale\x18\x08 \x01(\x05\x12\'\n\x1ftschchartaxiscategoryshowlabels\x18\t \x01(\x08\x12&\n\x1etschchartaxisdefaultshowlabels\x18\n \x01(\x08\x12$\n\x1ctschchartaxisvalueshowlabels\x18\x0b \x01(\x08\x12-\n%tschchartaxiscategoryshowserieslabels\x18\x0c \x01(\x08\x12.\n&tschchartaxismultidatashowserieslabels\x18\x13 \x01(\x08\x12&\n\x1etschchartaxiscategoryshowtitle\x18\r \x01(\x08\x12#\n\x1btschchartaxisvalueshowtitle\x18\x0e \x01(\x08\x12\"\n\x1atschchartaxiscategorytitle\x18\x0f \x01(\t\x12\x1f\n\x17tschchartaxisvaluetitle\x18\x10 \x01(\t\x12\x46\n\x1btschchartaxisdefaultusermax\x18\x11 \x01(\x0b\x32!.TSCH.ChartsNSNumberDoubleArchive\x12\x46\n\x1btschchartaxisdefaultusermin\x18\x12 \x01(\x0b\x32!.TSCH.ChartsNSNumberDoubleArchive2Z\n\x07\x63urrent\x12\x1e.TSCH.ChartAxisNonStyleArchive\x18\x90N \x01(\x0b\x32(.TSCH.Generated.ChartAxisNonStyleArchive\"\xb6/\n\x17\x43hartSeriesStyleArchive\x12I\n+tschchartseriesdefaultcalloutlineendlineend\x18\x82\x01 \x01(\x0b\x32\x13.TSD.LineEndArchive\x12K\n-tschchartseriesdefaultcalloutlinestartlineend\x18\x81\x01 \x01(\x0b\x32\x13.TSD.LineEndArchive\x12I\n,tschchartseriesdefaultcalloutlinestrokestyle\x18\x80\x01 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x42\n%tschchartseriesdefaulterrorbarlineend\x18\x01 \x01(\x0b\x32\x13.TSD.LineEndArchive\x12J\n-tschchartseriesdefaulterrorbarlineendscatterx\x18\x02 \x01(\x0b\x32\x13.TSD.LineEndArchive\x12@\n$tschchartseriesdefaulterrorbarshadow\x18\x03 \x01(\x0b\x32\x12.TSD.ShadowArchive\x12-\n%tschchartseriesdefaulterrorbarspacing\x18\x62 \x01(\x05\x12\x35\n-tschchartseriesdefaulterrorbarspacingscatterx\x18\x63 \x01(\x05\x12@\n$tschchartseriesdefaulterrorbarstroke\x18\x04 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12H\n,tschchartseriesdefaulterrorbarstrokescatterx\x18\x05 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x33\n\x19tschchartseries3dareafill\x18\x06 \x01(\x0b\x32\x10.TSD.FillArchive\x12\x32\n\x18tschchartseries3dbarfill\x18\x07 \x01(\x0b\x32\x10.TSD.FillArchive\x12\x35\n\x1btschchartseries3dcolumnfill\x18\x08 \x01(\x0b\x32\x10.TSD.FillArchive\x12\x33\n\x19tschchartseries3dlinefill\x18\t \x01(\x0b\x32\x10.TSD.FillArchive\x12\x32\n\x18tschchartseries3dpiefill\x18\n \x01(\x0b\x32\x10.TSD.FillArchive\x12\x31\n\x17tschchartseriesareafill\x18\x0b \x01(\x0b\x32\x10.TSD.FillArchive\x12\x30\n\x16tschchartseriesbarfill\x18\x0c \x01(\x0b\x32\x10.TSD.FillArchive\x12\x33\n\x19tschchartseriescolumnfill\x18\r \x01(\x0b\x32\x10.TSD.FillArchive\x12\x34\n\x1atschchartseriesdefaultfill\x18\x0e \x01(\x0b\x32\x10.TSD.FillArchive\x12\x36\n\x1ctschchartseriesmixedareafill\x18\x0f \x01(\x0b\x32\x10.TSD.FillArchive\x12\x38\n\x1etschchartseriesmixedcolumnfill\x18\x10 \x01(\x0b\x32\x10.TSD.FillArchive\x12\x30\n\x16tschchartseriespiefill\x18\x11 \x01(\x0b\x32\x10.TSD.FillArchive\x12\x33\n+tschchartseriesarealabelparagraphstyleindex\x18\x12 \x01(\x05\x12\x32\n*tschchartseriesbarlabelparagraphstyleindex\x18\x13 \x01(\x05\x12\x36\n.tschchartseriesdefaultlabelparagraphstyleindex\x18\x14 \x01(\x05\x12\x35\n,tschchartseriesdonutlabelparagraphstyleindex\x18\x98\x01 \x01(\x05\x12\x33\n+tschchartserieslinelabelparagraphstyleindex\x18\x15 \x01(\x05\x12\x34\n,tschchartseriesmixedlabelparagraphstyleindex\x18\x16 \x01(\x05\x12\x32\n*tschchartseriespielabelparagraphstyleindex\x18\x17 \x01(\x05\x12%\n\x1dtschchartseriesdefaultopacity\x18\x18 \x01(\x02\x12:\n2tschchartseriesareaoutsidelabelparagraphstyleindex\x18\x19 \x01(\x05\x12\x39\n1tschchartseriesbaroutsidelabelparagraphstyleindex\x18\x1a \x01(\x05\x12=\n5tschchartseriesdefaultoutsidelabelparagraphstyleindex\x18\x1b \x01(\x05\x12<\n3tschchartseriesdonutoutsidelabelparagraphstyleindex\x18\x99\x01 \x01(\x05\x12;\n3tschchartseriesmixedoutsidelabelparagraphstyleindex\x18\x1c \x01(\x05\x12\x39\n1tschchartseriespieoutsidelabelparagraphstyleindex\x18\x1d \x01(\x05\x12\x37\n\x1btschchartseries3dareashadow\x18\x1e \x01(\x0b\x32\x12.TSD.ShadowArchive\x12\x36\n\x1atschchartseries3dbarshadow\x18\x1f \x01(\x0b\x32\x12.TSD.ShadowArchive\x12\x39\n\x1dtschchartseries3dcolumnshadow\x18  \x01(\x0b\x32\x12.TSD.ShadowArchive\x12\x37\n\x1btschchartseries3dlineshadow\x18! \x01(\x0b\x32\x12.TSD.ShadowArchive\x12\x36\n\x1atschchartseries3dpieshadow\x18\" \x01(\x0b\x32\x12.TSD.ShadowArchive\x12\x35\n\x19tschchartseriesareashadow\x18# \x01(\x0b\x32\x12.TSD.ShadowArchive\x12\x34\n\x18tschchartseriesbarshadow\x18$ \x01(\x0b\x32\x12.TSD.ShadowArchive\x12\x37\n\x1btschchartseriesbubbleshadow\x18% \x01(\x0b\x32\x12.TSD.ShadowArchive\x12\x38\n\x1ctschchartseriesdefaultshadow\x18& \x01(\x0b\x32\x12.TSD.ShadowArchive\x12\x35\n\x19tschchartserieslineshadow\x18\' \x01(\x0b\x32\x12.TSD.ShadowArchive\x12:\n\x1etschchartseriesmixedareashadow\x18( \x01(\x0b\x32\x12.TSD.ShadowArchive\x12<\n tschchartseriesmixedcolumnshadow\x18) \x01(\x0b\x32\x12.TSD.ShadowArchive\x12:\n\x1etschchartseriesmixedlineshadow\x18* \x01(\x0b\x32\x12.TSD.ShadowArchive\x12\x34\n\x18tschchartseriespieshadow\x18+ \x01(\x0b\x32\x12.TSD.ShadowArchive\x12\x38\n\x1ctschchartseriesscattershadow\x18, \x01(\x0b\x32\x12.TSD.ShadowArchive\x12\x35\n\x19tschchartseriesareastroke\x18- \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x34\n\x18tschchartseriesbarstroke\x18. \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x37\n\x1btschchartseriesbubblestroke\x18/ \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x35\n\x19tschchartserieslinestroke\x18\x30 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12:\n\x1etschchartseriesmixedareastroke\x18\x31 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12<\n tschchartseriesmixedcolumnstroke\x18\x32 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12:\n\x1etschchartseriesmixedlinestroke\x18\x33 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x34\n\x18tschchartseriespiestroke\x18\x34 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x38\n\x1ctschchartseriesscatterstroke\x18\x35 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x37\n\x1dtschchartseriesareasymbolfill\x18\x36 \x01(\x0b\x32\x10.TSD.FillArchive\x12\x39\n\x1ftschchartseriesbubblesymbolfill\x18\x37 \x01(\x0b\x32\x10.TSD.FillArchive\x12\x37\n\x1dtschchartserieslinesymbolfill\x18\x38 \x01(\x0b\x32\x10.TSD.FillArchive\x12<\n\"tschchartseriesmixedareasymbolfill\x18\x39 \x01(\x0b\x32\x10.TSD.FillArchive\x12<\n\"tschchartseriesmixedlinesymbolfill\x18: \x01(\x0b\x32\x10.TSD.FillArchive\x12:\n tschchartseriesscattersymbolfill\x18; \x01(\x0b\x32\x10.TSD.FillArchive\x12\x32\n*tschchartseriesareasymbolfilluseseriesfill\x18< \x01(\x08\x12\x32\n*tschchartserieslinesymbolfilluseseriesfill\x18= \x01(\x08\x12\x37\n/tschchartseriesmixedareasymbolfilluseseriesfill\x18> \x01(\x08\x12\x37\n/tschchartseriesmixedlinesymbolfilluseseriesfill\x18? \x01(\x08\x12\x34\n,tschchartseriesareasymbolfilluseseriesstroke\x18@ \x01(\x08\x12\x36\n.tschchartseriesbubblesymbolfilluseseriesstroke\x18\x41 \x01(\x08\x12\x34\n,tschchartserieslinesymbolfilluseseriesstroke\x18\x42 \x01(\x08\x12\x39\n1tschchartseriesmixedareasymbolfilluseseriesstroke\x18\x43 \x01(\x08\x12\x39\n1tschchartseriesmixedlinesymbolfilluseseriesstroke\x18\x44 \x01(\x08\x12\x37\n/tschchartseriesscattersymbolfilluseseriesstroke\x18\x45 \x01(\x08\x12%\n\x1dtschchartseriesareasymbolsize\x18\x46 \x01(\x02\x12%\n\x1dtschchartserieslinesymbolsize\x18G \x01(\x02\x12*\n\"tschchartseriesmixedareasymbolsize\x18H \x01(\x02\x12*\n\"tschchartseriesmixedlinesymbolsize\x18I \x01(\x02\x12(\n tschchartseriesscattersymbolsize\x18J \x01(\x02\x12;\n\x1ftschchartseriesareasymbolstroke\x18K \x01(\x0b\x32\x12.TSD.StrokeArchive\x12=\n!tschchartseriesbubblesymbolstroke\x18L \x01(\x0b\x32\x12.TSD.StrokeArchive\x12;\n\x1ftschchartserieslinesymbolstroke\x18M \x01(\x0b\x32\x12.TSD.StrokeArchive\x12@\n$tschchartseriesmixedareasymbolstroke\x18N \x01(\x0b\x32\x12.TSD.StrokeArchive\x12@\n$tschchartseriesmixedlinesymbolstroke\x18O \x01(\x0b\x32\x12.TSD.StrokeArchive\x12>\n\"tschchartseriesscattersymbolstroke\x18P \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x41\n%tschchartseriesdefaulttrendlineshadow\x18U \x01(\x0b\x32\x12.TSD.ShadowArchive\x12\x41\n%tschchartseriesdefaulttrendlinestroke\x18V \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x36\n.tschchartseriesdefaulttrendlineequationopacity\x18Q \x01(\x02\x12\x42\n:tschchartseriesdefaulttrendlineequationparagraphstyleindex\x18R \x01(\x05\x12\x36\n.tschchartseriesdefaulttrendlinersquaredopacity\x18S \x01(\x02\x12\x42\n:tschchartseriesdefaulttrendlinersquaredparagraphstyleindex\x18T \x01(\x05\x12-\n%tschchartseriesareavaluelabelposition\x18W \x01(\x05\x12,\n$tschchartseriesbarvaluelabelposition\x18X \x01(\x05\x12/\n\'tschchartseriesbubblevaluelabelposition\x18Y \x01(\x05\x12\x30\n(tschchartseriesdefaultvaluelabelposition\x18Z \x01(\x05\x12-\n%tschchartserieslinevaluelabelposition\x18[ \x01(\x05\x12\x32\n*tschchartseriesmixedareavaluelabelposition\x18\\ \x01(\x05\x12\x34\n,tschchartseriesmixedcolumnvaluelabelposition\x18] \x01(\x05\x12\x32\n*tschchartseriesmixedlinevaluelabelposition\x18^ \x01(\x05\x12\x30\n(tschchartseriesscattervaluelabelposition\x18_ \x01(\x05\x12\x34\n,tschchartseriesstackedareavaluelabelposition\x18` \x01(\x05\x12\x33\n+tschchartseriesstackedbarvaluelabelposition\x18\x61 \x01(\x05\x12/\n\'tschchartseriesdefaultvaluelabelspacing\x18\x64 \x01(\x05\x32X\n\x07\x63urrent\x12\x1d.TSCH.ChartSeriesStyleArchive\x18\x90N \x01(\x0b\x32\'.TSCH.Generated.ChartSeriesStyleArchive\"\xb8&\n\x1a\x43hartSeriesNonStyleArchive\x12\x45\n#tschchartseriesdefault1_0dateformat\x18\x45 \x01(\x0b\x32\x18.TSK.FormatStructArchive\x12G\n%tschchartseriesdefault1_0numberformat\x18\x15 \x01(\x0b\x32\x18.TSK.FormatStructArchive\x12\x43\n!tschchartseriespie1_0numberformat\x18\x16 \x01(\x0b\x32\x18.TSK.FormatStructArchive\x12+\n#tschchartseriespie2_3labelexplosion\x18\x10 \x01(\x02\x12,\n$tschchartseriesbubbleadjustmentscale\x18\x01 \x01(\x02\x12\x42\n tschchartseriesdefaultdateformat\x18G \x01(\x0b\x32\x18.TSK.FormatStructArchive\x12\x46\n$tschchartseriesdefaultdurationformat\x18\x46 \x01(\x0b\x32\x18.TSK.FormatStructArchive\x12,\n$tschchartseriesareaenablecalloutline\x18g \x01(\x05\x12+\n#tschchartseriesbarenablecalloutline\x18h \x01(\x05\x12.\n&tschchartseriesbubbleenablecalloutline\x18i \x01(\x05\x12/\n\'tschchartseriesdefaultenablecalloutline\x18n \x01(\x05\x12,\n$tschchartserieslineenablecalloutline\x18j \x01(\x05\x12+\n#tschchartseriespieenablecalloutline\x18\x66 \x01(\x05\x12/\n\'tschchartseriesscatterenablecalloutline\x18k \x01(\x05\x12\x33\n+tschchartseriesstackedareaenablecalloutline\x18l \x01(\x05\x12\x32\n*tschchartseriesstackedbarenablecalloutline\x18m \x01(\x05\x12\x64\n0tschchartseriesdefaulterrorbarcustomnegativedata\x18\x02 \x01(\x0b\x32*.TSCH.ChartsNSArrayOfNSNumberDoubleArchive\x12l\n8tschchartseriesdefaulterrorbarcustomnegativedatascatterx\x18\x03 \x01(\x0b\x32*.TSCH.ChartsNSArrayOfNSNumberDoubleArchive\x12\x64\n0tschchartseriesdefaulterrorbarcustompositivedata\x18\x04 \x01(\x0b\x32*.TSCH.ChartsNSArrayOfNSNumberDoubleArchive\x12l\n8tschchartseriesdefaulterrorbarcustompositivedatascatterx\x18\x05 \x01(\x0b\x32*.TSCH.ChartsNSArrayOfNSNumberDoubleArchive\x12\x30\n(tschchartseriesdefaulterrorbarfixedvalue\x18\x06 \x01(\x02\x12\x38\n0tschchartseriesdefaulterrorbarfixedvaluescatterx\x18\x07 \x01(\x02\x12\x32\n*tschchartseriesdefaulterrorbarpercentvalue\x18\x08 \x01(\x02\x12:\n2tschchartseriesdefaulterrorbarpercentvaluescatterx\x18\t \x01(\x02\x12-\n%tschchartseriesdefaulterrorbarsetting\x18\n \x01(\x05\x12\x35\n-tschchartseriesdefaulterrorbarsettingscatterx\x18\x0b \x01(\x05\x12\x31\n)tschchartseriesdefaulterrorbarstddevvalue\x18\x0c \x01(\x02\x12\x39\n1tschchartseriesdefaulterrorbarstddevvaluescatterx\x18\r \x01(\x02\x12*\n\"tschchartseriesdefaulterrorbartype\x18\x0e \x01(\x05\x12\x32\n*tschchartseriesdefaulterrorbartypescatterx\x18\x0f \x01(\x05\x12)\n tschchartseriespielabelexplosion\x18\x93\x01 \x01(\x02\x12%\n\x1dtschchartseriesbubblelinetype\x18\x11 \x01(\x05\x12#\n\x1btschchartserieslinelinetype\x18\x12 \x01(\x05\x12(\n tschchartseriesmixedlinelinetype\x18\x13 \x01(\x05\x12&\n\x1etschchartseriesscatterlinetype\x18\x14 \x01(\x05\x12\x44\n\"tschchartseriesdefaultnumberformat\x18\x62 \x01(\x0b\x32\x18.TSK.FormatStructArchive\x12@\n\x1etschchartseriespienumberformat\x18\x63 \x01(\x0b\x32\x18.TSK.FormatStructArchive\x12.\n&tschchartseriesdefaultnumberformattype\x18\x17 \x01(\x05\x12*\n\"tschchartseriespienumberformattype\x18\x18 \x01(\x05\x12K\n)tschchartseriesstackedpercentnumberformat\x18\x19 \x01(\x0b\x32\x18.TSK.FormatStructArchive\x12(\n tschchartseriesdefaultseriestype\x18\x1a \x01(\x05\x12*\n\"tschchartseriesdefaultshowerrorbar\x18\x1b \x01(\x08\x12\x32\n*tschchartseriesdefaultshowerrorbarscatterx\x18\x1c \x01(\x08\x12.\n&tschchartseriesbubbleshowlabelsinfront\x18\x65 \x01(\x08\x12/\n\'tschchartseriesdefaultshowlabelsinfront\x18\x64 \x01(\x08\x12&\n\x1etschchartseriesscattershowline\x18\x1d \x01(\x08\x12-\n%tschchartseriesbubbleshownegativedata\x18\x1e \x01(\x08\x12-\n%tschchartseriesbubbleshowserieslabels\x18\x41 \x01(\x08\x12*\n\"tschchartseriespieshowserieslabels\x18\x1f \x01(\x08\x12.\n&tschchartseriesscattershowserieslabels\x18\x43 \x01(\x08\x12%\n\x1dtschchartseriesareashowsymbol\x18  \x01(\x08\x12%\n\x1dtschchartserieslineshowsymbol\x18! \x01(\x08\x12*\n\"tschchartseriesmixedareashowsymbol\x18\" \x01(\x08\x12*\n\"tschchartseriesmixedlineshowsymbol\x18# \x01(\x08\x12(\n tschchartseriesscattershowsymbol\x18$ \x01(\x08\x12+\n#tschchartseriesdefaultshowtrendline\x18% \x01(\x08\x12*\n\"tschchartseriesareashowvaluelabels\x18& \x01(\x08\x12)\n!tschchartseriesbarshowvaluelabels\x18\' \x01(\x08\x12,\n$tschchartseriesbubbleshowvaluelabels\x18( \x01(\x08\x12-\n%tschchartseriesdefaultshowvaluelabels\x18) \x01(\x08\x12*\n\"tschchartserieslineshowvaluelabels\x18* \x01(\x08\x12+\n#tschchartseriesmixedshowvaluelabels\x18+ \x01(\x08\x12)\n!tschchartseriespieshowvaluelabels\x18, \x01(\x08\x12-\n%tschchartseriesscattershowvaluelabels\x18- \x01(\x08\x12*\n\"tschchartseriesbubblesizedimension\x18. \x01(\x05\x12\'\n\x1etschchartseriesareastacklabels\x18\x8b\x01 \x01(\x08\x12&\n\x1dtschchartseriesbarstacklabels\x18\x8c\x01 \x01(\x08\x12)\n tschchartseriesbubblestacklabels\x18\x8d\x01 \x01(\x08\x12*\n!tschchartseriesdefaultstacklabels\x18\x92\x01 \x01(\x08\x12\'\n\x1etschchartserieslinestacklabels\x18\x8e\x01 \x01(\x08\x12&\n\x1dtschchartseriespiestacklabels\x18\x8a\x01 \x01(\x08\x12*\n!tschchartseriesscatterstacklabels\x18\x8f\x01 \x01(\x08\x12.\n%tschchartseriesstackedareastacklabels\x18\x90\x01 \x01(\x08\x12-\n$tschchartseriesstackedbarstacklabels\x18\x91\x01 \x01(\x08\x12%\n\x1dtschchartseriesareasymboltype\x18/ \x01(\x05\x12%\n\x1dtschchartserieslinesymboltype\x18\x30 \x01(\x05\x12*\n\"tschchartseriesmixedareasymboltype\x18\x31 \x01(\x05\x12*\n\"tschchartseriesmixedlinesymboltype\x18\x32 \x01(\x05\x12(\n tschchartseriesscattersymboltype\x18\x33 \x01(\x05\x12\x36\n.tschchartseriesdefaulttrendlineequationoffsetx\x18\x34 \x01(\x02\x12\x36\n.tschchartseriesdefaulttrendlineequationoffsety\x18\x35 \x01(\x02\x12\x32\n*tschchartseriesdefaulttrendlinelabelstring\x18\x36 \x01(\t\x12,\n$tschchartseriesdefaulttrendlineorder\x18\x37 \x01(\x05\x12-\n%tschchartseriesdefaulttrendlineperiod\x18\x38 \x01(\x05\x12\x36\n.tschchartseriesdefaulttrendlinersquaredoffsetx\x18\x39 \x01(\x02\x12\x36\n.tschchartseriesdefaulttrendlinersquaredoffsety\x18: \x01(\x02\x12\x33\n+tschchartseriesdefaulttrendlineshowequation\x18; \x01(\x08\x12\x30\n(tschchartseriesdefaulttrendlineshowlabel\x18< \x01(\x08\x12\x32\n*tschchartseriesdefaulttrendlineshowr2value\x18= \x01(\x08\x12+\n#tschchartseriesdefaulttrendlinetype\x18> \x01(\x05\x12,\n$tschchartseriesbubblevaluelabelsaxis\x18\x42 \x01(\x05\x12-\n%tschchartseriesscattervaluelabelsaxis\x18\x44 \x01(\x05\x12(\n tschchartseriespiewedgeexplosion\x18? \x01(\x02\x12*\n\"tschchartseriesdefaultyaxisordinal\x18@ \x01(\x05\x32^\n\x07\x63urrent\x12 .TSCH.ChartSeriesNonStyleArchive\x18\x90N \x01(\x0b\x32*.TSCH.Generated.ChartSeriesNonStyleArchive\"\xea\x02\n\x19ReferenceLineStyleArchive\x12\x38\n0tschreferencelinedefaultlabelparagraphstyleindex\x18\x03 \x01(\x05\x12:\n\x1etschreferencelinedefaultshadow\x18\x02 \x01(\x0b\x32\x12.TSD.ShadowArchive\x12:\n\x1etschreferencelinedefaultstroke\x18\x01 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12=\n5tschreferencelinedefaultvaluelabelparagraphstyleindex\x18\x04 \x01(\x05\x32\\\n\x07\x63urrent\x12\x1f.TSCH.ReferenceLineStyleArchive\x18\x90N \x01(\x0b\x32).TSCH.Generated.ReferenceLineStyleArchive\"\xa4\x03\n\x1cReferenceLineNonStyleArchive\x12N\n#tschreferencelinedefaultcustomvalue\x18\x06 \x01(\x0b\x32!.TSCH.ChartsNSNumberDoubleArchive\x12%\n\x1dtschreferencelinedefaultlabel\x18\x05 \x01(\t\x12)\n!tschreferencelinedefaultshowlabel\x18\x03 \x01(\x08\x12(\n tschreferencelinedefaultshowline\x18\x02 \x01(\x08\x12.\n&tschreferencelinedefaultshowvaluelabel\x18\x04 \x01(\x08\x12$\n\x1ctschreferencelinedefaulttype\x18\x01 \x01(\x05\x32\x62\n\x07\x63urrent\x12\".TSCH.ReferenceLineNonStyleArchive\x18\x90N \x01(\x0b\x32,.TSCH.Generated.ReferenceLineNonStyleArchive\"\xf1\x0c\n\x1e\x43hartGenericPropertyMapArchive\x12\x1f\n\x17tschchartinfo3dbarshape\x18\x01 \x01(\x05\x12!\n\x19tschchartinfo3dbeveledges\x18\x02 \x01(\x08\x12#\n\x1btschchartinfo3dchartopacity\x18\x03 \x01(\x02\x12\'\n\x1ftschchartinfo3dintersetdepthgap\x18\x04 \x01(\x02\x12K\n\x1etschchartinfo3dlightingpackage\x18\x05 \x01(\x0b\x32#.TSCH.Chart3DLightingPackageArchive\x12;\n\x17tschchartinfo3drotation\x18\x06 \x01(\x0b\x32\x1a.TSCH.Chart3DVectorArchive\x12\x38\n\x14tschchartinfo3dscale\x18\x07 \x01(\x0b\x32\x1a.TSCH.Chart3DVectorArchive\x12;\n\x17tschchartinfo3dviewport\x18\x08 \x01(\x0b\x32\x1a.TSCH.Chart3DVectorArchive\x12\x35\n\x1btschchartinfobackgroundfill\x18\t \x01(\x0b\x32\x10.TSD.FillArchive\x12\x39\n\x1dtschchartinfobackgroundstroke\x18\n \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\"\n\x1atschchartinfoborderopacity\x18\x0b \x01(\x02\x12\x35\n\x19tschchartinfobordershadow\x18\x0c \x01(\x0b\x32\x12.TSD.ShadowArchive\x12\x35\n\x19tschchartinfoborderstroke\x18\r \x01(\x0b\x32\x12.TSD.StrokeArchive\x12$\n\x1ctschchartinfocalloutlinetype\x18\x0e \x01(\x05\x12\"\n\x1atschchartinfocombinelayers\x18\x0f \x01(\x08\x12\x38\n0tschchartinfodeprecatedroundedcornerouterendonly\x18\x10 \x01(\x08\x12\x32\n*tschchartinfodeprecatedroundedcornerradius\x18\x11 \x01(\x02\x12(\n tschchartinfodatasetnamelocation\x18\x12 \x01(\x05\x12\x33\n+tschchartinfodatasetnameparagraphstyleindex\x18\x13 \x01(\x05\x12,\n$tschchartinfodonutplacetitleatcenter\x18\x14 \x01(\x08\x12\x39\n\x1ftschchartinfogridbackgroundfill\x18\x15 \x01(\x0b\x32\x10.TSD.FillArchive\x12*\n\"tschchartinfogridbackgroundopacity\x18\x16 \x01(\x02\x12 \n\x18tschchartinfoinnerradius\x18\x17 \x01(\x02\x12 \n\x18tschchartinfointerbargap\x18\x18 \x01(\x02\x12 \n\x18tschchartinfointersetgap\x18\x19 \x01(\x02\x12)\n!tschchartinfomultidatacontroltype\x18\x1a \x01(\x05\x12\"\n\x1atschchartinfopiestartangle\x18\x1b \x01(\x02\x12.\n&tschchartinforoundedcornerouterendonly\x18\x1c \x01(\x08\x12(\n tschchartinforoundedcornerradius\x18\x1d \x01(\x02\x12\x1f\n\x17tschchartinfoshowborder\x18\x1e \x01(\x08\x12\x1f\n\x17tschchartinfoshowlegend\x18\x1f \x01(\x08\x12\x1e\n\x16tschchartinfoshowtitle\x18  \x01(\x08\x12#\n\x1btschchartinfoskiphiddendata\x18! \x01(\x08\x12+\n\x17tschchartinfotitlecolor\x18\" \x01(\x0b\x32\n.TSP.Color\x12\x1a\n\x12tschchartinfotitle\x18# \x01(\t\x12-\n%tschchartinfotitleparagraphstyleindex\x18$ \x01(\x05\"\x87\x02\n\x1fLegendGenericPropertyMapArchive\x12-\n\x13tschlegendmodelfill\x18\x01 \x01(\x0b\x32\x10.TSD.FillArchive\x12/\n\'tschlegendmodellabelparagraphstyleindex\x18\x02 \x01(\x05\x12\x1e\n\x16tschlegendmodelopacity\x18\x03 \x01(\x02\x12\x31\n\x15tschlegendmodelshadow\x18\x04 \x01(\x0b\x32\x12.TSD.ShadowArchive\x12\x31\n\x15tschlegendmodelstroke\x18\x05 \x01(\x0b\x32\x12.TSD.StrokeArchive\"\xa4\x0e\n\"ChartAxisGenericPropertyMapArchive\x12<\n\x1atschchartaxis1_0dateformat\x18\x01 \x01(\x0b\x32\x18.TSK.FormatStructArchive\x12>\n\x1ctschchartaxis1_0numberformat\x18\x02 \x01(\x0b\x32\x18.TSK.FormatStructArchive\x12&\n\x1etschchartaxis3dgridlineopacity\x18\x03 \x01(\x02\x12\x39\n\x1dtschchartaxis3dgridlinestroke\x18\x04 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12$\n\x1ctschchartaxis3dlabelposition\x18\x05 \x01(\x05\x12\x39\n\x17tschchartaxisdateformat\x18\x06 \x01(\x0b\x32\x18.TSK.FormatStructArchive\x12=\n\x1btschchartaxisdurationformat\x18\x07 \x01(\x0b\x32\x18.TSK.FormatStructArchive\x12&\n\x1etschchartaxishorizontalspacing\x18\x08 \x01(\x05\x12-\n%tschchartaxislabelparagraphstyleindex\x18\t \x01(\x05\x12&\n\x1etschchartaxislabelsorientation\x18\n \x01(\x02\x12)\n!tschchartaxismajorgridlineopacity\x18\x0b \x01(\x02\x12<\n tschchartaxismajorgridlineshadow\x18\x0c \x01(\x0b\x32\x12.TSD.ShadowArchive\x12<\n tschchartaxismajorgridlinestroke\x18\r \x01(\x0b\x32\x12.TSD.StrokeArchive\x12)\n!tschchartaxisminorgridlineopacity\x18\x0e \x01(\x02\x12<\n tschchartaxisminorgridlineshadow\x18\x0f \x01(\x0b\x32\x12.TSD.ShadowArchive\x12<\n tschchartaxisminorgridlinestroke\x18\x10 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12;\n\x19tschchartaxisnumberformat\x18\x11 \x01(\x0b\x32\x18.TSK.FormatStructArchive\x12%\n\x1dtschchartaxisnumberformattype\x18\x12 \x01(\x05\x12$\n\x1ctschchartaxisnumberofdecades\x18\x13 \x01(\x05\x12+\n#tschchartaxisnumberofmajorgridlines\x18\x14 \x01(\x05\x12+\n#tschchartaxisnumberofminorgridlines\x18\x15 \x01(\x05\x12 \n\x18tschchartaxisplottoedges\x18\x16 \x01(\x08\x12\x1a\n\x12tschchartaxisscale\x18\x17 \x01(\x05\x12\x1d\n\x15tschchartaxisshowaxis\x18\x18 \x01(\x08\x12\x1f\n\x17tschchartaxisshowlabels\x18\x19 \x01(\x08\x12\"\n\x1atschchartaxisshowlastlabel\x18\x1a \x01(\x08\x12\'\n\x1ftschchartaxisshowmajorgridlines\x18\x1b \x01(\x08\x12\'\n\x1ftschchartaxisshowmajortickmarks\x18\x1c \x01(\x08\x12%\n\x1dtschchartaxisshowminimumlabel\x18\x1d \x01(\x08\x12\'\n\x1ftschchartaxisshowminorgridlines\x18\x1e \x01(\x08\x12\'\n\x1ftschchartaxisshowminortickmarks\x18\x1f \x01(\x08\x12%\n\x1dtschchartaxisshowserieslabels\x18  \x01(\x08\x12\x1e\n\x16tschchartaxisshowtitle\x18! \x01(\x08\x12%\n\x1dtschchartaxistickmarklocation\x18\" \x01(\x05\x12\x1a\n\x12tschchartaxistitle\x18# \x01(\t\x12-\n%tschchartaxistitleparagraphstyleindex\x18$ \x01(\x05\x12?\n\x14tschchartaxisusermax\x18% \x01(\x0b\x32!.TSCH.ChartsNSNumberDoubleArchive\x12?\n\x14tschchartaxisusermin\x18& \x01(\x0b\x32!.TSCH.ChartsNSNumberDoubleArchive\x12$\n\x1ctschchartaxisverticalspacing\x18\' \x01(\x05\"\xd6 \n$ChartSeriesGenericPropertyMapArchive\x12>\n\x1ctschchartseries1_0dateformat\x18\x01 \x01(\x0b\x32\x18.TSK.FormatStructArchive\x12@\n\x1etschchartseries1_0numberformat\x18\x02 \x01(\x0b\x32\x18.TSK.FormatStructArchive\x12(\n tschchartseries2_3labelexplosion\x18\x03 \x01(\x02\x12&\n\x1etschchartseriesadjustmentscale\x18\x04 \x01(\x02\x12\x41\n$tschchartseriescalloutlineendlineend\x18\x05 \x01(\x0b\x32\x13.TSD.LineEndArchive\x12\x43\n&tschchartseriescalloutlinestartlineend\x18\x06 \x01(\x0b\x32\x13.TSD.LineEndArchive\x12\x41\n%tschchartseriescalloutlinestrokestyle\x18\x07 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12;\n\x19tschchartseriesdateformat\x18\x08 \x01(\x0b\x32\x18.TSK.FormatStructArchive\x12?\n\x1dtschchartseriesdurationformat\x18\t \x01(\x0b\x32\x18.TSK.FormatStructArchive\x12(\n tschchartseriesenablecalloutline\x18\n \x01(\x05\x12]\n)tschchartserieserrorbarcustomnegativedata\x18\x0b \x01(\x0b\x32*.TSCH.ChartsNSArrayOfNSNumberDoubleArchive\x12\x65\n1tschchartserieserrorbarcustomnegativedatascatterx\x18\x0c \x01(\x0b\x32*.TSCH.ChartsNSArrayOfNSNumberDoubleArchive\x12]\n)tschchartserieserrorbarcustompositivedata\x18\r \x01(\x0b\x32*.TSCH.ChartsNSArrayOfNSNumberDoubleArchive\x12\x65\n1tschchartserieserrorbarcustompositivedatascatterx\x18\x0e \x01(\x0b\x32*.TSCH.ChartsNSArrayOfNSNumberDoubleArchive\x12)\n!tschchartserieserrorbarfixedvalue\x18\x0f \x01(\x02\x12\x31\n)tschchartserieserrorbarfixedvaluescatterx\x18\x10 \x01(\x02\x12;\n\x1etschchartserieserrorbarlineend\x18\x11 \x01(\x0b\x32\x13.TSD.LineEndArchive\x12\x43\n&tschchartserieserrorbarlineendscatterx\x18\x12 \x01(\x0b\x32\x13.TSD.LineEndArchive\x12+\n#tschchartserieserrorbarpercentvalue\x18\x13 \x01(\x02\x12\x33\n+tschchartserieserrorbarpercentvaluescatterx\x18\x14 \x01(\x02\x12&\n\x1etschchartserieserrorbarsetting\x18\x15 \x01(\x05\x12.\n&tschchartserieserrorbarsettingscatterx\x18\x16 \x01(\x05\x12\x39\n\x1dtschchartserieserrorbarshadow\x18\x17 \x01(\x0b\x32\x12.TSD.ShadowArchive\x12&\n\x1etschchartserieserrorbarspacing\x18\x18 \x01(\x05\x12.\n&tschchartserieserrorbarspacingscatterx\x18\x19 \x01(\x05\x12*\n\"tschchartserieserrorbarstddevvalue\x18\x1a \x01(\x02\x12\x32\n*tschchartserieserrorbarstddevvaluescatterx\x18\x1b \x01(\x02\x12\x39\n\x1dtschchartserieserrorbarstroke\x18\x1c \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x41\n%tschchartserieserrorbarstrokescatterx\x18\x1d \x01(\x0b\x32\x12.TSD.StrokeArchive\x12#\n\x1btschchartserieserrorbartype\x18\x1e \x01(\x05\x12+\n#tschchartserieserrorbartypescatterx\x18\x1f \x01(\x05\x12-\n\x13tschchartseriesfill\x18  \x01(\x0b\x32\x10.TSD.FillArchive\x12%\n\x1dtschchartserieslabelexplosion\x18! \x01(\x02\x12/\n\'tschchartserieslabelparagraphstyleindex\x18\" \x01(\x05\x12\x1f\n\x17tschchartserieslinetype\x18# \x01(\x05\x12=\n\x1btschchartseriesnumberformat\x18$ \x01(\x0b\x32\x18.TSK.FormatStructArchive\x12\'\n\x1ftschchartseriesnumberformattype\x18% \x01(\x05\x12\x1e\n\x16tschchartseriesopacity\x18& \x01(\x02\x12\x36\n.tschchartseriesoutsidelabelparagraphstyleindex\x18\' \x01(\x05\x12\x44\n\"tschchartseriespercentnumberformat\x18( \x01(\x0b\x32\x18.TSK.FormatStructArchive\x12!\n\x19tschchartseriesseriestype\x18) \x01(\x05\x12\x31\n\x15tschchartseriesshadow\x18* \x01(\x0b\x32\x12.TSD.ShadowArchive\x12#\n\x1btschchartseriesshowerrorbar\x18+ \x01(\x08\x12+\n#tschchartseriesshowerrorbarscatterx\x18, \x01(\x08\x12(\n tschchartseriesshowlabelsinfront\x18- \x01(\x08\x12\x1f\n\x17tschchartseriesshowline\x18. \x01(\x08\x12\'\n\x1ftschchartseriesshownegativedata\x18/ \x01(\x08\x12\'\n\x1ftschchartseriesshowserieslabels\x18\x30 \x01(\x08\x12!\n\x19tschchartseriesshowsymbol\x18\x31 \x01(\x08\x12$\n\x1ctschchartseriesshowtrendline\x18\x32 \x01(\x08\x12&\n\x1etschchartseriesshowvaluelabels\x18\x33 \x01(\x08\x12$\n\x1ctschchartseriessizedimension\x18\x34 \x01(\x05\x12\"\n\x1atschchartseriesstacklabels\x18\x35 \x01(\x08\x12\x31\n\x15tschchartseriesstroke\x18\x36 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x33\n\x19tschchartseriessymbolfill\x18\x37 \x01(\x0b\x32\x10.TSD.FillArchive\x12.\n&tschchartseriessymbolfilluseseriesfill\x18\x38 \x01(\x08\x12\x30\n(tschchartseriessymbolfilluseseriesstroke\x18\x39 \x01(\x08\x12!\n\x19tschchartseriessymbolsize\x18: \x01(\x02\x12\x37\n\x1btschchartseriessymbolstroke\x18; \x01(\x0b\x32\x12.TSD.StrokeArchive\x12!\n\x19tschchartseriessymboltype\x18< \x01(\x05\x12/\n\'tschchartseriestrendlineequationoffsetx\x18= \x01(\x02\x12/\n\'tschchartseriestrendlineequationoffsety\x18> \x01(\x02\x12+\n#tschchartseriestrendlinelabelstring\x18? \x01(\t\x12%\n\x1dtschchartseriestrendlineorder\x18@ \x01(\x05\x12&\n\x1etschchartseriestrendlineperiod\x18\x41 \x01(\x05\x12/\n\'tschchartseriestrendlinersquaredoffsetx\x18\x42 \x01(\x02\x12/\n\'tschchartseriestrendlinersquaredoffsety\x18\x43 \x01(\x02\x12:\n\x1etschchartseriestrendlineshadow\x18\x44 \x01(\x0b\x32\x12.TSD.ShadowArchive\x12,\n$tschchartseriestrendlineshowequation\x18\x45 \x01(\x08\x12)\n!tschchartseriestrendlineshowlabel\x18\x46 \x01(\x08\x12+\n#tschchartseriestrendlineshowr2value\x18G \x01(\x08\x12:\n\x1etschchartseriestrendlinestroke\x18H \x01(\x0b\x32\x12.TSD.StrokeArchive\x12$\n\x1ctschchartseriestrendlinetype\x18I \x01(\x05\x12/\n\'tschchartseriestrendlineequationopacity\x18J \x01(\x02\x12;\n3tschchartseriestrendlineequationparagraphstyleindex\x18K \x01(\x05\x12/\n\'tschchartseriestrendlinersquaredopacity\x18L \x01(\x02\x12;\n3tschchartseriestrendlinersquaredparagraphstyleindex\x18M \x01(\x05\x12)\n!tschchartseriesvaluelabelposition\x18N \x01(\x05\x12(\n tschchartseriesvaluelabelspacing\x18O \x01(\x05\x12&\n\x1etschchartseriesvaluelabelsaxis\x18P \x01(\x05\x12%\n\x1dtschchartserieswedgeexplosion\x18Q \x01(\x02\x12#\n\x1btschchartseriesyaxisordinal\x18R \x01(\x05\"\xf5\x03\n&ReferenceLineGenericPropertyMapArchive\x12G\n\x1ctschreferencelinecustomvalue\x18\x01 \x01(\x0b\x32!.TSCH.ChartsNSNumberDoubleArchive\x12\x1e\n\x16tschreferencelinelabel\x18\x02 \x01(\t\x12\x31\n)tschreferencelinelabelparagraphstyleindex\x18\x03 \x01(\x05\x12\x33\n\x17tschreferencelineshadow\x18\x04 \x01(\x0b\x32\x12.TSD.ShadowArchive\x12\"\n\x1atschreferencelineshowlabel\x18\x05 \x01(\x08\x12!\n\x19tschreferencelineshowline\x18\x06 \x01(\x08\x12\'\n\x1ftschreferencelineshowvaluelabel\x18\x07 \x01(\x08\x12\x33\n\x17tschreferencelinestroke\x18\x08 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x1d\n\x15tschreferencelinetype\x18\t \x01(\x05\x12\x36\n.tschreferencelinevaluelabelparagraphstyleindex\x18\n \x01(\x05')
  ,
  dependencies=[TSPMessages__pb2.DESCRIPTOR,TSKArchives__pb2.DESCRIPTOR,TSDArchives__pb2.DESCRIPTOR,TSSArchives__pb2.DESCRIPTOR,TSCHArchives__Common__pb2.DESCRIPTOR,TSCH3DArchives__pb2.DESCRIPTOR,])




_CHARTSTYLEARCHIVE = _descriptor.Descriptor(
  name='ChartStyleArchive',
  full_name='TSCH.Generated.ChartStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tschchartinfodefault3dchartopacity', full_name='TSCH.Generated.ChartStyleArchive.tschchartinfodefault3dchartopacity', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfoarea3dlightingpackage', full_name='TSCH.Generated.ChartStyleArchive.tschchartinfoarea3dlightingpackage', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfobar3dlightingpackage', full_name='TSCH.Generated.ChartStyleArchive.tschchartinfobar3dlightingpackage', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfocolumn3dlightingpackage', full_name='TSCH.Generated.ChartStyleArchive.tschchartinfocolumn3dlightingpackage', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefault3dlightingpackage', full_name='TSCH.Generated.ChartStyleArchive.tschchartinfodefault3dlightingpackage', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfoline3dlightingpackage', full_name='TSCH.Generated.ChartStyleArchive.tschchartinfoline3dlightingpackage', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfopie3dlightingpackage', full_name='TSCH.Generated.ChartStyleArchive.tschchartinfopie3dlightingpackage', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultbackgroundfill', full_name='TSCH.Generated.ChartStyleArchive.tschchartinfodefaultbackgroundfill', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultbackgroundstroke', full_name='TSCH.Generated.ChartStyleArchive.tschchartinfodefaultbackgroundstroke', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultborderopacity', full_name='TSCH.Generated.ChartStyleArchive.tschchartinfodefaultborderopacity', index=9,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultbordershadow', full_name='TSCH.Generated.ChartStyleArchive.tschchartinfodefaultbordershadow', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultborderstroke', full_name='TSCH.Generated.ChartStyleArchive.tschchartinfodefaultborderstroke', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultcombinelayers', full_name='TSCH.Generated.ChartStyleArchive.tschchartinfodefaultcombinelayers', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultdatasetnameparagraphstyleindex', full_name='TSCH.Generated.ChartStyleArchive.tschchartinfodefaultdatasetnameparagraphstyleindex', index=13,
      number=21, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultgridbackgroundfill', full_name='TSCH.Generated.ChartStyleArchive.tschchartinfodefaultgridbackgroundfill', index=14,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultgridbackgroundopacity', full_name='TSCH.Generated.ChartStyleArchive.tschchartinfodefaultgridbackgroundopacity', index=15,
      number=15, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultinterbargap', full_name='TSCH.Generated.ChartStyleArchive.tschchartinfodefaultinterbargap', index=16,
      number=16, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultintersetgap', full_name='TSCH.Generated.ChartStyleArchive.tschchartinfodefaultintersetgap', index=17,
      number=17, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultroundedcornerouterendonly', full_name='TSCH.Generated.ChartStyleArchive.tschchartinfodefaultroundedcornerouterendonly', index=18,
      number=123, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultroundedcornerradius', full_name='TSCH.Generated.ChartStyleArchive.tschchartinfodefaultroundedcornerradius', index=19,
      number=122, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultshowborder', full_name='TSCH.Generated.ChartStyleArchive.tschchartinfodefaultshowborder', index=20,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaulttitlecolor', full_name='TSCH.Generated.ChartStyleArchive.tschchartinfodefaulttitlecolor', index=21,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaulttitleparagraphstyleindex', full_name='TSCH.Generated.ChartStyleArchive.tschchartinfodefaulttitleparagraphstyleindex', index=22,
      number=20, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
    _descriptor.FieldDescriptor(
      name='current', full_name='TSCH.Generated.ChartStyleArchive.current', index=0,
      number=10000, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=168,
  serialized_end=1645,
)


_CHARTNONSTYLEARCHIVE = _descriptor.Descriptor(
  name='ChartNonStyleArchive',
  full_name='TSCH.Generated.ChartNonStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tschchartinfodefault3dbarshape', full_name='TSCH.Generated.ChartNonStyleArchive.tschchartinfodefault3dbarshape', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefault3dbeveledges', full_name='TSCH.Generated.ChartNonStyleArchive.tschchartinfodefault3dbeveledges', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefault3dintersetdepthgap', full_name='TSCH.Generated.ChartNonStyleArchive.tschchartinfodefault3dintersetdepthgap', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefault3drotation', full_name='TSCH.Generated.ChartNonStyleArchive.tschchartinfodefault3drotation', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfoarea3dscale', full_name='TSCH.Generated.ChartNonStyleArchive.tschchartinfoarea3dscale', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfobar3dscale', full_name='TSCH.Generated.ChartNonStyleArchive.tschchartinfobar3dscale', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfocolumn3dscale', full_name='TSCH.Generated.ChartNonStyleArchive.tschchartinfocolumn3dscale', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefault3dscale', full_name='TSCH.Generated.ChartNonStyleArchive.tschchartinfodefault3dscale', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfoline3dscale', full_name='TSCH.Generated.ChartNonStyleArchive.tschchartinfoline3dscale', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfopie3dscale', full_name='TSCH.Generated.ChartNonStyleArchive.tschchartinfopie3dscale', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefault3dviewport', full_name='TSCH.Generated.ChartNonStyleArchive.tschchartinfodefault3dviewport', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfoareacalloutlinetype', full_name='TSCH.Generated.ChartNonStyleArchive.tschchartinfoareacalloutlinetype', index=11,
      number=112, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfobarcalloutlinetype', full_name='TSCH.Generated.ChartNonStyleArchive.tschchartinfobarcalloutlinetype', index=12,
      number=113, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfobubblecalloutlinetype', full_name='TSCH.Generated.ChartNonStyleArchive.tschchartinfobubblecalloutlinetype', index=13,
      number=114, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultcalloutlinetype', full_name='TSCH.Generated.ChartNonStyleArchive.tschchartinfodefaultcalloutlinetype', index=14,
      number=119, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfolinecalloutlinetype', full_name='TSCH.Generated.ChartNonStyleArchive.tschchartinfolinecalloutlinetype', index=15,
      number=115, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfopiecalloutlinetype', full_name='TSCH.Generated.ChartNonStyleArchive.tschchartinfopiecalloutlinetype', index=16,
      number=111, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfoscattercalloutlinetype', full_name='TSCH.Generated.ChartNonStyleArchive.tschchartinfoscattercalloutlinetype', index=17,
      number=116, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfostackedareacalloutlinetype', full_name='TSCH.Generated.ChartNonStyleArchive.tschchartinfostackedareacalloutlinetype', index=18,
      number=117, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfostackedbarcalloutlinetype', full_name='TSCH.Generated.ChartNonStyleArchive.tschchartinfostackedbarcalloutlinetype', index=19,
      number=118, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultdeprecatedroundedcornerouterendonly', full_name='TSCH.Generated.ChartNonStyleArchive.tschchartinfodefaultdeprecatedroundedcornerouterendonly', index=20,
      number=121, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultdeprecatedroundedcornerradius', full_name='TSCH.Generated.ChartNonStyleArchive.tschchartinfodefaultdeprecatedroundedcornerradius', index=21,
      number=120, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultdatasetnamelocation', full_name='TSCH.Generated.ChartNonStyleArchive.tschchartinfodefaultdatasetnamelocation', index=22,
      number=24, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultdonutplacetitleatcenter', full_name='TSCH.Generated.ChartNonStyleArchive.tschchartinfodefaultdonutplacetitleatcenter', index=23,
      number=28, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultinnerradius', full_name='TSCH.Generated.ChartNonStyleArchive.tschchartinfodefaultinnerradius', index=24,
      number=27, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultmultidatacontroltype', full_name='TSCH.Generated.ChartNonStyleArchive.tschchartinfodefaultmultidatacontroltype', index=25,
      number=25, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultpiestartangle', full_name='TSCH.Generated.ChartNonStyleArchive.tschchartinfodefaultpiestartangle', index=26,
      number=19, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultshowlegend', full_name='TSCH.Generated.ChartNonStyleArchive.tschchartinfodefaultshowlegend', index=27,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultshowtitle', full_name='TSCH.Generated.ChartNonStyleArchive.tschchartinfodefaultshowtitle', index=28,
      number=21, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultskiphiddendata', full_name='TSCH.Generated.ChartNonStyleArchive.tschchartinfodefaultskiphiddendata', index=29,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaulttitle', full_name='TSCH.Generated.ChartNonStyleArchive.tschchartinfodefaulttitle', index=30,
      number=23, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
    _descriptor.FieldDescriptor(
      name='current', full_name='TSCH.Generated.ChartNonStyleArchive.current', index=0,
      number=10000, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1648,
  serialized_end=3310,
)


_LEGENDSTYLEARCHIVE = _descriptor.Descriptor(
  name='LegendStyleArchive',
  full_name='TSCH.Generated.LegendStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tschlegendmodeldefaultfill', full_name='TSCH.Generated.LegendStyleArchive.tschlegendmodeldefaultfill', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschlegendmodeldefaultlabelparagraphstyleindex', full_name='TSCH.Generated.LegendStyleArchive.tschlegendmodeldefaultlabelparagraphstyleindex', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschlegendmodeldefaultopacity', full_name='TSCH.Generated.LegendStyleArchive.tschlegendmodeldefaultopacity', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschlegendmodeldefaultshadow', full_name='TSCH.Generated.LegendStyleArchive.tschlegendmodeldefaultshadow', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschlegendmodeldefaultstroke', full_name='TSCH.Generated.LegendStyleArchive.tschlegendmodeldefaultstroke', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
    _descriptor.FieldDescriptor(
      name='current', full_name='TSCH.Generated.LegendStyleArchive.current', index=0,
      number=10000, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3313,
  serialized_end=3678,
)


_LEGENDNONSTYLEARCHIVE = _descriptor.Descriptor(
  name='LegendNonStyleArchive',
  full_name='TSCH.Generated.LegendNonStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
    _descriptor.FieldDescriptor(
      name='current', full_name='TSCH.Generated.LegendNonStyleArchive.current', index=0,
      number=10000, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3680,
  serialized_end=3789,
)


_CHARTAXISSTYLEARCHIVE = _descriptor.Descriptor(
  name='ChartAxisStyleArchive',
  full_name='TSCH.Generated.ChartAxisStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategory3dgridlineopacity', full_name='TSCH.Generated.ChartAxisStyleArchive.tschchartaxiscategory3dgridlineopacity', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvalue3dgridlineopacity', full_name='TSCH.Generated.ChartAxisStyleArchive.tschchartaxisvalue3dgridlineopacity', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategory3dgridlinestroke', full_name='TSCH.Generated.ChartAxisStyleArchive.tschchartaxiscategory3dgridlinestroke', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvalue3dgridlinestroke', full_name='TSCH.Generated.ChartAxisStyleArchive.tschchartaxisvalue3dgridlinestroke', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategoryhorizontalspacing', full_name='TSCH.Generated.ChartAxisStyleArchive.tschchartaxiscategoryhorizontalspacing', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategorylabelparagraphstyleindex', full_name='TSCH.Generated.ChartAxisStyleArchive.tschchartaxiscategorylabelparagraphstyleindex', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisdefaultlabelparagraphstyleindex', full_name='TSCH.Generated.ChartAxisStyleArchive.tschchartaxisdefaultlabelparagraphstyleindex', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvaluelabelparagraphstyleindex', full_name='TSCH.Generated.ChartAxisStyleArchive.tschchartaxisvaluelabelparagraphstyleindex', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategorylabelsorientation', full_name='TSCH.Generated.ChartAxisStyleArchive.tschchartaxiscategorylabelsorientation', index=8,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisdefaultlabelsorientation', full_name='TSCH.Generated.ChartAxisStyleArchive.tschchartaxisdefaultlabelsorientation', index=9,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvaluelabelsorientation', full_name='TSCH.Generated.ChartAxisStyleArchive.tschchartaxisvaluelabelsorientation', index=10,
      number=11, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategorymajorgridlineopacity', full_name='TSCH.Generated.ChartAxisStyleArchive.tschchartaxiscategorymajorgridlineopacity', index=11,
      number=12, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvaluemajorgridlineopacity', full_name='TSCH.Generated.ChartAxisStyleArchive.tschchartaxisvaluemajorgridlineopacity', index=12,
      number=13, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategorymajorgridlineshadow', full_name='TSCH.Generated.ChartAxisStyleArchive.tschchartaxiscategorymajorgridlineshadow', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvaluemajorgridlineshadow', full_name='TSCH.Generated.ChartAxisStyleArchive.tschchartaxisvaluemajorgridlineshadow', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategorymajorgridlinestroke', full_name='TSCH.Generated.ChartAxisStyleArchive.tschchartaxiscategorymajorgridlinestroke', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvaluemajorgridlinestroke', full_name='TSCH.Generated.ChartAxisStyleArchive.tschchartaxisvaluemajorgridlinestroke', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategoryminorgridlineopacity', full_name='TSCH.Generated.ChartAxisStyleArchive.tschchartaxiscategoryminorgridlineopacity', index=17,
      number=18, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvalueminorgridlineopacity', full_name='TSCH.Generated.ChartAxisStyleArchive.tschchartaxisvalueminorgridlineopacity', index=18,
      number=19, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategoryminorgridlineshadow', full_name='TSCH.Generated.ChartAxisStyleArchive.tschchartaxiscategoryminorgridlineshadow', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvalueminorgridlineshadow', full_name='TSCH.Generated.ChartAxisStyleArchive.tschchartaxisvalueminorgridlineshadow', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategoryminorgridlinestroke', full_name='TSCH.Generated.ChartAxisStyleArchive.tschchartaxiscategoryminorgridlinestroke', index=21,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvalueminorgridlinestroke', full_name='TSCH.Generated.ChartAxisStyleArchive.tschchartaxisvalueminorgridlinestroke', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategoryshowaxis', full_name='TSCH.Generated.ChartAxisStyleArchive.tschchartaxiscategoryshowaxis', index=23,
      number=24, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvalueshowaxis', full_name='TSCH.Generated.ChartAxisStyleArchive.tschchartaxisvalueshowaxis', index=24,
      number=25, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategoryshowlastlabel', full_name='TSCH.Generated.ChartAxisStyleArchive.tschchartaxiscategoryshowlastlabel', index=25,
      number=26, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategoryshowmajorgridlines', full_name='TSCH.Generated.ChartAxisStyleArchive.tschchartaxiscategoryshowmajorgridlines', index=26,
      number=27, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvalueshowmajorgridlines', full_name='TSCH.Generated.ChartAxisStyleArchive.tschchartaxisvalueshowmajorgridlines', index=27,
      number=28, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategoryshowmajortickmarks', full_name='TSCH.Generated.ChartAxisStyleArchive.tschchartaxiscategoryshowmajortickmarks', index=28,
      number=29, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvalueshowmajortickmarks', full_name='TSCH.Generated.ChartAxisStyleArchive.tschchartaxisvalueshowmajortickmarks', index=29,
      number=30, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvalueshowminimumlabel', full_name='TSCH.Generated.ChartAxisStyleArchive.tschchartaxisvalueshowminimumlabel', index=30,
      number=31, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategoryshowminorgridlines', full_name='TSCH.Generated.ChartAxisStyleArchive.tschchartaxiscategoryshowminorgridlines', index=31,
      number=32, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvalueshowminorgridlines', full_name='TSCH.Generated.ChartAxisStyleArchive.tschchartaxisvalueshowminorgridlines', index=32,
      number=33, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategoryshowminortickmarks', full_name='TSCH.Generated.ChartAxisStyleArchive.tschchartaxiscategoryshowminortickmarks', index=33,
      number=34, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvalueshowminortickmarks', full_name='TSCH.Generated.ChartAxisStyleArchive.tschchartaxisvalueshowminortickmarks', index=34,
      number=35, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategorytickmarklocation', full_name='TSCH.Generated.ChartAxisStyleArchive.tschchartaxiscategorytickmarklocation', index=35,
      number=36, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvaluetickmarklocation', full_name='TSCH.Generated.ChartAxisStyleArchive.tschchartaxisvaluetickmarklocation', index=36,
      number=37, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategorytitleparagraphstyleindex', full_name='TSCH.Generated.ChartAxisStyleArchive.tschchartaxiscategorytitleparagraphstyleindex', index=37,
      number=38, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisdefaulttitleparagraphstyleindex', full_name='TSCH.Generated.ChartAxisStyleArchive.tschchartaxisdefaulttitleparagraphstyleindex', index=38,
      number=39, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvaluetitleparagraphstyleindex', full_name='TSCH.Generated.ChartAxisStyleArchive.tschchartaxisvaluetitleparagraphstyleindex', index=39,
      number=40, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategoryverticalspacing', full_name='TSCH.Generated.ChartAxisStyleArchive.tschchartaxiscategoryverticalspacing', index=40,
      number=41, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
    _descriptor.FieldDescriptor(
      name='current', full_name='TSCH.Generated.ChartAxisStyleArchive.current', index=0,
      number=10000, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3792,
  serialized_end=6061,
)


_CHARTAXISNONSTYLEARCHIVE = _descriptor.Descriptor(
  name='ChartAxisNonStyleArchive',
  full_name='TSCH.Generated.ChartAxisNonStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tschchartaxisdefault1_0dateformat', full_name='TSCH.Generated.ChartAxisNonStyleArchive.tschchartaxisdefault1_0dateformat', index=0,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisdefault1_0numberformat', full_name='TSCH.Generated.ChartAxisNonStyleArchive.tschchartaxisdefault1_0numberformat', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisdefault3dlabelposition', full_name='TSCH.Generated.ChartAxisNonStyleArchive.tschchartaxisdefault3dlabelposition', index=2,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisdefaultdateformat', full_name='TSCH.Generated.ChartAxisNonStyleArchive.tschchartaxisdefaultdateformat', index=3,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisdefaultdurationformat', full_name='TSCH.Generated.ChartAxisNonStyleArchive.tschchartaxisdefaultdurationformat', index=4,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisdefaultnumberformat', full_name='TSCH.Generated.ChartAxisNonStyleArchive.tschchartaxisdefaultnumberformat', index=5,
      number=42, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisdefaultnumberformattype', full_name='TSCH.Generated.ChartAxisNonStyleArchive.tschchartaxisdefaultnumberformattype', index=6,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvaluenumberofdecades', full_name='TSCH.Generated.ChartAxisNonStyleArchive.tschchartaxisvaluenumberofdecades', index=7,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvaluenumberofmajorgridlines', full_name='TSCH.Generated.ChartAxisNonStyleArchive.tschchartaxisvaluenumberofmajorgridlines', index=8,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvaluenumberofminorgridlines', full_name='TSCH.Generated.ChartAxisNonStyleArchive.tschchartaxisvaluenumberofminorgridlines', index=9,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategoryplottoedges', full_name='TSCH.Generated.ChartAxisNonStyleArchive.tschchartaxiscategoryplottoedges', index=10,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvaluescale', full_name='TSCH.Generated.ChartAxisNonStyleArchive.tschchartaxisvaluescale', index=11,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategoryshowlabels', full_name='TSCH.Generated.ChartAxisNonStyleArchive.tschchartaxiscategoryshowlabels', index=12,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisdefaultshowlabels', full_name='TSCH.Generated.ChartAxisNonStyleArchive.tschchartaxisdefaultshowlabels', index=13,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvalueshowlabels', full_name='TSCH.Generated.ChartAxisNonStyleArchive.tschchartaxisvalueshowlabels', index=14,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategoryshowserieslabels', full_name='TSCH.Generated.ChartAxisNonStyleArchive.tschchartaxiscategoryshowserieslabels', index=15,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxismultidatashowserieslabels', full_name='TSCH.Generated.ChartAxisNonStyleArchive.tschchartaxismultidatashowserieslabels', index=16,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategoryshowtitle', full_name='TSCH.Generated.ChartAxisNonStyleArchive.tschchartaxiscategoryshowtitle', index=17,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvalueshowtitle', full_name='TSCH.Generated.ChartAxisNonStyleArchive.tschchartaxisvalueshowtitle', index=18,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategorytitle', full_name='TSCH.Generated.ChartAxisNonStyleArchive.tschchartaxiscategorytitle', index=19,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvaluetitle', full_name='TSCH.Generated.ChartAxisNonStyleArchive.tschchartaxisvaluetitle', index=20,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisdefaultusermax', full_name='TSCH.Generated.ChartAxisNonStyleArchive.tschchartaxisdefaultusermax', index=21,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisdefaultusermin', full_name='TSCH.Generated.ChartAxisNonStyleArchive.tschchartaxisdefaultusermin', index=22,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
    _descriptor.FieldDescriptor(
      name='current', full_name='TSCH.Generated.ChartAxisNonStyleArchive.current', index=0,
      number=10000, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6064,
  serialized_end=7339,
)


_CHARTSERIESSTYLEARCHIVE = _descriptor.Descriptor(
  name='ChartSeriesStyleArchive',
  full_name='TSCH.Generated.ChartSeriesStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaultcalloutlineendlineend', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesdefaultcalloutlineendlineend', index=0,
      number=130, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaultcalloutlinestartlineend', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesdefaultcalloutlinestartlineend', index=1,
      number=129, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaultcalloutlinestrokestyle', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesdefaultcalloutlinestrokestyle', index=2,
      number=128, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulterrorbarlineend', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesdefaulterrorbarlineend', index=3,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulterrorbarlineendscatterx', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesdefaulterrorbarlineendscatterx', index=4,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulterrorbarshadow', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesdefaulterrorbarshadow', index=5,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulterrorbarspacing', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesdefaulterrorbarspacing', index=6,
      number=98, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulterrorbarspacingscatterx', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesdefaulterrorbarspacingscatterx', index=7,
      number=99, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulterrorbarstroke', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesdefaulterrorbarstroke', index=8,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulterrorbarstrokescatterx', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesdefaulterrorbarstrokescatterx', index=9,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseries3dareafill', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseries3dareafill', index=10,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseries3dbarfill', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseries3dbarfill', index=11,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseries3dcolumnfill', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseries3dcolumnfill', index=12,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseries3dlinefill', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseries3dlinefill', index=13,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseries3dpiefill', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseries3dpiefill', index=14,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesareafill', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesareafill', index=15,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesbarfill', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesbarfill', index=16,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriescolumnfill', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriescolumnfill', index=17,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaultfill', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesdefaultfill', index=18,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedareafill', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesmixedareafill', index=19,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedcolumnfill', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesmixedcolumnfill', index=20,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriespiefill', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriespiefill', index=21,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesarealabelparagraphstyleindex', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesarealabelparagraphstyleindex', index=22,
      number=18, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesbarlabelparagraphstyleindex', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesbarlabelparagraphstyleindex', index=23,
      number=19, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaultlabelparagraphstyleindex', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesdefaultlabelparagraphstyleindex', index=24,
      number=20, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdonutlabelparagraphstyleindex', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesdonutlabelparagraphstyleindex', index=25,
      number=152, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieslinelabelparagraphstyleindex', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartserieslinelabelparagraphstyleindex', index=26,
      number=21, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedlabelparagraphstyleindex', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesmixedlabelparagraphstyleindex', index=27,
      number=22, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriespielabelparagraphstyleindex', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriespielabelparagraphstyleindex', index=28,
      number=23, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaultopacity', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesdefaultopacity', index=29,
      number=24, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesareaoutsidelabelparagraphstyleindex', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesareaoutsidelabelparagraphstyleindex', index=30,
      number=25, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesbaroutsidelabelparagraphstyleindex', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesbaroutsidelabelparagraphstyleindex', index=31,
      number=26, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaultoutsidelabelparagraphstyleindex', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesdefaultoutsidelabelparagraphstyleindex', index=32,
      number=27, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdonutoutsidelabelparagraphstyleindex', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesdonutoutsidelabelparagraphstyleindex', index=33,
      number=153, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedoutsidelabelparagraphstyleindex', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesmixedoutsidelabelparagraphstyleindex', index=34,
      number=28, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriespieoutsidelabelparagraphstyleindex', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriespieoutsidelabelparagraphstyleindex', index=35,
      number=29, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseries3dareashadow', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseries3dareashadow', index=36,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseries3dbarshadow', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseries3dbarshadow', index=37,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseries3dcolumnshadow', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseries3dcolumnshadow', index=38,
      number=32, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseries3dlineshadow', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseries3dlineshadow', index=39,
      number=33, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseries3dpieshadow', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseries3dpieshadow', index=40,
      number=34, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesareashadow', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesareashadow', index=41,
      number=35, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesbarshadow', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesbarshadow', index=42,
      number=36, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesbubbleshadow', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesbubbleshadow', index=43,
      number=37, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaultshadow', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesdefaultshadow', index=44,
      number=38, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieslineshadow', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartserieslineshadow', index=45,
      number=39, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedareashadow', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesmixedareashadow', index=46,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedcolumnshadow', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesmixedcolumnshadow', index=47,
      number=41, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedlineshadow', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesmixedlineshadow', index=48,
      number=42, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriespieshadow', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriespieshadow', index=49,
      number=43, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesscattershadow', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesscattershadow', index=50,
      number=44, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesareastroke', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesareastroke', index=51,
      number=45, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesbarstroke', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesbarstroke', index=52,
      number=46, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesbubblestroke', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesbubblestroke', index=53,
      number=47, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieslinestroke', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartserieslinestroke', index=54,
      number=48, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedareastroke', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesmixedareastroke', index=55,
      number=49, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedcolumnstroke', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesmixedcolumnstroke', index=56,
      number=50, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedlinestroke', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesmixedlinestroke', index=57,
      number=51, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriespiestroke', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriespiestroke', index=58,
      number=52, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesscatterstroke', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesscatterstroke', index=59,
      number=53, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesareasymbolfill', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesareasymbolfill', index=60,
      number=54, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesbubblesymbolfill', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesbubblesymbolfill', index=61,
      number=55, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieslinesymbolfill', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartserieslinesymbolfill', index=62,
      number=56, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedareasymbolfill', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesmixedareasymbolfill', index=63,
      number=57, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedlinesymbolfill', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesmixedlinesymbolfill', index=64,
      number=58, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesscattersymbolfill', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesscattersymbolfill', index=65,
      number=59, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesareasymbolfilluseseriesfill', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesareasymbolfilluseseriesfill', index=66,
      number=60, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieslinesymbolfilluseseriesfill', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartserieslinesymbolfilluseseriesfill', index=67,
      number=61, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedareasymbolfilluseseriesfill', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesmixedareasymbolfilluseseriesfill', index=68,
      number=62, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedlinesymbolfilluseseriesfill', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesmixedlinesymbolfilluseseriesfill', index=69,
      number=63, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesareasymbolfilluseseriesstroke', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesareasymbolfilluseseriesstroke', index=70,
      number=64, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesbubblesymbolfilluseseriesstroke', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesbubblesymbolfilluseseriesstroke', index=71,
      number=65, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieslinesymbolfilluseseriesstroke', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartserieslinesymbolfilluseseriesstroke', index=72,
      number=66, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedareasymbolfilluseseriesstroke', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesmixedareasymbolfilluseseriesstroke', index=73,
      number=67, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedlinesymbolfilluseseriesstroke', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesmixedlinesymbolfilluseseriesstroke', index=74,
      number=68, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesscattersymbolfilluseseriesstroke', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesscattersymbolfilluseseriesstroke', index=75,
      number=69, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesareasymbolsize', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesareasymbolsize', index=76,
      number=70, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieslinesymbolsize', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartserieslinesymbolsize', index=77,
      number=71, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedareasymbolsize', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesmixedareasymbolsize', index=78,
      number=72, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedlinesymbolsize', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesmixedlinesymbolsize', index=79,
      number=73, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesscattersymbolsize', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesscattersymbolsize', index=80,
      number=74, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesareasymbolstroke', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesareasymbolstroke', index=81,
      number=75, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesbubblesymbolstroke', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesbubblesymbolstroke', index=82,
      number=76, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieslinesymbolstroke', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartserieslinesymbolstroke', index=83,
      number=77, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedareasymbolstroke', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesmixedareasymbolstroke', index=84,
      number=78, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedlinesymbolstroke', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesmixedlinesymbolstroke', index=85,
      number=79, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesscattersymbolstroke', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesscattersymbolstroke', index=86,
      number=80, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulttrendlineshadow', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesdefaulttrendlineshadow', index=87,
      number=85, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulttrendlinestroke', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesdefaulttrendlinestroke', index=88,
      number=86, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulttrendlineequationopacity', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesdefaulttrendlineequationopacity', index=89,
      number=81, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulttrendlineequationparagraphstyleindex', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesdefaulttrendlineequationparagraphstyleindex', index=90,
      number=82, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulttrendlinersquaredopacity', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesdefaulttrendlinersquaredopacity', index=91,
      number=83, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulttrendlinersquaredparagraphstyleindex', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesdefaulttrendlinersquaredparagraphstyleindex', index=92,
      number=84, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesareavaluelabelposition', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesareavaluelabelposition', index=93,
      number=87, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesbarvaluelabelposition', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesbarvaluelabelposition', index=94,
      number=88, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesbubblevaluelabelposition', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesbubblevaluelabelposition', index=95,
      number=89, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaultvaluelabelposition', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesdefaultvaluelabelposition', index=96,
      number=90, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieslinevaluelabelposition', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartserieslinevaluelabelposition', index=97,
      number=91, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedareavaluelabelposition', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesmixedareavaluelabelposition', index=98,
      number=92, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedcolumnvaluelabelposition', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesmixedcolumnvaluelabelposition', index=99,
      number=93, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedlinevaluelabelposition', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesmixedlinevaluelabelposition', index=100,
      number=94, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesscattervaluelabelposition', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesscattervaluelabelposition', index=101,
      number=95, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesstackedareavaluelabelposition', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesstackedareavaluelabelposition', index=102,
      number=96, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesstackedbarvaluelabelposition', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesstackedbarvaluelabelposition', index=103,
      number=97, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaultvaluelabelspacing', full_name='TSCH.Generated.ChartSeriesStyleArchive.tschchartseriesdefaultvaluelabelspacing', index=104,
      number=100, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
    _descriptor.FieldDescriptor(
      name='current', full_name='TSCH.Generated.ChartSeriesStyleArchive.current', index=0,
      number=10000, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7342,
  serialized_end=13412,
)


_CHARTSERIESNONSTYLEARCHIVE = _descriptor.Descriptor(
  name='ChartSeriesNonStyleArchive',
  full_name='TSCH.Generated.ChartSeriesNonStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefault1_0dateformat', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesdefault1_0dateformat', index=0,
      number=69, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefault1_0numberformat', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesdefault1_0numberformat', index=1,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriespie1_0numberformat', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriespie1_0numberformat', index=2,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriespie2_3labelexplosion', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriespie2_3labelexplosion', index=3,
      number=16, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesbubbleadjustmentscale', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesbubbleadjustmentscale', index=4,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaultdateformat', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesdefaultdateformat', index=5,
      number=71, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaultdurationformat', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesdefaultdurationformat', index=6,
      number=70, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesareaenablecalloutline', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesareaenablecalloutline', index=7,
      number=103, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesbarenablecalloutline', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesbarenablecalloutline', index=8,
      number=104, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesbubbleenablecalloutline', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesbubbleenablecalloutline', index=9,
      number=105, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaultenablecalloutline', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesdefaultenablecalloutline', index=10,
      number=110, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieslineenablecalloutline', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartserieslineenablecalloutline', index=11,
      number=106, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriespieenablecalloutline', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriespieenablecalloutline', index=12,
      number=102, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesscatterenablecalloutline', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesscatterenablecalloutline', index=13,
      number=107, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesstackedareaenablecalloutline', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesstackedareaenablecalloutline', index=14,
      number=108, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesstackedbarenablecalloutline', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesstackedbarenablecalloutline', index=15,
      number=109, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulterrorbarcustomnegativedata', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesdefaulterrorbarcustomnegativedata', index=16,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulterrorbarcustomnegativedatascatterx', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesdefaulterrorbarcustomnegativedatascatterx', index=17,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulterrorbarcustompositivedata', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesdefaulterrorbarcustompositivedata', index=18,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulterrorbarcustompositivedatascatterx', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesdefaulterrorbarcustompositivedatascatterx', index=19,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulterrorbarfixedvalue', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesdefaulterrorbarfixedvalue', index=20,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulterrorbarfixedvaluescatterx', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesdefaulterrorbarfixedvaluescatterx', index=21,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulterrorbarpercentvalue', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesdefaulterrorbarpercentvalue', index=22,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulterrorbarpercentvaluescatterx', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesdefaulterrorbarpercentvaluescatterx', index=23,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulterrorbarsetting', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesdefaulterrorbarsetting', index=24,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulterrorbarsettingscatterx', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesdefaulterrorbarsettingscatterx', index=25,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulterrorbarstddevvalue', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesdefaulterrorbarstddevvalue', index=26,
      number=12, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulterrorbarstddevvaluescatterx', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesdefaulterrorbarstddevvaluescatterx', index=27,
      number=13, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulterrorbartype', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesdefaulterrorbartype', index=28,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulterrorbartypescatterx', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesdefaulterrorbartypescatterx', index=29,
      number=15, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriespielabelexplosion', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriespielabelexplosion', index=30,
      number=147, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesbubblelinetype', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesbubblelinetype', index=31,
      number=17, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieslinelinetype', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartserieslinelinetype', index=32,
      number=18, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedlinelinetype', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesmixedlinelinetype', index=33,
      number=19, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesscatterlinetype', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesscatterlinetype', index=34,
      number=20, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaultnumberformat', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesdefaultnumberformat', index=35,
      number=98, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriespienumberformat', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriespienumberformat', index=36,
      number=99, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaultnumberformattype', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesdefaultnumberformattype', index=37,
      number=23, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriespienumberformattype', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriespienumberformattype', index=38,
      number=24, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesstackedpercentnumberformat', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesstackedpercentnumberformat', index=39,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaultseriestype', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesdefaultseriestype', index=40,
      number=26, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaultshowerrorbar', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesdefaultshowerrorbar', index=41,
      number=27, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaultshowerrorbarscatterx', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesdefaultshowerrorbarscatterx', index=42,
      number=28, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesbubbleshowlabelsinfront', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesbubbleshowlabelsinfront', index=43,
      number=101, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaultshowlabelsinfront', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesdefaultshowlabelsinfront', index=44,
      number=100, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesscattershowline', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesscattershowline', index=45,
      number=29, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesbubbleshownegativedata', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesbubbleshownegativedata', index=46,
      number=30, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesbubbleshowserieslabels', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesbubbleshowserieslabels', index=47,
      number=65, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriespieshowserieslabels', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriespieshowserieslabels', index=48,
      number=31, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesscattershowserieslabels', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesscattershowserieslabels', index=49,
      number=67, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesareashowsymbol', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesareashowsymbol', index=50,
      number=32, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieslineshowsymbol', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartserieslineshowsymbol', index=51,
      number=33, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedareashowsymbol', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesmixedareashowsymbol', index=52,
      number=34, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedlineshowsymbol', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesmixedlineshowsymbol', index=53,
      number=35, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesscattershowsymbol', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesscattershowsymbol', index=54,
      number=36, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaultshowtrendline', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesdefaultshowtrendline', index=55,
      number=37, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesareashowvaluelabels', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesareashowvaluelabels', index=56,
      number=38, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesbarshowvaluelabels', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesbarshowvaluelabels', index=57,
      number=39, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesbubbleshowvaluelabels', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesbubbleshowvaluelabels', index=58,
      number=40, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaultshowvaluelabels', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesdefaultshowvaluelabels', index=59,
      number=41, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieslineshowvaluelabels', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartserieslineshowvaluelabels', index=60,
      number=42, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedshowvaluelabels', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesmixedshowvaluelabels', index=61,
      number=43, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriespieshowvaluelabels', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriespieshowvaluelabels', index=62,
      number=44, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesscattershowvaluelabels', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesscattershowvaluelabels', index=63,
      number=45, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesbubblesizedimension', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesbubblesizedimension', index=64,
      number=46, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesareastacklabels', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesareastacklabels', index=65,
      number=139, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesbarstacklabels', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesbarstacklabels', index=66,
      number=140, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesbubblestacklabels', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesbubblestacklabels', index=67,
      number=141, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaultstacklabels', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesdefaultstacklabels', index=68,
      number=146, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieslinestacklabels', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartserieslinestacklabels', index=69,
      number=142, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriespiestacklabels', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriespiestacklabels', index=70,
      number=138, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesscatterstacklabels', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesscatterstacklabels', index=71,
      number=143, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesstackedareastacklabels', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesstackedareastacklabels', index=72,
      number=144, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesstackedbarstacklabels', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesstackedbarstacklabels', index=73,
      number=145, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesareasymboltype', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesareasymboltype', index=74,
      number=47, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieslinesymboltype', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartserieslinesymboltype', index=75,
      number=48, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedareasymboltype', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesmixedareasymboltype', index=76,
      number=49, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedlinesymboltype', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesmixedlinesymboltype', index=77,
      number=50, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesscattersymboltype', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesscattersymboltype', index=78,
      number=51, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulttrendlineequationoffsetx', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesdefaulttrendlineequationoffsetx', index=79,
      number=52, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulttrendlineequationoffsety', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesdefaulttrendlineequationoffsety', index=80,
      number=53, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulttrendlinelabelstring', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesdefaulttrendlinelabelstring', index=81,
      number=54, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulttrendlineorder', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesdefaulttrendlineorder', index=82,
      number=55, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulttrendlineperiod', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesdefaulttrendlineperiod', index=83,
      number=56, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulttrendlinersquaredoffsetx', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesdefaulttrendlinersquaredoffsetx', index=84,
      number=57, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulttrendlinersquaredoffsety', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesdefaulttrendlinersquaredoffsety', index=85,
      number=58, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulttrendlineshowequation', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesdefaulttrendlineshowequation', index=86,
      number=59, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulttrendlineshowlabel', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesdefaulttrendlineshowlabel', index=87,
      number=60, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulttrendlineshowr2value', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesdefaulttrendlineshowr2value', index=88,
      number=61, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulttrendlinetype', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesdefaulttrendlinetype', index=89,
      number=62, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesbubblevaluelabelsaxis', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesbubblevaluelabelsaxis', index=90,
      number=66, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesscattervaluelabelsaxis', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesscattervaluelabelsaxis', index=91,
      number=68, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriespiewedgeexplosion', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriespiewedgeexplosion', index=92,
      number=63, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaultyaxisordinal', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.tschchartseriesdefaultyaxisordinal', index=93,
      number=64, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
    _descriptor.FieldDescriptor(
      name='current', full_name='TSCH.Generated.ChartSeriesNonStyleArchive.current', index=0,
      number=10000, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13415,
  serialized_end=18335,
)


_REFERENCELINESTYLEARCHIVE = _descriptor.Descriptor(
  name='ReferenceLineStyleArchive',
  full_name='TSCH.Generated.ReferenceLineStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tschreferencelinedefaultlabelparagraphstyleindex', full_name='TSCH.Generated.ReferenceLineStyleArchive.tschreferencelinedefaultlabelparagraphstyleindex', index=0,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschreferencelinedefaultshadow', full_name='TSCH.Generated.ReferenceLineStyleArchive.tschreferencelinedefaultshadow', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschreferencelinedefaultstroke', full_name='TSCH.Generated.ReferenceLineStyleArchive.tschreferencelinedefaultstroke', index=2,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschreferencelinedefaultvaluelabelparagraphstyleindex', full_name='TSCH.Generated.ReferenceLineStyleArchive.tschreferencelinedefaultvaluelabelparagraphstyleindex', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
    _descriptor.FieldDescriptor(
      name='current', full_name='TSCH.Generated.ReferenceLineStyleArchive.current', index=0,
      number=10000, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18338,
  serialized_end=18700,
)


_REFERENCELINENONSTYLEARCHIVE = _descriptor.Descriptor(
  name='ReferenceLineNonStyleArchive',
  full_name='TSCH.Generated.ReferenceLineNonStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tschreferencelinedefaultcustomvalue', full_name='TSCH.Generated.ReferenceLineNonStyleArchive.tschreferencelinedefaultcustomvalue', index=0,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschreferencelinedefaultlabel', full_name='TSCH.Generated.ReferenceLineNonStyleArchive.tschreferencelinedefaultlabel', index=1,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschreferencelinedefaultshowlabel', full_name='TSCH.Generated.ReferenceLineNonStyleArchive.tschreferencelinedefaultshowlabel', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschreferencelinedefaultshowline', full_name='TSCH.Generated.ReferenceLineNonStyleArchive.tschreferencelinedefaultshowline', index=3,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschreferencelinedefaultshowvaluelabel', full_name='TSCH.Generated.ReferenceLineNonStyleArchive.tschreferencelinedefaultshowvaluelabel', index=4,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschreferencelinedefaulttype', full_name='TSCH.Generated.ReferenceLineNonStyleArchive.tschreferencelinedefaulttype', index=5,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
    _descriptor.FieldDescriptor(
      name='current', full_name='TSCH.Generated.ReferenceLineNonStyleArchive.current', index=0,
      number=10000, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18703,
  serialized_end=19123,
)


_CHARTGENERICPROPERTYMAPARCHIVE = _descriptor.Descriptor(
  name='ChartGenericPropertyMapArchive',
  full_name='TSCH.Generated.ChartGenericPropertyMapArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tschchartinfo3dbarshape', full_name='TSCH.Generated.ChartGenericPropertyMapArchive.tschchartinfo3dbarshape', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfo3dbeveledges', full_name='TSCH.Generated.ChartGenericPropertyMapArchive.tschchartinfo3dbeveledges', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfo3dchartopacity', full_name='TSCH.Generated.ChartGenericPropertyMapArchive.tschchartinfo3dchartopacity', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfo3dintersetdepthgap', full_name='TSCH.Generated.ChartGenericPropertyMapArchive.tschchartinfo3dintersetdepthgap', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfo3dlightingpackage', full_name='TSCH.Generated.ChartGenericPropertyMapArchive.tschchartinfo3dlightingpackage', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfo3drotation', full_name='TSCH.Generated.ChartGenericPropertyMapArchive.tschchartinfo3drotation', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfo3dscale', full_name='TSCH.Generated.ChartGenericPropertyMapArchive.tschchartinfo3dscale', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfo3dviewport', full_name='TSCH.Generated.ChartGenericPropertyMapArchive.tschchartinfo3dviewport', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfobackgroundfill', full_name='TSCH.Generated.ChartGenericPropertyMapArchive.tschchartinfobackgroundfill', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfobackgroundstroke', full_name='TSCH.Generated.ChartGenericPropertyMapArchive.tschchartinfobackgroundstroke', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfoborderopacity', full_name='TSCH.Generated.ChartGenericPropertyMapArchive.tschchartinfoborderopacity', index=10,
      number=11, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfobordershadow', full_name='TSCH.Generated.ChartGenericPropertyMapArchive.tschchartinfobordershadow', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfoborderstroke', full_name='TSCH.Generated.ChartGenericPropertyMapArchive.tschchartinfoborderstroke', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfocalloutlinetype', full_name='TSCH.Generated.ChartGenericPropertyMapArchive.tschchartinfocalloutlinetype', index=13,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfocombinelayers', full_name='TSCH.Generated.ChartGenericPropertyMapArchive.tschchartinfocombinelayers', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodeprecatedroundedcornerouterendonly', full_name='TSCH.Generated.ChartGenericPropertyMapArchive.tschchartinfodeprecatedroundedcornerouterendonly', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodeprecatedroundedcornerradius', full_name='TSCH.Generated.ChartGenericPropertyMapArchive.tschchartinfodeprecatedroundedcornerradius', index=16,
      number=17, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodatasetnamelocation', full_name='TSCH.Generated.ChartGenericPropertyMapArchive.tschchartinfodatasetnamelocation', index=17,
      number=18, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodatasetnameparagraphstyleindex', full_name='TSCH.Generated.ChartGenericPropertyMapArchive.tschchartinfodatasetnameparagraphstyleindex', index=18,
      number=19, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodonutplacetitleatcenter', full_name='TSCH.Generated.ChartGenericPropertyMapArchive.tschchartinfodonutplacetitleatcenter', index=19,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfogridbackgroundfill', full_name='TSCH.Generated.ChartGenericPropertyMapArchive.tschchartinfogridbackgroundfill', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfogridbackgroundopacity', full_name='TSCH.Generated.ChartGenericPropertyMapArchive.tschchartinfogridbackgroundopacity', index=21,
      number=22, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfoinnerradius', full_name='TSCH.Generated.ChartGenericPropertyMapArchive.tschchartinfoinnerradius', index=22,
      number=23, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfointerbargap', full_name='TSCH.Generated.ChartGenericPropertyMapArchive.tschchartinfointerbargap', index=23,
      number=24, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfointersetgap', full_name='TSCH.Generated.ChartGenericPropertyMapArchive.tschchartinfointersetgap', index=24,
      number=25, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfomultidatacontroltype', full_name='TSCH.Generated.ChartGenericPropertyMapArchive.tschchartinfomultidatacontroltype', index=25,
      number=26, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfopiestartangle', full_name='TSCH.Generated.ChartGenericPropertyMapArchive.tschchartinfopiestartangle', index=26,
      number=27, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinforoundedcornerouterendonly', full_name='TSCH.Generated.ChartGenericPropertyMapArchive.tschchartinforoundedcornerouterendonly', index=27,
      number=28, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinforoundedcornerradius', full_name='TSCH.Generated.ChartGenericPropertyMapArchive.tschchartinforoundedcornerradius', index=28,
      number=29, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfoshowborder', full_name='TSCH.Generated.ChartGenericPropertyMapArchive.tschchartinfoshowborder', index=29,
      number=30, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfoshowlegend', full_name='TSCH.Generated.ChartGenericPropertyMapArchive.tschchartinfoshowlegend', index=30,
      number=31, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfoshowtitle', full_name='TSCH.Generated.ChartGenericPropertyMapArchive.tschchartinfoshowtitle', index=31,
      number=32, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfoskiphiddendata', full_name='TSCH.Generated.ChartGenericPropertyMapArchive.tschchartinfoskiphiddendata', index=32,
      number=33, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfotitlecolor', full_name='TSCH.Generated.ChartGenericPropertyMapArchive.tschchartinfotitlecolor', index=33,
      number=34, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfotitle', full_name='TSCH.Generated.ChartGenericPropertyMapArchive.tschchartinfotitle', index=34,
      number=35, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfotitleparagraphstyleindex', full_name='TSCH.Generated.ChartGenericPropertyMapArchive.tschchartinfotitleparagraphstyleindex', index=35,
      number=36, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19126,
  serialized_end=20775,
)


_LEGENDGENERICPROPERTYMAPARCHIVE = _descriptor.Descriptor(
  name='LegendGenericPropertyMapArchive',
  full_name='TSCH.Generated.LegendGenericPropertyMapArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tschlegendmodelfill', full_name='TSCH.Generated.LegendGenericPropertyMapArchive.tschlegendmodelfill', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschlegendmodellabelparagraphstyleindex', full_name='TSCH.Generated.LegendGenericPropertyMapArchive.tschlegendmodellabelparagraphstyleindex', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschlegendmodelopacity', full_name='TSCH.Generated.LegendGenericPropertyMapArchive.tschlegendmodelopacity', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschlegendmodelshadow', full_name='TSCH.Generated.LegendGenericPropertyMapArchive.tschlegendmodelshadow', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschlegendmodelstroke', full_name='TSCH.Generated.LegendGenericPropertyMapArchive.tschlegendmodelstroke', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20778,
  serialized_end=21041,
)


_CHARTAXISGENERICPROPERTYMAPARCHIVE = _descriptor.Descriptor(
  name='ChartAxisGenericPropertyMapArchive',
  full_name='TSCH.Generated.ChartAxisGenericPropertyMapArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tschchartaxis1_0dateformat', full_name='TSCH.Generated.ChartAxisGenericPropertyMapArchive.tschchartaxis1_0dateformat', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxis1_0numberformat', full_name='TSCH.Generated.ChartAxisGenericPropertyMapArchive.tschchartaxis1_0numberformat', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxis3dgridlineopacity', full_name='TSCH.Generated.ChartAxisGenericPropertyMapArchive.tschchartaxis3dgridlineopacity', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxis3dgridlinestroke', full_name='TSCH.Generated.ChartAxisGenericPropertyMapArchive.tschchartaxis3dgridlinestroke', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxis3dlabelposition', full_name='TSCH.Generated.ChartAxisGenericPropertyMapArchive.tschchartaxis3dlabelposition', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisdateformat', full_name='TSCH.Generated.ChartAxisGenericPropertyMapArchive.tschchartaxisdateformat', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisdurationformat', full_name='TSCH.Generated.ChartAxisGenericPropertyMapArchive.tschchartaxisdurationformat', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxishorizontalspacing', full_name='TSCH.Generated.ChartAxisGenericPropertyMapArchive.tschchartaxishorizontalspacing', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxislabelparagraphstyleindex', full_name='TSCH.Generated.ChartAxisGenericPropertyMapArchive.tschchartaxislabelparagraphstyleindex', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxislabelsorientation', full_name='TSCH.Generated.ChartAxisGenericPropertyMapArchive.tschchartaxislabelsorientation', index=9,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxismajorgridlineopacity', full_name='TSCH.Generated.ChartAxisGenericPropertyMapArchive.tschchartaxismajorgridlineopacity', index=10,
      number=11, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxismajorgridlineshadow', full_name='TSCH.Generated.ChartAxisGenericPropertyMapArchive.tschchartaxismajorgridlineshadow', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxismajorgridlinestroke', full_name='TSCH.Generated.ChartAxisGenericPropertyMapArchive.tschchartaxismajorgridlinestroke', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisminorgridlineopacity', full_name='TSCH.Generated.ChartAxisGenericPropertyMapArchive.tschchartaxisminorgridlineopacity', index=13,
      number=14, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisminorgridlineshadow', full_name='TSCH.Generated.ChartAxisGenericPropertyMapArchive.tschchartaxisminorgridlineshadow', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisminorgridlinestroke', full_name='TSCH.Generated.ChartAxisGenericPropertyMapArchive.tschchartaxisminorgridlinestroke', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisnumberformat', full_name='TSCH.Generated.ChartAxisGenericPropertyMapArchive.tschchartaxisnumberformat', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisnumberformattype', full_name='TSCH.Generated.ChartAxisGenericPropertyMapArchive.tschchartaxisnumberformattype', index=17,
      number=18, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisnumberofdecades', full_name='TSCH.Generated.ChartAxisGenericPropertyMapArchive.tschchartaxisnumberofdecades', index=18,
      number=19, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisnumberofmajorgridlines', full_name='TSCH.Generated.ChartAxisGenericPropertyMapArchive.tschchartaxisnumberofmajorgridlines', index=19,
      number=20, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisnumberofminorgridlines', full_name='TSCH.Generated.ChartAxisGenericPropertyMapArchive.tschchartaxisnumberofminorgridlines', index=20,
      number=21, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisplottoedges', full_name='TSCH.Generated.ChartAxisGenericPropertyMapArchive.tschchartaxisplottoedges', index=21,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisscale', full_name='TSCH.Generated.ChartAxisGenericPropertyMapArchive.tschchartaxisscale', index=22,
      number=23, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisshowaxis', full_name='TSCH.Generated.ChartAxisGenericPropertyMapArchive.tschchartaxisshowaxis', index=23,
      number=24, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisshowlabels', full_name='TSCH.Generated.ChartAxisGenericPropertyMapArchive.tschchartaxisshowlabels', index=24,
      number=25, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisshowlastlabel', full_name='TSCH.Generated.ChartAxisGenericPropertyMapArchive.tschchartaxisshowlastlabel', index=25,
      number=26, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisshowmajorgridlines', full_name='TSCH.Generated.ChartAxisGenericPropertyMapArchive.tschchartaxisshowmajorgridlines', index=26,
      number=27, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisshowmajortickmarks', full_name='TSCH.Generated.ChartAxisGenericPropertyMapArchive.tschchartaxisshowmajortickmarks', index=27,
      number=28, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisshowminimumlabel', full_name='TSCH.Generated.ChartAxisGenericPropertyMapArchive.tschchartaxisshowminimumlabel', index=28,
      number=29, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisshowminorgridlines', full_name='TSCH.Generated.ChartAxisGenericPropertyMapArchive.tschchartaxisshowminorgridlines', index=29,
      number=30, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisshowminortickmarks', full_name='TSCH.Generated.ChartAxisGenericPropertyMapArchive.tschchartaxisshowminortickmarks', index=30,
      number=31, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisshowserieslabels', full_name='TSCH.Generated.ChartAxisGenericPropertyMapArchive.tschchartaxisshowserieslabels', index=31,
      number=32, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisshowtitle', full_name='TSCH.Generated.ChartAxisGenericPropertyMapArchive.tschchartaxisshowtitle', index=32,
      number=33, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxistickmarklocation', full_name='TSCH.Generated.ChartAxisGenericPropertyMapArchive.tschchartaxistickmarklocation', index=33,
      number=34, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxistitle', full_name='TSCH.Generated.ChartAxisGenericPropertyMapArchive.tschchartaxistitle', index=34,
      number=35, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxistitleparagraphstyleindex', full_name='TSCH.Generated.ChartAxisGenericPropertyMapArchive.tschchartaxistitleparagraphstyleindex', index=35,
      number=36, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisusermax', full_name='TSCH.Generated.ChartAxisGenericPropertyMapArchive.tschchartaxisusermax', index=36,
      number=37, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisusermin', full_name='TSCH.Generated.ChartAxisGenericPropertyMapArchive.tschchartaxisusermin', index=37,
      number=38, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisverticalspacing', full_name='TSCH.Generated.ChartAxisGenericPropertyMapArchive.tschchartaxisverticalspacing', index=38,
      number=39, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21044,
  serialized_end=22872,
)


_CHARTSERIESGENERICPROPERTYMAPARCHIVE = _descriptor.Descriptor(
  name='ChartSeriesGenericPropertyMapArchive',
  full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tschchartseries1_0dateformat', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseries1_0dateformat', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseries1_0numberformat', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseries1_0numberformat', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseries2_3labelexplosion', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseries2_3labelexplosion', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesadjustmentscale', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriesadjustmentscale', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriescalloutlineendlineend', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriescalloutlineendlineend', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriescalloutlinestartlineend', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriescalloutlinestartlineend', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriescalloutlinestrokestyle', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriescalloutlinestrokestyle', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdateformat', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriesdateformat', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdurationformat', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriesdurationformat', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesenablecalloutline', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriesenablecalloutline', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieserrorbarcustomnegativedata', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartserieserrorbarcustomnegativedata', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieserrorbarcustomnegativedatascatterx', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartserieserrorbarcustomnegativedatascatterx', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieserrorbarcustompositivedata', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartserieserrorbarcustompositivedata', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieserrorbarcustompositivedatascatterx', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartserieserrorbarcustompositivedatascatterx', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieserrorbarfixedvalue', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartserieserrorbarfixedvalue', index=14,
      number=15, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieserrorbarfixedvaluescatterx', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartserieserrorbarfixedvaluescatterx', index=15,
      number=16, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieserrorbarlineend', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartserieserrorbarlineend', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieserrorbarlineendscatterx', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartserieserrorbarlineendscatterx', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieserrorbarpercentvalue', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartserieserrorbarpercentvalue', index=18,
      number=19, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieserrorbarpercentvaluescatterx', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartserieserrorbarpercentvaluescatterx', index=19,
      number=20, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieserrorbarsetting', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartserieserrorbarsetting', index=20,
      number=21, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieserrorbarsettingscatterx', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartserieserrorbarsettingscatterx', index=21,
      number=22, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieserrorbarshadow', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartserieserrorbarshadow', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieserrorbarspacing', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartserieserrorbarspacing', index=23,
      number=24, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieserrorbarspacingscatterx', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartserieserrorbarspacingscatterx', index=24,
      number=25, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieserrorbarstddevvalue', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartserieserrorbarstddevvalue', index=25,
      number=26, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieserrorbarstddevvaluescatterx', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartserieserrorbarstddevvaluescatterx', index=26,
      number=27, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieserrorbarstroke', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartserieserrorbarstroke', index=27,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieserrorbarstrokescatterx', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartserieserrorbarstrokescatterx', index=28,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieserrorbartype', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartserieserrorbartype', index=29,
      number=30, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieserrorbartypescatterx', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartserieserrorbartypescatterx', index=30,
      number=31, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesfill', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriesfill', index=31,
      number=32, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieslabelexplosion', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartserieslabelexplosion', index=32,
      number=33, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieslabelparagraphstyleindex', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartserieslabelparagraphstyleindex', index=33,
      number=34, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieslinetype', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartserieslinetype', index=34,
      number=35, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesnumberformat', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriesnumberformat', index=35,
      number=36, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesnumberformattype', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriesnumberformattype', index=36,
      number=37, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesopacity', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriesopacity', index=37,
      number=38, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesoutsidelabelparagraphstyleindex', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriesoutsidelabelparagraphstyleindex', index=38,
      number=39, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriespercentnumberformat', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriespercentnumberformat', index=39,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesseriestype', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriesseriestype', index=40,
      number=41, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesshadow', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriesshadow', index=41,
      number=42, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesshowerrorbar', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriesshowerrorbar', index=42,
      number=43, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesshowerrorbarscatterx', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriesshowerrorbarscatterx', index=43,
      number=44, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesshowlabelsinfront', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriesshowlabelsinfront', index=44,
      number=45, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesshowline', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriesshowline', index=45,
      number=46, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesshownegativedata', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriesshownegativedata', index=46,
      number=47, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesshowserieslabels', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriesshowserieslabels', index=47,
      number=48, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesshowsymbol', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriesshowsymbol', index=48,
      number=49, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesshowtrendline', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriesshowtrendline', index=49,
      number=50, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesshowvaluelabels', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriesshowvaluelabels', index=50,
      number=51, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriessizedimension', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriessizedimension', index=51,
      number=52, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesstacklabels', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriesstacklabels', index=52,
      number=53, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesstroke', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriesstroke', index=53,
      number=54, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriessymbolfill', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriessymbolfill', index=54,
      number=55, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriessymbolfilluseseriesfill', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriessymbolfilluseseriesfill', index=55,
      number=56, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriessymbolfilluseseriesstroke', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriessymbolfilluseseriesstroke', index=56,
      number=57, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriessymbolsize', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriessymbolsize', index=57,
      number=58, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriessymbolstroke', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriessymbolstroke', index=58,
      number=59, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriessymboltype', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriessymboltype', index=59,
      number=60, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriestrendlineequationoffsetx', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriestrendlineequationoffsetx', index=60,
      number=61, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriestrendlineequationoffsety', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriestrendlineequationoffsety', index=61,
      number=62, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriestrendlinelabelstring', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriestrendlinelabelstring', index=62,
      number=63, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriestrendlineorder', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriestrendlineorder', index=63,
      number=64, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriestrendlineperiod', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriestrendlineperiod', index=64,
      number=65, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriestrendlinersquaredoffsetx', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriestrendlinersquaredoffsetx', index=65,
      number=66, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriestrendlinersquaredoffsety', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriestrendlinersquaredoffsety', index=66,
      number=67, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriestrendlineshadow', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriestrendlineshadow', index=67,
      number=68, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriestrendlineshowequation', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriestrendlineshowequation', index=68,
      number=69, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriestrendlineshowlabel', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriestrendlineshowlabel', index=69,
      number=70, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriestrendlineshowr2value', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriestrendlineshowr2value', index=70,
      number=71, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriestrendlinestroke', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriestrendlinestroke', index=71,
      number=72, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriestrendlinetype', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriestrendlinetype', index=72,
      number=73, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriestrendlineequationopacity', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriestrendlineequationopacity', index=73,
      number=74, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriestrendlineequationparagraphstyleindex', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriestrendlineequationparagraphstyleindex', index=74,
      number=75, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriestrendlinersquaredopacity', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriestrendlinersquaredopacity', index=75,
      number=76, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriestrendlinersquaredparagraphstyleindex', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriestrendlinersquaredparagraphstyleindex', index=76,
      number=77, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesvaluelabelposition', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriesvaluelabelposition', index=77,
      number=78, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesvaluelabelspacing', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriesvaluelabelspacing', index=78,
      number=79, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesvaluelabelsaxis', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriesvaluelabelsaxis', index=79,
      number=80, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieswedgeexplosion', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartserieswedgeexplosion', index=80,
      number=81, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesyaxisordinal', full_name='TSCH.Generated.ChartSeriesGenericPropertyMapArchive.tschchartseriesyaxisordinal', index=81,
      number=82, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22875,
  serialized_end=27057,
)


_REFERENCELINEGENERICPROPERTYMAPARCHIVE = _descriptor.Descriptor(
  name='ReferenceLineGenericPropertyMapArchive',
  full_name='TSCH.Generated.ReferenceLineGenericPropertyMapArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tschreferencelinecustomvalue', full_name='TSCH.Generated.ReferenceLineGenericPropertyMapArchive.tschreferencelinecustomvalue', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschreferencelinelabel', full_name='TSCH.Generated.ReferenceLineGenericPropertyMapArchive.tschreferencelinelabel', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschreferencelinelabelparagraphstyleindex', full_name='TSCH.Generated.ReferenceLineGenericPropertyMapArchive.tschreferencelinelabelparagraphstyleindex', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschreferencelineshadow', full_name='TSCH.Generated.ReferenceLineGenericPropertyMapArchive.tschreferencelineshadow', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschreferencelineshowlabel', full_name='TSCH.Generated.ReferenceLineGenericPropertyMapArchive.tschreferencelineshowlabel', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschreferencelineshowline', full_name='TSCH.Generated.ReferenceLineGenericPropertyMapArchive.tschreferencelineshowline', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschreferencelineshowvaluelabel', full_name='TSCH.Generated.ReferenceLineGenericPropertyMapArchive.tschreferencelineshowvaluelabel', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschreferencelinestroke', full_name='TSCH.Generated.ReferenceLineGenericPropertyMapArchive.tschreferencelinestroke', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschreferencelinetype', full_name='TSCH.Generated.ReferenceLineGenericPropertyMapArchive.tschreferencelinetype', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschreferencelinevaluelabelparagraphstyleindex', full_name='TSCH.Generated.ReferenceLineGenericPropertyMapArchive.tschreferencelinevaluelabelparagraphstyleindex', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27060,
  serialized_end=27561,
)

_CHARTSTYLEARCHIVE.fields_by_name['tschchartinfoarea3dlightingpackage'].message_type = TSCH3DArchives__pb2._CHART3DLIGHTINGPACKAGEARCHIVE
_CHARTSTYLEARCHIVE.fields_by_name['tschchartinfobar3dlightingpackage'].message_type = TSCH3DArchives__pb2._CHART3DLIGHTINGPACKAGEARCHIVE
_CHARTSTYLEARCHIVE.fields_by_name['tschchartinfocolumn3dlightingpackage'].message_type = TSCH3DArchives__pb2._CHART3DLIGHTINGPACKAGEARCHIVE
_CHARTSTYLEARCHIVE.fields_by_name['tschchartinfodefault3dlightingpackage'].message_type = TSCH3DArchives__pb2._CHART3DLIGHTINGPACKAGEARCHIVE
_CHARTSTYLEARCHIVE.fields_by_name['tschchartinfoline3dlightingpackage'].message_type = TSCH3DArchives__pb2._CHART3DLIGHTINGPACKAGEARCHIVE
_CHARTSTYLEARCHIVE.fields_by_name['tschchartinfopie3dlightingpackage'].message_type = TSCH3DArchives__pb2._CHART3DLIGHTINGPACKAGEARCHIVE
_CHARTSTYLEARCHIVE.fields_by_name['tschchartinfodefaultbackgroundfill'].message_type = TSDArchives__pb2._FILLARCHIVE
_CHARTSTYLEARCHIVE.fields_by_name['tschchartinfodefaultbackgroundstroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTSTYLEARCHIVE.fields_by_name['tschchartinfodefaultbordershadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTSTYLEARCHIVE.fields_by_name['tschchartinfodefaultborderstroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTSTYLEARCHIVE.fields_by_name['tschchartinfodefaultgridbackgroundfill'].message_type = TSDArchives__pb2._FILLARCHIVE
_CHARTSTYLEARCHIVE.fields_by_name['tschchartinfodefaulttitlecolor'].message_type = TSPMessages__pb2._COLOR
_CHARTNONSTYLEARCHIVE.fields_by_name['tschchartinfodefault3drotation'].message_type = TSCH3DArchives__pb2._CHART3DVECTORARCHIVE
_CHARTNONSTYLEARCHIVE.fields_by_name['tschchartinfoarea3dscale'].message_type = TSCH3DArchives__pb2._CHART3DVECTORARCHIVE
_CHARTNONSTYLEARCHIVE.fields_by_name['tschchartinfobar3dscale'].message_type = TSCH3DArchives__pb2._CHART3DVECTORARCHIVE
_CHARTNONSTYLEARCHIVE.fields_by_name['tschchartinfocolumn3dscale'].message_type = TSCH3DArchives__pb2._CHART3DVECTORARCHIVE
_CHARTNONSTYLEARCHIVE.fields_by_name['tschchartinfodefault3dscale'].message_type = TSCH3DArchives__pb2._CHART3DVECTORARCHIVE
_CHARTNONSTYLEARCHIVE.fields_by_name['tschchartinfoline3dscale'].message_type = TSCH3DArchives__pb2._CHART3DVECTORARCHIVE
_CHARTNONSTYLEARCHIVE.fields_by_name['tschchartinfopie3dscale'].message_type = TSCH3DArchives__pb2._CHART3DVECTORARCHIVE
_CHARTNONSTYLEARCHIVE.fields_by_name['tschchartinfodefault3dviewport'].message_type = TSCH3DArchives__pb2._CHART3DVECTORARCHIVE
_LEGENDSTYLEARCHIVE.fields_by_name['tschlegendmodeldefaultfill'].message_type = TSDArchives__pb2._FILLARCHIVE
_LEGENDSTYLEARCHIVE.fields_by_name['tschlegendmodeldefaultshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_LEGENDSTYLEARCHIVE.fields_by_name['tschlegendmodeldefaultstroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTAXISSTYLEARCHIVE.fields_by_name['tschchartaxiscategory3dgridlinestroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTAXISSTYLEARCHIVE.fields_by_name['tschchartaxisvalue3dgridlinestroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTAXISSTYLEARCHIVE.fields_by_name['tschchartaxiscategorymajorgridlineshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTAXISSTYLEARCHIVE.fields_by_name['tschchartaxisvaluemajorgridlineshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTAXISSTYLEARCHIVE.fields_by_name['tschchartaxiscategorymajorgridlinestroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTAXISSTYLEARCHIVE.fields_by_name['tschchartaxisvaluemajorgridlinestroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTAXISSTYLEARCHIVE.fields_by_name['tschchartaxiscategoryminorgridlineshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTAXISSTYLEARCHIVE.fields_by_name['tschchartaxisvalueminorgridlineshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTAXISSTYLEARCHIVE.fields_by_name['tschchartaxiscategoryminorgridlinestroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTAXISSTYLEARCHIVE.fields_by_name['tschchartaxisvalueminorgridlinestroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTAXISNONSTYLEARCHIVE.fields_by_name['tschchartaxisdefault1_0dateformat'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_CHARTAXISNONSTYLEARCHIVE.fields_by_name['tschchartaxisdefault1_0numberformat'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_CHARTAXISNONSTYLEARCHIVE.fields_by_name['tschchartaxisdefaultdateformat'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_CHARTAXISNONSTYLEARCHIVE.fields_by_name['tschchartaxisdefaultdurationformat'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_CHARTAXISNONSTYLEARCHIVE.fields_by_name['tschchartaxisdefaultnumberformat'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_CHARTAXISNONSTYLEARCHIVE.fields_by_name['tschchartaxisdefaultusermax'].message_type = TSCHArchives__Common__pb2._CHARTSNSNUMBERDOUBLEARCHIVE
_CHARTAXISNONSTYLEARCHIVE.fields_by_name['tschchartaxisdefaultusermin'].message_type = TSCHArchives__Common__pb2._CHARTSNSNUMBERDOUBLEARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesdefaultcalloutlineendlineend'].message_type = TSDArchives__pb2._LINEENDARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesdefaultcalloutlinestartlineend'].message_type = TSDArchives__pb2._LINEENDARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesdefaultcalloutlinestrokestyle'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesdefaulterrorbarlineend'].message_type = TSDArchives__pb2._LINEENDARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesdefaulterrorbarlineendscatterx'].message_type = TSDArchives__pb2._LINEENDARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesdefaulterrorbarshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesdefaulterrorbarstroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesdefaulterrorbarstrokescatterx'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseries3dareafill'].message_type = TSDArchives__pb2._FILLARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseries3dbarfill'].message_type = TSDArchives__pb2._FILLARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseries3dcolumnfill'].message_type = TSDArchives__pb2._FILLARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseries3dlinefill'].message_type = TSDArchives__pb2._FILLARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseries3dpiefill'].message_type = TSDArchives__pb2._FILLARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesareafill'].message_type = TSDArchives__pb2._FILLARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesbarfill'].message_type = TSDArchives__pb2._FILLARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriescolumnfill'].message_type = TSDArchives__pb2._FILLARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesdefaultfill'].message_type = TSDArchives__pb2._FILLARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesmixedareafill'].message_type = TSDArchives__pb2._FILLARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesmixedcolumnfill'].message_type = TSDArchives__pb2._FILLARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriespiefill'].message_type = TSDArchives__pb2._FILLARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseries3dareashadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseries3dbarshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseries3dcolumnshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseries3dlineshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseries3dpieshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesareashadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesbarshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesbubbleshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesdefaultshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartserieslineshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesmixedareashadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesmixedcolumnshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesmixedlineshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriespieshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesscattershadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesareastroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesbarstroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesbubblestroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartserieslinestroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesmixedareastroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesmixedcolumnstroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesmixedlinestroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriespiestroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesscatterstroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesareasymbolfill'].message_type = TSDArchives__pb2._FILLARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesbubblesymbolfill'].message_type = TSDArchives__pb2._FILLARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartserieslinesymbolfill'].message_type = TSDArchives__pb2._FILLARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesmixedareasymbolfill'].message_type = TSDArchives__pb2._FILLARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesmixedlinesymbolfill'].message_type = TSDArchives__pb2._FILLARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesscattersymbolfill'].message_type = TSDArchives__pb2._FILLARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesareasymbolstroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesbubblesymbolstroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartserieslinesymbolstroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesmixedareasymbolstroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesmixedlinesymbolstroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesscattersymbolstroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesdefaulttrendlineshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesdefaulttrendlinestroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTSERIESNONSTYLEARCHIVE.fields_by_name['tschchartseriesdefault1_0dateformat'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_CHARTSERIESNONSTYLEARCHIVE.fields_by_name['tschchartseriesdefault1_0numberformat'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_CHARTSERIESNONSTYLEARCHIVE.fields_by_name['tschchartseriespie1_0numberformat'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_CHARTSERIESNONSTYLEARCHIVE.fields_by_name['tschchartseriesdefaultdateformat'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_CHARTSERIESNONSTYLEARCHIVE.fields_by_name['tschchartseriesdefaultdurationformat'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_CHARTSERIESNONSTYLEARCHIVE.fields_by_name['tschchartseriesdefaulterrorbarcustomnegativedata'].message_type = TSCHArchives__Common__pb2._CHARTSNSARRAYOFNSNUMBERDOUBLEARCHIVE
_CHARTSERIESNONSTYLEARCHIVE.fields_by_name['tschchartseriesdefaulterrorbarcustomnegativedatascatterx'].message_type = TSCHArchives__Common__pb2._CHARTSNSARRAYOFNSNUMBERDOUBLEARCHIVE
_CHARTSERIESNONSTYLEARCHIVE.fields_by_name['tschchartseriesdefaulterrorbarcustompositivedata'].message_type = TSCHArchives__Common__pb2._CHARTSNSARRAYOFNSNUMBERDOUBLEARCHIVE
_CHARTSERIESNONSTYLEARCHIVE.fields_by_name['tschchartseriesdefaulterrorbarcustompositivedatascatterx'].message_type = TSCHArchives__Common__pb2._CHARTSNSARRAYOFNSNUMBERDOUBLEARCHIVE
_CHARTSERIESNONSTYLEARCHIVE.fields_by_name['tschchartseriesdefaultnumberformat'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_CHARTSERIESNONSTYLEARCHIVE.fields_by_name['tschchartseriespienumberformat'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_CHARTSERIESNONSTYLEARCHIVE.fields_by_name['tschchartseriesstackedpercentnumberformat'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_REFERENCELINESTYLEARCHIVE.fields_by_name['tschreferencelinedefaultshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_REFERENCELINESTYLEARCHIVE.fields_by_name['tschreferencelinedefaultstroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_REFERENCELINENONSTYLEARCHIVE.fields_by_name['tschreferencelinedefaultcustomvalue'].message_type = TSCHArchives__Common__pb2._CHARTSNSNUMBERDOUBLEARCHIVE
_CHARTGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartinfo3dlightingpackage'].message_type = TSCH3DArchives__pb2._CHART3DLIGHTINGPACKAGEARCHIVE
_CHARTGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartinfo3drotation'].message_type = TSCH3DArchives__pb2._CHART3DVECTORARCHIVE
_CHARTGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartinfo3dscale'].message_type = TSCH3DArchives__pb2._CHART3DVECTORARCHIVE
_CHARTGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartinfo3dviewport'].message_type = TSCH3DArchives__pb2._CHART3DVECTORARCHIVE
_CHARTGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartinfobackgroundfill'].message_type = TSDArchives__pb2._FILLARCHIVE
_CHARTGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartinfobackgroundstroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartinfobordershadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartinfoborderstroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartinfogridbackgroundfill'].message_type = TSDArchives__pb2._FILLARCHIVE
_CHARTGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartinfotitlecolor'].message_type = TSPMessages__pb2._COLOR
_LEGENDGENERICPROPERTYMAPARCHIVE.fields_by_name['tschlegendmodelfill'].message_type = TSDArchives__pb2._FILLARCHIVE
_LEGENDGENERICPROPERTYMAPARCHIVE.fields_by_name['tschlegendmodelshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_LEGENDGENERICPROPERTYMAPARCHIVE.fields_by_name['tschlegendmodelstroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTAXISGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartaxis1_0dateformat'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_CHARTAXISGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartaxis1_0numberformat'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_CHARTAXISGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartaxis3dgridlinestroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTAXISGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartaxisdateformat'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_CHARTAXISGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartaxisdurationformat'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_CHARTAXISGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartaxismajorgridlineshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTAXISGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartaxismajorgridlinestroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTAXISGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartaxisminorgridlineshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTAXISGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartaxisminorgridlinestroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTAXISGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartaxisnumberformat'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_CHARTAXISGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartaxisusermax'].message_type = TSCHArchives__Common__pb2._CHARTSNSNUMBERDOUBLEARCHIVE
_CHARTAXISGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartaxisusermin'].message_type = TSCHArchives__Common__pb2._CHARTSNSNUMBERDOUBLEARCHIVE
_CHARTSERIESGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartseries1_0dateformat'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_CHARTSERIESGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartseries1_0numberformat'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_CHARTSERIESGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartseriescalloutlineendlineend'].message_type = TSDArchives__pb2._LINEENDARCHIVE
_CHARTSERIESGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartseriescalloutlinestartlineend'].message_type = TSDArchives__pb2._LINEENDARCHIVE
_CHARTSERIESGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartseriescalloutlinestrokestyle'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTSERIESGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartseriesdateformat'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_CHARTSERIESGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartseriesdurationformat'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_CHARTSERIESGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartserieserrorbarcustomnegativedata'].message_type = TSCHArchives__Common__pb2._CHARTSNSARRAYOFNSNUMBERDOUBLEARCHIVE
_CHARTSERIESGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartserieserrorbarcustomnegativedatascatterx'].message_type = TSCHArchives__Common__pb2._CHARTSNSARRAYOFNSNUMBERDOUBLEARCHIVE
_CHARTSERIESGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartserieserrorbarcustompositivedata'].message_type = TSCHArchives__Common__pb2._CHARTSNSARRAYOFNSNUMBERDOUBLEARCHIVE
_CHARTSERIESGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartserieserrorbarcustompositivedatascatterx'].message_type = TSCHArchives__Common__pb2._CHARTSNSARRAYOFNSNUMBERDOUBLEARCHIVE
_CHARTSERIESGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartserieserrorbarlineend'].message_type = TSDArchives__pb2._LINEENDARCHIVE
_CHARTSERIESGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartserieserrorbarlineendscatterx'].message_type = TSDArchives__pb2._LINEENDARCHIVE
_CHARTSERIESGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartserieserrorbarshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTSERIESGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartserieserrorbarstroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTSERIESGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartserieserrorbarstrokescatterx'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTSERIESGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartseriesfill'].message_type = TSDArchives__pb2._FILLARCHIVE
_CHARTSERIESGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartseriesnumberformat'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_CHARTSERIESGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartseriespercentnumberformat'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_CHARTSERIESGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartseriesshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTSERIESGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartseriesstroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTSERIESGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartseriessymbolfill'].message_type = TSDArchives__pb2._FILLARCHIVE
_CHARTSERIESGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartseriessymbolstroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTSERIESGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartseriestrendlineshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTSERIESGENERICPROPERTYMAPARCHIVE.fields_by_name['tschchartseriestrendlinestroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_REFERENCELINEGENERICPROPERTYMAPARCHIVE.fields_by_name['tschreferencelinecustomvalue'].message_type = TSCHArchives__Common__pb2._CHARTSNSNUMBERDOUBLEARCHIVE
_REFERENCELINEGENERICPROPERTYMAPARCHIVE.fields_by_name['tschreferencelineshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_REFERENCELINEGENERICPROPERTYMAPARCHIVE.fields_by_name['tschreferencelinestroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
DESCRIPTOR.message_types_by_name['ChartStyleArchive'] = _CHARTSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['ChartNonStyleArchive'] = _CHARTNONSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['LegendStyleArchive'] = _LEGENDSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['LegendNonStyleArchive'] = _LEGENDNONSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['ChartAxisStyleArchive'] = _CHARTAXISSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['ChartAxisNonStyleArchive'] = _CHARTAXISNONSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['ChartSeriesStyleArchive'] = _CHARTSERIESSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['ChartSeriesNonStyleArchive'] = _CHARTSERIESNONSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['ReferenceLineStyleArchive'] = _REFERENCELINESTYLEARCHIVE
DESCRIPTOR.message_types_by_name['ReferenceLineNonStyleArchive'] = _REFERENCELINENONSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['ChartGenericPropertyMapArchive'] = _CHARTGENERICPROPERTYMAPARCHIVE
DESCRIPTOR.message_types_by_name['LegendGenericPropertyMapArchive'] = _LEGENDGENERICPROPERTYMAPARCHIVE
DESCRIPTOR.message_types_by_name['ChartAxisGenericPropertyMapArchive'] = _CHARTAXISGENERICPROPERTYMAPARCHIVE
DESCRIPTOR.message_types_by_name['ChartSeriesGenericPropertyMapArchive'] = _CHARTSERIESGENERICPROPERTYMAPARCHIVE
DESCRIPTOR.message_types_by_name['ReferenceLineGenericPropertyMapArchive'] = _REFERENCELINEGENERICPROPERTYMAPARCHIVE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ChartStyleArchive = _reflection.GeneratedProtocolMessageType('ChartStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTSTYLEARCHIVE,
  __module__ = 'TSCHArchives_GEN_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.Generated.ChartStyleArchive)
  ))
_sym_db.RegisterMessage(ChartStyleArchive)

ChartNonStyleArchive = _reflection.GeneratedProtocolMessageType('ChartNonStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTNONSTYLEARCHIVE,
  __module__ = 'TSCHArchives_GEN_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.Generated.ChartNonStyleArchive)
  ))
_sym_db.RegisterMessage(ChartNonStyleArchive)

LegendStyleArchive = _reflection.GeneratedProtocolMessageType('LegendStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _LEGENDSTYLEARCHIVE,
  __module__ = 'TSCHArchives_GEN_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.Generated.LegendStyleArchive)
  ))
_sym_db.RegisterMessage(LegendStyleArchive)

LegendNonStyleArchive = _reflection.GeneratedProtocolMessageType('LegendNonStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _LEGENDNONSTYLEARCHIVE,
  __module__ = 'TSCHArchives_GEN_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.Generated.LegendNonStyleArchive)
  ))
_sym_db.RegisterMessage(LegendNonStyleArchive)

ChartAxisStyleArchive = _reflection.GeneratedProtocolMessageType('ChartAxisStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTAXISSTYLEARCHIVE,
  __module__ = 'TSCHArchives_GEN_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.Generated.ChartAxisStyleArchive)
  ))
_sym_db.RegisterMessage(ChartAxisStyleArchive)

ChartAxisNonStyleArchive = _reflection.GeneratedProtocolMessageType('ChartAxisNonStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTAXISNONSTYLEARCHIVE,
  __module__ = 'TSCHArchives_GEN_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.Generated.ChartAxisNonStyleArchive)
  ))
_sym_db.RegisterMessage(ChartAxisNonStyleArchive)

ChartSeriesStyleArchive = _reflection.GeneratedProtocolMessageType('ChartSeriesStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTSERIESSTYLEARCHIVE,
  __module__ = 'TSCHArchives_GEN_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.Generated.ChartSeriesStyleArchive)
  ))
_sym_db.RegisterMessage(ChartSeriesStyleArchive)

ChartSeriesNonStyleArchive = _reflection.GeneratedProtocolMessageType('ChartSeriesNonStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTSERIESNONSTYLEARCHIVE,
  __module__ = 'TSCHArchives_GEN_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.Generated.ChartSeriesNonStyleArchive)
  ))
_sym_db.RegisterMessage(ChartSeriesNonStyleArchive)

ReferenceLineStyleArchive = _reflection.GeneratedProtocolMessageType('ReferenceLineStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _REFERENCELINESTYLEARCHIVE,
  __module__ = 'TSCHArchives_GEN_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.Generated.ReferenceLineStyleArchive)
  ))
_sym_db.RegisterMessage(ReferenceLineStyleArchive)

ReferenceLineNonStyleArchive = _reflection.GeneratedProtocolMessageType('ReferenceLineNonStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _REFERENCELINENONSTYLEARCHIVE,
  __module__ = 'TSCHArchives_GEN_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.Generated.ReferenceLineNonStyleArchive)
  ))
_sym_db.RegisterMessage(ReferenceLineNonStyleArchive)

ChartGenericPropertyMapArchive = _reflection.GeneratedProtocolMessageType('ChartGenericPropertyMapArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTGENERICPROPERTYMAPARCHIVE,
  __module__ = 'TSCHArchives_GEN_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.Generated.ChartGenericPropertyMapArchive)
  ))
_sym_db.RegisterMessage(ChartGenericPropertyMapArchive)

LegendGenericPropertyMapArchive = _reflection.GeneratedProtocolMessageType('LegendGenericPropertyMapArchive', (_message.Message,), dict(
  DESCRIPTOR = _LEGENDGENERICPROPERTYMAPARCHIVE,
  __module__ = 'TSCHArchives_GEN_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.Generated.LegendGenericPropertyMapArchive)
  ))
_sym_db.RegisterMessage(LegendGenericPropertyMapArchive)

ChartAxisGenericPropertyMapArchive = _reflection.GeneratedProtocolMessageType('ChartAxisGenericPropertyMapArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTAXISGENERICPROPERTYMAPARCHIVE,
  __module__ = 'TSCHArchives_GEN_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.Generated.ChartAxisGenericPropertyMapArchive)
  ))
_sym_db.RegisterMessage(ChartAxisGenericPropertyMapArchive)

ChartSeriesGenericPropertyMapArchive = _reflection.GeneratedProtocolMessageType('ChartSeriesGenericPropertyMapArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTSERIESGENERICPROPERTYMAPARCHIVE,
  __module__ = 'TSCHArchives_GEN_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.Generated.ChartSeriesGenericPropertyMapArchive)
  ))
_sym_db.RegisterMessage(ChartSeriesGenericPropertyMapArchive)

ReferenceLineGenericPropertyMapArchive = _reflection.GeneratedProtocolMessageType('ReferenceLineGenericPropertyMapArchive', (_message.Message,), dict(
  DESCRIPTOR = _REFERENCELINEGENERICPROPERTYMAPARCHIVE,
  __module__ = 'TSCHArchives_GEN_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.Generated.ReferenceLineGenericPropertyMapArchive)
  ))
_sym_db.RegisterMessage(ReferenceLineGenericPropertyMapArchive)

_CHARTSTYLEARCHIVE.extensions_by_name['current'].message_type = _CHARTSTYLEARCHIVE
TSCHArchives__Common__pb2.ChartStyleArchive.RegisterExtension(_CHARTSTYLEARCHIVE.extensions_by_name['current'])
_CHARTNONSTYLEARCHIVE.extensions_by_name['current'].message_type = _CHARTNONSTYLEARCHIVE
TSCHArchives__Common__pb2.ChartNonStyleArchive.RegisterExtension(_CHARTNONSTYLEARCHIVE.extensions_by_name['current'])
_LEGENDSTYLEARCHIVE.extensions_by_name['current'].message_type = _LEGENDSTYLEARCHIVE
TSCHArchives__Common__pb2.LegendStyleArchive.RegisterExtension(_LEGENDSTYLEARCHIVE.extensions_by_name['current'])
_LEGENDNONSTYLEARCHIVE.extensions_by_name['current'].message_type = _LEGENDNONSTYLEARCHIVE
TSCHArchives__Common__pb2.LegendNonStyleArchive.RegisterExtension(_LEGENDNONSTYLEARCHIVE.extensions_by_name['current'])
_CHARTAXISSTYLEARCHIVE.extensions_by_name['current'].message_type = _CHARTAXISSTYLEARCHIVE
TSCHArchives__Common__pb2.ChartAxisStyleArchive.RegisterExtension(_CHARTAXISSTYLEARCHIVE.extensions_by_name['current'])
_CHARTAXISNONSTYLEARCHIVE.extensions_by_name['current'].message_type = _CHARTAXISNONSTYLEARCHIVE
TSCHArchives__Common__pb2.ChartAxisNonStyleArchive.RegisterExtension(_CHARTAXISNONSTYLEARCHIVE.extensions_by_name['current'])
_CHARTSERIESSTYLEARCHIVE.extensions_by_name['current'].message_type = _CHARTSERIESSTYLEARCHIVE
TSCHArchives__Common__pb2.ChartSeriesStyleArchive.RegisterExtension(_CHARTSERIESSTYLEARCHIVE.extensions_by_name['current'])
_CHARTSERIESNONSTYLEARCHIVE.extensions_by_name['current'].message_type = _CHARTSERIESNONSTYLEARCHIVE
TSCHArchives__Common__pb2.ChartSeriesNonStyleArchive.RegisterExtension(_CHARTSERIESNONSTYLEARCHIVE.extensions_by_name['current'])
_REFERENCELINESTYLEARCHIVE.extensions_by_name['current'].message_type = _REFERENCELINESTYLEARCHIVE
TSCHArchives__Common__pb2.ReferenceLineStyleArchive.RegisterExtension(_REFERENCELINESTYLEARCHIVE.extensions_by_name['current'])
_REFERENCELINENONSTYLEARCHIVE.extensions_by_name['current'].message_type = _REFERENCELINENONSTYLEARCHIVE
TSCHArchives__Common__pb2.ReferenceLineNonStyleArchive.RegisterExtension(_REFERENCELINENONSTYLEARCHIVE.extensions_by_name['current'])

# @@protoc_insertion_point(module_scope)
