from __future__ import absolute_import
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: TSTCommandArchives.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import TSPMessages_pb2 as TSPMessages__pb2
from . import TSDArchives_pb2 as TSDArchives__pb2
from . import TSDCommandArchives_pb2 as TSDCommandArchives__pb2
from . import TSKArchives_pb2 as TSKArchives__pb2
from . import TSSArchives_pb2 as TSSArchives__pb2
from . import TSCEArchives_pb2 as TSCEArchives__pb2
from . import TSWPArchives_pb2 as TSWPArchives__pb2
from . import TSTArchives_pb2 as TSTArchives__pb2
from . import TSTArchives_sos_pb2 as TSTArchives__sos__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='TSTCommandArchives.proto',
  package='TST',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x18TSTCommandArchives.proto\x12\x03TST\x1a\x11TSPMessages.proto\x1a\x11TSDArchives.proto\x1a\x18TSDCommandArchives.proto\x1a\x11TSKArchives.proto\x1a\x11TSSArchives.proto\x1a\x12TSCEArchives.proto\x1a\x12TSWPArchives.proto\x1a\x11TSTArchives.proto\x1a\x15TSTArchives_sos.proto\"\xb7\x02\n\x13TableCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12)\n\x12table_info_id_path\x18\x02 \x02(\x0b\x32\r.TSP.UUIDPath\x12\x13\n\x0b\x63ommandname\x18\x03 \x01(\t\x12\x35\n\x1d\x64\x65\x66\x61ult_cell_styles_container\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\x12\x11\n\ttimestamp\x18\x05 \x01(\x01\x12\x16\n\x0erandom_seed_lo\x18\x06 \x01(\r\x12\x16\n\x0erandom_seed_hi\x18\x07 \x01(\r\x12\x12\n\nis_inverse\x18\x08 \x01(\x08\x12\x15\n\rold_timestamp\x18\t \x01(\x01\x12\x17\n\x0fold_random_seed\x18\n \x01(\x04\"\xdf\x01\n\x1f\x43ommandApplyCellContentsArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12%\n\rcell_diff_map\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12.\n\x16rollback_cell_diff_map\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12%\n\x12\x63ustom_format_keys\x18\x04 \x03(\x0b\x32\t.TSP.UUID\x12\x15\n\raction_string\x18\x05 \x01(\t\"\xec\x01\n\x1e\x43ommandApplyCellDiffMapArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12%\n\rcell_diff_map\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12$\n\x1cshould_allow_merge_fragments\x18\x03 \x02(\x08\x12-\n\x15inverse_cell_diff_map\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\x12%\n\x12\x63ustom_format_keys\x18\x05 \x03(\x0b\x32\t.TSP.UUID\"\xdd\x02\n\x1a\x43ommandApplyCellMapArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12%\n\rredo_cell_map\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12%\n\rundo_cell_map\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12\x34\n\x1cundo_formula_rewrite_command\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\x12%\n\x12\x63ustom_format_keys\x18\x05 \x03(\x0b\x32\t.TSP.UUID\x12\"\n\x1amerge_owner_rollback_index\x18\x06 \x01(\r\x12\x15\n\ris_from_paste\x18\x07 \x02(\x08\x12\x30\n\x18\x66ormula_rewrite_commands\x18\x08 \x03(\x0b\x32\x0e.TSP.Reference\"\xfd\x02\n$CommandApplyConcurrentCellMapArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12\x30\n\x18redo_concurrent_cell_map\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12\x30\n\x18undo_concurrent_cell_map\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12\x34\n\x1cundo_formula_rewrite_command\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\x12%\n\x12\x63ustom_format_keys\x18\x05 \x03(\x0b\x32\t.TSP.UUID\x12\"\n\x1amerge_owner_rollback_index\x18\x06 \x01(\r\x12\x15\n\ris_from_paste\x18\x07 \x02(\x08\x12\x30\n\x18\x66ormula_rewrite_commands\x18\x08 \x03(\x0b\x32\x0e.TSP.Reference\"\xb4\x01\n%CommandChangeFreezeHeaderStateArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12-\n\tdirection\x18\x02 \x02(\x0e\x32\x1a.TST.TableDimensionArchive\x12\x18\n\x10new_freeze_state\x18\x03 \x02(\x08\x12\x19\n\x11prev_freeze_state\x18\x04 \x02(\x08\"\xc7\x02\n\x19\x43ommandDeleteCellsArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12 \n\x18update_border_visibility\x18\x04 \x01(\x08\x12\x1b\n\x13invalidate_comments\x18\x05 \x01(\x08\x12!\n\x19invalidate_comments_valid\x18\x06 \x01(\x08\x12\x32\n\x0f\x63\x65ll_uid_region\x18\x07 \x01(\x0b\x32\x19.TST.CellUIDRegionArchive\x12\x36\n\x15summary_cell_uid_list\x18\x08 \x01(\x0b\x32\x17.TST.CellUIDListArchive\x12\x33\n\x1binverse_concurrent_cell_map\x18\t \x01(\x0b\x32\x0e.TSP.Reference\"\xaa\x01\n CommandDeleteCellContentsArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12.\n\rcell_uid_list\x18\x02 \x02(\x0b\x32\x17.TST.CellUIDListArchive\x12-\n\x15inverse_cell_diff_map\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\"\xf5\x01\n\x1e\x43ommandMutateCellFormatArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12.\n\rcell_uid_list\x18\x02 \x01(\x0b\x32\x17.TST.CellUIDListArchive\x12-\n\x15inverse_cell_diff_map\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12-\n\x15whole_format_diff_map\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\x12\x1c\n\x14intended_format_type\x18\x05 \x02(\r\"v\n\'CommandSetAutomaticDurationUnitsArchive\x12\x32\n\x05super\x18\x01 \x02(\x0b\x32#.TST.CommandMutateCellFormatArchive\x12\x17\n\x0f\x61utomatic_units\x18\x04 \x01(\x08\"l\n\x1e\x43ommandSetDurationStyleArchive\x12\x32\n\x05super\x18\x01 \x02(\x0b\x32#.TST.CommandMutateCellFormatArchive\x12\x16\n\x0e\x64uration_style\x18\x02 \x01(\r\"\x8f\x01\n,CommandSetDurationUnitSmallestLargestArchive\x12\x32\n\x05super\x18\x01 \x02(\x0b\x32#.TST.CommandMutateCellFormatArchive\x12\x15\n\rsmallest_unit\x18\x02 \x01(\r\x12\x14\n\x0clargest_unit\x18\x03 \x01(\r\"\x9c\x01\n!CommandReplaceCustomFormatArchive\x12%\n\rundo_diff_map\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\x12\'\n\x0f\x63ommit_diff_map\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12\'\n\x05super\x18\x06 \x02(\x0b\x32\x18.TST.TableCommandArchive\"\xe0\x05\n\x17\x43ommandMoveCellsArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12-\n\x16\x64st_table_info_id_path\x18\x02 \x02(\x0b\x32\r.TSP.UUIDPath\x12+\n\rsrc_uid_range\x18\x03 \x02(\x0b\x32\x14.TSP.UUIDRectArchive\x12+\n\rdst_uid_range\x18\x04 \x02(\x0b\x32\x14.TSP.UUIDRectArchive\x12\x33\n\x0ftable_dimension\x18\x05 \x01(\x0e\x32\x1a.TST.TableDimensionArchive\x12$\n\x0csrc_cell_map\x18\x06 \x02(\x0b\x32\x0e.TSP.Reference\x12$\n\x0c\x64st_cell_map\x18\x07 \x01(\x0b\x32\x0e.TSP.Reference\x12\x31\n\x19\x64st_cell_styles_container\x18\x08 \x01(\x0b\x32\x0e.TSP.Reference\x12)\n\x11src_undo_cell_map\x18\t \x01(\x0b\x32\x0e.TSP.Reference\x12)\n\x11\x64st_undo_cell_map\x18\n \x01(\x0b\x32\x0e.TSP.Reference\x12&\n\x1e\x64st_merge_owner_rollback_index\x18\x0b \x02(\r\x12\x30\n\x18\x66ormula_rewrite_commands\x18\x0c \x03(\x0b\x32\x0e.TSP.Reference\x12;\n\x17merge_action_to_restore\x18\r \x01(\x0b\x32\x1a.TST.MergeOperationArchive\x12=\n\x1c\x63omment_cell_uids_to_restore\x18\x0e \x01(\x0b\x32\x17.TST.CellUIDListArchive\x12\x33\n\x1b\x63omment_storages_to_restore\x18\x0f \x03(\x0b\x32\x0e.TSP.Reference\"\xa0\x01\n\x18\x43olumnRowMetadataArchive\x12\x0c\n\x04size\x18\x01 \x02(\x01\x12\x15\n\rhiding_action\x18\x02 \x02(\r\x12\"\n\ncell_style\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12\"\n\ntext_style\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\x12\x17\n\x04uuid\x18\x05 \x01(\x0b\x32\t.TSP.UUID\"\xf1\x03\n!CommandInsertColumnsOrRowsArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12+\n\x06\x62undle\x18\x02 \x02(\x0b\x32\x1b.TST.ColumnRowBundleArchive\x12 \n\x08\x63\x65ll_map\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12%\n\rundo_commands\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\x12%\n\rundo_cell_map\x18\x05 \x01(\x0b\x32\x0e.TSP.Reference\x12\x31\n\nsort_order\x18\x06 \x01(\x0b\x32\x1d.TST.TableSortOrderUIDArchive\x12\"\n\nfilter_set\x18\x07 \x01(\x0b\x32\x0e.TSP.Reference\x12)\n!should_edge_expand_formula_ranges\x18\x08 \x01(\x08\x12\x17\n\x0fwas_categorized\x18\t \x01(\x08\x12\x1d\n\nundo_order\x18\n \x03(\x0b\x32\t.TSP.UUID\x12%\n\x12src_row_column_uid\x18\x0b \x02(\x0b\x32\t.TSP.UUID\x12%\n\x12opp_row_column_uid\x18\x0c \x02(\x0b\x32\t.TSP.UUID\"\xe8\x02\n\x16\x43olumnRowBundleArchive\x12\x0e\n\x06is_row\x18\x01 \x02(\x08\x12 \n\rview_uid_list\x18\x02 \x03(\x0b\x32\t.TSP.UUID\x12.\n\x0eview_type_list\x18\x03 \x03(\x0e\x32\x16.TST.ColumnRowTypeEnum\x12 \n\rbase_uid_list\x18\x04 \x03(\x0b\x32\t.TSP.UUID\x12.\n\x0e\x62\x61se_type_list\x18\x05 \x03(\x0e\x32\x16.TST.ColumnRowTypeEnum\x12*\n\x17\x63\x61tegory_order_uid_list\x18\x06 \x03(\x0b\x32\t.TSP.UUID\x12\x38\n\x18\x63\x61tegory_order_type_list\x18\x07 \x03(\x0e\x32\x16.TST.ColumnRowTypeEnum\x12\x34\n\rmetadata_list\x18\x08 \x03(\x0b\x32\x1d.TST.ColumnRowMetadataArchive\"\xaf\x03\n!CommandRemoveColumnsOrRowsArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12+\n\x06\x62undle\x18\x02 \x02(\x0b\x32\x1b.TST.ColumnRowBundleArchive\x12 \n\x08\x63\x65ll_map\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12%\n\rundo_cell_map\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\x12\'\n\x0fundo_filter_set\x18\x05 \x01(\x0b\x32\x0e.TSP.Reference\x12\x36\n\x0fundo_sort_order\x18\x06 \x01(\x0b\x32\x1d.TST.TableSortOrderUIDArchive\x12\x38\n formula_rewrite_command_for_undo\x18\x07 \x01(\x0b\x32\x0e.TSP.Reference\x12\x31\n)inverse_should_edge_expand_formula_ranges\x18\x08 \x01(\x08\x12\x1d\n\nundo_order\x18\t \x03(\x0b\x32\t.TSP.UUID\"p\n\x1c\x43ommandRowColumnRangeArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12\x17\n\x04uids\x18\x02 \x03(\x0b\x32\t.TSP.UUID\x12\x0e\n\x06is_row\x18\x03 \x02(\x08\"z\n\x1f\x43ommandResizeColumnOrRowArchive\x12\x30\n\x05super\x18\x01 \x02(\x0b\x32!.TST.CommandRowColumnRangeArchive\x12\r\n\x05sizes\x18\x02 \x03(\x02\x12\x16\n\x0esizes_for_undo\x18\x03 \x03(\x02\"\xa5\x02\n\'CommandCategoryResizeColumnOrRowArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12\x1a\n\x12\x63\x61tegory_row_sizes\x18\x02 \x03(\x02\x12#\n\x1b\x63\x61tegory_row_sizes_for_undo\x18\x03 \x03(\x02\x12 \n\x18\x63\x61tegory_label_row_sizes\x18\x04 \x03(\x02\x12)\n!category_label_row_sizes_for_undo\x18\x05 \x03(\x02\x12\x1c\n\x14\x63\x61tegory_column_size\x18\x06 \x01(\x01\x12%\n\x1d\x63\x61tegory_column_size_for_undo\x18\x07 \x01(\x01\"\xd6\x01\n\x16\x43ommandHideShowArchive\x12\x30\n\x05super\x18\x01 \x02(\x0b\x32!.TST.CommandRowColumnRangeArchive\x12\x34\n\x10hide_show_action\x18\x02 \x02(\x0e\x32\x1a.TST.HideShowActionArchive\x12\x15\n\rhiding_action\x18\x03 \x02(\r\x12=\n\x19hide_show_action_for_undo\x18\x04 \x03(\x0e\x32\x1a.TST.HideShowActionArchive\"\xa2\x03\n%CommandTextPreflightInsertCellArchive\x12\'\n\x05super\x18\x03 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12-\n\x15\x63oalesced_textcommand\x18\x06 \x01(\x0b\x32\x0e.TSP.Reference\x12)\n\x11postflightcommand\x18\x08 \x01(\x0b\x32\x0e.TSP.Reference\x12\x1f\n\x17grouped_with_postflight\x18\t \x01(\x08\x12\x1f\n\x0c\x65\x64iting_cell\x18\n \x02(\x0b\x32\t.TST.Cell\x12\'\n\x0f\x65\x64iting_storage\x18\x0b \x02(\x0b\x32\x0e.TSP.Reference\x12\x1e\n\x16last_column_hit_by_tap\x18\x0c \x01(\r\x12\'\n\x08\x63\x65ll_uid\x18\r \x02(\x0b\x32\x15.TSP.UUIDCoordArchive\x12\x42\n\x1f\x61rchived_initial_selection_path\x18\x0e \x01(\x0b\x32\x19.TSK.SelectionPathArchive\"\xa4\x02\n\x1f\x43ommandPostflightSetCellArchive\x12\'\n\x05super\x18\x03 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12(\n\x10\x63hildcommandundo\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\x12\x1f\n\x0c\x65\x64iting_cell\x18\x06 \x02(\x0b\x32\t.TST.Cell\x12\x1b\n\x08new_cell\x18\x07 \x02(\x0b\x32\t.TST.Cell\x12\'\n\x0f\x65\x64iting_storage\x18\x08 \x02(\x0b\x32\x0e.TSP.Reference\x12\x1e\n\x16last_column_hit_by_tap\x18\t \x01(\r\x12\'\n\x08\x63\x65ll_uid\x18\n \x02(\x0b\x32\x15.TSP.UUIDCoordArchive\"\xa9\x02\n+CommandChangeTableAreaForColumnOrRowArchive\x12\x30\n\x05super\x18\x01 \x02(\x0b\x32!.TST.CommandRowColumnRangeArchive\x12\x37\n\x15table_area_transition\x18\x02 \x02(\x0e\x32\x18.TST.TableAreaTransition\x12%\n\rcell_diff_map\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12*\n\x12undo_cell_diff_map\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\x12%\n\rundo_commands\x18\x05 \x01(\x0b\x32\x0e.TSP.Reference\x12\x15\n\raction_string\x18\x06 \x01(\t\"\x9c\x02\n\"CommandSetPencilAnnotationsArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12#\n\x0b\x61nnotations\x18\x02 \x03(\x0b\x32\x0e.TSP.Reference\x12&\n\x08\x66ormulas\x18\x03 \x03(\x0b\x32\x14.TSCE.FormulaArchive\x12\x17\n\x0f\x66ormula_indexes\x18\x04 \x03(\x04\x12.\n\x10inverse_formulas\x18\x05 \x03(\x0b\x32\x14.TSCE.FormulaArchive\x12\x1f\n\x17inverse_formula_indexes\x18\x06 \x03(\x04\x12\x16\n\x0erollback_index\x18\x07 \x01(\x04\"\xd5\x02\n\x1a\x43ommandSetTableNameArchive\x12\x14\n\x0cnewtablename\x18\x01 \x02(\t\x12\x14\n\x0coldtablename\x18\x02 \x01(\t\x12 \n\x08newstyle\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12 \n\x08oldstyle\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\x12\'\n\x05super\x18\x05 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12\'\n\x0fold_shape_style\x18\x06 \x01(\x0b\x32\x0e.TSP.Reference\x12\'\n\x0fnew_shape_style\x18\x07 \x01(\x0b\x32\x0e.TSP.Reference\x12%\n\x1dold_table_name_border_enabled\x18\x08 \x01(\x08\x12%\n\x1dnew_table_name_border_enabled\x18\t \x01(\x08\"\x89\x01\n!CommandSetTableNameEnabledArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12\x1a\n\x12table_name_enabled\x18\x02 \x02(\x08\x12\x1f\n\x17prev_table_name_enabled\x18\x03 \x01(\x08\"\xab\x02\n\x1e\x43ommandSetTableFontSizeArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12\x13\n\x0bis_increase\x18\x02 \x02(\x08\x12\x16\n\x0e\x66ont_size_diff\x18\x03 \x02(\x05\x12\x16\n\x0e\x66ont_size_list\x18\x04 \x03(\x01\x12\x1e\n\x16inverse_font_size_list\x18\x05 \x03(\x01\x12%\n\rcell_diff_map\x18\x06 \x01(\x0b\x32\x0e.TSP.Reference\x12-\n\x15inverse_cell_diff_map\x18\x07 \x01(\x0b\x32\x0e.TSP.Reference\x12%\n\x1dstyles_container_refresh_done\x18\x08 \x02(\x08\"\xc1\x02\n\x1e\x43ommandSetTableFontNameArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12\x11\n\tfont_name\x18\x02 \x02(\t\x12\x15\n\rpreserve_face\x18\x03 \x02(\x08\x12\x1a\n\x12previous_font_name\x18\x04 \x01(\t\x12,\n\x14previous_table_style\x18\x05 \x01(\x0b\x32\x0e.TSP.Reference\x12,\n\x14previous_text_styles\x18\x06 \x03(\x0b\x32\x0e.TSP.Reference\x12%\n\rcell_diff_map\x18\x07 \x02(\x0b\x32\x0e.TSP.Reference\x12-\n\x15inverse_cell_diff_map\x18\x08 \x01(\x0b\x32\x0e.TSP.Reference\"\x89\x01\n CommandSetTableNameHeightArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12\x1d\n\x15old_table_name_height\x18\x02 \x02(\x01\x12\x1d\n\x15new_table_name_height\x18\x03 \x02(\x01\"?\n\x14\x43ommandSetNowArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\"\x85\x02\n\x17\x43ommandSetWasCutArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12!\n\x0e\x66rom_table_uid\x18\x02 \x02(\x0b\x32\t.TSP.UUID\x12&\n\x13prev_from_table_uid\x18\x03 \x02(\x0b\x32\t.TSP.UUID\x12\x0f\n\x07was_cut\x18\x04 \x02(\x08\x12\x14\n\x0cprev_was_cut\x18\x05 \x02(\x08\x12$\n\x11\x66rom_group_by_uid\x18\x06 \x02(\x0b\x32\t.TSP.UUID\x12)\n\x16prev_from_group_by_uid\x18\x07 \x02(\x0b\x32\t.TSP.UUID\"\x93\x02\n\x18\x43ommandStyleCellsArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12\x33\n\x11\x66ormat_properties\x18\x02 \x01(\x0b\x32\x18.TSP.ReferenceDictionary\x12(\n\tselection\x18\x03 \x02(\x0b\x32\x15.TST.SelectionArchive\x12%\n\rundo_cell_map\x18\x04 \x02(\x0b\x32\x0e.TSP.Reference\x12%\n\rredo_cell_map\x18\x05 \x02(\x0b\x32\x0e.TSP.Reference\x12!\n\ttext_undo\x18\x06 \x01(\x0b\x32\x0e.TSP.Reference\"\xf0\x01\n\x18\x43ommandStyleTableArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12\x33\n\x11\x66ormat_properties\x18\x02 \x01(\x0b\x32\x18.TSP.ReferenceDictionary\x12:\n\told_style\x18\x03 \x01(\x0b\x32\'.TST.TableStylePropertyChangeSetArchive\x12:\n\tnew_style\x18\x04 \x01(\x0b\x32\'.TST.TableStylePropertyChangeSetArchive\"\xca\x01\n\'CommandSetRepeatingHeaderEnabledArchive\x12 \n\x18repeating_header_enabled\x18\x01 \x02(\x08\x12-\n\tdirection\x18\x02 \x02(\x0e\x32\x1a.TST.TableDimensionArchive\x12\'\n\x05super\x18\x03 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12%\n\x1dprev_repeating_header_enabled\x18\x04 \x01(\x08\"\xaa\x01\n\x1f\x43ommandSetFiltersEnabledArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12\x1b\n\x13new_filters_enabled\x18\x02 \x02(\x08\x12\x1b\n\x13old_filters_enabled\x18\x03 \x01(\x08\x12$\n\x11rollback_uid_list\x18\x04 \x03(\x0b\x32\t.TSP.UUID\"\xa3\x01\n!CommandAddTableStylePresetArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12\x14\n\x0cpreset_index\x18\x02 \x02(\x05\x12$\n\x0ctable_styles\x18\x03 \x02(\x0b\x32\x0e.TSP.Reference\x12\x19\n\x11send_notification\x18\x04 \x02(\x08\"\xc9\x01\n$CommandRemoveTableStylePresetArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x1d\n\x05theme\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12,\n\x14removed_table_styles\x18\x03 \x02(\x0b\x32\x0e.TSP.Reference\x12\x11\n\tpreset_id\x18\x04 \x02(\x05\x12\x1d\n\x15preset_index_in_theme\x18\x05 \x02(\x05\"\xbe\x01\n%CommandReplaceTableStylePresetArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x1d\n\x05theme\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12(\n\x10old_table_styles\x18\x03 \x02(\x0b\x32\x0e.TSP.Reference\x12(\n\x10new_table_styles\x18\x04 \x02(\x0b\x32\x0e.TSP.Reference\"\xaf\x04\n#CommandApplyTableStylePresetArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12\x1e\n\x06preset\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12\x1e\n\x06styles\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12#\n\x0bundo_preset\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\x12#\n\x0bundo_styles\x18\x05 \x01(\x0b\x32\x0e.TSP.Reference\x12%\n\rcell_diff_map\x18\x06 \x01(\x0b\x32\x0e.TSP.Reference\x12*\n\x12undo_cell_diff_map\x18\x07 \x01(\x0b\x32\x0e.TSP.Reference\x12\x1b\n\x13\x61pply_preset_option\x18\x08 \x02(\x05\x12\x1d\n\x15table_clears_all_flag\x18\x0b \x02(\x08\x12\"\n\x1aundo_table_clears_all_flag\x18\x0c \x02(\x08\x12\x35\n\x0erow_col_styles\x18\r \x03(\x0b\x32\x1d.TST.ColumnRowMetadataArchive\x12:\n\x13undo_row_col_styles\x18\x0e \x03(\x0b\x32\x1d.TST.ColumnRowMetadataArchive\x12/\n\x17\x63hange_prop_map_wrapper\x18\x0f \x01(\x0b\x32\x0e.TSP.Reference\"Y\n\x15\x43ommandSetBaseArchive\x12\x32\n\x05super\x18\x01 \x02(\x0b\x32#.TST.CommandMutateCellFormatArchive\x12\x0c\n\x04\x62\x61se\x18\x02 \x02(\r\"f\n\x1b\x43ommandSetBasePlacesArchive\x12\x32\n\x05super\x18\x01 \x02(\x0b\x32#.TST.CommandMutateCellFormatArchive\x12\x13\n\x0b\x62\x61se_places\x18\x02 \x02(\r\"t\n!CommandSetBaseUseMinusSignArchive\x12\x32\n\x05super\x18\x01 \x02(\x0b\x32#.TST.CommandMutateCellFormatArchive\x12\x1b\n\x13\x62\x61se_use_minus_sign\x18\x02 \x02(\x08\"j\n\x1d\x43ommandSetCurrencyCodeArchive\x12\x32\n\x05super\x18\x01 \x02(\x0b\x32#.TST.CommandMutateCellFormatArchive\x12\x15\n\rcurrency_code\x18\x02 \x02(\t\"r\n!CommandSetFractionAccuracyArchive\x12\x32\n\x05super\x18\x01 \x02(\x0b\x32#.TST.CommandMutateCellFormatArchive\x12\x19\n\x11\x66raction_accuracy\x18\x02 \x02(\r\"y\n$CommandSetNegativeNumberStyleArchive\x12\x32\n\x05super\x18\x01 \x02(\x0b\x32#.TST.CommandMutateCellFormatArchive\x12\x1d\n\x15negative_number_style\x18\x02 \x02(\r\"t\n&CommandSetNumberOfDecimalPlacesArchive\x12\x32\n\x05super\x18\x01 \x02(\x0b\x32#.TST.CommandMutateCellFormatArchive\x12\x16\n\x0e\x64\x65\x63imal_places\x18\x02 \x02(\r\"\x8d\x01\n\x1f\x43ommandSetDateTimeFormatArchive\x12\x32\n\x05super\x18\x01 \x02(\x0b\x32#.TST.CommandMutateCellFormatArchive\x12\x1a\n\x12\x64\x61te_format_string\x18\x02 \x01(\t\x12\x1a\n\x12time_format_string\x18\x03 \x01(\t\"\x7f\n\'CommandSetShowThousandsSeparatorArchive\x12\x32\n\x05super\x18\x01 \x02(\x0b\x32#.TST.CommandMutateCellFormatArchive\x12 \n\x18show_thousands_separator\x18\x02 \x02(\x08\"w\n#CommandSetUseAccountingStyleArchive\x12\x32\n\x05super\x18\x01 \x02(\x0b\x32#.TST.CommandMutateCellFormatArchive\x12\x1c\n\x14use_accounting_style\x18\x02 \x02(\x08\"\xa5\x02\n&CommandSetRangeControlMinMaxIncArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12\x0f\n\x07minimum\x18\x02 \x01(\x01\x12\x0f\n\x07maximum\x18\x03 \x01(\x01\x12\x11\n\tincrement\x18\x04 \x01(\x01\x12%\n\rcell_diff_map\x18\x05 \x01(\x0b\x32\x0e.TSP.Reference\x12.\n\rcell_uid_list\x18\x06 \x01(\x0b\x32\x17.TST.CellUIDListArchive\x12-\n\x15inverse_cell_diff_map\x18\x07 \x01(\x0b\x32\x0e.TSP.Reference\x12\x17\n\x0fis_first_commit\x18\x08 \x02(\x08\"\xa7\x02\n\x1f\x43ommandMoveColumnsOrRowsArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12\x1b\n\x08\x64\x65st_uid\x18\x02 \x02(\x0b\x32\t.TSP.UUID\x12\x0e\n\x06\x62\x65\x66ore\x18\x03 \x02(\x08\x12 \n\rundo_dest_uid\x18\x04 \x02(\x0b\x32\t.TSP.UUID\x12\x13\n\x0bundo_before\x18\x05 \x02(\x08\x12\x17\n\x04uids\x18\x06 \x03(\x0b\x32\t.TSP.UUID\x12-\n\tdirection\x18\x07 \x02(\x0e\x32\x1a.TST.TableDimensionArchive\x12/\n\x17\x66ormula_rewrite_command\x18\x08 \x01(\x0b\x32\x0e.TSP.Reference\"\xb0\x01\n\x12\x43ommandSortArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12 \n\rfrom_row_uids\x18\x02 \x03(\x0b\x32\t.TSP.UUID\x12\x1e\n\x0bto_row_uids\x18\x03 \x03(\x0b\x32\t.TSP.UUID\x12/\n\x17\x66ormula_rewrite_command\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\"\x85\x02\n)CommandRewriteFormulasForTransposeArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12\x35\n\x0crewrite_spec\x18\x02 \x02(\x0b\x32\x1f.TSCE.FormulaRewriteSpecArchive\x12\x39\n\x13\x66ormulas_to_rewrite\x18\x03 \x02(\x0b\x32\x1c.TSCE.FormulasForUndoArchive\x12=\n\x0ewarningset_map\x18\x04 \x01(\x0b\x32%.TST.ImportWarningSetByCellRefArchive\"\xcd\x01\n0CommandRewriteTableFormulasForRewriteSpecArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12\x35\n\x0crewrite_spec\x18\x02 \x02(\x0b\x32\x1f.TSCE.FormulaRewriteSpecArchive\x12\x39\n\x13\x66ormulas_to_rewrite\x18\x03 \x02(\x0b\x32\x1c.TSCE.FormulasForUndoArchive\"\xbf\x01\n\"CommandRewriteMergeFormulasArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12\x35\n\x0crewrite_spec\x18\x02 \x02(\x0b\x32\x1f.TSCE.FormulaRewriteSpecArchive\x12\x39\n\x13\x66ormulas_to_rewrite\x18\x03 \x02(\x0b\x32\x1c.TSCE.FormulasForUndoArchive\"\xc2\x01\n%CommandRewriteCategoryFormulasArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12\x35\n\x0crewrite_spec\x18\x02 \x02(\x0b\x32\x1f.TSCE.FormulaRewriteSpecArchive\x12\x39\n\x13\x66ormulas_to_rewrite\x18\x03 \x02(\x0b\x32\x1c.TSCE.FormulasForUndoArchive\"\\\n1CommandRewriteFilterFormulasForTableResizeArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\"\xb7\x01\n1CommandRewriteFilterFormulasForRewriteSpecArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12\"\n\nfilter_set\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12\x35\n\x0crewrite_spec\x18\x03 \x02(\x0b\x32\x1f.TSCE.FormulaRewriteSpecArchive\"\x98\x02\n4CommandRewriteConditionalStylesForRewriteSpecArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12\x35\n\x0crewrite_spec\x18\x02 \x02(\x0b\x32\x1f.TSCE.FormulaRewriteSpecArchive\x12\x39\n\x13\x66ormulas_to_rewrite\x18\x03 \x01(\x0b\x32\x1c.TSCE.FormulasForUndoArchive\x12\x45\n\x16\x63onditional_style_sets\x18\x04 \x01(\x0b\x32%.TSCE.ExpandedCellRefObjectMapArchive\"\x92\x02\n\x13\x43ommandMergeArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12.\n\rcell_uid_list\x18\x02 \x02(\x0b\x32\x17.TST.CellUIDListArchive\x12%\n\rundo_cell_map\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12\x34\n\x1cundo_formula_rewrite_command\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\x12\x1c\n\x14merge_owner_rollback\x18\x05 \x01(\r\x12\'\n\x0f\x63ommit_cell_map\x18\x06 \x01(\x0b\x32\x0e.TSP.Reference\"\x82\x01\n\x1a\x43ommandInverseMergeArchive\x12.\n\x05super\x18\x01 \x02(\x0b\x32\x1f.TST.CommandApplyCellMapArchive\x12\x34\n\x15merge_source_cell_uid\x18\x02 \x02(\x0b\x32\x15.TSP.UUIDCoordArchive\"\xcf\x01\n\x15\x43ommandUnmergeArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12\x30\n\x12unmerge_uid_ranges\x18\x02 \x03(\x0b\x32\x14.TSP.UUIDRectArchive\x12%\n\rundo_cell_map\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12\x34\n\x1cundo_formula_rewrite_command\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\"\xd5\x01\n#CommandChooseTableIdRemapperArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x37\n\x0ftable_id_mapper\x18\x02 \x02(\x0b\x32\x1e.TST.MultiTableRemapperArchive\x12\x38\n formula_rewrite_command_for_undo\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12\x17\n\x0f\x61pply_and_clear\x18\x04 \x02(\x08\"\xe2\x08\n(CommandCategorySetGroupingColumnsArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12\x1c\n\x14new_enabled_changing\x18\x02 \x02(\x05\x12\x1c\n\x14old_enabled_changing\x18\x03 \x02(\x05\x12\x39\n\x14new_grouping_columns\x18\x04 \x02(\x0b\x32\x1b.TST.GroupColumnListArchive\x12\x39\n\x14old_grouping_columns\x18\x05 \x01(\x0b\x32\x1b.TST.GroupColumnListArchive\x12\x1a\n\x12restore_base_order\x18\x06 \x02(\x08\x12!\n\x0e\x62\x61se_row_order\x18\x07 \x03(\x0b\x32\t.TSP.UUID\x12\x1f\n\x17undo_restore_base_order\x18\x08 \x02(\x08\x12&\n\x13undo_base_row_order\x18\t \x03(\x0b\x32\t.TSP.UUID\x12\x1a\n\x12restore_view_order\x18\n \x02(\x08\x12!\n\x0eview_row_order\x18\x0b \x03(\x0b\x32\t.TSP.UUID\x12\x1f\n\x17undo_restore_view_order\x18\x0c \x02(\x08\x12&\n\x13undo_view_row_order\x18\r \x03(\x0b\x32\t.TSP.UUID\x12!\n\x0e\x63ollapse_state\x18\x0e \x03(\x0b\x32\t.TSP.UUID\x12&\n\x13undo_collapse_state\x18\x0f \x03(\x0b\x32\t.TSP.UUID\x12H\n\x14summary_change_state\x18\x10 \x01(\x0b\x32*.TST.SummaryModelGroupByChangeStateArchive\x12M\n\x19undo_summary_change_state\x18\x11 \x01(\x0b\x32*.TST.SummaryModelGroupByChangeStateArchive\x12>\n\x15new_column_aggregates\x18\x12 \x01(\x0b\x32\x1f.TST.ColumnAggregateListArchive\x12>\n\x15old_column_aggregates\x18\x13 \x01(\x0b\x32\x1f.TST.ColumnAggregateListArchive\x12\x38\n undo_set_enabled_rewrite_command\x18\x14 \x01(\x0b\x32\x0e.TSP.Reference\x12\x38\n undo_set_columns_rewrite_command\x18\x15 \x01(\x0b\x32\x0e.TSP.Reference\x12 \n\x18\x66orce_restore_all_states\x18\x16 \x02(\x08\x12%\n\rcell_diff_map\x18\x17 \x01(\x0b\x32\x0e.TSP.Reference\x12*\n\x12undo_cell_diff_map\x18\x18 \x01(\x0b\x32\x0e.TSP.Reference\"\xb3\x02\n!FormulaEditingCommandGroupArchive\x12\x32\n\x05super\x18\x01 \x02(\x0b\x32#.TSK.ProgressiveCommandGroupArchive\x12\x1a\n\x12undoSelectionValid\x18\x02 \x02(\x08\x12\x1a\n\x12undoSelectionStart\x18\x03 \x02(\r\x12\x1b\n\x13undoSelectionLength\x18\x04 \x02(\r\x12\x17\n\x0fundoActiveToken\x18\x05 \x02(\r\x12\x1a\n\x12redoSelectionValid\x18\x06 \x02(\x08\x12\x1a\n\x12redoSelectionStart\x18\x07 \x02(\r\x12\x1b\n\x13redoSelectionLength\x18\x08 \x02(\r\x12\x17\n\x0fredoActiveToken\x18\t \x02(\r\"\x96\x01\n-FormulaEditingCommandSelectionBehaviorArchive\x12\x33\n\x05super\x18\x01 \x02(\x0b\x32$.TSK.CommandSelectionBehaviorArchive\x12\x17\n\x0fundoActiveToken\x18\x02 \x01(\r\x12\x17\n\x0fredoActiveToken\x18\x03 \x01(\r\"\xcb\x01\n$TableCommandSelectionBehaviorArchive\x12\x33\n\x05super\x18\x01 \x02(\x0b\x32$.TSK.CommandSelectionBehaviorArchive\x12\"\n\ntable_info\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12-\n\x1alast_column_uid_hit_by_tap\x18\x03 \x01(\x0b\x32\t.TSP.UUID\x12\x1b\n\x13invalidate_comments\x18\x04 \x01(\r\"\xb6\x02\n\x1e\x43ommandApplyCellCommentArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12\'\n\x08\x63\x65ll_uid\x18\x02 \x02(\x0b\x32\x15.TSP.UUIDCoordArchive\x12+\n\x13old_comment_storage\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12+\n\x13new_comment_storage\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\x12\x33\n\x0f\x66orward_variant\x18\x05 \x01(\x0e\x32\x1a.TSD.CommentCommandVariant\x12\x33\n\x0finverse_variant\x18\x06 \x01(\x0e\x32\x1a.TSD.CommentCommandVariant\"`\n$CommandSetFormulaTokenizationArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x14\n\x0ctokenization\x18\x02 \x02(\x08\"\xf3\x01\n\x1e\x43ommandSetFilterSetTypeArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12@\n\x13old_filter_set_type\x18\x02 \x01(\x0e\x32#.TST.FilterSetArchive.FilterSetType\x12@\n\x13new_filter_set_type\x18\x03 \x02(\x0e\x32#.TST.FilterSetArchive.FilterSetType\x12$\n\x11rollback_uid_list\x18\x04 \x03(\x0b\x32\t.TSP.UUID\"\x9b\x01\n\x1a\x43ommandSetTextStyleArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12%\n\rcell_diff_map\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12-\n\x15inverse_cell_diff_map\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\"\xc1\x01\n$CommandSetTextStylePropertiesArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12%\n\rcell_diff_map\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12\x1a\n\x12\x63\x65ll_was_rich_text\x18\x03 \x03(\x08\x12-\n\x15inverse_cell_diff_map\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\"i\n\x1e\x43ommandJustForNotifyingArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12\x1e\n\x16\x63hange_descriptor_type\x18\x02 \x02(\r\"\xd8\x01\n CommandSetStorageLanguageArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x1f\n\x07storage\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12\x10\n\x08language\x18\x03 \x02(\t\x12\x16\n\x0erange_location\x18\x04 \x02(\r\x12\x14\n\x0crange_length\x18\x05 \x02(\r\x12/\n\x10undo_transaction\x18\x06 \x01(\x0b\x32\x15.TSWP.UndoTransaction\"\xad\x01\n\x1a\x43ommandSetSortOrderArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12\x32\n\x0eold_sort_order\x18\x02 \x01(\x0b\x32\x1a.TST.TableSortOrderArchive\x12\x32\n\x0enew_sort_order\x18\x03 \x01(\x0b\x32\x1a.TST.TableSortOrderArchive\"\xbf\x01\n,CommandRewriteSortOrderForTableResizeArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12\x32\n\x0eold_sort_order\x18\x02 \x01(\x0b\x32\x1a.TST.TableSortOrderArchive\x12\x32\n\x0enew_sort_order\x18\x03 \x01(\x0b\x32\x1a.TST.TableSortOrderArchive\"\xf6\x01\n,CommandRewriteSortOrderForRewriteSpecArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12\x35\n\x0crewrite_spec\x18\x02 \x02(\x0b\x32\x1f.TSCE.FormulaRewriteSpecArchive\x12\x32\n\x0eold_sort_order\x18\x03 \x01(\x0b\x32\x1a.TST.TableSortOrderArchive\x12\x32\n\x0enew_sort_order\x18\x04 \x01(\x0b\x32\x1a.TST.TableSortOrderArchive\"\xbb\x01\n\x1a\x43ommandSetFilterSetArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12&\n\x0enew_filter_set\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12&\n\x0eold_filter_set\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12$\n\x11rollback_uid_list\x18\x04 \x03(\x0b\x32\t.TSP.UUID\"l\n\x1b\x43olumnRowRestoreDataArchive\x12\x1b\n\x08uid_list\x18\x01 \x03(\x0b\x32\t.TSP.UUID\x12\x30\n\tmetadatas\x18\x02 \x03(\x0b\x32\x1d.TST.ColumnRowMetadataArchive\"\xc5\x04\n\x1c\x43ommandTransposeTableArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12\x34\n\x14original_table_range\x18\x02 \x02(\x0b\x32\x16.TST.ExpandedCellRange\x12)\n\x11original_cell_map\x18\x03 \x02(\x0b\x32\x0e.TSP.Reference\x12!\n\x19original_footer_row_count\x18\x04 \x02(\r\x12\x1e\n\x16original_column_widths\x18\x05 \x03(\x02\x12\x1c\n\x14original_row_heights\x18\x06 \x03(\x02\x12-\n\x15ineligible_merge_list\x18\x07 \x03(\x0b\x32\x0e.TST.CellRange\x12+\n\x13transposed_cell_map\x18\x08 \x02(\x0b\x32\x0e.TSP.Reference\x12\x34\n\x1cundo_formula_rewrite_command\x18\t \x01(\x0b\x32\x0e.TSP.Reference\x12-\n\x15rich_text_subcommands\x18\n \x01(\x0b\x32\x0e.TSP.Reference\x12=\n\x13\x63olumn_restore_data\x18\x0b \x01(\x0b\x32 .TST.ColumnRowRestoreDataArchive\x12:\n\x10row_restore_data\x18\x0c \x01(\x0b\x32 .TST.ColumnRowRestoreDataArchive\"\xce\x01\n+CommandSetStructuredTextImportRecordArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12:\n\x11new_import_record\x18\x02 \x01(\x0b\x32\x1f.TST.StructuredTextImportRecord\x12:\n\x11old_import_record\x18\x03 \x01(\x0b\x32\x1f.TST.StructuredTextImportRecord\"\x99\x02\n)CommandCategoryCollapseExpandGroupArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12\x15\n\ris_collapsing\x18\x02 \x02(\x08\x12\x35\n\x10grouping_columns\x18\x03 \x02(\x0b\x32\x1b.TST.GroupColumnListArchive\x12\x37\n\x0e\x63ollapse_state\x18\x04 \x02(\x0b\x32\x1f.TST.ExpandCollapseStateArchive\x12<\n\x13undo_collapse_state\x18\x05 \x01(\x0b\x32\x1f.TST.ExpandCollapseStateArchive\"\xbd\x01\n)CommandCategoryChangeSummaryAggregateType\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12\x16\n\x0e\x61ggregate_type\x18\x02 \x02(\r\x12\x1b\n\x13undo_aggregate_type\x18\x03 \x02(\r\x12\x1d\n\ncolumn_uid\x18\x04 \x02(\x0b\x32\t.TSP.UUID\x12\x13\n\x0bgroup_level\x18\x05 \x02(\x11\"\xa5\x01\n$CommandCategorySetLabelRowVisibility\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12\x13\n\x0bgroup_level\x18\x02 \x02(\r\x12\x1c\n\x14label_row_visibility\x18\x03 \x02(\r\x12!\n\x19undo_label_row_visibility\x18\x04 \x02(\r\"\xaa\x02\n#CommandCategoryWillChangeGroupValue\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12!\n\x0egroup_node_uid\x18\x02 \x02(\x0b\x32\t.TSP.UUID\x12&\n\x13undo_group_node_uid\x18\x03 \x01(\x0b\x32\t.TSP.UUID\x12+\n\x0bgroup_value\x18\x04 \x01(\x0b\x32\x16.TSCE.CellValueArchive\x12\x30\n\x10undo_group_value\x18\x05 \x01(\x0b\x32\x16.TSCE.CellValueArchive\x12\x30\n\x18rewrite_command_for_undo\x18\x06 \x01(\x0b\x32\x0e.TSP.Reference\"S\n%IdempotentSelectionTransformerArchive\x12*\n\x12\x61rchived_selection\x18\x01 \x02(\x0b\x32\x0e.TSP.Reference\"\xb8\x01\n\x1dWPSelectionTransformerArchive\x12;\n\x05super\x18\x01 \x02(\x0b\x32,.TST.TableSubSelectionTransformerBaseArchive\x12*\n\x12\x61rchived_selection\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12.\n\x0forigin_cell_uid\x18\x03 \x01(\x0b\x32\x15.TSP.UUIDCoordArchive\"T\n\'TableSubSelectionTransformerBaseArchive\x12)\n\x12table_info_id_path\x18\x01 \x02(\x0b\x32\r.TSP.UUIDPath\"c\n$TableNameSelectionTransformerArchive\x12;\n\x05super\x18\x01 \x02(\x0b\x32,.TST.TableSubSelectionTransformerBaseArchive\"\xf6\x01\n&ControlCellSelectionTransformerArchive\x12;\n\x05super\x18\x01 \x02(\x0b\x32,.TST.TableSubSelectionTransformerBaseArchive\x12*\n\tcell_uids\x18\x02 \x01(\x0b\x32\x17.TST.CellUIDListArchive\x12.\n\x0forigin_cell_uid\x18\x03 \x01(\x0b\x32\x15.TSP.UUIDCoordArchive\x12\x33\n\x0eorigin_cell_id\x18\x04 \x02(\x0b\x32\x1b.TSCE.CellCoordinateArchive\"\xf4\x01\n$StockCellSelectionTransformerArchive\x12;\n\x05super\x18\x01 \x02(\x0b\x32,.TST.TableSubSelectionTransformerBaseArchive\x12*\n\tcell_uids\x18\x02 \x01(\x0b\x32\x17.TST.CellUIDListArchive\x12.\n\x0forigin_cell_uid\x18\x03 \x01(\x0b\x32\x15.TSP.UUIDCoordArchive\x12\x33\n\x0eorigin_cell_id\x18\x04 \x02(\x0b\x32\x1b.TSCE.CellCoordinateArchive\"\x9c\x02\n!RegionSelectionTransformerArchive\x12;\n\x05super\x18\x01 \x02(\x0b\x32,.TST.TableSubSelectionTransformerBaseArchive\x12*\n\tcell_uids\x18\x02 \x01(\x0b\x32\x17.TST.CellUIDListArchive\x12.\n\x0forigin_cell_uid\x18\x03 \x01(\x0b\x32\x15.TSP.UUIDCoordArchive\x12.\n\x0f\x61nchor_cell_uid\x18\x04 \x02(\x0b\x32\x15.TSP.UUIDCoordArchive\x12.\n\x0f\x63ursor_cell_uid\x18\x05 \x02(\x0b\x32\x15.TSP.UUIDCoordArchive\"\x8c\x01\n!StrokeSelectionTransformerArchive\x12;\n\x05super\x18\x01 \x02(\x0b\x32,.TST.TableSubSelectionTransformerBaseArchive\x12*\n\x12\x61rchived_selection\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\"\xb7\x01\n$RowColumnSelectionTransformerArchive\x12;\n\x05super\x18\x01 \x02(\x0b\x32,.TST.TableSubSelectionTransformerBaseArchive\x12\x31\n\x0eselection_type\x18\x02 \x02(\x0e\x32\x19.TST.SelectionTypeArchive\x12\x1f\n\x0crow_col_uids\x18\x03 \x03(\x0b\x32\t.TSP.UUID\"\xbb\x02\n\x1e\x43ommandCategoryMoveRowsArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12\x13\n\x0b\x61\x63tion_type\x18\x02 \x02(\r\x12%\n\x12\x63\x61tegory_row_order\x18\x03 \x03(\x0b\x32\t.TSP.UUID\x12*\n\x17undo_category_row_order\x18\x04 \x03(\x0b\x32\t.TSP.UUID\x12%\n\rcell_diff_map\x18\x05 \x02(\x0b\x32\x0e.TSP.Reference\x12*\n\x12undo_cell_diff_map\x18\x06 \x01(\x0b\x32\x0e.TSP.Reference\x12\x35\n\x10grouping_columns\x18\x07 \x01(\x0b\x32\x1b.TST.GroupColumnListArchive\"\xcb\x01\n1CommandRewriteHiddenStatesForGroupByChangeArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12\x33\n\x0fgroup_by_change\x18\x02 \x02(\x0b\x32\x1a.TSCE.GroupByChangeArchive\x12\x38\n\x0f\x63ollapsed_state\x18\x03 \x01(\x0b\x32\x1f.TST.ExpandCollapseStateArchive\"\xf0\x02\n-CommandRewritePencilAnnotationFormulasArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TST.TableCommandArchive\x12\x35\n\x0crewrite_spec\x18\x02 \x02(\x0b\x32\x1f.TSCE.FormulaRewriteSpecArchive\x12\x39\n\x13\x66ormulas_to_rewrite\x18\x03 \x02(\x0b\x32\x1c.TSCE.FormulasForUndoArchive\x12_\n\x14\x61nnotations_for_undo\x18\x04 \x03(\x0b\x32\x41.TST.CommandRewritePencilAnnotationFormulasArchive.AnnotationPair\x1a\x43\n\x0e\x41nnotationPair\x12\r\n\x05index\x18\x01 \x02(\x04\x12\"\n\nannotation\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference*i\n\tTableArea\x12\x11\n\rTableAreaBody\x10\x01\x12\x16\n\x12TableAreaHeaderRow\x10\x02\x12\x19\n\x15TableAreaHeaderColumn\x10\x03\x12\x16\n\x12TableAreaFooterRow\x10\x04*\x8b\x02\n\x13TableAreaTransition\x12&\n\"TableAreaTransitionHeaderRowToBody\x10\x01\x12&\n\"TableAreaTransitionBodyToHeaderRow\x10\x02\x12&\n\"TableAreaTransitionFooterRowToBody\x10\x03\x12&\n\"TableAreaTransitionBodyToFooterRow\x10\x04\x12)\n%TableAreaTransitionHeaderColumnToBody\x10\x05\x12)\n%TableAreaTransitionBodyToHeaderColumn\x10\x06*\xba\x01\n\x11\x43olumnRowTypeEnum\x12\x17\n\x13\x43olumnRowTypeAnchor\x10\x00\x12\x1a\n\x16\x43olumnRowTypeHeaderRow\x10\x01\x12\x18\n\x14\x43olumnRowTypeBodyRow\x10\x02\x12\x1a\n\x16\x43olumnRowTypeFooterRow\x10\x03\x12\x1d\n\x19\x43olumnRowTypeHeaderColumn\x10\x04\x12\x1b\n\x17\x43olumnRowTypeBodyColumn\x10\x05')
  ,
  dependencies=[TSPMessages__pb2.DESCRIPTOR,TSDArchives__pb2.DESCRIPTOR,TSDCommandArchives__pb2.DESCRIPTOR,TSKArchives__pb2.DESCRIPTOR,TSSArchives__pb2.DESCRIPTOR,TSCEArchives__pb2.DESCRIPTOR,TSWPArchives__pb2.DESCRIPTOR,TSTArchives__pb2.DESCRIPTOR,TSTArchives__sos__pb2.DESCRIPTOR,])

_TABLEAREA = _descriptor.EnumDescriptor(
  name='TableArea',
  full_name='TST.TableArea',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TableAreaBody', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TableAreaHeaderRow', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TableAreaHeaderColumn', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TableAreaFooterRow', index=3, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=23518,
  serialized_end=23623,
)
_sym_db.RegisterEnumDescriptor(_TABLEAREA)

TableArea = enum_type_wrapper.EnumTypeWrapper(_TABLEAREA)
_TABLEAREATRANSITION = _descriptor.EnumDescriptor(
  name='TableAreaTransition',
  full_name='TST.TableAreaTransition',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TableAreaTransitionHeaderRowToBody', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TableAreaTransitionBodyToHeaderRow', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TableAreaTransitionFooterRowToBody', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TableAreaTransitionBodyToFooterRow', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TableAreaTransitionHeaderColumnToBody', index=4, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TableAreaTransitionBodyToHeaderColumn', index=5, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=23626,
  serialized_end=23893,
)
_sym_db.RegisterEnumDescriptor(_TABLEAREATRANSITION)

TableAreaTransition = enum_type_wrapper.EnumTypeWrapper(_TABLEAREATRANSITION)
_COLUMNROWTYPEENUM = _descriptor.EnumDescriptor(
  name='ColumnRowTypeEnum',
  full_name='TST.ColumnRowTypeEnum',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ColumnRowTypeAnchor', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ColumnRowTypeHeaderRow', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ColumnRowTypeBodyRow', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ColumnRowTypeFooterRow', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ColumnRowTypeHeaderColumn', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ColumnRowTypeBodyColumn', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=23896,
  serialized_end=24082,
)
_sym_db.RegisterEnumDescriptor(_COLUMNROWTYPEENUM)

ColumnRowTypeEnum = enum_type_wrapper.EnumTypeWrapper(_COLUMNROWTYPEENUM)
TableAreaBody = 1
TableAreaHeaderRow = 2
TableAreaHeaderColumn = 3
TableAreaFooterRow = 4
TableAreaTransitionHeaderRowToBody = 1
TableAreaTransitionBodyToHeaderRow = 2
TableAreaTransitionFooterRowToBody = 3
TableAreaTransitionBodyToFooterRow = 4
TableAreaTransitionHeaderColumnToBody = 5
TableAreaTransitionBodyToHeaderColumn = 6
ColumnRowTypeAnchor = 0
ColumnRowTypeHeaderRow = 1
ColumnRowTypeBodyRow = 2
ColumnRowTypeFooterRow = 3
ColumnRowTypeHeaderColumn = 4
ColumnRowTypeBodyColumn = 5



_TABLECOMMANDARCHIVE = _descriptor.Descriptor(
  name='TableCommandArchive',
  full_name='TST.TableCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.TableCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_info_id_path', full_name='TST.TableCommandArchive.table_info_id_path', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commandname', full_name='TST.TableCommandArchive.commandname', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_cell_styles_container', full_name='TST.TableCommandArchive.default_cell_styles_container', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='TST.TableCommandArchive.timestamp', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='random_seed_lo', full_name='TST.TableCommandArchive.random_seed_lo', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='random_seed_hi', full_name='TST.TableCommandArchive.random_seed_hi', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_inverse', full_name='TST.TableCommandArchive.is_inverse', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_timestamp', full_name='TST.TableCommandArchive.old_timestamp', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_random_seed', full_name='TST.TableCommandArchive.old_random_seed', index=9,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=218,
  serialized_end=529,
)


_COMMANDAPPLYCELLCONTENTSARCHIVE = _descriptor.Descriptor(
  name='CommandApplyCellContentsArchive',
  full_name='TST.CommandApplyCellContentsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandApplyCellContentsArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_diff_map', full_name='TST.CommandApplyCellContentsArchive.cell_diff_map', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rollback_cell_diff_map', full_name='TST.CommandApplyCellContentsArchive.rollback_cell_diff_map', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_format_keys', full_name='TST.CommandApplyCellContentsArchive.custom_format_keys', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action_string', full_name='TST.CommandApplyCellContentsArchive.action_string', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=532,
  serialized_end=755,
)


_COMMANDAPPLYCELLDIFFMAPARCHIVE = _descriptor.Descriptor(
  name='CommandApplyCellDiffMapArchive',
  full_name='TST.CommandApplyCellDiffMapArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandApplyCellDiffMapArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_diff_map', full_name='TST.CommandApplyCellDiffMapArchive.cell_diff_map', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='should_allow_merge_fragments', full_name='TST.CommandApplyCellDiffMapArchive.should_allow_merge_fragments', index=2,
      number=3, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inverse_cell_diff_map', full_name='TST.CommandApplyCellDiffMapArchive.inverse_cell_diff_map', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_format_keys', full_name='TST.CommandApplyCellDiffMapArchive.custom_format_keys', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=758,
  serialized_end=994,
)


_COMMANDAPPLYCELLMAPARCHIVE = _descriptor.Descriptor(
  name='CommandApplyCellMapArchive',
  full_name='TST.CommandApplyCellMapArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandApplyCellMapArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='redo_cell_map', full_name='TST.CommandApplyCellMapArchive.redo_cell_map', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_cell_map', full_name='TST.CommandApplyCellMapArchive.undo_cell_map', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_formula_rewrite_command', full_name='TST.CommandApplyCellMapArchive.undo_formula_rewrite_command', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_format_keys', full_name='TST.CommandApplyCellMapArchive.custom_format_keys', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='merge_owner_rollback_index', full_name='TST.CommandApplyCellMapArchive.merge_owner_rollback_index', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_from_paste', full_name='TST.CommandApplyCellMapArchive.is_from_paste', index=6,
      number=7, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formula_rewrite_commands', full_name='TST.CommandApplyCellMapArchive.formula_rewrite_commands', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=997,
  serialized_end=1346,
)


_COMMANDAPPLYCONCURRENTCELLMAPARCHIVE = _descriptor.Descriptor(
  name='CommandApplyConcurrentCellMapArchive',
  full_name='TST.CommandApplyConcurrentCellMapArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandApplyConcurrentCellMapArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='redo_concurrent_cell_map', full_name='TST.CommandApplyConcurrentCellMapArchive.redo_concurrent_cell_map', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_concurrent_cell_map', full_name='TST.CommandApplyConcurrentCellMapArchive.undo_concurrent_cell_map', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_formula_rewrite_command', full_name='TST.CommandApplyConcurrentCellMapArchive.undo_formula_rewrite_command', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_format_keys', full_name='TST.CommandApplyConcurrentCellMapArchive.custom_format_keys', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='merge_owner_rollback_index', full_name='TST.CommandApplyConcurrentCellMapArchive.merge_owner_rollback_index', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_from_paste', full_name='TST.CommandApplyConcurrentCellMapArchive.is_from_paste', index=6,
      number=7, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formula_rewrite_commands', full_name='TST.CommandApplyConcurrentCellMapArchive.formula_rewrite_commands', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1349,
  serialized_end=1730,
)


_COMMANDCHANGEFREEZEHEADERSTATEARCHIVE = _descriptor.Descriptor(
  name='CommandChangeFreezeHeaderStateArchive',
  full_name='TST.CommandChangeFreezeHeaderStateArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandChangeFreezeHeaderStateArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='direction', full_name='TST.CommandChangeFreezeHeaderStateArchive.direction', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_freeze_state', full_name='TST.CommandChangeFreezeHeaderStateArchive.new_freeze_state', index=2,
      number=3, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prev_freeze_state', full_name='TST.CommandChangeFreezeHeaderStateArchive.prev_freeze_state', index=3,
      number=4, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1733,
  serialized_end=1913,
)


_COMMANDDELETECELLSARCHIVE = _descriptor.Descriptor(
  name='CommandDeleteCellsArchive',
  full_name='TST.CommandDeleteCellsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandDeleteCellsArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update_border_visibility', full_name='TST.CommandDeleteCellsArchive.update_border_visibility', index=1,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='invalidate_comments', full_name='TST.CommandDeleteCellsArchive.invalidate_comments', index=2,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='invalidate_comments_valid', full_name='TST.CommandDeleteCellsArchive.invalidate_comments_valid', index=3,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_uid_region', full_name='TST.CommandDeleteCellsArchive.cell_uid_region', index=4,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='summary_cell_uid_list', full_name='TST.CommandDeleteCellsArchive.summary_cell_uid_list', index=5,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inverse_concurrent_cell_map', full_name='TST.CommandDeleteCellsArchive.inverse_concurrent_cell_map', index=6,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1916,
  serialized_end=2243,
)


_COMMANDDELETECELLCONTENTSARCHIVE = _descriptor.Descriptor(
  name='CommandDeleteCellContentsArchive',
  full_name='TST.CommandDeleteCellContentsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandDeleteCellContentsArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_uid_list', full_name='TST.CommandDeleteCellContentsArchive.cell_uid_list', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inverse_cell_diff_map', full_name='TST.CommandDeleteCellContentsArchive.inverse_cell_diff_map', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2246,
  serialized_end=2416,
)


_COMMANDMUTATECELLFORMATARCHIVE = _descriptor.Descriptor(
  name='CommandMutateCellFormatArchive',
  full_name='TST.CommandMutateCellFormatArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandMutateCellFormatArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_uid_list', full_name='TST.CommandMutateCellFormatArchive.cell_uid_list', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inverse_cell_diff_map', full_name='TST.CommandMutateCellFormatArchive.inverse_cell_diff_map', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='whole_format_diff_map', full_name='TST.CommandMutateCellFormatArchive.whole_format_diff_map', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='intended_format_type', full_name='TST.CommandMutateCellFormatArchive.intended_format_type', index=4,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2419,
  serialized_end=2664,
)


_COMMANDSETAUTOMATICDURATIONUNITSARCHIVE = _descriptor.Descriptor(
  name='CommandSetAutomaticDurationUnitsArchive',
  full_name='TST.CommandSetAutomaticDurationUnitsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandSetAutomaticDurationUnitsArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='automatic_units', full_name='TST.CommandSetAutomaticDurationUnitsArchive.automatic_units', index=1,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2666,
  serialized_end=2784,
)


_COMMANDSETDURATIONSTYLEARCHIVE = _descriptor.Descriptor(
  name='CommandSetDurationStyleArchive',
  full_name='TST.CommandSetDurationStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandSetDurationStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration_style', full_name='TST.CommandSetDurationStyleArchive.duration_style', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2786,
  serialized_end=2894,
)


_COMMANDSETDURATIONUNITSMALLESTLARGESTARCHIVE = _descriptor.Descriptor(
  name='CommandSetDurationUnitSmallestLargestArchive',
  full_name='TST.CommandSetDurationUnitSmallestLargestArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandSetDurationUnitSmallestLargestArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='smallest_unit', full_name='TST.CommandSetDurationUnitSmallestLargestArchive.smallest_unit', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='largest_unit', full_name='TST.CommandSetDurationUnitSmallestLargestArchive.largest_unit', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2897,
  serialized_end=3040,
)


_COMMANDREPLACECUSTOMFORMATARCHIVE = _descriptor.Descriptor(
  name='CommandReplaceCustomFormatArchive',
  full_name='TST.CommandReplaceCustomFormatArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='undo_diff_map', full_name='TST.CommandReplaceCustomFormatArchive.undo_diff_map', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commit_diff_map', full_name='TST.CommandReplaceCustomFormatArchive.commit_diff_map', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandReplaceCustomFormatArchive.super', index=2,
      number=6, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3043,
  serialized_end=3199,
)


_COMMANDMOVECELLSARCHIVE = _descriptor.Descriptor(
  name='CommandMoveCellsArchive',
  full_name='TST.CommandMoveCellsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandMoveCellsArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dst_table_info_id_path', full_name='TST.CommandMoveCellsArchive.dst_table_info_id_path', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='src_uid_range', full_name='TST.CommandMoveCellsArchive.src_uid_range', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dst_uid_range', full_name='TST.CommandMoveCellsArchive.dst_uid_range', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_dimension', full_name='TST.CommandMoveCellsArchive.table_dimension', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='src_cell_map', full_name='TST.CommandMoveCellsArchive.src_cell_map', index=5,
      number=6, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dst_cell_map', full_name='TST.CommandMoveCellsArchive.dst_cell_map', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dst_cell_styles_container', full_name='TST.CommandMoveCellsArchive.dst_cell_styles_container', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='src_undo_cell_map', full_name='TST.CommandMoveCellsArchive.src_undo_cell_map', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dst_undo_cell_map', full_name='TST.CommandMoveCellsArchive.dst_undo_cell_map', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dst_merge_owner_rollback_index', full_name='TST.CommandMoveCellsArchive.dst_merge_owner_rollback_index', index=10,
      number=11, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formula_rewrite_commands', full_name='TST.CommandMoveCellsArchive.formula_rewrite_commands', index=11,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='merge_action_to_restore', full_name='TST.CommandMoveCellsArchive.merge_action_to_restore', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='comment_cell_uids_to_restore', full_name='TST.CommandMoveCellsArchive.comment_cell_uids_to_restore', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='comment_storages_to_restore', full_name='TST.CommandMoveCellsArchive.comment_storages_to_restore', index=14,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3202,
  serialized_end=3938,
)


_COLUMNROWMETADATAARCHIVE = _descriptor.Descriptor(
  name='ColumnRowMetadataArchive',
  full_name='TST.ColumnRowMetadataArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='size', full_name='TST.ColumnRowMetadataArchive.size', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hiding_action', full_name='TST.ColumnRowMetadataArchive.hiding_action', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_style', full_name='TST.ColumnRowMetadataArchive.cell_style', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text_style', full_name='TST.ColumnRowMetadataArchive.text_style', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='TST.ColumnRowMetadataArchive.uuid', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3941,
  serialized_end=4101,
)


_COMMANDINSERTCOLUMNSORROWSARCHIVE = _descriptor.Descriptor(
  name='CommandInsertColumnsOrRowsArchive',
  full_name='TST.CommandInsertColumnsOrRowsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandInsertColumnsOrRowsArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bundle', full_name='TST.CommandInsertColumnsOrRowsArchive.bundle', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_map', full_name='TST.CommandInsertColumnsOrRowsArchive.cell_map', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_commands', full_name='TST.CommandInsertColumnsOrRowsArchive.undo_commands', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_cell_map', full_name='TST.CommandInsertColumnsOrRowsArchive.undo_cell_map', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sort_order', full_name='TST.CommandInsertColumnsOrRowsArchive.sort_order', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filter_set', full_name='TST.CommandInsertColumnsOrRowsArchive.filter_set', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='should_edge_expand_formula_ranges', full_name='TST.CommandInsertColumnsOrRowsArchive.should_edge_expand_formula_ranges', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='was_categorized', full_name='TST.CommandInsertColumnsOrRowsArchive.was_categorized', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_order', full_name='TST.CommandInsertColumnsOrRowsArchive.undo_order', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='src_row_column_uid', full_name='TST.CommandInsertColumnsOrRowsArchive.src_row_column_uid', index=10,
      number=11, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='opp_row_column_uid', full_name='TST.CommandInsertColumnsOrRowsArchive.opp_row_column_uid', index=11,
      number=12, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4104,
  serialized_end=4601,
)


_COLUMNROWBUNDLEARCHIVE = _descriptor.Descriptor(
  name='ColumnRowBundleArchive',
  full_name='TST.ColumnRowBundleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_row', full_name='TST.ColumnRowBundleArchive.is_row', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='view_uid_list', full_name='TST.ColumnRowBundleArchive.view_uid_list', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='view_type_list', full_name='TST.ColumnRowBundleArchive.view_type_list', index=2,
      number=3, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='base_uid_list', full_name='TST.ColumnRowBundleArchive.base_uid_list', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='base_type_list', full_name='TST.ColumnRowBundleArchive.base_type_list', index=4,
      number=5, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_order_uid_list', full_name='TST.ColumnRowBundleArchive.category_order_uid_list', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_order_type_list', full_name='TST.ColumnRowBundleArchive.category_order_type_list', index=6,
      number=7, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata_list', full_name='TST.ColumnRowBundleArchive.metadata_list', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4604,
  serialized_end=4964,
)


_COMMANDREMOVECOLUMNSORROWSARCHIVE = _descriptor.Descriptor(
  name='CommandRemoveColumnsOrRowsArchive',
  full_name='TST.CommandRemoveColumnsOrRowsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandRemoveColumnsOrRowsArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bundle', full_name='TST.CommandRemoveColumnsOrRowsArchive.bundle', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_map', full_name='TST.CommandRemoveColumnsOrRowsArchive.cell_map', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_cell_map', full_name='TST.CommandRemoveColumnsOrRowsArchive.undo_cell_map', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_filter_set', full_name='TST.CommandRemoveColumnsOrRowsArchive.undo_filter_set', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_sort_order', full_name='TST.CommandRemoveColumnsOrRowsArchive.undo_sort_order', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formula_rewrite_command_for_undo', full_name='TST.CommandRemoveColumnsOrRowsArchive.formula_rewrite_command_for_undo', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inverse_should_edge_expand_formula_ranges', full_name='TST.CommandRemoveColumnsOrRowsArchive.inverse_should_edge_expand_formula_ranges', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_order', full_name='TST.CommandRemoveColumnsOrRowsArchive.undo_order', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4967,
  serialized_end=5398,
)


_COMMANDROWCOLUMNRANGEARCHIVE = _descriptor.Descriptor(
  name='CommandRowColumnRangeArchive',
  full_name='TST.CommandRowColumnRangeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandRowColumnRangeArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uids', full_name='TST.CommandRowColumnRangeArchive.uids', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_row', full_name='TST.CommandRowColumnRangeArchive.is_row', index=2,
      number=3, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5400,
  serialized_end=5512,
)


_COMMANDRESIZECOLUMNORROWARCHIVE = _descriptor.Descriptor(
  name='CommandResizeColumnOrRowArchive',
  full_name='TST.CommandResizeColumnOrRowArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandResizeColumnOrRowArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sizes', full_name='TST.CommandResizeColumnOrRowArchive.sizes', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sizes_for_undo', full_name='TST.CommandResizeColumnOrRowArchive.sizes_for_undo', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5514,
  serialized_end=5636,
)


_COMMANDCATEGORYRESIZECOLUMNORROWARCHIVE = _descriptor.Descriptor(
  name='CommandCategoryResizeColumnOrRowArchive',
  full_name='TST.CommandCategoryResizeColumnOrRowArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandCategoryResizeColumnOrRowArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_row_sizes', full_name='TST.CommandCategoryResizeColumnOrRowArchive.category_row_sizes', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_row_sizes_for_undo', full_name='TST.CommandCategoryResizeColumnOrRowArchive.category_row_sizes_for_undo', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_label_row_sizes', full_name='TST.CommandCategoryResizeColumnOrRowArchive.category_label_row_sizes', index=3,
      number=4, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_label_row_sizes_for_undo', full_name='TST.CommandCategoryResizeColumnOrRowArchive.category_label_row_sizes_for_undo', index=4,
      number=5, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_column_size', full_name='TST.CommandCategoryResizeColumnOrRowArchive.category_column_size', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_column_size_for_undo', full_name='TST.CommandCategoryResizeColumnOrRowArchive.category_column_size_for_undo', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5639,
  serialized_end=5932,
)


_COMMANDHIDESHOWARCHIVE = _descriptor.Descriptor(
  name='CommandHideShowArchive',
  full_name='TST.CommandHideShowArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandHideShowArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hide_show_action', full_name='TST.CommandHideShowArchive.hide_show_action', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hiding_action', full_name='TST.CommandHideShowArchive.hiding_action', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hide_show_action_for_undo', full_name='TST.CommandHideShowArchive.hide_show_action_for_undo', index=3,
      number=4, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5935,
  serialized_end=6149,
)


_COMMANDTEXTPREFLIGHTINSERTCELLARCHIVE = _descriptor.Descriptor(
  name='CommandTextPreflightInsertCellArchive',
  full_name='TST.CommandTextPreflightInsertCellArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandTextPreflightInsertCellArchive.super', index=0,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='coalesced_textcommand', full_name='TST.CommandTextPreflightInsertCellArchive.coalesced_textcommand', index=1,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='postflightcommand', full_name='TST.CommandTextPreflightInsertCellArchive.postflightcommand', index=2,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='grouped_with_postflight', full_name='TST.CommandTextPreflightInsertCellArchive.grouped_with_postflight', index=3,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='editing_cell', full_name='TST.CommandTextPreflightInsertCellArchive.editing_cell', index=4,
      number=10, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='editing_storage', full_name='TST.CommandTextPreflightInsertCellArchive.editing_storage', index=5,
      number=11, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_column_hit_by_tap', full_name='TST.CommandTextPreflightInsertCellArchive.last_column_hit_by_tap', index=6,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_uid', full_name='TST.CommandTextPreflightInsertCellArchive.cell_uid', index=7,
      number=13, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='archived_initial_selection_path', full_name='TST.CommandTextPreflightInsertCellArchive.archived_initial_selection_path', index=8,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6152,
  serialized_end=6570,
)


_COMMANDPOSTFLIGHTSETCELLARCHIVE = _descriptor.Descriptor(
  name='CommandPostflightSetCellArchive',
  full_name='TST.CommandPostflightSetCellArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandPostflightSetCellArchive.super', index=0,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='childcommandundo', full_name='TST.CommandPostflightSetCellArchive.childcommandundo', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='editing_cell', full_name='TST.CommandPostflightSetCellArchive.editing_cell', index=2,
      number=6, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_cell', full_name='TST.CommandPostflightSetCellArchive.new_cell', index=3,
      number=7, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='editing_storage', full_name='TST.CommandPostflightSetCellArchive.editing_storage', index=4,
      number=8, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_column_hit_by_tap', full_name='TST.CommandPostflightSetCellArchive.last_column_hit_by_tap', index=5,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_uid', full_name='TST.CommandPostflightSetCellArchive.cell_uid', index=6,
      number=10, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6573,
  serialized_end=6865,
)


_COMMANDCHANGETABLEAREAFORCOLUMNORROWARCHIVE = _descriptor.Descriptor(
  name='CommandChangeTableAreaForColumnOrRowArchive',
  full_name='TST.CommandChangeTableAreaForColumnOrRowArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandChangeTableAreaForColumnOrRowArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_area_transition', full_name='TST.CommandChangeTableAreaForColumnOrRowArchive.table_area_transition', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_diff_map', full_name='TST.CommandChangeTableAreaForColumnOrRowArchive.cell_diff_map', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_cell_diff_map', full_name='TST.CommandChangeTableAreaForColumnOrRowArchive.undo_cell_diff_map', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_commands', full_name='TST.CommandChangeTableAreaForColumnOrRowArchive.undo_commands', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action_string', full_name='TST.CommandChangeTableAreaForColumnOrRowArchive.action_string', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6868,
  serialized_end=7165,
)


_COMMANDSETPENCILANNOTATIONSARCHIVE = _descriptor.Descriptor(
  name='CommandSetPencilAnnotationsArchive',
  full_name='TST.CommandSetPencilAnnotationsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandSetPencilAnnotationsArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='annotations', full_name='TST.CommandSetPencilAnnotationsArchive.annotations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formulas', full_name='TST.CommandSetPencilAnnotationsArchive.formulas', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formula_indexes', full_name='TST.CommandSetPencilAnnotationsArchive.formula_indexes', index=3,
      number=4, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inverse_formulas', full_name='TST.CommandSetPencilAnnotationsArchive.inverse_formulas', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inverse_formula_indexes', full_name='TST.CommandSetPencilAnnotationsArchive.inverse_formula_indexes', index=5,
      number=6, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rollback_index', full_name='TST.CommandSetPencilAnnotationsArchive.rollback_index', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7168,
  serialized_end=7452,
)


_COMMANDSETTABLENAMEARCHIVE = _descriptor.Descriptor(
  name='CommandSetTableNameArchive',
  full_name='TST.CommandSetTableNameArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='newtablename', full_name='TST.CommandSetTableNameArchive.newtablename', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='oldtablename', full_name='TST.CommandSetTableNameArchive.oldtablename', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='newstyle', full_name='TST.CommandSetTableNameArchive.newstyle', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='oldstyle', full_name='TST.CommandSetTableNameArchive.oldstyle', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandSetTableNameArchive.super', index=4,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_shape_style', full_name='TST.CommandSetTableNameArchive.old_shape_style', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_shape_style', full_name='TST.CommandSetTableNameArchive.new_shape_style', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_table_name_border_enabled', full_name='TST.CommandSetTableNameArchive.old_table_name_border_enabled', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_table_name_border_enabled', full_name='TST.CommandSetTableNameArchive.new_table_name_border_enabled', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7455,
  serialized_end=7796,
)


_COMMANDSETTABLENAMEENABLEDARCHIVE = _descriptor.Descriptor(
  name='CommandSetTableNameEnabledArchive',
  full_name='TST.CommandSetTableNameEnabledArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandSetTableNameEnabledArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_name_enabled', full_name='TST.CommandSetTableNameEnabledArchive.table_name_enabled', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prev_table_name_enabled', full_name='TST.CommandSetTableNameEnabledArchive.prev_table_name_enabled', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7799,
  serialized_end=7936,
)


_COMMANDSETTABLEFONTSIZEARCHIVE = _descriptor.Descriptor(
  name='CommandSetTableFontSizeArchive',
  full_name='TST.CommandSetTableFontSizeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandSetTableFontSizeArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_increase', full_name='TST.CommandSetTableFontSizeArchive.is_increase', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='font_size_diff', full_name='TST.CommandSetTableFontSizeArchive.font_size_diff', index=2,
      number=3, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='font_size_list', full_name='TST.CommandSetTableFontSizeArchive.font_size_list', index=3,
      number=4, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inverse_font_size_list', full_name='TST.CommandSetTableFontSizeArchive.inverse_font_size_list', index=4,
      number=5, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_diff_map', full_name='TST.CommandSetTableFontSizeArchive.cell_diff_map', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inverse_cell_diff_map', full_name='TST.CommandSetTableFontSizeArchive.inverse_cell_diff_map', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='styles_container_refresh_done', full_name='TST.CommandSetTableFontSizeArchive.styles_container_refresh_done', index=7,
      number=8, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7939,
  serialized_end=8238,
)


_COMMANDSETTABLEFONTNAMEARCHIVE = _descriptor.Descriptor(
  name='CommandSetTableFontNameArchive',
  full_name='TST.CommandSetTableFontNameArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandSetTableFontNameArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='font_name', full_name='TST.CommandSetTableFontNameArchive.font_name', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preserve_face', full_name='TST.CommandSetTableFontNameArchive.preserve_face', index=2,
      number=3, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='previous_font_name', full_name='TST.CommandSetTableFontNameArchive.previous_font_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='previous_table_style', full_name='TST.CommandSetTableFontNameArchive.previous_table_style', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='previous_text_styles', full_name='TST.CommandSetTableFontNameArchive.previous_text_styles', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_diff_map', full_name='TST.CommandSetTableFontNameArchive.cell_diff_map', index=6,
      number=7, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inverse_cell_diff_map', full_name='TST.CommandSetTableFontNameArchive.inverse_cell_diff_map', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8241,
  serialized_end=8562,
)


_COMMANDSETTABLENAMEHEIGHTARCHIVE = _descriptor.Descriptor(
  name='CommandSetTableNameHeightArchive',
  full_name='TST.CommandSetTableNameHeightArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandSetTableNameHeightArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_table_name_height', full_name='TST.CommandSetTableNameHeightArchive.old_table_name_height', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_table_name_height', full_name='TST.CommandSetTableNameHeightArchive.new_table_name_height', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8565,
  serialized_end=8702,
)


_COMMANDSETNOWARCHIVE = _descriptor.Descriptor(
  name='CommandSetNowArchive',
  full_name='TST.CommandSetNowArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandSetNowArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8704,
  serialized_end=8767,
)


_COMMANDSETWASCUTARCHIVE = _descriptor.Descriptor(
  name='CommandSetWasCutArchive',
  full_name='TST.CommandSetWasCutArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandSetWasCutArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='from_table_uid', full_name='TST.CommandSetWasCutArchive.from_table_uid', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prev_from_table_uid', full_name='TST.CommandSetWasCutArchive.prev_from_table_uid', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='was_cut', full_name='TST.CommandSetWasCutArchive.was_cut', index=3,
      number=4, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prev_was_cut', full_name='TST.CommandSetWasCutArchive.prev_was_cut', index=4,
      number=5, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='from_group_by_uid', full_name='TST.CommandSetWasCutArchive.from_group_by_uid', index=5,
      number=6, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prev_from_group_by_uid', full_name='TST.CommandSetWasCutArchive.prev_from_group_by_uid', index=6,
      number=7, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8770,
  serialized_end=9031,
)


_COMMANDSTYLECELLSARCHIVE = _descriptor.Descriptor(
  name='CommandStyleCellsArchive',
  full_name='TST.CommandStyleCellsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandStyleCellsArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='format_properties', full_name='TST.CommandStyleCellsArchive.format_properties', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='selection', full_name='TST.CommandStyleCellsArchive.selection', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_cell_map', full_name='TST.CommandStyleCellsArchive.undo_cell_map', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='redo_cell_map', full_name='TST.CommandStyleCellsArchive.redo_cell_map', index=4,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text_undo', full_name='TST.CommandStyleCellsArchive.text_undo', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9034,
  serialized_end=9309,
)


_COMMANDSTYLETABLEARCHIVE = _descriptor.Descriptor(
  name='CommandStyleTableArchive',
  full_name='TST.CommandStyleTableArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandStyleTableArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='format_properties', full_name='TST.CommandStyleTableArchive.format_properties', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_style', full_name='TST.CommandStyleTableArchive.old_style', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_style', full_name='TST.CommandStyleTableArchive.new_style', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9312,
  serialized_end=9552,
)


_COMMANDSETREPEATINGHEADERENABLEDARCHIVE = _descriptor.Descriptor(
  name='CommandSetRepeatingHeaderEnabledArchive',
  full_name='TST.CommandSetRepeatingHeaderEnabledArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='repeating_header_enabled', full_name='TST.CommandSetRepeatingHeaderEnabledArchive.repeating_header_enabled', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='direction', full_name='TST.CommandSetRepeatingHeaderEnabledArchive.direction', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandSetRepeatingHeaderEnabledArchive.super', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prev_repeating_header_enabled', full_name='TST.CommandSetRepeatingHeaderEnabledArchive.prev_repeating_header_enabled', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9555,
  serialized_end=9757,
)


_COMMANDSETFILTERSENABLEDARCHIVE = _descriptor.Descriptor(
  name='CommandSetFiltersEnabledArchive',
  full_name='TST.CommandSetFiltersEnabledArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandSetFiltersEnabledArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_filters_enabled', full_name='TST.CommandSetFiltersEnabledArchive.new_filters_enabled', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_filters_enabled', full_name='TST.CommandSetFiltersEnabledArchive.old_filters_enabled', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rollback_uid_list', full_name='TST.CommandSetFiltersEnabledArchive.rollback_uid_list', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9760,
  serialized_end=9930,
)


_COMMANDADDTABLESTYLEPRESETARCHIVE = _descriptor.Descriptor(
  name='CommandAddTableStylePresetArchive',
  full_name='TST.CommandAddTableStylePresetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandAddTableStylePresetArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preset_index', full_name='TST.CommandAddTableStylePresetArchive.preset_index', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_styles', full_name='TST.CommandAddTableStylePresetArchive.table_styles', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='send_notification', full_name='TST.CommandAddTableStylePresetArchive.send_notification', index=3,
      number=4, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9933,
  serialized_end=10096,
)


_COMMANDREMOVETABLESTYLEPRESETARCHIVE = _descriptor.Descriptor(
  name='CommandRemoveTableStylePresetArchive',
  full_name='TST.CommandRemoveTableStylePresetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandRemoveTableStylePresetArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='theme', full_name='TST.CommandRemoveTableStylePresetArchive.theme', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='removed_table_styles', full_name='TST.CommandRemoveTableStylePresetArchive.removed_table_styles', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preset_id', full_name='TST.CommandRemoveTableStylePresetArchive.preset_id', index=3,
      number=4, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preset_index_in_theme', full_name='TST.CommandRemoveTableStylePresetArchive.preset_index_in_theme', index=4,
      number=5, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10099,
  serialized_end=10300,
)


_COMMANDREPLACETABLESTYLEPRESETARCHIVE = _descriptor.Descriptor(
  name='CommandReplaceTableStylePresetArchive',
  full_name='TST.CommandReplaceTableStylePresetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandReplaceTableStylePresetArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='theme', full_name='TST.CommandReplaceTableStylePresetArchive.theme', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_table_styles', full_name='TST.CommandReplaceTableStylePresetArchive.old_table_styles', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_table_styles', full_name='TST.CommandReplaceTableStylePresetArchive.new_table_styles', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10303,
  serialized_end=10493,
)


_COMMANDAPPLYTABLESTYLEPRESETARCHIVE = _descriptor.Descriptor(
  name='CommandApplyTableStylePresetArchive',
  full_name='TST.CommandApplyTableStylePresetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandApplyTableStylePresetArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preset', full_name='TST.CommandApplyTableStylePresetArchive.preset', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='styles', full_name='TST.CommandApplyTableStylePresetArchive.styles', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_preset', full_name='TST.CommandApplyTableStylePresetArchive.undo_preset', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_styles', full_name='TST.CommandApplyTableStylePresetArchive.undo_styles', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_diff_map', full_name='TST.CommandApplyTableStylePresetArchive.cell_diff_map', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_cell_diff_map', full_name='TST.CommandApplyTableStylePresetArchive.undo_cell_diff_map', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='apply_preset_option', full_name='TST.CommandApplyTableStylePresetArchive.apply_preset_option', index=7,
      number=8, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_clears_all_flag', full_name='TST.CommandApplyTableStylePresetArchive.table_clears_all_flag', index=8,
      number=11, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_table_clears_all_flag', full_name='TST.CommandApplyTableStylePresetArchive.undo_table_clears_all_flag', index=9,
      number=12, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row_col_styles', full_name='TST.CommandApplyTableStylePresetArchive.row_col_styles', index=10,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_row_col_styles', full_name='TST.CommandApplyTableStylePresetArchive.undo_row_col_styles', index=11,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='change_prop_map_wrapper', full_name='TST.CommandApplyTableStylePresetArchive.change_prop_map_wrapper', index=12,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10496,
  serialized_end=11055,
)


_COMMANDSETBASEARCHIVE = _descriptor.Descriptor(
  name='CommandSetBaseArchive',
  full_name='TST.CommandSetBaseArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandSetBaseArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='base', full_name='TST.CommandSetBaseArchive.base', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11057,
  serialized_end=11146,
)


_COMMANDSETBASEPLACESARCHIVE = _descriptor.Descriptor(
  name='CommandSetBasePlacesArchive',
  full_name='TST.CommandSetBasePlacesArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandSetBasePlacesArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='base_places', full_name='TST.CommandSetBasePlacesArchive.base_places', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11148,
  serialized_end=11250,
)


_COMMANDSETBASEUSEMINUSSIGNARCHIVE = _descriptor.Descriptor(
  name='CommandSetBaseUseMinusSignArchive',
  full_name='TST.CommandSetBaseUseMinusSignArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandSetBaseUseMinusSignArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='base_use_minus_sign', full_name='TST.CommandSetBaseUseMinusSignArchive.base_use_minus_sign', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11252,
  serialized_end=11368,
)


_COMMANDSETCURRENCYCODEARCHIVE = _descriptor.Descriptor(
  name='CommandSetCurrencyCodeArchive',
  full_name='TST.CommandSetCurrencyCodeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandSetCurrencyCodeArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency_code', full_name='TST.CommandSetCurrencyCodeArchive.currency_code', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11370,
  serialized_end=11476,
)


_COMMANDSETFRACTIONACCURACYARCHIVE = _descriptor.Descriptor(
  name='CommandSetFractionAccuracyArchive',
  full_name='TST.CommandSetFractionAccuracyArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandSetFractionAccuracyArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fraction_accuracy', full_name='TST.CommandSetFractionAccuracyArchive.fraction_accuracy', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11478,
  serialized_end=11592,
)


_COMMANDSETNEGATIVENUMBERSTYLEARCHIVE = _descriptor.Descriptor(
  name='CommandSetNegativeNumberStyleArchive',
  full_name='TST.CommandSetNegativeNumberStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandSetNegativeNumberStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='negative_number_style', full_name='TST.CommandSetNegativeNumberStyleArchive.negative_number_style', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11594,
  serialized_end=11715,
)


_COMMANDSETNUMBEROFDECIMALPLACESARCHIVE = _descriptor.Descriptor(
  name='CommandSetNumberOfDecimalPlacesArchive',
  full_name='TST.CommandSetNumberOfDecimalPlacesArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandSetNumberOfDecimalPlacesArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='decimal_places', full_name='TST.CommandSetNumberOfDecimalPlacesArchive.decimal_places', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11717,
  serialized_end=11833,
)


_COMMANDSETDATETIMEFORMATARCHIVE = _descriptor.Descriptor(
  name='CommandSetDateTimeFormatArchive',
  full_name='TST.CommandSetDateTimeFormatArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandSetDateTimeFormatArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date_format_string', full_name='TST.CommandSetDateTimeFormatArchive.date_format_string', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_format_string', full_name='TST.CommandSetDateTimeFormatArchive.time_format_string', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11836,
  serialized_end=11977,
)


_COMMANDSETSHOWTHOUSANDSSEPARATORARCHIVE = _descriptor.Descriptor(
  name='CommandSetShowThousandsSeparatorArchive',
  full_name='TST.CommandSetShowThousandsSeparatorArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandSetShowThousandsSeparatorArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='show_thousands_separator', full_name='TST.CommandSetShowThousandsSeparatorArchive.show_thousands_separator', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11979,
  serialized_end=12106,
)


_COMMANDSETUSEACCOUNTINGSTYLEARCHIVE = _descriptor.Descriptor(
  name='CommandSetUseAccountingStyleArchive',
  full_name='TST.CommandSetUseAccountingStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandSetUseAccountingStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_accounting_style', full_name='TST.CommandSetUseAccountingStyleArchive.use_accounting_style', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12108,
  serialized_end=12227,
)


_COMMANDSETRANGECONTROLMINMAXINCARCHIVE = _descriptor.Descriptor(
  name='CommandSetRangeControlMinMaxIncArchive',
  full_name='TST.CommandSetRangeControlMinMaxIncArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandSetRangeControlMinMaxIncArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='minimum', full_name='TST.CommandSetRangeControlMinMaxIncArchive.minimum', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maximum', full_name='TST.CommandSetRangeControlMinMaxIncArchive.maximum', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='increment', full_name='TST.CommandSetRangeControlMinMaxIncArchive.increment', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_diff_map', full_name='TST.CommandSetRangeControlMinMaxIncArchive.cell_diff_map', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_uid_list', full_name='TST.CommandSetRangeControlMinMaxIncArchive.cell_uid_list', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inverse_cell_diff_map', full_name='TST.CommandSetRangeControlMinMaxIncArchive.inverse_cell_diff_map', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_first_commit', full_name='TST.CommandSetRangeControlMinMaxIncArchive.is_first_commit', index=7,
      number=8, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12230,
  serialized_end=12523,
)


_COMMANDMOVECOLUMNSORROWSARCHIVE = _descriptor.Descriptor(
  name='CommandMoveColumnsOrRowsArchive',
  full_name='TST.CommandMoveColumnsOrRowsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandMoveColumnsOrRowsArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dest_uid', full_name='TST.CommandMoveColumnsOrRowsArchive.dest_uid', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='before', full_name='TST.CommandMoveColumnsOrRowsArchive.before', index=2,
      number=3, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_dest_uid', full_name='TST.CommandMoveColumnsOrRowsArchive.undo_dest_uid', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_before', full_name='TST.CommandMoveColumnsOrRowsArchive.undo_before', index=4,
      number=5, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uids', full_name='TST.CommandMoveColumnsOrRowsArchive.uids', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='direction', full_name='TST.CommandMoveColumnsOrRowsArchive.direction', index=6,
      number=7, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formula_rewrite_command', full_name='TST.CommandMoveColumnsOrRowsArchive.formula_rewrite_command', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12526,
  serialized_end=12821,
)


_COMMANDSORTARCHIVE = _descriptor.Descriptor(
  name='CommandSortArchive',
  full_name='TST.CommandSortArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandSortArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='from_row_uids', full_name='TST.CommandSortArchive.from_row_uids', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='to_row_uids', full_name='TST.CommandSortArchive.to_row_uids', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formula_rewrite_command', full_name='TST.CommandSortArchive.formula_rewrite_command', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12824,
  serialized_end=13000,
)


_COMMANDREWRITEFORMULASFORTRANSPOSEARCHIVE = _descriptor.Descriptor(
  name='CommandRewriteFormulasForTransposeArchive',
  full_name='TST.CommandRewriteFormulasForTransposeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandRewriteFormulasForTransposeArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rewrite_spec', full_name='TST.CommandRewriteFormulasForTransposeArchive.rewrite_spec', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formulas_to_rewrite', full_name='TST.CommandRewriteFormulasForTransposeArchive.formulas_to_rewrite', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='warningset_map', full_name='TST.CommandRewriteFormulasForTransposeArchive.warningset_map', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13003,
  serialized_end=13264,
)


_COMMANDREWRITETABLEFORMULASFORREWRITESPECARCHIVE = _descriptor.Descriptor(
  name='CommandRewriteTableFormulasForRewriteSpecArchive',
  full_name='TST.CommandRewriteTableFormulasForRewriteSpecArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandRewriteTableFormulasForRewriteSpecArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rewrite_spec', full_name='TST.CommandRewriteTableFormulasForRewriteSpecArchive.rewrite_spec', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formulas_to_rewrite', full_name='TST.CommandRewriteTableFormulasForRewriteSpecArchive.formulas_to_rewrite', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13267,
  serialized_end=13472,
)


_COMMANDREWRITEMERGEFORMULASARCHIVE = _descriptor.Descriptor(
  name='CommandRewriteMergeFormulasArchive',
  full_name='TST.CommandRewriteMergeFormulasArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandRewriteMergeFormulasArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rewrite_spec', full_name='TST.CommandRewriteMergeFormulasArchive.rewrite_spec', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formulas_to_rewrite', full_name='TST.CommandRewriteMergeFormulasArchive.formulas_to_rewrite', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13475,
  serialized_end=13666,
)


_COMMANDREWRITECATEGORYFORMULASARCHIVE = _descriptor.Descriptor(
  name='CommandRewriteCategoryFormulasArchive',
  full_name='TST.CommandRewriteCategoryFormulasArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandRewriteCategoryFormulasArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rewrite_spec', full_name='TST.CommandRewriteCategoryFormulasArchive.rewrite_spec', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formulas_to_rewrite', full_name='TST.CommandRewriteCategoryFormulasArchive.formulas_to_rewrite', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13669,
  serialized_end=13863,
)


_COMMANDREWRITEFILTERFORMULASFORTABLERESIZEARCHIVE = _descriptor.Descriptor(
  name='CommandRewriteFilterFormulasForTableResizeArchive',
  full_name='TST.CommandRewriteFilterFormulasForTableResizeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandRewriteFilterFormulasForTableResizeArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13865,
  serialized_end=13957,
)


_COMMANDREWRITEFILTERFORMULASFORREWRITESPECARCHIVE = _descriptor.Descriptor(
  name='CommandRewriteFilterFormulasForRewriteSpecArchive',
  full_name='TST.CommandRewriteFilterFormulasForRewriteSpecArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandRewriteFilterFormulasForRewriteSpecArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filter_set', full_name='TST.CommandRewriteFilterFormulasForRewriteSpecArchive.filter_set', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rewrite_spec', full_name='TST.CommandRewriteFilterFormulasForRewriteSpecArchive.rewrite_spec', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13960,
  serialized_end=14143,
)


_COMMANDREWRITECONDITIONALSTYLESFORREWRITESPECARCHIVE = _descriptor.Descriptor(
  name='CommandRewriteConditionalStylesForRewriteSpecArchive',
  full_name='TST.CommandRewriteConditionalStylesForRewriteSpecArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandRewriteConditionalStylesForRewriteSpecArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rewrite_spec', full_name='TST.CommandRewriteConditionalStylesForRewriteSpecArchive.rewrite_spec', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formulas_to_rewrite', full_name='TST.CommandRewriteConditionalStylesForRewriteSpecArchive.formulas_to_rewrite', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conditional_style_sets', full_name='TST.CommandRewriteConditionalStylesForRewriteSpecArchive.conditional_style_sets', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14146,
  serialized_end=14426,
)


_COMMANDMERGEARCHIVE = _descriptor.Descriptor(
  name='CommandMergeArchive',
  full_name='TST.CommandMergeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandMergeArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_uid_list', full_name='TST.CommandMergeArchive.cell_uid_list', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_cell_map', full_name='TST.CommandMergeArchive.undo_cell_map', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_formula_rewrite_command', full_name='TST.CommandMergeArchive.undo_formula_rewrite_command', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='merge_owner_rollback', full_name='TST.CommandMergeArchive.merge_owner_rollback', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commit_cell_map', full_name='TST.CommandMergeArchive.commit_cell_map', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14429,
  serialized_end=14703,
)


_COMMANDINVERSEMERGEARCHIVE = _descriptor.Descriptor(
  name='CommandInverseMergeArchive',
  full_name='TST.CommandInverseMergeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandInverseMergeArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='merge_source_cell_uid', full_name='TST.CommandInverseMergeArchive.merge_source_cell_uid', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14706,
  serialized_end=14836,
)


_COMMANDUNMERGEARCHIVE = _descriptor.Descriptor(
  name='CommandUnmergeArchive',
  full_name='TST.CommandUnmergeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandUnmergeArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unmerge_uid_ranges', full_name='TST.CommandUnmergeArchive.unmerge_uid_ranges', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_cell_map', full_name='TST.CommandUnmergeArchive.undo_cell_map', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_formula_rewrite_command', full_name='TST.CommandUnmergeArchive.undo_formula_rewrite_command', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14839,
  serialized_end=15046,
)


_COMMANDCHOOSETABLEIDREMAPPERARCHIVE = _descriptor.Descriptor(
  name='CommandChooseTableIdRemapperArchive',
  full_name='TST.CommandChooseTableIdRemapperArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandChooseTableIdRemapperArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_id_mapper', full_name='TST.CommandChooseTableIdRemapperArchive.table_id_mapper', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formula_rewrite_command_for_undo', full_name='TST.CommandChooseTableIdRemapperArchive.formula_rewrite_command_for_undo', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='apply_and_clear', full_name='TST.CommandChooseTableIdRemapperArchive.apply_and_clear', index=3,
      number=4, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15049,
  serialized_end=15262,
)


_COMMANDCATEGORYSETGROUPINGCOLUMNSARCHIVE = _descriptor.Descriptor(
  name='CommandCategorySetGroupingColumnsArchive',
  full_name='TST.CommandCategorySetGroupingColumnsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandCategorySetGroupingColumnsArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_enabled_changing', full_name='TST.CommandCategorySetGroupingColumnsArchive.new_enabled_changing', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_enabled_changing', full_name='TST.CommandCategorySetGroupingColumnsArchive.old_enabled_changing', index=2,
      number=3, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_grouping_columns', full_name='TST.CommandCategorySetGroupingColumnsArchive.new_grouping_columns', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_grouping_columns', full_name='TST.CommandCategorySetGroupingColumnsArchive.old_grouping_columns', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='restore_base_order', full_name='TST.CommandCategorySetGroupingColumnsArchive.restore_base_order', index=5,
      number=6, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='base_row_order', full_name='TST.CommandCategorySetGroupingColumnsArchive.base_row_order', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_restore_base_order', full_name='TST.CommandCategorySetGroupingColumnsArchive.undo_restore_base_order', index=7,
      number=8, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_base_row_order', full_name='TST.CommandCategorySetGroupingColumnsArchive.undo_base_row_order', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='restore_view_order', full_name='TST.CommandCategorySetGroupingColumnsArchive.restore_view_order', index=9,
      number=10, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='view_row_order', full_name='TST.CommandCategorySetGroupingColumnsArchive.view_row_order', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_restore_view_order', full_name='TST.CommandCategorySetGroupingColumnsArchive.undo_restore_view_order', index=11,
      number=12, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_view_row_order', full_name='TST.CommandCategorySetGroupingColumnsArchive.undo_view_row_order', index=12,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collapse_state', full_name='TST.CommandCategorySetGroupingColumnsArchive.collapse_state', index=13,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_collapse_state', full_name='TST.CommandCategorySetGroupingColumnsArchive.undo_collapse_state', index=14,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='summary_change_state', full_name='TST.CommandCategorySetGroupingColumnsArchive.summary_change_state', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_summary_change_state', full_name='TST.CommandCategorySetGroupingColumnsArchive.undo_summary_change_state', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_column_aggregates', full_name='TST.CommandCategorySetGroupingColumnsArchive.new_column_aggregates', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_column_aggregates', full_name='TST.CommandCategorySetGroupingColumnsArchive.old_column_aggregates', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_set_enabled_rewrite_command', full_name='TST.CommandCategorySetGroupingColumnsArchive.undo_set_enabled_rewrite_command', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_set_columns_rewrite_command', full_name='TST.CommandCategorySetGroupingColumnsArchive.undo_set_columns_rewrite_command', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='force_restore_all_states', full_name='TST.CommandCategorySetGroupingColumnsArchive.force_restore_all_states', index=21,
      number=22, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_diff_map', full_name='TST.CommandCategorySetGroupingColumnsArchive.cell_diff_map', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_cell_diff_map', full_name='TST.CommandCategorySetGroupingColumnsArchive.undo_cell_diff_map', index=23,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15265,
  serialized_end=16387,
)


_FORMULAEDITINGCOMMANDGROUPARCHIVE = _descriptor.Descriptor(
  name='FormulaEditingCommandGroupArchive',
  full_name='TST.FormulaEditingCommandGroupArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.FormulaEditingCommandGroupArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undoSelectionValid', full_name='TST.FormulaEditingCommandGroupArchive.undoSelectionValid', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undoSelectionStart', full_name='TST.FormulaEditingCommandGroupArchive.undoSelectionStart', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undoSelectionLength', full_name='TST.FormulaEditingCommandGroupArchive.undoSelectionLength', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undoActiveToken', full_name='TST.FormulaEditingCommandGroupArchive.undoActiveToken', index=4,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='redoSelectionValid', full_name='TST.FormulaEditingCommandGroupArchive.redoSelectionValid', index=5,
      number=6, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='redoSelectionStart', full_name='TST.FormulaEditingCommandGroupArchive.redoSelectionStart', index=6,
      number=7, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='redoSelectionLength', full_name='TST.FormulaEditingCommandGroupArchive.redoSelectionLength', index=7,
      number=8, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='redoActiveToken', full_name='TST.FormulaEditingCommandGroupArchive.redoActiveToken', index=8,
      number=9, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16390,
  serialized_end=16697,
)


_FORMULAEDITINGCOMMANDSELECTIONBEHAVIORARCHIVE = _descriptor.Descriptor(
  name='FormulaEditingCommandSelectionBehaviorArchive',
  full_name='TST.FormulaEditingCommandSelectionBehaviorArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.FormulaEditingCommandSelectionBehaviorArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undoActiveToken', full_name='TST.FormulaEditingCommandSelectionBehaviorArchive.undoActiveToken', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='redoActiveToken', full_name='TST.FormulaEditingCommandSelectionBehaviorArchive.redoActiveToken', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16700,
  serialized_end=16850,
)


_TABLECOMMANDSELECTIONBEHAVIORARCHIVE = _descriptor.Descriptor(
  name='TableCommandSelectionBehaviorArchive',
  full_name='TST.TableCommandSelectionBehaviorArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.TableCommandSelectionBehaviorArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_info', full_name='TST.TableCommandSelectionBehaviorArchive.table_info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_column_uid_hit_by_tap', full_name='TST.TableCommandSelectionBehaviorArchive.last_column_uid_hit_by_tap', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='invalidate_comments', full_name='TST.TableCommandSelectionBehaviorArchive.invalidate_comments', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16853,
  serialized_end=17056,
)


_COMMANDAPPLYCELLCOMMENTARCHIVE = _descriptor.Descriptor(
  name='CommandApplyCellCommentArchive',
  full_name='TST.CommandApplyCellCommentArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandApplyCellCommentArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_uid', full_name='TST.CommandApplyCellCommentArchive.cell_uid', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_comment_storage', full_name='TST.CommandApplyCellCommentArchive.old_comment_storage', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_comment_storage', full_name='TST.CommandApplyCellCommentArchive.new_comment_storage', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='forward_variant', full_name='TST.CommandApplyCellCommentArchive.forward_variant', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inverse_variant', full_name='TST.CommandApplyCellCommentArchive.inverse_variant', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17059,
  serialized_end=17369,
)


_COMMANDSETFORMULATOKENIZATIONARCHIVE = _descriptor.Descriptor(
  name='CommandSetFormulaTokenizationArchive',
  full_name='TST.CommandSetFormulaTokenizationArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandSetFormulaTokenizationArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tokenization', full_name='TST.CommandSetFormulaTokenizationArchive.tokenization', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17371,
  serialized_end=17467,
)


_COMMANDSETFILTERSETTYPEARCHIVE = _descriptor.Descriptor(
  name='CommandSetFilterSetTypeArchive',
  full_name='TST.CommandSetFilterSetTypeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandSetFilterSetTypeArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_filter_set_type', full_name='TST.CommandSetFilterSetTypeArchive.old_filter_set_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_filter_set_type', full_name='TST.CommandSetFilterSetTypeArchive.new_filter_set_type', index=2,
      number=3, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rollback_uid_list', full_name='TST.CommandSetFilterSetTypeArchive.rollback_uid_list', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17470,
  serialized_end=17713,
)


_COMMANDSETTEXTSTYLEARCHIVE = _descriptor.Descriptor(
  name='CommandSetTextStyleArchive',
  full_name='TST.CommandSetTextStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandSetTextStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_diff_map', full_name='TST.CommandSetTextStyleArchive.cell_diff_map', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inverse_cell_diff_map', full_name='TST.CommandSetTextStyleArchive.inverse_cell_diff_map', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17716,
  serialized_end=17871,
)


_COMMANDSETTEXTSTYLEPROPERTIESARCHIVE = _descriptor.Descriptor(
  name='CommandSetTextStylePropertiesArchive',
  full_name='TST.CommandSetTextStylePropertiesArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandSetTextStylePropertiesArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_diff_map', full_name='TST.CommandSetTextStylePropertiesArchive.cell_diff_map', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_was_rich_text', full_name='TST.CommandSetTextStylePropertiesArchive.cell_was_rich_text', index=2,
      number=3, type=8, cpp_type=7, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inverse_cell_diff_map', full_name='TST.CommandSetTextStylePropertiesArchive.inverse_cell_diff_map', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17874,
  serialized_end=18067,
)


_COMMANDJUSTFORNOTIFYINGARCHIVE = _descriptor.Descriptor(
  name='CommandJustForNotifyingArchive',
  full_name='TST.CommandJustForNotifyingArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandJustForNotifyingArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='change_descriptor_type', full_name='TST.CommandJustForNotifyingArchive.change_descriptor_type', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18069,
  serialized_end=18174,
)


_COMMANDSETSTORAGELANGUAGEARCHIVE = _descriptor.Descriptor(
  name='CommandSetStorageLanguageArchive',
  full_name='TST.CommandSetStorageLanguageArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandSetStorageLanguageArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='storage', full_name='TST.CommandSetStorageLanguageArchive.storage', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='language', full_name='TST.CommandSetStorageLanguageArchive.language', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range_location', full_name='TST.CommandSetStorageLanguageArchive.range_location', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range_length', full_name='TST.CommandSetStorageLanguageArchive.range_length', index=4,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_transaction', full_name='TST.CommandSetStorageLanguageArchive.undo_transaction', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18177,
  serialized_end=18393,
)


_COMMANDSETSORTORDERARCHIVE = _descriptor.Descriptor(
  name='CommandSetSortOrderArchive',
  full_name='TST.CommandSetSortOrderArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandSetSortOrderArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_sort_order', full_name='TST.CommandSetSortOrderArchive.old_sort_order', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_sort_order', full_name='TST.CommandSetSortOrderArchive.new_sort_order', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18396,
  serialized_end=18569,
)


_COMMANDREWRITESORTORDERFORTABLERESIZEARCHIVE = _descriptor.Descriptor(
  name='CommandRewriteSortOrderForTableResizeArchive',
  full_name='TST.CommandRewriteSortOrderForTableResizeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandRewriteSortOrderForTableResizeArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_sort_order', full_name='TST.CommandRewriteSortOrderForTableResizeArchive.old_sort_order', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_sort_order', full_name='TST.CommandRewriteSortOrderForTableResizeArchive.new_sort_order', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18572,
  serialized_end=18763,
)


_COMMANDREWRITESORTORDERFORREWRITESPECARCHIVE = _descriptor.Descriptor(
  name='CommandRewriteSortOrderForRewriteSpecArchive',
  full_name='TST.CommandRewriteSortOrderForRewriteSpecArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandRewriteSortOrderForRewriteSpecArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rewrite_spec', full_name='TST.CommandRewriteSortOrderForRewriteSpecArchive.rewrite_spec', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_sort_order', full_name='TST.CommandRewriteSortOrderForRewriteSpecArchive.old_sort_order', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_sort_order', full_name='TST.CommandRewriteSortOrderForRewriteSpecArchive.new_sort_order', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18766,
  serialized_end=19012,
)


_COMMANDSETFILTERSETARCHIVE = _descriptor.Descriptor(
  name='CommandSetFilterSetArchive',
  full_name='TST.CommandSetFilterSetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandSetFilterSetArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_filter_set', full_name='TST.CommandSetFilterSetArchive.new_filter_set', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_filter_set', full_name='TST.CommandSetFilterSetArchive.old_filter_set', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rollback_uid_list', full_name='TST.CommandSetFilterSetArchive.rollback_uid_list', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19015,
  serialized_end=19202,
)


_COLUMNROWRESTOREDATAARCHIVE = _descriptor.Descriptor(
  name='ColumnRowRestoreDataArchive',
  full_name='TST.ColumnRowRestoreDataArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid_list', full_name='TST.ColumnRowRestoreDataArchive.uid_list', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadatas', full_name='TST.ColumnRowRestoreDataArchive.metadatas', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19204,
  serialized_end=19312,
)


_COMMANDTRANSPOSETABLEARCHIVE = _descriptor.Descriptor(
  name='CommandTransposeTableArchive',
  full_name='TST.CommandTransposeTableArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandTransposeTableArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='original_table_range', full_name='TST.CommandTransposeTableArchive.original_table_range', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='original_cell_map', full_name='TST.CommandTransposeTableArchive.original_cell_map', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='original_footer_row_count', full_name='TST.CommandTransposeTableArchive.original_footer_row_count', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='original_column_widths', full_name='TST.CommandTransposeTableArchive.original_column_widths', index=4,
      number=5, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='original_row_heights', full_name='TST.CommandTransposeTableArchive.original_row_heights', index=5,
      number=6, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ineligible_merge_list', full_name='TST.CommandTransposeTableArchive.ineligible_merge_list', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transposed_cell_map', full_name='TST.CommandTransposeTableArchive.transposed_cell_map', index=7,
      number=8, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_formula_rewrite_command', full_name='TST.CommandTransposeTableArchive.undo_formula_rewrite_command', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rich_text_subcommands', full_name='TST.CommandTransposeTableArchive.rich_text_subcommands', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column_restore_data', full_name='TST.CommandTransposeTableArchive.column_restore_data', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row_restore_data', full_name='TST.CommandTransposeTableArchive.row_restore_data', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19315,
  serialized_end=19896,
)


_COMMANDSETSTRUCTUREDTEXTIMPORTRECORDARCHIVE = _descriptor.Descriptor(
  name='CommandSetStructuredTextImportRecordArchive',
  full_name='TST.CommandSetStructuredTextImportRecordArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandSetStructuredTextImportRecordArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_import_record', full_name='TST.CommandSetStructuredTextImportRecordArchive.new_import_record', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_import_record', full_name='TST.CommandSetStructuredTextImportRecordArchive.old_import_record', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19899,
  serialized_end=20105,
)


_COMMANDCATEGORYCOLLAPSEEXPANDGROUPARCHIVE = _descriptor.Descriptor(
  name='CommandCategoryCollapseExpandGroupArchive',
  full_name='TST.CommandCategoryCollapseExpandGroupArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandCategoryCollapseExpandGroupArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_collapsing', full_name='TST.CommandCategoryCollapseExpandGroupArchive.is_collapsing', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='grouping_columns', full_name='TST.CommandCategoryCollapseExpandGroupArchive.grouping_columns', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collapse_state', full_name='TST.CommandCategoryCollapseExpandGroupArchive.collapse_state', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_collapse_state', full_name='TST.CommandCategoryCollapseExpandGroupArchive.undo_collapse_state', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20108,
  serialized_end=20389,
)


_COMMANDCATEGORYCHANGESUMMARYAGGREGATETYPE = _descriptor.Descriptor(
  name='CommandCategoryChangeSummaryAggregateType',
  full_name='TST.CommandCategoryChangeSummaryAggregateType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandCategoryChangeSummaryAggregateType.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aggregate_type', full_name='TST.CommandCategoryChangeSummaryAggregateType.aggregate_type', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_aggregate_type', full_name='TST.CommandCategoryChangeSummaryAggregateType.undo_aggregate_type', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column_uid', full_name='TST.CommandCategoryChangeSummaryAggregateType.column_uid', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group_level', full_name='TST.CommandCategoryChangeSummaryAggregateType.group_level', index=4,
      number=5, type=17, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20392,
  serialized_end=20581,
)


_COMMANDCATEGORYSETLABELROWVISIBILITY = _descriptor.Descriptor(
  name='CommandCategorySetLabelRowVisibility',
  full_name='TST.CommandCategorySetLabelRowVisibility',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandCategorySetLabelRowVisibility.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group_level', full_name='TST.CommandCategorySetLabelRowVisibility.group_level', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_row_visibility', full_name='TST.CommandCategorySetLabelRowVisibility.label_row_visibility', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_label_row_visibility', full_name='TST.CommandCategorySetLabelRowVisibility.undo_label_row_visibility', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20584,
  serialized_end=20749,
)


_COMMANDCATEGORYWILLCHANGEGROUPVALUE = _descriptor.Descriptor(
  name='CommandCategoryWillChangeGroupValue',
  full_name='TST.CommandCategoryWillChangeGroupValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandCategoryWillChangeGroupValue.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group_node_uid', full_name='TST.CommandCategoryWillChangeGroupValue.group_node_uid', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_group_node_uid', full_name='TST.CommandCategoryWillChangeGroupValue.undo_group_node_uid', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group_value', full_name='TST.CommandCategoryWillChangeGroupValue.group_value', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_group_value', full_name='TST.CommandCategoryWillChangeGroupValue.undo_group_value', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rewrite_command_for_undo', full_name='TST.CommandCategoryWillChangeGroupValue.rewrite_command_for_undo', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20752,
  serialized_end=21050,
)


_IDEMPOTENTSELECTIONTRANSFORMERARCHIVE = _descriptor.Descriptor(
  name='IdempotentSelectionTransformerArchive',
  full_name='TST.IdempotentSelectionTransformerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='archived_selection', full_name='TST.IdempotentSelectionTransformerArchive.archived_selection', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21052,
  serialized_end=21135,
)


_WPSELECTIONTRANSFORMERARCHIVE = _descriptor.Descriptor(
  name='WPSelectionTransformerArchive',
  full_name='TST.WPSelectionTransformerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.WPSelectionTransformerArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='archived_selection', full_name='TST.WPSelectionTransformerArchive.archived_selection', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='origin_cell_uid', full_name='TST.WPSelectionTransformerArchive.origin_cell_uid', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21138,
  serialized_end=21322,
)


_TABLESUBSELECTIONTRANSFORMERBASEARCHIVE = _descriptor.Descriptor(
  name='TableSubSelectionTransformerBaseArchive',
  full_name='TST.TableSubSelectionTransformerBaseArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='table_info_id_path', full_name='TST.TableSubSelectionTransformerBaseArchive.table_info_id_path', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21324,
  serialized_end=21408,
)


_TABLENAMESELECTIONTRANSFORMERARCHIVE = _descriptor.Descriptor(
  name='TableNameSelectionTransformerArchive',
  full_name='TST.TableNameSelectionTransformerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.TableNameSelectionTransformerArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21410,
  serialized_end=21509,
)


_CONTROLCELLSELECTIONTRANSFORMERARCHIVE = _descriptor.Descriptor(
  name='ControlCellSelectionTransformerArchive',
  full_name='TST.ControlCellSelectionTransformerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.ControlCellSelectionTransformerArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_uids', full_name='TST.ControlCellSelectionTransformerArchive.cell_uids', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='origin_cell_uid', full_name='TST.ControlCellSelectionTransformerArchive.origin_cell_uid', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='origin_cell_id', full_name='TST.ControlCellSelectionTransformerArchive.origin_cell_id', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21512,
  serialized_end=21758,
)


_STOCKCELLSELECTIONTRANSFORMERARCHIVE = _descriptor.Descriptor(
  name='StockCellSelectionTransformerArchive',
  full_name='TST.StockCellSelectionTransformerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.StockCellSelectionTransformerArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_uids', full_name='TST.StockCellSelectionTransformerArchive.cell_uids', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='origin_cell_uid', full_name='TST.StockCellSelectionTransformerArchive.origin_cell_uid', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='origin_cell_id', full_name='TST.StockCellSelectionTransformerArchive.origin_cell_id', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21761,
  serialized_end=22005,
)


_REGIONSELECTIONTRANSFORMERARCHIVE = _descriptor.Descriptor(
  name='RegionSelectionTransformerArchive',
  full_name='TST.RegionSelectionTransformerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.RegionSelectionTransformerArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_uids', full_name='TST.RegionSelectionTransformerArchive.cell_uids', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='origin_cell_uid', full_name='TST.RegionSelectionTransformerArchive.origin_cell_uid', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='anchor_cell_uid', full_name='TST.RegionSelectionTransformerArchive.anchor_cell_uid', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cursor_cell_uid', full_name='TST.RegionSelectionTransformerArchive.cursor_cell_uid', index=4,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22008,
  serialized_end=22292,
)


_STROKESELECTIONTRANSFORMERARCHIVE = _descriptor.Descriptor(
  name='StrokeSelectionTransformerArchive',
  full_name='TST.StrokeSelectionTransformerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.StrokeSelectionTransformerArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='archived_selection', full_name='TST.StrokeSelectionTransformerArchive.archived_selection', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22295,
  serialized_end=22435,
)


_ROWCOLUMNSELECTIONTRANSFORMERARCHIVE = _descriptor.Descriptor(
  name='RowColumnSelectionTransformerArchive',
  full_name='TST.RowColumnSelectionTransformerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.RowColumnSelectionTransformerArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='selection_type', full_name='TST.RowColumnSelectionTransformerArchive.selection_type', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row_col_uids', full_name='TST.RowColumnSelectionTransformerArchive.row_col_uids', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22438,
  serialized_end=22621,
)


_COMMANDCATEGORYMOVEROWSARCHIVE = _descriptor.Descriptor(
  name='CommandCategoryMoveRowsArchive',
  full_name='TST.CommandCategoryMoveRowsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandCategoryMoveRowsArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action_type', full_name='TST.CommandCategoryMoveRowsArchive.action_type', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_row_order', full_name='TST.CommandCategoryMoveRowsArchive.category_row_order', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_category_row_order', full_name='TST.CommandCategoryMoveRowsArchive.undo_category_row_order', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_diff_map', full_name='TST.CommandCategoryMoveRowsArchive.cell_diff_map', index=4,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_cell_diff_map', full_name='TST.CommandCategoryMoveRowsArchive.undo_cell_diff_map', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='grouping_columns', full_name='TST.CommandCategoryMoveRowsArchive.grouping_columns', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22624,
  serialized_end=22939,
)


_COMMANDREWRITEHIDDENSTATESFORGROUPBYCHANGEARCHIVE = _descriptor.Descriptor(
  name='CommandRewriteHiddenStatesForGroupByChangeArchive',
  full_name='TST.CommandRewriteHiddenStatesForGroupByChangeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandRewriteHiddenStatesForGroupByChangeArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group_by_change', full_name='TST.CommandRewriteHiddenStatesForGroupByChangeArchive.group_by_change', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collapsed_state', full_name='TST.CommandRewriteHiddenStatesForGroupByChangeArchive.collapsed_state', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22942,
  serialized_end=23145,
)


_COMMANDREWRITEPENCILANNOTATIONFORMULASARCHIVE_ANNOTATIONPAIR = _descriptor.Descriptor(
  name='AnnotationPair',
  full_name='TST.CommandRewritePencilAnnotationFormulasArchive.AnnotationPair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='TST.CommandRewritePencilAnnotationFormulasArchive.AnnotationPair.index', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='annotation', full_name='TST.CommandRewritePencilAnnotationFormulasArchive.AnnotationPair.annotation', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23449,
  serialized_end=23516,
)

_COMMANDREWRITEPENCILANNOTATIONFORMULASARCHIVE = _descriptor.Descriptor(
  name='CommandRewritePencilAnnotationFormulasArchive',
  full_name='TST.CommandRewritePencilAnnotationFormulasArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TST.CommandRewritePencilAnnotationFormulasArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rewrite_spec', full_name='TST.CommandRewritePencilAnnotationFormulasArchive.rewrite_spec', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formulas_to_rewrite', full_name='TST.CommandRewritePencilAnnotationFormulasArchive.formulas_to_rewrite', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='annotations_for_undo', full_name='TST.CommandRewritePencilAnnotationFormulasArchive.annotations_for_undo', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_COMMANDREWRITEPENCILANNOTATIONFORMULASARCHIVE_ANNOTATIONPAIR, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23148,
  serialized_end=23516,
)

_TABLECOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_TABLECOMMANDARCHIVE.fields_by_name['table_info_id_path'].message_type = TSPMessages__pb2._UUIDPATH
_TABLECOMMANDARCHIVE.fields_by_name['default_cell_styles_container'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDAPPLYCELLCONTENTSARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDAPPLYCELLCONTENTSARCHIVE.fields_by_name['cell_diff_map'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDAPPLYCELLCONTENTSARCHIVE.fields_by_name['rollback_cell_diff_map'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDAPPLYCELLCONTENTSARCHIVE.fields_by_name['custom_format_keys'].message_type = TSPMessages__pb2._UUID
_COMMANDAPPLYCELLDIFFMAPARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDAPPLYCELLDIFFMAPARCHIVE.fields_by_name['cell_diff_map'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDAPPLYCELLDIFFMAPARCHIVE.fields_by_name['inverse_cell_diff_map'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDAPPLYCELLDIFFMAPARCHIVE.fields_by_name['custom_format_keys'].message_type = TSPMessages__pb2._UUID
_COMMANDAPPLYCELLMAPARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDAPPLYCELLMAPARCHIVE.fields_by_name['redo_cell_map'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDAPPLYCELLMAPARCHIVE.fields_by_name['undo_cell_map'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDAPPLYCELLMAPARCHIVE.fields_by_name['undo_formula_rewrite_command'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDAPPLYCELLMAPARCHIVE.fields_by_name['custom_format_keys'].message_type = TSPMessages__pb2._UUID
_COMMANDAPPLYCELLMAPARCHIVE.fields_by_name['formula_rewrite_commands'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDAPPLYCONCURRENTCELLMAPARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDAPPLYCONCURRENTCELLMAPARCHIVE.fields_by_name['redo_concurrent_cell_map'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDAPPLYCONCURRENTCELLMAPARCHIVE.fields_by_name['undo_concurrent_cell_map'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDAPPLYCONCURRENTCELLMAPARCHIVE.fields_by_name['undo_formula_rewrite_command'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDAPPLYCONCURRENTCELLMAPARCHIVE.fields_by_name['custom_format_keys'].message_type = TSPMessages__pb2._UUID
_COMMANDAPPLYCONCURRENTCELLMAPARCHIVE.fields_by_name['formula_rewrite_commands'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDCHANGEFREEZEHEADERSTATEARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDCHANGEFREEZEHEADERSTATEARCHIVE.fields_by_name['direction'].enum_type = TSTArchives__pb2._TABLEDIMENSIONARCHIVE
_COMMANDDELETECELLSARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDDELETECELLSARCHIVE.fields_by_name['cell_uid_region'].message_type = TSTArchives__pb2._CELLUIDREGIONARCHIVE
_COMMANDDELETECELLSARCHIVE.fields_by_name['summary_cell_uid_list'].message_type = TSTArchives__pb2._CELLUIDLISTARCHIVE
_COMMANDDELETECELLSARCHIVE.fields_by_name['inverse_concurrent_cell_map'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDDELETECELLCONTENTSARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDDELETECELLCONTENTSARCHIVE.fields_by_name['cell_uid_list'].message_type = TSTArchives__pb2._CELLUIDLISTARCHIVE
_COMMANDDELETECELLCONTENTSARCHIVE.fields_by_name['inverse_cell_diff_map'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDMUTATECELLFORMATARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDMUTATECELLFORMATARCHIVE.fields_by_name['cell_uid_list'].message_type = TSTArchives__pb2._CELLUIDLISTARCHIVE
_COMMANDMUTATECELLFORMATARCHIVE.fields_by_name['inverse_cell_diff_map'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDMUTATECELLFORMATARCHIVE.fields_by_name['whole_format_diff_map'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSETAUTOMATICDURATIONUNITSARCHIVE.fields_by_name['super'].message_type = _COMMANDMUTATECELLFORMATARCHIVE
_COMMANDSETDURATIONSTYLEARCHIVE.fields_by_name['super'].message_type = _COMMANDMUTATECELLFORMATARCHIVE
_COMMANDSETDURATIONUNITSMALLESTLARGESTARCHIVE.fields_by_name['super'].message_type = _COMMANDMUTATECELLFORMATARCHIVE
_COMMANDREPLACECUSTOMFORMATARCHIVE.fields_by_name['undo_diff_map'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDREPLACECUSTOMFORMATARCHIVE.fields_by_name['commit_diff_map'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDREPLACECUSTOMFORMATARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDMOVECELLSARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDMOVECELLSARCHIVE.fields_by_name['dst_table_info_id_path'].message_type = TSPMessages__pb2._UUIDPATH
_COMMANDMOVECELLSARCHIVE.fields_by_name['src_uid_range'].message_type = TSPMessages__pb2._UUIDRECTARCHIVE
_COMMANDMOVECELLSARCHIVE.fields_by_name['dst_uid_range'].message_type = TSPMessages__pb2._UUIDRECTARCHIVE
_COMMANDMOVECELLSARCHIVE.fields_by_name['table_dimension'].enum_type = TSTArchives__pb2._TABLEDIMENSIONARCHIVE
_COMMANDMOVECELLSARCHIVE.fields_by_name['src_cell_map'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDMOVECELLSARCHIVE.fields_by_name['dst_cell_map'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDMOVECELLSARCHIVE.fields_by_name['dst_cell_styles_container'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDMOVECELLSARCHIVE.fields_by_name['src_undo_cell_map'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDMOVECELLSARCHIVE.fields_by_name['dst_undo_cell_map'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDMOVECELLSARCHIVE.fields_by_name['formula_rewrite_commands'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDMOVECELLSARCHIVE.fields_by_name['merge_action_to_restore'].message_type = TSTArchives__pb2._MERGEOPERATIONARCHIVE
_COMMANDMOVECELLSARCHIVE.fields_by_name['comment_cell_uids_to_restore'].message_type = TSTArchives__pb2._CELLUIDLISTARCHIVE
_COMMANDMOVECELLSARCHIVE.fields_by_name['comment_storages_to_restore'].message_type = TSPMessages__pb2._REFERENCE
_COLUMNROWMETADATAARCHIVE.fields_by_name['cell_style'].message_type = TSPMessages__pb2._REFERENCE
_COLUMNROWMETADATAARCHIVE.fields_by_name['text_style'].message_type = TSPMessages__pb2._REFERENCE
_COLUMNROWMETADATAARCHIVE.fields_by_name['uuid'].message_type = TSPMessages__pb2._UUID
_COMMANDINSERTCOLUMNSORROWSARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDINSERTCOLUMNSORROWSARCHIVE.fields_by_name['bundle'].message_type = _COLUMNROWBUNDLEARCHIVE
_COMMANDINSERTCOLUMNSORROWSARCHIVE.fields_by_name['cell_map'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDINSERTCOLUMNSORROWSARCHIVE.fields_by_name['undo_commands'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDINSERTCOLUMNSORROWSARCHIVE.fields_by_name['undo_cell_map'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDINSERTCOLUMNSORROWSARCHIVE.fields_by_name['sort_order'].message_type = TSTArchives__pb2._TABLESORTORDERUIDARCHIVE
_COMMANDINSERTCOLUMNSORROWSARCHIVE.fields_by_name['filter_set'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDINSERTCOLUMNSORROWSARCHIVE.fields_by_name['undo_order'].message_type = TSPMessages__pb2._UUID
_COMMANDINSERTCOLUMNSORROWSARCHIVE.fields_by_name['src_row_column_uid'].message_type = TSPMessages__pb2._UUID
_COMMANDINSERTCOLUMNSORROWSARCHIVE.fields_by_name['opp_row_column_uid'].message_type = TSPMessages__pb2._UUID
_COLUMNROWBUNDLEARCHIVE.fields_by_name['view_uid_list'].message_type = TSPMessages__pb2._UUID
_COLUMNROWBUNDLEARCHIVE.fields_by_name['view_type_list'].enum_type = _COLUMNROWTYPEENUM
_COLUMNROWBUNDLEARCHIVE.fields_by_name['base_uid_list'].message_type = TSPMessages__pb2._UUID
_COLUMNROWBUNDLEARCHIVE.fields_by_name['base_type_list'].enum_type = _COLUMNROWTYPEENUM
_COLUMNROWBUNDLEARCHIVE.fields_by_name['category_order_uid_list'].message_type = TSPMessages__pb2._UUID
_COLUMNROWBUNDLEARCHIVE.fields_by_name['category_order_type_list'].enum_type = _COLUMNROWTYPEENUM
_COLUMNROWBUNDLEARCHIVE.fields_by_name['metadata_list'].message_type = _COLUMNROWMETADATAARCHIVE
_COMMANDREMOVECOLUMNSORROWSARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDREMOVECOLUMNSORROWSARCHIVE.fields_by_name['bundle'].message_type = _COLUMNROWBUNDLEARCHIVE
_COMMANDREMOVECOLUMNSORROWSARCHIVE.fields_by_name['cell_map'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDREMOVECOLUMNSORROWSARCHIVE.fields_by_name['undo_cell_map'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDREMOVECOLUMNSORROWSARCHIVE.fields_by_name['undo_filter_set'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDREMOVECOLUMNSORROWSARCHIVE.fields_by_name['undo_sort_order'].message_type = TSTArchives__pb2._TABLESORTORDERUIDARCHIVE
_COMMANDREMOVECOLUMNSORROWSARCHIVE.fields_by_name['formula_rewrite_command_for_undo'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDREMOVECOLUMNSORROWSARCHIVE.fields_by_name['undo_order'].message_type = TSPMessages__pb2._UUID
_COMMANDROWCOLUMNRANGEARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDROWCOLUMNRANGEARCHIVE.fields_by_name['uids'].message_type = TSPMessages__pb2._UUID
_COMMANDRESIZECOLUMNORROWARCHIVE.fields_by_name['super'].message_type = _COMMANDROWCOLUMNRANGEARCHIVE
_COMMANDCATEGORYRESIZECOLUMNORROWARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDHIDESHOWARCHIVE.fields_by_name['super'].message_type = _COMMANDROWCOLUMNRANGEARCHIVE
_COMMANDHIDESHOWARCHIVE.fields_by_name['hide_show_action'].enum_type = TSTArchives__pb2._HIDESHOWACTIONARCHIVE
_COMMANDHIDESHOWARCHIVE.fields_by_name['hide_show_action_for_undo'].enum_type = TSTArchives__pb2._HIDESHOWACTIONARCHIVE
_COMMANDTEXTPREFLIGHTINSERTCELLARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDTEXTPREFLIGHTINSERTCELLARCHIVE.fields_by_name['coalesced_textcommand'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDTEXTPREFLIGHTINSERTCELLARCHIVE.fields_by_name['postflightcommand'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDTEXTPREFLIGHTINSERTCELLARCHIVE.fields_by_name['editing_cell'].message_type = TSTArchives__pb2._CELL
_COMMANDTEXTPREFLIGHTINSERTCELLARCHIVE.fields_by_name['editing_storage'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDTEXTPREFLIGHTINSERTCELLARCHIVE.fields_by_name['cell_uid'].message_type = TSPMessages__pb2._UUIDCOORDARCHIVE
_COMMANDTEXTPREFLIGHTINSERTCELLARCHIVE.fields_by_name['archived_initial_selection_path'].message_type = TSKArchives__pb2._SELECTIONPATHARCHIVE
_COMMANDPOSTFLIGHTSETCELLARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDPOSTFLIGHTSETCELLARCHIVE.fields_by_name['childcommandundo'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDPOSTFLIGHTSETCELLARCHIVE.fields_by_name['editing_cell'].message_type = TSTArchives__pb2._CELL
_COMMANDPOSTFLIGHTSETCELLARCHIVE.fields_by_name['new_cell'].message_type = TSTArchives__pb2._CELL
_COMMANDPOSTFLIGHTSETCELLARCHIVE.fields_by_name['editing_storage'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDPOSTFLIGHTSETCELLARCHIVE.fields_by_name['cell_uid'].message_type = TSPMessages__pb2._UUIDCOORDARCHIVE
_COMMANDCHANGETABLEAREAFORCOLUMNORROWARCHIVE.fields_by_name['super'].message_type = _COMMANDROWCOLUMNRANGEARCHIVE
_COMMANDCHANGETABLEAREAFORCOLUMNORROWARCHIVE.fields_by_name['table_area_transition'].enum_type = _TABLEAREATRANSITION
_COMMANDCHANGETABLEAREAFORCOLUMNORROWARCHIVE.fields_by_name['cell_diff_map'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDCHANGETABLEAREAFORCOLUMNORROWARCHIVE.fields_by_name['undo_cell_diff_map'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDCHANGETABLEAREAFORCOLUMNORROWARCHIVE.fields_by_name['undo_commands'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSETPENCILANNOTATIONSARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDSETPENCILANNOTATIONSARCHIVE.fields_by_name['annotations'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSETPENCILANNOTATIONSARCHIVE.fields_by_name['formulas'].message_type = TSCEArchives__pb2._FORMULAARCHIVE
_COMMANDSETPENCILANNOTATIONSARCHIVE.fields_by_name['inverse_formulas'].message_type = TSCEArchives__pb2._FORMULAARCHIVE
_COMMANDSETTABLENAMEARCHIVE.fields_by_name['newstyle'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSETTABLENAMEARCHIVE.fields_by_name['oldstyle'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSETTABLENAMEARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDSETTABLENAMEARCHIVE.fields_by_name['old_shape_style'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSETTABLENAMEARCHIVE.fields_by_name['new_shape_style'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSETTABLENAMEENABLEDARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDSETTABLEFONTSIZEARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDSETTABLEFONTSIZEARCHIVE.fields_by_name['cell_diff_map'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSETTABLEFONTSIZEARCHIVE.fields_by_name['inverse_cell_diff_map'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSETTABLEFONTNAMEARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDSETTABLEFONTNAMEARCHIVE.fields_by_name['previous_table_style'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSETTABLEFONTNAMEARCHIVE.fields_by_name['previous_text_styles'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSETTABLEFONTNAMEARCHIVE.fields_by_name['cell_diff_map'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSETTABLEFONTNAMEARCHIVE.fields_by_name['inverse_cell_diff_map'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSETTABLENAMEHEIGHTARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDSETNOWARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDSETWASCUTARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDSETWASCUTARCHIVE.fields_by_name['from_table_uid'].message_type = TSPMessages__pb2._UUID
_COMMANDSETWASCUTARCHIVE.fields_by_name['prev_from_table_uid'].message_type = TSPMessages__pb2._UUID
_COMMANDSETWASCUTARCHIVE.fields_by_name['from_group_by_uid'].message_type = TSPMessages__pb2._UUID
_COMMANDSETWASCUTARCHIVE.fields_by_name['prev_from_group_by_uid'].message_type = TSPMessages__pb2._UUID
_COMMANDSTYLECELLSARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDSTYLECELLSARCHIVE.fields_by_name['format_properties'].message_type = TSPMessages__pb2._REFERENCEDICTIONARY
_COMMANDSTYLECELLSARCHIVE.fields_by_name['selection'].message_type = TSTArchives__pb2._SELECTIONARCHIVE
_COMMANDSTYLECELLSARCHIVE.fields_by_name['undo_cell_map'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSTYLECELLSARCHIVE.fields_by_name['redo_cell_map'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSTYLECELLSARCHIVE.fields_by_name['text_undo'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSTYLETABLEARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDSTYLETABLEARCHIVE.fields_by_name['format_properties'].message_type = TSPMessages__pb2._REFERENCEDICTIONARY
_COMMANDSTYLETABLEARCHIVE.fields_by_name['old_style'].message_type = TSTArchives__sos__pb2._TABLESTYLEPROPERTYCHANGESETARCHIVE
_COMMANDSTYLETABLEARCHIVE.fields_by_name['new_style'].message_type = TSTArchives__sos__pb2._TABLESTYLEPROPERTYCHANGESETARCHIVE
_COMMANDSETREPEATINGHEADERENABLEDARCHIVE.fields_by_name['direction'].enum_type = TSTArchives__pb2._TABLEDIMENSIONARCHIVE
_COMMANDSETREPEATINGHEADERENABLEDARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDSETFILTERSENABLEDARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDSETFILTERSENABLEDARCHIVE.fields_by_name['rollback_uid_list'].message_type = TSPMessages__pb2._UUID
_COMMANDADDTABLESTYLEPRESETARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDADDTABLESTYLEPRESETARCHIVE.fields_by_name['table_styles'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDREMOVETABLESTYLEPRESETARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDREMOVETABLESTYLEPRESETARCHIVE.fields_by_name['theme'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDREMOVETABLESTYLEPRESETARCHIVE.fields_by_name['removed_table_styles'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDREPLACETABLESTYLEPRESETARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDREPLACETABLESTYLEPRESETARCHIVE.fields_by_name['theme'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDREPLACETABLESTYLEPRESETARCHIVE.fields_by_name['old_table_styles'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDREPLACETABLESTYLEPRESETARCHIVE.fields_by_name['new_table_styles'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDAPPLYTABLESTYLEPRESETARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDAPPLYTABLESTYLEPRESETARCHIVE.fields_by_name['preset'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDAPPLYTABLESTYLEPRESETARCHIVE.fields_by_name['styles'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDAPPLYTABLESTYLEPRESETARCHIVE.fields_by_name['undo_preset'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDAPPLYTABLESTYLEPRESETARCHIVE.fields_by_name['undo_styles'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDAPPLYTABLESTYLEPRESETARCHIVE.fields_by_name['cell_diff_map'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDAPPLYTABLESTYLEPRESETARCHIVE.fields_by_name['undo_cell_diff_map'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDAPPLYTABLESTYLEPRESETARCHIVE.fields_by_name['row_col_styles'].message_type = _COLUMNROWMETADATAARCHIVE
_COMMANDAPPLYTABLESTYLEPRESETARCHIVE.fields_by_name['undo_row_col_styles'].message_type = _COLUMNROWMETADATAARCHIVE
_COMMANDAPPLYTABLESTYLEPRESETARCHIVE.fields_by_name['change_prop_map_wrapper'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSETBASEARCHIVE.fields_by_name['super'].message_type = _COMMANDMUTATECELLFORMATARCHIVE
_COMMANDSETBASEPLACESARCHIVE.fields_by_name['super'].message_type = _COMMANDMUTATECELLFORMATARCHIVE
_COMMANDSETBASEUSEMINUSSIGNARCHIVE.fields_by_name['super'].message_type = _COMMANDMUTATECELLFORMATARCHIVE
_COMMANDSETCURRENCYCODEARCHIVE.fields_by_name['super'].message_type = _COMMANDMUTATECELLFORMATARCHIVE
_COMMANDSETFRACTIONACCURACYARCHIVE.fields_by_name['super'].message_type = _COMMANDMUTATECELLFORMATARCHIVE
_COMMANDSETNEGATIVENUMBERSTYLEARCHIVE.fields_by_name['super'].message_type = _COMMANDMUTATECELLFORMATARCHIVE
_COMMANDSETNUMBEROFDECIMALPLACESARCHIVE.fields_by_name['super'].message_type = _COMMANDMUTATECELLFORMATARCHIVE
_COMMANDSETDATETIMEFORMATARCHIVE.fields_by_name['super'].message_type = _COMMANDMUTATECELLFORMATARCHIVE
_COMMANDSETSHOWTHOUSANDSSEPARATORARCHIVE.fields_by_name['super'].message_type = _COMMANDMUTATECELLFORMATARCHIVE
_COMMANDSETUSEACCOUNTINGSTYLEARCHIVE.fields_by_name['super'].message_type = _COMMANDMUTATECELLFORMATARCHIVE
_COMMANDSETRANGECONTROLMINMAXINCARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDSETRANGECONTROLMINMAXINCARCHIVE.fields_by_name['cell_diff_map'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSETRANGECONTROLMINMAXINCARCHIVE.fields_by_name['cell_uid_list'].message_type = TSTArchives__pb2._CELLUIDLISTARCHIVE
_COMMANDSETRANGECONTROLMINMAXINCARCHIVE.fields_by_name['inverse_cell_diff_map'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDMOVECOLUMNSORROWSARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDMOVECOLUMNSORROWSARCHIVE.fields_by_name['dest_uid'].message_type = TSPMessages__pb2._UUID
_COMMANDMOVECOLUMNSORROWSARCHIVE.fields_by_name['undo_dest_uid'].message_type = TSPMessages__pb2._UUID
_COMMANDMOVECOLUMNSORROWSARCHIVE.fields_by_name['uids'].message_type = TSPMessages__pb2._UUID
_COMMANDMOVECOLUMNSORROWSARCHIVE.fields_by_name['direction'].enum_type = TSTArchives__pb2._TABLEDIMENSIONARCHIVE
_COMMANDMOVECOLUMNSORROWSARCHIVE.fields_by_name['formula_rewrite_command'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSORTARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDSORTARCHIVE.fields_by_name['from_row_uids'].message_type = TSPMessages__pb2._UUID
_COMMANDSORTARCHIVE.fields_by_name['to_row_uids'].message_type = TSPMessages__pb2._UUID
_COMMANDSORTARCHIVE.fields_by_name['formula_rewrite_command'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDREWRITEFORMULASFORTRANSPOSEARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDREWRITEFORMULASFORTRANSPOSEARCHIVE.fields_by_name['rewrite_spec'].message_type = TSCEArchives__pb2._FORMULAREWRITESPECARCHIVE
_COMMANDREWRITEFORMULASFORTRANSPOSEARCHIVE.fields_by_name['formulas_to_rewrite'].message_type = TSCEArchives__pb2._FORMULASFORUNDOARCHIVE
_COMMANDREWRITEFORMULASFORTRANSPOSEARCHIVE.fields_by_name['warningset_map'].message_type = TSTArchives__pb2._IMPORTWARNINGSETBYCELLREFARCHIVE
_COMMANDREWRITETABLEFORMULASFORREWRITESPECARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDREWRITETABLEFORMULASFORREWRITESPECARCHIVE.fields_by_name['rewrite_spec'].message_type = TSCEArchives__pb2._FORMULAREWRITESPECARCHIVE
_COMMANDREWRITETABLEFORMULASFORREWRITESPECARCHIVE.fields_by_name['formulas_to_rewrite'].message_type = TSCEArchives__pb2._FORMULASFORUNDOARCHIVE
_COMMANDREWRITEMERGEFORMULASARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDREWRITEMERGEFORMULASARCHIVE.fields_by_name['rewrite_spec'].message_type = TSCEArchives__pb2._FORMULAREWRITESPECARCHIVE
_COMMANDREWRITEMERGEFORMULASARCHIVE.fields_by_name['formulas_to_rewrite'].message_type = TSCEArchives__pb2._FORMULASFORUNDOARCHIVE
_COMMANDREWRITECATEGORYFORMULASARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDREWRITECATEGORYFORMULASARCHIVE.fields_by_name['rewrite_spec'].message_type = TSCEArchives__pb2._FORMULAREWRITESPECARCHIVE
_COMMANDREWRITECATEGORYFORMULASARCHIVE.fields_by_name['formulas_to_rewrite'].message_type = TSCEArchives__pb2._FORMULASFORUNDOARCHIVE
_COMMANDREWRITEFILTERFORMULASFORTABLERESIZEARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDREWRITEFILTERFORMULASFORREWRITESPECARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDREWRITEFILTERFORMULASFORREWRITESPECARCHIVE.fields_by_name['filter_set'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDREWRITEFILTERFORMULASFORREWRITESPECARCHIVE.fields_by_name['rewrite_spec'].message_type = TSCEArchives__pb2._FORMULAREWRITESPECARCHIVE
_COMMANDREWRITECONDITIONALSTYLESFORREWRITESPECARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDREWRITECONDITIONALSTYLESFORREWRITESPECARCHIVE.fields_by_name['rewrite_spec'].message_type = TSCEArchives__pb2._FORMULAREWRITESPECARCHIVE
_COMMANDREWRITECONDITIONALSTYLESFORREWRITESPECARCHIVE.fields_by_name['formulas_to_rewrite'].message_type = TSCEArchives__pb2._FORMULASFORUNDOARCHIVE
_COMMANDREWRITECONDITIONALSTYLESFORREWRITESPECARCHIVE.fields_by_name['conditional_style_sets'].message_type = TSCEArchives__pb2._EXPANDEDCELLREFOBJECTMAPARCHIVE
_COMMANDMERGEARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDMERGEARCHIVE.fields_by_name['cell_uid_list'].message_type = TSTArchives__pb2._CELLUIDLISTARCHIVE
_COMMANDMERGEARCHIVE.fields_by_name['undo_cell_map'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDMERGEARCHIVE.fields_by_name['undo_formula_rewrite_command'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDMERGEARCHIVE.fields_by_name['commit_cell_map'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDINVERSEMERGEARCHIVE.fields_by_name['super'].message_type = _COMMANDAPPLYCELLMAPARCHIVE
_COMMANDINVERSEMERGEARCHIVE.fields_by_name['merge_source_cell_uid'].message_type = TSPMessages__pb2._UUIDCOORDARCHIVE
_COMMANDUNMERGEARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDUNMERGEARCHIVE.fields_by_name['unmerge_uid_ranges'].message_type = TSPMessages__pb2._UUIDRECTARCHIVE
_COMMANDUNMERGEARCHIVE.fields_by_name['undo_cell_map'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDUNMERGEARCHIVE.fields_by_name['undo_formula_rewrite_command'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDCHOOSETABLEIDREMAPPERARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDCHOOSETABLEIDREMAPPERARCHIVE.fields_by_name['table_id_mapper'].message_type = TSTArchives__pb2._MULTITABLEREMAPPERARCHIVE
_COMMANDCHOOSETABLEIDREMAPPERARCHIVE.fields_by_name['formula_rewrite_command_for_undo'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDCATEGORYSETGROUPINGCOLUMNSARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDCATEGORYSETGROUPINGCOLUMNSARCHIVE.fields_by_name['new_grouping_columns'].message_type = TSTArchives__pb2._GROUPCOLUMNLISTARCHIVE
_COMMANDCATEGORYSETGROUPINGCOLUMNSARCHIVE.fields_by_name['old_grouping_columns'].message_type = TSTArchives__pb2._GROUPCOLUMNLISTARCHIVE
_COMMANDCATEGORYSETGROUPINGCOLUMNSARCHIVE.fields_by_name['base_row_order'].message_type = TSPMessages__pb2._UUID
_COMMANDCATEGORYSETGROUPINGCOLUMNSARCHIVE.fields_by_name['undo_base_row_order'].message_type = TSPMessages__pb2._UUID
_COMMANDCATEGORYSETGROUPINGCOLUMNSARCHIVE.fields_by_name['view_row_order'].message_type = TSPMessages__pb2._UUID
_COMMANDCATEGORYSETGROUPINGCOLUMNSARCHIVE.fields_by_name['undo_view_row_order'].message_type = TSPMessages__pb2._UUID
_COMMANDCATEGORYSETGROUPINGCOLUMNSARCHIVE.fields_by_name['collapse_state'].message_type = TSPMessages__pb2._UUID
_COMMANDCATEGORYSETGROUPINGCOLUMNSARCHIVE.fields_by_name['undo_collapse_state'].message_type = TSPMessages__pb2._UUID
_COMMANDCATEGORYSETGROUPINGCOLUMNSARCHIVE.fields_by_name['summary_change_state'].message_type = TSTArchives__pb2._SUMMARYMODELGROUPBYCHANGESTATEARCHIVE
_COMMANDCATEGORYSETGROUPINGCOLUMNSARCHIVE.fields_by_name['undo_summary_change_state'].message_type = TSTArchives__pb2._SUMMARYMODELGROUPBYCHANGESTATEARCHIVE
_COMMANDCATEGORYSETGROUPINGCOLUMNSARCHIVE.fields_by_name['new_column_aggregates'].message_type = TSTArchives__pb2._COLUMNAGGREGATELISTARCHIVE
_COMMANDCATEGORYSETGROUPINGCOLUMNSARCHIVE.fields_by_name['old_column_aggregates'].message_type = TSTArchives__pb2._COLUMNAGGREGATELISTARCHIVE
_COMMANDCATEGORYSETGROUPINGCOLUMNSARCHIVE.fields_by_name['undo_set_enabled_rewrite_command'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDCATEGORYSETGROUPINGCOLUMNSARCHIVE.fields_by_name['undo_set_columns_rewrite_command'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDCATEGORYSETGROUPINGCOLUMNSARCHIVE.fields_by_name['cell_diff_map'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDCATEGORYSETGROUPINGCOLUMNSARCHIVE.fields_by_name['undo_cell_diff_map'].message_type = TSPMessages__pb2._REFERENCE
_FORMULAEDITINGCOMMANDGROUPARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._PROGRESSIVECOMMANDGROUPARCHIVE
_FORMULAEDITINGCOMMANDSELECTIONBEHAVIORARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDSELECTIONBEHAVIORARCHIVE
_TABLECOMMANDSELECTIONBEHAVIORARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDSELECTIONBEHAVIORARCHIVE
_TABLECOMMANDSELECTIONBEHAVIORARCHIVE.fields_by_name['table_info'].message_type = TSPMessages__pb2._REFERENCE
_TABLECOMMANDSELECTIONBEHAVIORARCHIVE.fields_by_name['last_column_uid_hit_by_tap'].message_type = TSPMessages__pb2._UUID
_COMMANDAPPLYCELLCOMMENTARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDAPPLYCELLCOMMENTARCHIVE.fields_by_name['cell_uid'].message_type = TSPMessages__pb2._UUIDCOORDARCHIVE
_COMMANDAPPLYCELLCOMMENTARCHIVE.fields_by_name['old_comment_storage'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDAPPLYCELLCOMMENTARCHIVE.fields_by_name['new_comment_storage'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDAPPLYCELLCOMMENTARCHIVE.fields_by_name['forward_variant'].enum_type = TSDCommandArchives__pb2._COMMENTCOMMANDVARIANT
_COMMANDAPPLYCELLCOMMENTARCHIVE.fields_by_name['inverse_variant'].enum_type = TSDCommandArchives__pb2._COMMENTCOMMANDVARIANT
_COMMANDSETFORMULATOKENIZATIONARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSETFILTERSETTYPEARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDSETFILTERSETTYPEARCHIVE.fields_by_name['old_filter_set_type'].enum_type = TSTArchives__pb2._FILTERSETARCHIVE_FILTERSETTYPE
_COMMANDSETFILTERSETTYPEARCHIVE.fields_by_name['new_filter_set_type'].enum_type = TSTArchives__pb2._FILTERSETARCHIVE_FILTERSETTYPE
_COMMANDSETFILTERSETTYPEARCHIVE.fields_by_name['rollback_uid_list'].message_type = TSPMessages__pb2._UUID
_COMMANDSETTEXTSTYLEARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDSETTEXTSTYLEARCHIVE.fields_by_name['cell_diff_map'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSETTEXTSTYLEARCHIVE.fields_by_name['inverse_cell_diff_map'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSETTEXTSTYLEPROPERTIESARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDSETTEXTSTYLEPROPERTIESARCHIVE.fields_by_name['cell_diff_map'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSETTEXTSTYLEPROPERTIESARCHIVE.fields_by_name['inverse_cell_diff_map'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDJUSTFORNOTIFYINGARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDSETSTORAGELANGUAGEARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSETSTORAGELANGUAGEARCHIVE.fields_by_name['storage'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSETSTORAGELANGUAGEARCHIVE.fields_by_name['undo_transaction'].message_type = TSWPArchives__pb2._UNDOTRANSACTION
_COMMANDSETSORTORDERARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDSETSORTORDERARCHIVE.fields_by_name['old_sort_order'].message_type = TSTArchives__pb2._TABLESORTORDERARCHIVE
_COMMANDSETSORTORDERARCHIVE.fields_by_name['new_sort_order'].message_type = TSTArchives__pb2._TABLESORTORDERARCHIVE
_COMMANDREWRITESORTORDERFORTABLERESIZEARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDREWRITESORTORDERFORTABLERESIZEARCHIVE.fields_by_name['old_sort_order'].message_type = TSTArchives__pb2._TABLESORTORDERARCHIVE
_COMMANDREWRITESORTORDERFORTABLERESIZEARCHIVE.fields_by_name['new_sort_order'].message_type = TSTArchives__pb2._TABLESORTORDERARCHIVE
_COMMANDREWRITESORTORDERFORREWRITESPECARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDREWRITESORTORDERFORREWRITESPECARCHIVE.fields_by_name['rewrite_spec'].message_type = TSCEArchives__pb2._FORMULAREWRITESPECARCHIVE
_COMMANDREWRITESORTORDERFORREWRITESPECARCHIVE.fields_by_name['old_sort_order'].message_type = TSTArchives__pb2._TABLESORTORDERARCHIVE
_COMMANDREWRITESORTORDERFORREWRITESPECARCHIVE.fields_by_name['new_sort_order'].message_type = TSTArchives__pb2._TABLESORTORDERARCHIVE
_COMMANDSETFILTERSETARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDSETFILTERSETARCHIVE.fields_by_name['new_filter_set'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSETFILTERSETARCHIVE.fields_by_name['old_filter_set'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSETFILTERSETARCHIVE.fields_by_name['rollback_uid_list'].message_type = TSPMessages__pb2._UUID
_COLUMNROWRESTOREDATAARCHIVE.fields_by_name['uid_list'].message_type = TSPMessages__pb2._UUID
_COLUMNROWRESTOREDATAARCHIVE.fields_by_name['metadatas'].message_type = _COLUMNROWMETADATAARCHIVE
_COMMANDTRANSPOSETABLEARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDTRANSPOSETABLEARCHIVE.fields_by_name['original_table_range'].message_type = TSTArchives__pb2._EXPANDEDCELLRANGE
_COMMANDTRANSPOSETABLEARCHIVE.fields_by_name['original_cell_map'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDTRANSPOSETABLEARCHIVE.fields_by_name['ineligible_merge_list'].message_type = TSTArchives__pb2._CELLRANGE
_COMMANDTRANSPOSETABLEARCHIVE.fields_by_name['transposed_cell_map'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDTRANSPOSETABLEARCHIVE.fields_by_name['undo_formula_rewrite_command'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDTRANSPOSETABLEARCHIVE.fields_by_name['rich_text_subcommands'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDTRANSPOSETABLEARCHIVE.fields_by_name['column_restore_data'].message_type = _COLUMNROWRESTOREDATAARCHIVE
_COMMANDTRANSPOSETABLEARCHIVE.fields_by_name['row_restore_data'].message_type = _COLUMNROWRESTOREDATAARCHIVE
_COMMANDSETSTRUCTUREDTEXTIMPORTRECORDARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDSETSTRUCTUREDTEXTIMPORTRECORDARCHIVE.fields_by_name['new_import_record'].message_type = TSTArchives__pb2._STRUCTUREDTEXTIMPORTRECORD
_COMMANDSETSTRUCTUREDTEXTIMPORTRECORDARCHIVE.fields_by_name['old_import_record'].message_type = TSTArchives__pb2._STRUCTUREDTEXTIMPORTRECORD
_COMMANDCATEGORYCOLLAPSEEXPANDGROUPARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDCATEGORYCOLLAPSEEXPANDGROUPARCHIVE.fields_by_name['grouping_columns'].message_type = TSTArchives__pb2._GROUPCOLUMNLISTARCHIVE
_COMMANDCATEGORYCOLLAPSEEXPANDGROUPARCHIVE.fields_by_name['collapse_state'].message_type = TSTArchives__pb2._EXPANDCOLLAPSESTATEARCHIVE
_COMMANDCATEGORYCOLLAPSEEXPANDGROUPARCHIVE.fields_by_name['undo_collapse_state'].message_type = TSTArchives__pb2._EXPANDCOLLAPSESTATEARCHIVE
_COMMANDCATEGORYCHANGESUMMARYAGGREGATETYPE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDCATEGORYCHANGESUMMARYAGGREGATETYPE.fields_by_name['column_uid'].message_type = TSPMessages__pb2._UUID
_COMMANDCATEGORYSETLABELROWVISIBILITY.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDCATEGORYWILLCHANGEGROUPVALUE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDCATEGORYWILLCHANGEGROUPVALUE.fields_by_name['group_node_uid'].message_type = TSPMessages__pb2._UUID
_COMMANDCATEGORYWILLCHANGEGROUPVALUE.fields_by_name['undo_group_node_uid'].message_type = TSPMessages__pb2._UUID
_COMMANDCATEGORYWILLCHANGEGROUPVALUE.fields_by_name['group_value'].message_type = TSCEArchives__pb2._CELLVALUEARCHIVE
_COMMANDCATEGORYWILLCHANGEGROUPVALUE.fields_by_name['undo_group_value'].message_type = TSCEArchives__pb2._CELLVALUEARCHIVE
_COMMANDCATEGORYWILLCHANGEGROUPVALUE.fields_by_name['rewrite_command_for_undo'].message_type = TSPMessages__pb2._REFERENCE
_IDEMPOTENTSELECTIONTRANSFORMERARCHIVE.fields_by_name['archived_selection'].message_type = TSPMessages__pb2._REFERENCE
_WPSELECTIONTRANSFORMERARCHIVE.fields_by_name['super'].message_type = _TABLESUBSELECTIONTRANSFORMERBASEARCHIVE
_WPSELECTIONTRANSFORMERARCHIVE.fields_by_name['archived_selection'].message_type = TSPMessages__pb2._REFERENCE
_WPSELECTIONTRANSFORMERARCHIVE.fields_by_name['origin_cell_uid'].message_type = TSPMessages__pb2._UUIDCOORDARCHIVE
_TABLESUBSELECTIONTRANSFORMERBASEARCHIVE.fields_by_name['table_info_id_path'].message_type = TSPMessages__pb2._UUIDPATH
_TABLENAMESELECTIONTRANSFORMERARCHIVE.fields_by_name['super'].message_type = _TABLESUBSELECTIONTRANSFORMERBASEARCHIVE
_CONTROLCELLSELECTIONTRANSFORMERARCHIVE.fields_by_name['super'].message_type = _TABLESUBSELECTIONTRANSFORMERBASEARCHIVE
_CONTROLCELLSELECTIONTRANSFORMERARCHIVE.fields_by_name['cell_uids'].message_type = TSTArchives__pb2._CELLUIDLISTARCHIVE
_CONTROLCELLSELECTIONTRANSFORMERARCHIVE.fields_by_name['origin_cell_uid'].message_type = TSPMessages__pb2._UUIDCOORDARCHIVE
_CONTROLCELLSELECTIONTRANSFORMERARCHIVE.fields_by_name['origin_cell_id'].message_type = TSCEArchives__pb2._CELLCOORDINATEARCHIVE
_STOCKCELLSELECTIONTRANSFORMERARCHIVE.fields_by_name['super'].message_type = _TABLESUBSELECTIONTRANSFORMERBASEARCHIVE
_STOCKCELLSELECTIONTRANSFORMERARCHIVE.fields_by_name['cell_uids'].message_type = TSTArchives__pb2._CELLUIDLISTARCHIVE
_STOCKCELLSELECTIONTRANSFORMERARCHIVE.fields_by_name['origin_cell_uid'].message_type = TSPMessages__pb2._UUIDCOORDARCHIVE
_STOCKCELLSELECTIONTRANSFORMERARCHIVE.fields_by_name['origin_cell_id'].message_type = TSCEArchives__pb2._CELLCOORDINATEARCHIVE
_REGIONSELECTIONTRANSFORMERARCHIVE.fields_by_name['super'].message_type = _TABLESUBSELECTIONTRANSFORMERBASEARCHIVE
_REGIONSELECTIONTRANSFORMERARCHIVE.fields_by_name['cell_uids'].message_type = TSTArchives__pb2._CELLUIDLISTARCHIVE
_REGIONSELECTIONTRANSFORMERARCHIVE.fields_by_name['origin_cell_uid'].message_type = TSPMessages__pb2._UUIDCOORDARCHIVE
_REGIONSELECTIONTRANSFORMERARCHIVE.fields_by_name['anchor_cell_uid'].message_type = TSPMessages__pb2._UUIDCOORDARCHIVE
_REGIONSELECTIONTRANSFORMERARCHIVE.fields_by_name['cursor_cell_uid'].message_type = TSPMessages__pb2._UUIDCOORDARCHIVE
_STROKESELECTIONTRANSFORMERARCHIVE.fields_by_name['super'].message_type = _TABLESUBSELECTIONTRANSFORMERBASEARCHIVE
_STROKESELECTIONTRANSFORMERARCHIVE.fields_by_name['archived_selection'].message_type = TSPMessages__pb2._REFERENCE
_ROWCOLUMNSELECTIONTRANSFORMERARCHIVE.fields_by_name['super'].message_type = _TABLESUBSELECTIONTRANSFORMERBASEARCHIVE
_ROWCOLUMNSELECTIONTRANSFORMERARCHIVE.fields_by_name['selection_type'].enum_type = TSTArchives__pb2._SELECTIONTYPEARCHIVE
_ROWCOLUMNSELECTIONTRANSFORMERARCHIVE.fields_by_name['row_col_uids'].message_type = TSPMessages__pb2._UUID
_COMMANDCATEGORYMOVEROWSARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDCATEGORYMOVEROWSARCHIVE.fields_by_name['category_row_order'].message_type = TSPMessages__pb2._UUID
_COMMANDCATEGORYMOVEROWSARCHIVE.fields_by_name['undo_category_row_order'].message_type = TSPMessages__pb2._UUID
_COMMANDCATEGORYMOVEROWSARCHIVE.fields_by_name['cell_diff_map'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDCATEGORYMOVEROWSARCHIVE.fields_by_name['undo_cell_diff_map'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDCATEGORYMOVEROWSARCHIVE.fields_by_name['grouping_columns'].message_type = TSTArchives__pb2._GROUPCOLUMNLISTARCHIVE
_COMMANDREWRITEHIDDENSTATESFORGROUPBYCHANGEARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDREWRITEHIDDENSTATESFORGROUPBYCHANGEARCHIVE.fields_by_name['group_by_change'].message_type = TSCEArchives__pb2._GROUPBYCHANGEARCHIVE
_COMMANDREWRITEHIDDENSTATESFORGROUPBYCHANGEARCHIVE.fields_by_name['collapsed_state'].message_type = TSTArchives__pb2._EXPANDCOLLAPSESTATEARCHIVE
_COMMANDREWRITEPENCILANNOTATIONFORMULASARCHIVE_ANNOTATIONPAIR.fields_by_name['annotation'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDREWRITEPENCILANNOTATIONFORMULASARCHIVE_ANNOTATIONPAIR.containing_type = _COMMANDREWRITEPENCILANNOTATIONFORMULASARCHIVE
_COMMANDREWRITEPENCILANNOTATIONFORMULASARCHIVE.fields_by_name['super'].message_type = _TABLECOMMANDARCHIVE
_COMMANDREWRITEPENCILANNOTATIONFORMULASARCHIVE.fields_by_name['rewrite_spec'].message_type = TSCEArchives__pb2._FORMULAREWRITESPECARCHIVE
_COMMANDREWRITEPENCILANNOTATIONFORMULASARCHIVE.fields_by_name['formulas_to_rewrite'].message_type = TSCEArchives__pb2._FORMULASFORUNDOARCHIVE
_COMMANDREWRITEPENCILANNOTATIONFORMULASARCHIVE.fields_by_name['annotations_for_undo'].message_type = _COMMANDREWRITEPENCILANNOTATIONFORMULASARCHIVE_ANNOTATIONPAIR
DESCRIPTOR.message_types_by_name['TableCommandArchive'] = _TABLECOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['CommandApplyCellContentsArchive'] = _COMMANDAPPLYCELLCONTENTSARCHIVE
DESCRIPTOR.message_types_by_name['CommandApplyCellDiffMapArchive'] = _COMMANDAPPLYCELLDIFFMAPARCHIVE
DESCRIPTOR.message_types_by_name['CommandApplyCellMapArchive'] = _COMMANDAPPLYCELLMAPARCHIVE
DESCRIPTOR.message_types_by_name['CommandApplyConcurrentCellMapArchive'] = _COMMANDAPPLYCONCURRENTCELLMAPARCHIVE
DESCRIPTOR.message_types_by_name['CommandChangeFreezeHeaderStateArchive'] = _COMMANDCHANGEFREEZEHEADERSTATEARCHIVE
DESCRIPTOR.message_types_by_name['CommandDeleteCellsArchive'] = _COMMANDDELETECELLSARCHIVE
DESCRIPTOR.message_types_by_name['CommandDeleteCellContentsArchive'] = _COMMANDDELETECELLCONTENTSARCHIVE
DESCRIPTOR.message_types_by_name['CommandMutateCellFormatArchive'] = _COMMANDMUTATECELLFORMATARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetAutomaticDurationUnitsArchive'] = _COMMANDSETAUTOMATICDURATIONUNITSARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetDurationStyleArchive'] = _COMMANDSETDURATIONSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetDurationUnitSmallestLargestArchive'] = _COMMANDSETDURATIONUNITSMALLESTLARGESTARCHIVE
DESCRIPTOR.message_types_by_name['CommandReplaceCustomFormatArchive'] = _COMMANDREPLACECUSTOMFORMATARCHIVE
DESCRIPTOR.message_types_by_name['CommandMoveCellsArchive'] = _COMMANDMOVECELLSARCHIVE
DESCRIPTOR.message_types_by_name['ColumnRowMetadataArchive'] = _COLUMNROWMETADATAARCHIVE
DESCRIPTOR.message_types_by_name['CommandInsertColumnsOrRowsArchive'] = _COMMANDINSERTCOLUMNSORROWSARCHIVE
DESCRIPTOR.message_types_by_name['ColumnRowBundleArchive'] = _COLUMNROWBUNDLEARCHIVE
DESCRIPTOR.message_types_by_name['CommandRemoveColumnsOrRowsArchive'] = _COMMANDREMOVECOLUMNSORROWSARCHIVE
DESCRIPTOR.message_types_by_name['CommandRowColumnRangeArchive'] = _COMMANDROWCOLUMNRANGEARCHIVE
DESCRIPTOR.message_types_by_name['CommandResizeColumnOrRowArchive'] = _COMMANDRESIZECOLUMNORROWARCHIVE
DESCRIPTOR.message_types_by_name['CommandCategoryResizeColumnOrRowArchive'] = _COMMANDCATEGORYRESIZECOLUMNORROWARCHIVE
DESCRIPTOR.message_types_by_name['CommandHideShowArchive'] = _COMMANDHIDESHOWARCHIVE
DESCRIPTOR.message_types_by_name['CommandTextPreflightInsertCellArchive'] = _COMMANDTEXTPREFLIGHTINSERTCELLARCHIVE
DESCRIPTOR.message_types_by_name['CommandPostflightSetCellArchive'] = _COMMANDPOSTFLIGHTSETCELLARCHIVE
DESCRIPTOR.message_types_by_name['CommandChangeTableAreaForColumnOrRowArchive'] = _COMMANDCHANGETABLEAREAFORCOLUMNORROWARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetPencilAnnotationsArchive'] = _COMMANDSETPENCILANNOTATIONSARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetTableNameArchive'] = _COMMANDSETTABLENAMEARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetTableNameEnabledArchive'] = _COMMANDSETTABLENAMEENABLEDARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetTableFontSizeArchive'] = _COMMANDSETTABLEFONTSIZEARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetTableFontNameArchive'] = _COMMANDSETTABLEFONTNAMEARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetTableNameHeightArchive'] = _COMMANDSETTABLENAMEHEIGHTARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetNowArchive'] = _COMMANDSETNOWARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetWasCutArchive'] = _COMMANDSETWASCUTARCHIVE
DESCRIPTOR.message_types_by_name['CommandStyleCellsArchive'] = _COMMANDSTYLECELLSARCHIVE
DESCRIPTOR.message_types_by_name['CommandStyleTableArchive'] = _COMMANDSTYLETABLEARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetRepeatingHeaderEnabledArchive'] = _COMMANDSETREPEATINGHEADERENABLEDARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetFiltersEnabledArchive'] = _COMMANDSETFILTERSENABLEDARCHIVE
DESCRIPTOR.message_types_by_name['CommandAddTableStylePresetArchive'] = _COMMANDADDTABLESTYLEPRESETARCHIVE
DESCRIPTOR.message_types_by_name['CommandRemoveTableStylePresetArchive'] = _COMMANDREMOVETABLESTYLEPRESETARCHIVE
DESCRIPTOR.message_types_by_name['CommandReplaceTableStylePresetArchive'] = _COMMANDREPLACETABLESTYLEPRESETARCHIVE
DESCRIPTOR.message_types_by_name['CommandApplyTableStylePresetArchive'] = _COMMANDAPPLYTABLESTYLEPRESETARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetBaseArchive'] = _COMMANDSETBASEARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetBasePlacesArchive'] = _COMMANDSETBASEPLACESARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetBaseUseMinusSignArchive'] = _COMMANDSETBASEUSEMINUSSIGNARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetCurrencyCodeArchive'] = _COMMANDSETCURRENCYCODEARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetFractionAccuracyArchive'] = _COMMANDSETFRACTIONACCURACYARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetNegativeNumberStyleArchive'] = _COMMANDSETNEGATIVENUMBERSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetNumberOfDecimalPlacesArchive'] = _COMMANDSETNUMBEROFDECIMALPLACESARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetDateTimeFormatArchive'] = _COMMANDSETDATETIMEFORMATARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetShowThousandsSeparatorArchive'] = _COMMANDSETSHOWTHOUSANDSSEPARATORARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetUseAccountingStyleArchive'] = _COMMANDSETUSEACCOUNTINGSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetRangeControlMinMaxIncArchive'] = _COMMANDSETRANGECONTROLMINMAXINCARCHIVE
DESCRIPTOR.message_types_by_name['CommandMoveColumnsOrRowsArchive'] = _COMMANDMOVECOLUMNSORROWSARCHIVE
DESCRIPTOR.message_types_by_name['CommandSortArchive'] = _COMMANDSORTARCHIVE
DESCRIPTOR.message_types_by_name['CommandRewriteFormulasForTransposeArchive'] = _COMMANDREWRITEFORMULASFORTRANSPOSEARCHIVE
DESCRIPTOR.message_types_by_name['CommandRewriteTableFormulasForRewriteSpecArchive'] = _COMMANDREWRITETABLEFORMULASFORREWRITESPECARCHIVE
DESCRIPTOR.message_types_by_name['CommandRewriteMergeFormulasArchive'] = _COMMANDREWRITEMERGEFORMULASARCHIVE
DESCRIPTOR.message_types_by_name['CommandRewriteCategoryFormulasArchive'] = _COMMANDREWRITECATEGORYFORMULASARCHIVE
DESCRIPTOR.message_types_by_name['CommandRewriteFilterFormulasForTableResizeArchive'] = _COMMANDREWRITEFILTERFORMULASFORTABLERESIZEARCHIVE
DESCRIPTOR.message_types_by_name['CommandRewriteFilterFormulasForRewriteSpecArchive'] = _COMMANDREWRITEFILTERFORMULASFORREWRITESPECARCHIVE
DESCRIPTOR.message_types_by_name['CommandRewriteConditionalStylesForRewriteSpecArchive'] = _COMMANDREWRITECONDITIONALSTYLESFORREWRITESPECARCHIVE
DESCRIPTOR.message_types_by_name['CommandMergeArchive'] = _COMMANDMERGEARCHIVE
DESCRIPTOR.message_types_by_name['CommandInverseMergeArchive'] = _COMMANDINVERSEMERGEARCHIVE
DESCRIPTOR.message_types_by_name['CommandUnmergeArchive'] = _COMMANDUNMERGEARCHIVE
DESCRIPTOR.message_types_by_name['CommandChooseTableIdRemapperArchive'] = _COMMANDCHOOSETABLEIDREMAPPERARCHIVE
DESCRIPTOR.message_types_by_name['CommandCategorySetGroupingColumnsArchive'] = _COMMANDCATEGORYSETGROUPINGCOLUMNSARCHIVE
DESCRIPTOR.message_types_by_name['FormulaEditingCommandGroupArchive'] = _FORMULAEDITINGCOMMANDGROUPARCHIVE
DESCRIPTOR.message_types_by_name['FormulaEditingCommandSelectionBehaviorArchive'] = _FORMULAEDITINGCOMMANDSELECTIONBEHAVIORARCHIVE
DESCRIPTOR.message_types_by_name['TableCommandSelectionBehaviorArchive'] = _TABLECOMMANDSELECTIONBEHAVIORARCHIVE
DESCRIPTOR.message_types_by_name['CommandApplyCellCommentArchive'] = _COMMANDAPPLYCELLCOMMENTARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetFormulaTokenizationArchive'] = _COMMANDSETFORMULATOKENIZATIONARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetFilterSetTypeArchive'] = _COMMANDSETFILTERSETTYPEARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetTextStyleArchive'] = _COMMANDSETTEXTSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetTextStylePropertiesArchive'] = _COMMANDSETTEXTSTYLEPROPERTIESARCHIVE
DESCRIPTOR.message_types_by_name['CommandJustForNotifyingArchive'] = _COMMANDJUSTFORNOTIFYINGARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetStorageLanguageArchive'] = _COMMANDSETSTORAGELANGUAGEARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetSortOrderArchive'] = _COMMANDSETSORTORDERARCHIVE
DESCRIPTOR.message_types_by_name['CommandRewriteSortOrderForTableResizeArchive'] = _COMMANDREWRITESORTORDERFORTABLERESIZEARCHIVE
DESCRIPTOR.message_types_by_name['CommandRewriteSortOrderForRewriteSpecArchive'] = _COMMANDREWRITESORTORDERFORREWRITESPECARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetFilterSetArchive'] = _COMMANDSETFILTERSETARCHIVE
DESCRIPTOR.message_types_by_name['ColumnRowRestoreDataArchive'] = _COLUMNROWRESTOREDATAARCHIVE
DESCRIPTOR.message_types_by_name['CommandTransposeTableArchive'] = _COMMANDTRANSPOSETABLEARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetStructuredTextImportRecordArchive'] = _COMMANDSETSTRUCTUREDTEXTIMPORTRECORDARCHIVE
DESCRIPTOR.message_types_by_name['CommandCategoryCollapseExpandGroupArchive'] = _COMMANDCATEGORYCOLLAPSEEXPANDGROUPARCHIVE
DESCRIPTOR.message_types_by_name['CommandCategoryChangeSummaryAggregateType'] = _COMMANDCATEGORYCHANGESUMMARYAGGREGATETYPE
DESCRIPTOR.message_types_by_name['CommandCategorySetLabelRowVisibility'] = _COMMANDCATEGORYSETLABELROWVISIBILITY
DESCRIPTOR.message_types_by_name['CommandCategoryWillChangeGroupValue'] = _COMMANDCATEGORYWILLCHANGEGROUPVALUE
DESCRIPTOR.message_types_by_name['IdempotentSelectionTransformerArchive'] = _IDEMPOTENTSELECTIONTRANSFORMERARCHIVE
DESCRIPTOR.message_types_by_name['WPSelectionTransformerArchive'] = _WPSELECTIONTRANSFORMERARCHIVE
DESCRIPTOR.message_types_by_name['TableSubSelectionTransformerBaseArchive'] = _TABLESUBSELECTIONTRANSFORMERBASEARCHIVE
DESCRIPTOR.message_types_by_name['TableNameSelectionTransformerArchive'] = _TABLENAMESELECTIONTRANSFORMERARCHIVE
DESCRIPTOR.message_types_by_name['ControlCellSelectionTransformerArchive'] = _CONTROLCELLSELECTIONTRANSFORMERARCHIVE
DESCRIPTOR.message_types_by_name['StockCellSelectionTransformerArchive'] = _STOCKCELLSELECTIONTRANSFORMERARCHIVE
DESCRIPTOR.message_types_by_name['RegionSelectionTransformerArchive'] = _REGIONSELECTIONTRANSFORMERARCHIVE
DESCRIPTOR.message_types_by_name['StrokeSelectionTransformerArchive'] = _STROKESELECTIONTRANSFORMERARCHIVE
DESCRIPTOR.message_types_by_name['RowColumnSelectionTransformerArchive'] = _ROWCOLUMNSELECTIONTRANSFORMERARCHIVE
DESCRIPTOR.message_types_by_name['CommandCategoryMoveRowsArchive'] = _COMMANDCATEGORYMOVEROWSARCHIVE
DESCRIPTOR.message_types_by_name['CommandRewriteHiddenStatesForGroupByChangeArchive'] = _COMMANDREWRITEHIDDENSTATESFORGROUPBYCHANGEARCHIVE
DESCRIPTOR.message_types_by_name['CommandRewritePencilAnnotationFormulasArchive'] = _COMMANDREWRITEPENCILANNOTATIONFORMULASARCHIVE
DESCRIPTOR.enum_types_by_name['TableArea'] = _TABLEAREA
DESCRIPTOR.enum_types_by_name['TableAreaTransition'] = _TABLEAREATRANSITION
DESCRIPTOR.enum_types_by_name['ColumnRowTypeEnum'] = _COLUMNROWTYPEENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TableCommandArchive = _reflection.GeneratedProtocolMessageType('TableCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _TABLECOMMANDARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.TableCommandArchive)
  ))
_sym_db.RegisterMessage(TableCommandArchive)

CommandApplyCellContentsArchive = _reflection.GeneratedProtocolMessageType('CommandApplyCellContentsArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDAPPLYCELLCONTENTSARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandApplyCellContentsArchive)
  ))
_sym_db.RegisterMessage(CommandApplyCellContentsArchive)

CommandApplyCellDiffMapArchive = _reflection.GeneratedProtocolMessageType('CommandApplyCellDiffMapArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDAPPLYCELLDIFFMAPARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandApplyCellDiffMapArchive)
  ))
_sym_db.RegisterMessage(CommandApplyCellDiffMapArchive)

CommandApplyCellMapArchive = _reflection.GeneratedProtocolMessageType('CommandApplyCellMapArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDAPPLYCELLMAPARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandApplyCellMapArchive)
  ))
_sym_db.RegisterMessage(CommandApplyCellMapArchive)

CommandApplyConcurrentCellMapArchive = _reflection.GeneratedProtocolMessageType('CommandApplyConcurrentCellMapArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDAPPLYCONCURRENTCELLMAPARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandApplyConcurrentCellMapArchive)
  ))
_sym_db.RegisterMessage(CommandApplyConcurrentCellMapArchive)

CommandChangeFreezeHeaderStateArchive = _reflection.GeneratedProtocolMessageType('CommandChangeFreezeHeaderStateArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDCHANGEFREEZEHEADERSTATEARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandChangeFreezeHeaderStateArchive)
  ))
_sym_db.RegisterMessage(CommandChangeFreezeHeaderStateArchive)

CommandDeleteCellsArchive = _reflection.GeneratedProtocolMessageType('CommandDeleteCellsArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDDELETECELLSARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandDeleteCellsArchive)
  ))
_sym_db.RegisterMessage(CommandDeleteCellsArchive)

CommandDeleteCellContentsArchive = _reflection.GeneratedProtocolMessageType('CommandDeleteCellContentsArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDDELETECELLCONTENTSARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandDeleteCellContentsArchive)
  ))
_sym_db.RegisterMessage(CommandDeleteCellContentsArchive)

CommandMutateCellFormatArchive = _reflection.GeneratedProtocolMessageType('CommandMutateCellFormatArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDMUTATECELLFORMATARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandMutateCellFormatArchive)
  ))
_sym_db.RegisterMessage(CommandMutateCellFormatArchive)

CommandSetAutomaticDurationUnitsArchive = _reflection.GeneratedProtocolMessageType('CommandSetAutomaticDurationUnitsArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSETAUTOMATICDURATIONUNITSARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandSetAutomaticDurationUnitsArchive)
  ))
_sym_db.RegisterMessage(CommandSetAutomaticDurationUnitsArchive)

CommandSetDurationStyleArchive = _reflection.GeneratedProtocolMessageType('CommandSetDurationStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSETDURATIONSTYLEARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandSetDurationStyleArchive)
  ))
_sym_db.RegisterMessage(CommandSetDurationStyleArchive)

CommandSetDurationUnitSmallestLargestArchive = _reflection.GeneratedProtocolMessageType('CommandSetDurationUnitSmallestLargestArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSETDURATIONUNITSMALLESTLARGESTARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandSetDurationUnitSmallestLargestArchive)
  ))
_sym_db.RegisterMessage(CommandSetDurationUnitSmallestLargestArchive)

CommandReplaceCustomFormatArchive = _reflection.GeneratedProtocolMessageType('CommandReplaceCustomFormatArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDREPLACECUSTOMFORMATARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandReplaceCustomFormatArchive)
  ))
_sym_db.RegisterMessage(CommandReplaceCustomFormatArchive)

CommandMoveCellsArchive = _reflection.GeneratedProtocolMessageType('CommandMoveCellsArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDMOVECELLSARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandMoveCellsArchive)
  ))
_sym_db.RegisterMessage(CommandMoveCellsArchive)

ColumnRowMetadataArchive = _reflection.GeneratedProtocolMessageType('ColumnRowMetadataArchive', (_message.Message,), dict(
  DESCRIPTOR = _COLUMNROWMETADATAARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.ColumnRowMetadataArchive)
  ))
_sym_db.RegisterMessage(ColumnRowMetadataArchive)

CommandInsertColumnsOrRowsArchive = _reflection.GeneratedProtocolMessageType('CommandInsertColumnsOrRowsArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDINSERTCOLUMNSORROWSARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandInsertColumnsOrRowsArchive)
  ))
_sym_db.RegisterMessage(CommandInsertColumnsOrRowsArchive)

ColumnRowBundleArchive = _reflection.GeneratedProtocolMessageType('ColumnRowBundleArchive', (_message.Message,), dict(
  DESCRIPTOR = _COLUMNROWBUNDLEARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.ColumnRowBundleArchive)
  ))
_sym_db.RegisterMessage(ColumnRowBundleArchive)

CommandRemoveColumnsOrRowsArchive = _reflection.GeneratedProtocolMessageType('CommandRemoveColumnsOrRowsArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDREMOVECOLUMNSORROWSARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandRemoveColumnsOrRowsArchive)
  ))
_sym_db.RegisterMessage(CommandRemoveColumnsOrRowsArchive)

CommandRowColumnRangeArchive = _reflection.GeneratedProtocolMessageType('CommandRowColumnRangeArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDROWCOLUMNRANGEARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandRowColumnRangeArchive)
  ))
_sym_db.RegisterMessage(CommandRowColumnRangeArchive)

CommandResizeColumnOrRowArchive = _reflection.GeneratedProtocolMessageType('CommandResizeColumnOrRowArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDRESIZECOLUMNORROWARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandResizeColumnOrRowArchive)
  ))
_sym_db.RegisterMessage(CommandResizeColumnOrRowArchive)

CommandCategoryResizeColumnOrRowArchive = _reflection.GeneratedProtocolMessageType('CommandCategoryResizeColumnOrRowArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDCATEGORYRESIZECOLUMNORROWARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandCategoryResizeColumnOrRowArchive)
  ))
_sym_db.RegisterMessage(CommandCategoryResizeColumnOrRowArchive)

CommandHideShowArchive = _reflection.GeneratedProtocolMessageType('CommandHideShowArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDHIDESHOWARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandHideShowArchive)
  ))
_sym_db.RegisterMessage(CommandHideShowArchive)

CommandTextPreflightInsertCellArchive = _reflection.GeneratedProtocolMessageType('CommandTextPreflightInsertCellArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDTEXTPREFLIGHTINSERTCELLARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandTextPreflightInsertCellArchive)
  ))
_sym_db.RegisterMessage(CommandTextPreflightInsertCellArchive)

CommandPostflightSetCellArchive = _reflection.GeneratedProtocolMessageType('CommandPostflightSetCellArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDPOSTFLIGHTSETCELLARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandPostflightSetCellArchive)
  ))
_sym_db.RegisterMessage(CommandPostflightSetCellArchive)

CommandChangeTableAreaForColumnOrRowArchive = _reflection.GeneratedProtocolMessageType('CommandChangeTableAreaForColumnOrRowArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDCHANGETABLEAREAFORCOLUMNORROWARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandChangeTableAreaForColumnOrRowArchive)
  ))
_sym_db.RegisterMessage(CommandChangeTableAreaForColumnOrRowArchive)

CommandSetPencilAnnotationsArchive = _reflection.GeneratedProtocolMessageType('CommandSetPencilAnnotationsArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSETPENCILANNOTATIONSARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandSetPencilAnnotationsArchive)
  ))
_sym_db.RegisterMessage(CommandSetPencilAnnotationsArchive)

CommandSetTableNameArchive = _reflection.GeneratedProtocolMessageType('CommandSetTableNameArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSETTABLENAMEARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandSetTableNameArchive)
  ))
_sym_db.RegisterMessage(CommandSetTableNameArchive)

CommandSetTableNameEnabledArchive = _reflection.GeneratedProtocolMessageType('CommandSetTableNameEnabledArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSETTABLENAMEENABLEDARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandSetTableNameEnabledArchive)
  ))
_sym_db.RegisterMessage(CommandSetTableNameEnabledArchive)

CommandSetTableFontSizeArchive = _reflection.GeneratedProtocolMessageType('CommandSetTableFontSizeArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSETTABLEFONTSIZEARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandSetTableFontSizeArchive)
  ))
_sym_db.RegisterMessage(CommandSetTableFontSizeArchive)

CommandSetTableFontNameArchive = _reflection.GeneratedProtocolMessageType('CommandSetTableFontNameArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSETTABLEFONTNAMEARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandSetTableFontNameArchive)
  ))
_sym_db.RegisterMessage(CommandSetTableFontNameArchive)

CommandSetTableNameHeightArchive = _reflection.GeneratedProtocolMessageType('CommandSetTableNameHeightArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSETTABLENAMEHEIGHTARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandSetTableNameHeightArchive)
  ))
_sym_db.RegisterMessage(CommandSetTableNameHeightArchive)

CommandSetNowArchive = _reflection.GeneratedProtocolMessageType('CommandSetNowArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSETNOWARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandSetNowArchive)
  ))
_sym_db.RegisterMessage(CommandSetNowArchive)

CommandSetWasCutArchive = _reflection.GeneratedProtocolMessageType('CommandSetWasCutArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSETWASCUTARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandSetWasCutArchive)
  ))
_sym_db.RegisterMessage(CommandSetWasCutArchive)

CommandStyleCellsArchive = _reflection.GeneratedProtocolMessageType('CommandStyleCellsArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSTYLECELLSARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandStyleCellsArchive)
  ))
_sym_db.RegisterMessage(CommandStyleCellsArchive)

CommandStyleTableArchive = _reflection.GeneratedProtocolMessageType('CommandStyleTableArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSTYLETABLEARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandStyleTableArchive)
  ))
_sym_db.RegisterMessage(CommandStyleTableArchive)

CommandSetRepeatingHeaderEnabledArchive = _reflection.GeneratedProtocolMessageType('CommandSetRepeatingHeaderEnabledArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSETREPEATINGHEADERENABLEDARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandSetRepeatingHeaderEnabledArchive)
  ))
_sym_db.RegisterMessage(CommandSetRepeatingHeaderEnabledArchive)

CommandSetFiltersEnabledArchive = _reflection.GeneratedProtocolMessageType('CommandSetFiltersEnabledArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSETFILTERSENABLEDARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandSetFiltersEnabledArchive)
  ))
_sym_db.RegisterMessage(CommandSetFiltersEnabledArchive)

CommandAddTableStylePresetArchive = _reflection.GeneratedProtocolMessageType('CommandAddTableStylePresetArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDADDTABLESTYLEPRESETARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandAddTableStylePresetArchive)
  ))
_sym_db.RegisterMessage(CommandAddTableStylePresetArchive)

CommandRemoveTableStylePresetArchive = _reflection.GeneratedProtocolMessageType('CommandRemoveTableStylePresetArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDREMOVETABLESTYLEPRESETARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandRemoveTableStylePresetArchive)
  ))
_sym_db.RegisterMessage(CommandRemoveTableStylePresetArchive)

CommandReplaceTableStylePresetArchive = _reflection.GeneratedProtocolMessageType('CommandReplaceTableStylePresetArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDREPLACETABLESTYLEPRESETARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandReplaceTableStylePresetArchive)
  ))
_sym_db.RegisterMessage(CommandReplaceTableStylePresetArchive)

CommandApplyTableStylePresetArchive = _reflection.GeneratedProtocolMessageType('CommandApplyTableStylePresetArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDAPPLYTABLESTYLEPRESETARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandApplyTableStylePresetArchive)
  ))
_sym_db.RegisterMessage(CommandApplyTableStylePresetArchive)

CommandSetBaseArchive = _reflection.GeneratedProtocolMessageType('CommandSetBaseArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSETBASEARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandSetBaseArchive)
  ))
_sym_db.RegisterMessage(CommandSetBaseArchive)

CommandSetBasePlacesArchive = _reflection.GeneratedProtocolMessageType('CommandSetBasePlacesArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSETBASEPLACESARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandSetBasePlacesArchive)
  ))
_sym_db.RegisterMessage(CommandSetBasePlacesArchive)

CommandSetBaseUseMinusSignArchive = _reflection.GeneratedProtocolMessageType('CommandSetBaseUseMinusSignArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSETBASEUSEMINUSSIGNARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandSetBaseUseMinusSignArchive)
  ))
_sym_db.RegisterMessage(CommandSetBaseUseMinusSignArchive)

CommandSetCurrencyCodeArchive = _reflection.GeneratedProtocolMessageType('CommandSetCurrencyCodeArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSETCURRENCYCODEARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandSetCurrencyCodeArchive)
  ))
_sym_db.RegisterMessage(CommandSetCurrencyCodeArchive)

CommandSetFractionAccuracyArchive = _reflection.GeneratedProtocolMessageType('CommandSetFractionAccuracyArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSETFRACTIONACCURACYARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandSetFractionAccuracyArchive)
  ))
_sym_db.RegisterMessage(CommandSetFractionAccuracyArchive)

CommandSetNegativeNumberStyleArchive = _reflection.GeneratedProtocolMessageType('CommandSetNegativeNumberStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSETNEGATIVENUMBERSTYLEARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandSetNegativeNumberStyleArchive)
  ))
_sym_db.RegisterMessage(CommandSetNegativeNumberStyleArchive)

CommandSetNumberOfDecimalPlacesArchive = _reflection.GeneratedProtocolMessageType('CommandSetNumberOfDecimalPlacesArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSETNUMBEROFDECIMALPLACESARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandSetNumberOfDecimalPlacesArchive)
  ))
_sym_db.RegisterMessage(CommandSetNumberOfDecimalPlacesArchive)

CommandSetDateTimeFormatArchive = _reflection.GeneratedProtocolMessageType('CommandSetDateTimeFormatArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSETDATETIMEFORMATARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandSetDateTimeFormatArchive)
  ))
_sym_db.RegisterMessage(CommandSetDateTimeFormatArchive)

CommandSetShowThousandsSeparatorArchive = _reflection.GeneratedProtocolMessageType('CommandSetShowThousandsSeparatorArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSETSHOWTHOUSANDSSEPARATORARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandSetShowThousandsSeparatorArchive)
  ))
_sym_db.RegisterMessage(CommandSetShowThousandsSeparatorArchive)

CommandSetUseAccountingStyleArchive = _reflection.GeneratedProtocolMessageType('CommandSetUseAccountingStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSETUSEACCOUNTINGSTYLEARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandSetUseAccountingStyleArchive)
  ))
_sym_db.RegisterMessage(CommandSetUseAccountingStyleArchive)

CommandSetRangeControlMinMaxIncArchive = _reflection.GeneratedProtocolMessageType('CommandSetRangeControlMinMaxIncArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSETRANGECONTROLMINMAXINCARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandSetRangeControlMinMaxIncArchive)
  ))
_sym_db.RegisterMessage(CommandSetRangeControlMinMaxIncArchive)

CommandMoveColumnsOrRowsArchive = _reflection.GeneratedProtocolMessageType('CommandMoveColumnsOrRowsArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDMOVECOLUMNSORROWSARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandMoveColumnsOrRowsArchive)
  ))
_sym_db.RegisterMessage(CommandMoveColumnsOrRowsArchive)

CommandSortArchive = _reflection.GeneratedProtocolMessageType('CommandSortArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSORTARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandSortArchive)
  ))
_sym_db.RegisterMessage(CommandSortArchive)

CommandRewriteFormulasForTransposeArchive = _reflection.GeneratedProtocolMessageType('CommandRewriteFormulasForTransposeArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDREWRITEFORMULASFORTRANSPOSEARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandRewriteFormulasForTransposeArchive)
  ))
_sym_db.RegisterMessage(CommandRewriteFormulasForTransposeArchive)

CommandRewriteTableFormulasForRewriteSpecArchive = _reflection.GeneratedProtocolMessageType('CommandRewriteTableFormulasForRewriteSpecArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDREWRITETABLEFORMULASFORREWRITESPECARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandRewriteTableFormulasForRewriteSpecArchive)
  ))
_sym_db.RegisterMessage(CommandRewriteTableFormulasForRewriteSpecArchive)

CommandRewriteMergeFormulasArchive = _reflection.GeneratedProtocolMessageType('CommandRewriteMergeFormulasArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDREWRITEMERGEFORMULASARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandRewriteMergeFormulasArchive)
  ))
_sym_db.RegisterMessage(CommandRewriteMergeFormulasArchive)

CommandRewriteCategoryFormulasArchive = _reflection.GeneratedProtocolMessageType('CommandRewriteCategoryFormulasArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDREWRITECATEGORYFORMULASARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandRewriteCategoryFormulasArchive)
  ))
_sym_db.RegisterMessage(CommandRewriteCategoryFormulasArchive)

CommandRewriteFilterFormulasForTableResizeArchive = _reflection.GeneratedProtocolMessageType('CommandRewriteFilterFormulasForTableResizeArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDREWRITEFILTERFORMULASFORTABLERESIZEARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandRewriteFilterFormulasForTableResizeArchive)
  ))
_sym_db.RegisterMessage(CommandRewriteFilterFormulasForTableResizeArchive)

CommandRewriteFilterFormulasForRewriteSpecArchive = _reflection.GeneratedProtocolMessageType('CommandRewriteFilterFormulasForRewriteSpecArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDREWRITEFILTERFORMULASFORREWRITESPECARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandRewriteFilterFormulasForRewriteSpecArchive)
  ))
_sym_db.RegisterMessage(CommandRewriteFilterFormulasForRewriteSpecArchive)

CommandRewriteConditionalStylesForRewriteSpecArchive = _reflection.GeneratedProtocolMessageType('CommandRewriteConditionalStylesForRewriteSpecArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDREWRITECONDITIONALSTYLESFORREWRITESPECARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandRewriteConditionalStylesForRewriteSpecArchive)
  ))
_sym_db.RegisterMessage(CommandRewriteConditionalStylesForRewriteSpecArchive)

CommandMergeArchive = _reflection.GeneratedProtocolMessageType('CommandMergeArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDMERGEARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandMergeArchive)
  ))
_sym_db.RegisterMessage(CommandMergeArchive)

CommandInverseMergeArchive = _reflection.GeneratedProtocolMessageType('CommandInverseMergeArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDINVERSEMERGEARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandInverseMergeArchive)
  ))
_sym_db.RegisterMessage(CommandInverseMergeArchive)

CommandUnmergeArchive = _reflection.GeneratedProtocolMessageType('CommandUnmergeArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDUNMERGEARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandUnmergeArchive)
  ))
_sym_db.RegisterMessage(CommandUnmergeArchive)

CommandChooseTableIdRemapperArchive = _reflection.GeneratedProtocolMessageType('CommandChooseTableIdRemapperArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDCHOOSETABLEIDREMAPPERARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandChooseTableIdRemapperArchive)
  ))
_sym_db.RegisterMessage(CommandChooseTableIdRemapperArchive)

CommandCategorySetGroupingColumnsArchive = _reflection.GeneratedProtocolMessageType('CommandCategorySetGroupingColumnsArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDCATEGORYSETGROUPINGCOLUMNSARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandCategorySetGroupingColumnsArchive)
  ))
_sym_db.RegisterMessage(CommandCategorySetGroupingColumnsArchive)

FormulaEditingCommandGroupArchive = _reflection.GeneratedProtocolMessageType('FormulaEditingCommandGroupArchive', (_message.Message,), dict(
  DESCRIPTOR = _FORMULAEDITINGCOMMANDGROUPARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.FormulaEditingCommandGroupArchive)
  ))
_sym_db.RegisterMessage(FormulaEditingCommandGroupArchive)

FormulaEditingCommandSelectionBehaviorArchive = _reflection.GeneratedProtocolMessageType('FormulaEditingCommandSelectionBehaviorArchive', (_message.Message,), dict(
  DESCRIPTOR = _FORMULAEDITINGCOMMANDSELECTIONBEHAVIORARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.FormulaEditingCommandSelectionBehaviorArchive)
  ))
_sym_db.RegisterMessage(FormulaEditingCommandSelectionBehaviorArchive)

TableCommandSelectionBehaviorArchive = _reflection.GeneratedProtocolMessageType('TableCommandSelectionBehaviorArchive', (_message.Message,), dict(
  DESCRIPTOR = _TABLECOMMANDSELECTIONBEHAVIORARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.TableCommandSelectionBehaviorArchive)
  ))
_sym_db.RegisterMessage(TableCommandSelectionBehaviorArchive)

CommandApplyCellCommentArchive = _reflection.GeneratedProtocolMessageType('CommandApplyCellCommentArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDAPPLYCELLCOMMENTARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandApplyCellCommentArchive)
  ))
_sym_db.RegisterMessage(CommandApplyCellCommentArchive)

CommandSetFormulaTokenizationArchive = _reflection.GeneratedProtocolMessageType('CommandSetFormulaTokenizationArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSETFORMULATOKENIZATIONARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandSetFormulaTokenizationArchive)
  ))
_sym_db.RegisterMessage(CommandSetFormulaTokenizationArchive)

CommandSetFilterSetTypeArchive = _reflection.GeneratedProtocolMessageType('CommandSetFilterSetTypeArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSETFILTERSETTYPEARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandSetFilterSetTypeArchive)
  ))
_sym_db.RegisterMessage(CommandSetFilterSetTypeArchive)

CommandSetTextStyleArchive = _reflection.GeneratedProtocolMessageType('CommandSetTextStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSETTEXTSTYLEARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandSetTextStyleArchive)
  ))
_sym_db.RegisterMessage(CommandSetTextStyleArchive)

CommandSetTextStylePropertiesArchive = _reflection.GeneratedProtocolMessageType('CommandSetTextStylePropertiesArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSETTEXTSTYLEPROPERTIESARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandSetTextStylePropertiesArchive)
  ))
_sym_db.RegisterMessage(CommandSetTextStylePropertiesArchive)

CommandJustForNotifyingArchive = _reflection.GeneratedProtocolMessageType('CommandJustForNotifyingArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDJUSTFORNOTIFYINGARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandJustForNotifyingArchive)
  ))
_sym_db.RegisterMessage(CommandJustForNotifyingArchive)

CommandSetStorageLanguageArchive = _reflection.GeneratedProtocolMessageType('CommandSetStorageLanguageArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSETSTORAGELANGUAGEARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandSetStorageLanguageArchive)
  ))
_sym_db.RegisterMessage(CommandSetStorageLanguageArchive)

CommandSetSortOrderArchive = _reflection.GeneratedProtocolMessageType('CommandSetSortOrderArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSETSORTORDERARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandSetSortOrderArchive)
  ))
_sym_db.RegisterMessage(CommandSetSortOrderArchive)

CommandRewriteSortOrderForTableResizeArchive = _reflection.GeneratedProtocolMessageType('CommandRewriteSortOrderForTableResizeArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDREWRITESORTORDERFORTABLERESIZEARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandRewriteSortOrderForTableResizeArchive)
  ))
_sym_db.RegisterMessage(CommandRewriteSortOrderForTableResizeArchive)

CommandRewriteSortOrderForRewriteSpecArchive = _reflection.GeneratedProtocolMessageType('CommandRewriteSortOrderForRewriteSpecArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDREWRITESORTORDERFORREWRITESPECARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandRewriteSortOrderForRewriteSpecArchive)
  ))
_sym_db.RegisterMessage(CommandRewriteSortOrderForRewriteSpecArchive)

CommandSetFilterSetArchive = _reflection.GeneratedProtocolMessageType('CommandSetFilterSetArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSETFILTERSETARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandSetFilterSetArchive)
  ))
_sym_db.RegisterMessage(CommandSetFilterSetArchive)

ColumnRowRestoreDataArchive = _reflection.GeneratedProtocolMessageType('ColumnRowRestoreDataArchive', (_message.Message,), dict(
  DESCRIPTOR = _COLUMNROWRESTOREDATAARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.ColumnRowRestoreDataArchive)
  ))
_sym_db.RegisterMessage(ColumnRowRestoreDataArchive)

CommandTransposeTableArchive = _reflection.GeneratedProtocolMessageType('CommandTransposeTableArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDTRANSPOSETABLEARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandTransposeTableArchive)
  ))
_sym_db.RegisterMessage(CommandTransposeTableArchive)

CommandSetStructuredTextImportRecordArchive = _reflection.GeneratedProtocolMessageType('CommandSetStructuredTextImportRecordArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSETSTRUCTUREDTEXTIMPORTRECORDARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandSetStructuredTextImportRecordArchive)
  ))
_sym_db.RegisterMessage(CommandSetStructuredTextImportRecordArchive)

CommandCategoryCollapseExpandGroupArchive = _reflection.GeneratedProtocolMessageType('CommandCategoryCollapseExpandGroupArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDCATEGORYCOLLAPSEEXPANDGROUPARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandCategoryCollapseExpandGroupArchive)
  ))
_sym_db.RegisterMessage(CommandCategoryCollapseExpandGroupArchive)

CommandCategoryChangeSummaryAggregateType = _reflection.GeneratedProtocolMessageType('CommandCategoryChangeSummaryAggregateType', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDCATEGORYCHANGESUMMARYAGGREGATETYPE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandCategoryChangeSummaryAggregateType)
  ))
_sym_db.RegisterMessage(CommandCategoryChangeSummaryAggregateType)

CommandCategorySetLabelRowVisibility = _reflection.GeneratedProtocolMessageType('CommandCategorySetLabelRowVisibility', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDCATEGORYSETLABELROWVISIBILITY,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandCategorySetLabelRowVisibility)
  ))
_sym_db.RegisterMessage(CommandCategorySetLabelRowVisibility)

CommandCategoryWillChangeGroupValue = _reflection.GeneratedProtocolMessageType('CommandCategoryWillChangeGroupValue', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDCATEGORYWILLCHANGEGROUPVALUE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandCategoryWillChangeGroupValue)
  ))
_sym_db.RegisterMessage(CommandCategoryWillChangeGroupValue)

IdempotentSelectionTransformerArchive = _reflection.GeneratedProtocolMessageType('IdempotentSelectionTransformerArchive', (_message.Message,), dict(
  DESCRIPTOR = _IDEMPOTENTSELECTIONTRANSFORMERARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.IdempotentSelectionTransformerArchive)
  ))
_sym_db.RegisterMessage(IdempotentSelectionTransformerArchive)

WPSelectionTransformerArchive = _reflection.GeneratedProtocolMessageType('WPSelectionTransformerArchive', (_message.Message,), dict(
  DESCRIPTOR = _WPSELECTIONTRANSFORMERARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.WPSelectionTransformerArchive)
  ))
_sym_db.RegisterMessage(WPSelectionTransformerArchive)

TableSubSelectionTransformerBaseArchive = _reflection.GeneratedProtocolMessageType('TableSubSelectionTransformerBaseArchive', (_message.Message,), dict(
  DESCRIPTOR = _TABLESUBSELECTIONTRANSFORMERBASEARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.TableSubSelectionTransformerBaseArchive)
  ))
_sym_db.RegisterMessage(TableSubSelectionTransformerBaseArchive)

TableNameSelectionTransformerArchive = _reflection.GeneratedProtocolMessageType('TableNameSelectionTransformerArchive', (_message.Message,), dict(
  DESCRIPTOR = _TABLENAMESELECTIONTRANSFORMERARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.TableNameSelectionTransformerArchive)
  ))
_sym_db.RegisterMessage(TableNameSelectionTransformerArchive)

ControlCellSelectionTransformerArchive = _reflection.GeneratedProtocolMessageType('ControlCellSelectionTransformerArchive', (_message.Message,), dict(
  DESCRIPTOR = _CONTROLCELLSELECTIONTRANSFORMERARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.ControlCellSelectionTransformerArchive)
  ))
_sym_db.RegisterMessage(ControlCellSelectionTransformerArchive)

StockCellSelectionTransformerArchive = _reflection.GeneratedProtocolMessageType('StockCellSelectionTransformerArchive', (_message.Message,), dict(
  DESCRIPTOR = _STOCKCELLSELECTIONTRANSFORMERARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.StockCellSelectionTransformerArchive)
  ))
_sym_db.RegisterMessage(StockCellSelectionTransformerArchive)

RegionSelectionTransformerArchive = _reflection.GeneratedProtocolMessageType('RegionSelectionTransformerArchive', (_message.Message,), dict(
  DESCRIPTOR = _REGIONSELECTIONTRANSFORMERARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.RegionSelectionTransformerArchive)
  ))
_sym_db.RegisterMessage(RegionSelectionTransformerArchive)

StrokeSelectionTransformerArchive = _reflection.GeneratedProtocolMessageType('StrokeSelectionTransformerArchive', (_message.Message,), dict(
  DESCRIPTOR = _STROKESELECTIONTRANSFORMERARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.StrokeSelectionTransformerArchive)
  ))
_sym_db.RegisterMessage(StrokeSelectionTransformerArchive)

RowColumnSelectionTransformerArchive = _reflection.GeneratedProtocolMessageType('RowColumnSelectionTransformerArchive', (_message.Message,), dict(
  DESCRIPTOR = _ROWCOLUMNSELECTIONTRANSFORMERARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.RowColumnSelectionTransformerArchive)
  ))
_sym_db.RegisterMessage(RowColumnSelectionTransformerArchive)

CommandCategoryMoveRowsArchive = _reflection.GeneratedProtocolMessageType('CommandCategoryMoveRowsArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDCATEGORYMOVEROWSARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandCategoryMoveRowsArchive)
  ))
_sym_db.RegisterMessage(CommandCategoryMoveRowsArchive)

CommandRewriteHiddenStatesForGroupByChangeArchive = _reflection.GeneratedProtocolMessageType('CommandRewriteHiddenStatesForGroupByChangeArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDREWRITEHIDDENSTATESFORGROUPBYCHANGEARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandRewriteHiddenStatesForGroupByChangeArchive)
  ))
_sym_db.RegisterMessage(CommandRewriteHiddenStatesForGroupByChangeArchive)

CommandRewritePencilAnnotationFormulasArchive = _reflection.GeneratedProtocolMessageType('CommandRewritePencilAnnotationFormulasArchive', (_message.Message,), dict(

  AnnotationPair = _reflection.GeneratedProtocolMessageType('AnnotationPair', (_message.Message,), dict(
    DESCRIPTOR = _COMMANDREWRITEPENCILANNOTATIONFORMULASARCHIVE_ANNOTATIONPAIR,
    __module__ = 'TSTCommandArchives_pb2'
    # @@protoc_insertion_point(class_scope:TST.CommandRewritePencilAnnotationFormulasArchive.AnnotationPair)
    ))
  ,
  DESCRIPTOR = _COMMANDREWRITEPENCILANNOTATIONFORMULASARCHIVE,
  __module__ = 'TSTCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TST.CommandRewritePencilAnnotationFormulasArchive)
  ))
_sym_db.RegisterMessage(CommandRewritePencilAnnotationFormulasArchive)
_sym_db.RegisterMessage(CommandRewritePencilAnnotationFormulasArchive.AnnotationPair)


# @@protoc_insertion_point(module_scope)
